Class: Telnyx::Client

Inherits:
Internal::Transport::BaseClient show all
Defined in:
lib/telnyx/client.rb,
sig/telnyx/client.rbs

Constant Summary collapse

DEFAULT_MAX_RETRIES =

Default max number of retries to attempt after a failed retryable request.

Returns:

  • (2)
2
DEFAULT_TIMEOUT_IN_SECONDS =

Default per-request timeout.

Returns:

  • (Float)
60.0
DEFAULT_INITIAL_RETRY_DELAY =

Default initial retry delay in seconds. Overall delay is calculated using exponential backoff + jitter.

Returns:

  • (Float)
0.5
DEFAULT_MAX_RETRY_DELAY =

Default max retry delay in seconds.

Returns:

  • (Float)
8.0

Constants inherited from Internal::Transport::BaseClient

Internal::Transport::BaseClient::MAX_REDIRECTS, Internal::Transport::BaseClient::PLATFORM_HEADERS, Internal::Transport::BaseClient::Telnyx

Instance Attribute Summary collapse

Attributes inherited from Internal::Transport::BaseClient

#base_url, #headers, #idempotency_header, #initial_retry_delay, #max_retries, #max_retry_delay, #requester, #timeout

Instance Method Summary collapse

Methods inherited from Internal::Transport::BaseClient

follow_redirect, #inspect, reap_connection!, #request, #send_request, should_retry?, validate!

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_key: ENV["TELNYX_API_KEY"], client_id: ENV["TELNYX_CLIENT_ID"], client_secret: ENV["TELNYX_CLIENT_SECRET"], public_key: ENV["TELNYX_PUBLIC_KEY"], base_url: ENV["TELNYX_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY) ⇒ Client

Creates and returns a new client for interacting with the API.

"https://api.example.com/v2/". Defaults to ENV["TELNYX_BASE_URL"]

Parameters:

  • api_key (String, nil) (defaults to: ENV["TELNYX_API_KEY"])

    Defaults to ENV["TELNYX_API_KEY"]

  • client_id (String, nil) (defaults to: ENV["TELNYX_CLIENT_ID"])

    Defaults to ENV["TELNYX_CLIENT_ID"]

  • client_secret (String, nil) (defaults to: ENV["TELNYX_CLIENT_SECRET"])

    Defaults to ENV["TELNYX_CLIENT_SECRET"]

  • public_key (String, nil) (defaults to: ENV["TELNYX_PUBLIC_KEY"])

    Defaults to ENV["TELNYX_PUBLIC_KEY"]

  • base_url (String, nil) (defaults to: ENV["TELNYX_BASE_URL"])

    Override the default base URL for the API, e.g.,

  • max_retries (Integer) (defaults to: self.class::DEFAULT_MAX_RETRIES)

    Max number of retries to attempt after a failed retryable request.

  • timeout (Float) (defaults to: self.class::DEFAULT_TIMEOUT_IN_SECONDS)
  • initial_retry_delay (Float) (defaults to: self.class::DEFAULT_INITIAL_RETRY_DELAY)
  • max_retry_delay (Float) (defaults to: self.class::DEFAULT_MAX_RETRY_DELAY)


759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
# File 'lib/telnyx/client.rb', line 759

def initialize(
  api_key: ENV["TELNYX_API_KEY"],
  client_id: ENV["TELNYX_CLIENT_ID"],
  client_secret: ENV["TELNYX_CLIENT_SECRET"],
  public_key: ENV["TELNYX_PUBLIC_KEY"],
  base_url: ENV["TELNYX_BASE_URL"],
  max_retries: self.class::DEFAULT_MAX_RETRIES,
  timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS,
  initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY,
  max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY
)
  @base_url_overridden = !base_url.nil?

  base_url ||= "https://api.telnyx.com/v2"

  headers = {}
  custom_headers_env = ENV["TELNYX_CUSTOM_HEADERS"]
  unless custom_headers_env.nil?
    parsed = {}
    custom_headers_env.split("\n").each do |line|
      colon = line.index(":")
      unless colon.nil?
        parsed[line[0...colon].strip] = line[(colon + 1)..].strip
      end
    end
    headers = parsed.merge(headers)
  end

  @api_key = api_key&.to_s
  @client_id = client_id&.to_s
  @client_secret = client_secret&.to_s
  @public_key = public_key&.to_s

  super(
    base_url: base_url,
    timeout: timeout,
    max_retries: max_retries,
    initial_retry_delay: initial_retry_delay,
    max_retry_delay: max_retry_delay,
    headers: headers
  )

  @legacy = Telnyx::Resources::Legacy.new(client: self)
  @oauth = Telnyx::Resources::OAuth.new(client: self)
  @oauth_clients = Telnyx::Resources::OAuthClients.new(client: self)
  @oauth_grants = Telnyx::Resources::OAuthGrants.new(client: self)
  @webhooks = Telnyx::Resources::Webhooks.new(client: self)
  @access_ip_address = Telnyx::Resources::AccessIPAddress.new(client: self)
  @access_ip_ranges = Telnyx::Resources::AccessIPRanges.new(client: self)
  @actions = Telnyx::Resources::Actions.new(client: self)
  @addresses = Telnyx::Resources::Addresses.new(client: self)
  @advanced_orders = Telnyx::Resources::AdvancedOrders.new(client: self)
  @ai = Telnyx::Resources::AI.new(client: self)
  @audit_events = Telnyx::Resources::AuditEvents.new(client: self)
  @authentication_providers = Telnyx::Resources::AuthenticationProviders.new(client: self)
  @available_phone_number_blocks = Telnyx::Resources::AvailablePhoneNumberBlocks.new(client: self)
  @available_phone_numbers = Telnyx::Resources::AvailablePhoneNumbers.new(client: self)
  @balance = Telnyx::Resources::Balance.new(client: self)
  @billing_groups = Telnyx::Resources::BillingGroups.new(client: self)
  @bulk_sim_card_actions = Telnyx::Resources::BulkSimCardActions.new(client: self)
  @bundle_pricing = Telnyx::Resources::BundlePricing.new(client: self)
  @call_control_applications = Telnyx::Resources::CallControlApplications.new(client: self)
  @call_events = Telnyx::Resources::CallEvents.new(client: self)
  @calls = Telnyx::Resources::Calls.new(client: self)
  @channel_zones = Telnyx::Resources::ChannelZones.new(client: self)
  @charges_breakdown = Telnyx::Resources::ChargesBreakdown.new(client: self)
  @charges_summary = Telnyx::Resources::ChargesSummary.new(client: self)
  @comments = Telnyx::Resources::Comments.new(client: self)
  @conferences = Telnyx::Resources::Conferences.new(client: self)
  @connections = Telnyx::Resources::Connections.new(client: self)
  @country_coverage = Telnyx::Resources::CountryCoverage.new(client: self)
  @credential_connections = Telnyx::Resources::CredentialConnections.new(client: self)
  @custom_storage_credentials = Telnyx::Resources::CustomStorageCredentials.new(client: self)
  @customer_service_records = Telnyx::Resources::CustomerServiceRecords.new(client: self)
  @detail_records = Telnyx::Resources::DetailRecords.new(client: self)
  @dialogflow_connections = Telnyx::Resources::DialogflowConnections.new(client: self)
  @document_links = Telnyx::Resources::DocumentLinks.new(client: self)
  @documents = Telnyx::Resources::Documents.new(client: self)
  @dynamic_emergency_addresses = Telnyx::Resources::DynamicEmergencyAddresses.new(client: self)
  @dynamic_emergency_endpoints = Telnyx::Resources::DynamicEmergencyEndpoints.new(client: self)
  @external_connections = Telnyx::Resources::ExternalConnections.new(client: self)
  @fax_applications = Telnyx::Resources::FaxApplications.new(client: self)
  @faxes = Telnyx::Resources::Faxes.new(client: self)
  @fqdn_connections = Telnyx::Resources::FqdnConnections.new(client: self)
  @fqdns = Telnyx::Resources::Fqdns.new(client: self)
  @global_ip_allowed_ports = Telnyx::Resources::GlobalIPAllowedPorts.new(client: self)
  @global_ip_assignment_health = Telnyx::Resources::GlobalIPAssignmentHealth.new(client: self)
  @global_ip_assignments = Telnyx::Resources::GlobalIPAssignments.new(client: self)
  @global_ip_assignments_usage = Telnyx::Resources::GlobalIPAssignmentsUsage.new(client: self)
  @global_ip_health_check_types = Telnyx::Resources::GlobalIPHealthCheckTypes.new(client: self)
  @global_ip_health_checks = Telnyx::Resources::GlobalIPHealthChecks.new(client: self)
  @global_ip_latency = Telnyx::Resources::GlobalIPLatency.new(client: self)
  @global_ip_protocols = Telnyx::Resources::GlobalIPProtocols.new(client: self)
  @global_ip_usage = Telnyx::Resources::GlobalIPUsage.new(client: self)
  @global_ips = Telnyx::Resources::GlobalIPs.new(client: self)
  @inbound_channels = Telnyx::Resources::InboundChannels.new(client: self)
  @integration_secrets = Telnyx::Resources::IntegrationSecrets.new(client: self)
  @inventory_coverage = Telnyx::Resources::InventoryCoverage.new(client: self)
  @invoices = Telnyx::Resources::Invoices.new(client: self)
  @ip_connections = Telnyx::Resources::IPConnections.new(client: self)
  @ips = Telnyx::Resources::IPs.new(client: self)
  @ledger_billing_group_reports = Telnyx::Resources::LedgerBillingGroupReports.new(client: self)
  @list = Telnyx::Resources::List.new(client: self)
  @managed_accounts = Telnyx::Resources::ManagedAccounts.new(client: self)
  @media = Telnyx::Resources::Media.new(client: self)
  @messages = Telnyx::Resources::Messages.new(client: self)
  @messaging = Telnyx::Resources::Messaging.new(client: self)
  @messaging_hosted_number_orders = Telnyx::Resources::MessagingHostedNumberOrders.new(client: self)
  @messaging_hosted_numbers = Telnyx::Resources::MessagingHostedNumbers.new(client: self)
  @messaging_numbers_bulk_updates = Telnyx::Resources::MessagingNumbersBulkUpdates.new(client: self)
  @messaging_optouts = Telnyx::Resources::MessagingOptouts.new(client: self)
  @messaging_profiles = Telnyx::Resources::MessagingProfiles.new(client: self)
  @messaging_tollfree = Telnyx::Resources::MessagingTollfree.new(client: self)
  @messaging_url_domains = Telnyx::Resources::MessagingURLDomains.new(client: self)
  @mobile_network_operators = Telnyx::Resources::MobileNetworkOperators.new(client: self)
  @mobile_push_credentials = Telnyx::Resources::MobilePushCredentials.new(client: self)
  @network_coverage = Telnyx::Resources::NetworkCoverage.new(client: self)
  @networks = Telnyx::Resources::Networks.new(client: self)
  @notification_channels = Telnyx::Resources::NotificationChannels.new(client: self)
  @notification_event_conditions = Telnyx::Resources::NotificationEventConditions.new(client: self)
  @notification_events = Telnyx::Resources::NotificationEvents.new(client: self)
  @notification_profiles = Telnyx::Resources::NotificationProfiles.new(client: self)
  @notification_settings = Telnyx::Resources::NotificationSettings.new(client: self)
  @number_block_orders = Telnyx::Resources::NumberBlockOrders.new(client: self)
  @number_lookup = Telnyx::Resources::NumberLookup.new(client: self)
  @number_order_phone_numbers = Telnyx::Resources::NumberOrderPhoneNumbers.new(client: self)
  @number_orders = Telnyx::Resources::NumberOrders.new(client: self)
  @number_reservations = Telnyx::Resources::NumberReservations.new(client: self)
  @numbers_features = Telnyx::Resources::NumbersFeatures.new(client: self)
  @operator_connect = Telnyx::Resources::OperatorConnect.new(client: self)
  @ota_updates = Telnyx::Resources::OtaUpdates.new(client: self)
  @outbound_voice_profiles = Telnyx::Resources::OutboundVoiceProfiles.new(client: self)
  @payment = Telnyx::Resources::Payment.new(client: self)
  @phone_number_blocks = Telnyx::Resources::PhoneNumberBlocks.new(client: self)
  @phone_numbers = Telnyx::Resources::PhoneNumbers.new(client: self)
  @phone_numbers_regulatory_requirements =
    Telnyx::Resources::PhoneNumbersRegulatoryRequirements.new(client: self)
  @portability_checks = Telnyx::Resources::PortabilityChecks.new(client: self)
  @porting = Telnyx::Resources::Porting.new(client: self)
  @porting_orders = Telnyx::Resources::PortingOrders.new(client: self)
  @porting_phone_numbers = Telnyx::Resources::PortingPhoneNumbers.new(client: self)
  @portouts = Telnyx::Resources::Portouts.new(client: self)
  @private_wireless_gateways = Telnyx::Resources::PrivateWirelessGateways.new(client: self)
  @public_internet_gateways = Telnyx::Resources::PublicInternetGateways.new(client: self)
  @queues = Telnyx::Resources::Queues.new(client: self)
  @rcs_agents = Telnyx::Resources::RcsAgents.new(client: self)
  @recording_transcriptions = Telnyx::Resources::RecordingTranscriptions.new(client: self)
  @recordings = Telnyx::Resources::Recordings.new(client: self)
  @regions = Telnyx::Resources::Regions.new(client: self)
  @regulatory_requirements = Telnyx::Resources::RegulatoryRequirements.new(client: self)
  @reports = Telnyx::Resources::Reports.new(client: self)
  @speech_to_text = Telnyx::Resources::SpeechToText.new(client: self)
  @requirement_groups = Telnyx::Resources::RequirementGroups.new(client: self)
  @requirement_types = Telnyx::Resources::RequirementTypes.new(client: self)
  @requirements = Telnyx::Resources::Requirements.new(client: self)
  @room_compositions = Telnyx::Resources::RoomCompositions.new(client: self)
  @room_participants = Telnyx::Resources::RoomParticipants.new(client: self)
  @room_recordings = Telnyx::Resources::RoomRecordings.new(client: self)
  @rooms = Telnyx::Resources::Rooms.new(client: self)
  @seti = Telnyx::Resources::Seti.new(client: self)
  @short_codes = Telnyx::Resources::ShortCodes.new(client: self)
  @sim_card_data_usage_notifications = Telnyx::Resources::SimCardDataUsageNotifications.new(client: self)
  @sim_card_groups = Telnyx::Resources::SimCardGroups.new(client: self)
  @sim_card_order_preview = Telnyx::Resources::SimCardOrderPreview.new(client: self)
  @sim_card_orders = Telnyx::Resources::SimCardOrders.new(client: self)
  @sim_cards = Telnyx::Resources::SimCards.new(client: self)
  @siprec_connectors = Telnyx::Resources::SiprecConnectors.new(client: self)
  @storage = Telnyx::Resources::Storage.new(client: self)
  @sub_number_orders = Telnyx::Resources::SubNumberOrders.new(client: self)
  @sub_number_orders_report = Telnyx::Resources::SubNumberOrdersReport.new(client: self)
  @telephony_credentials = Telnyx::Resources::TelephonyCredentials.new(client: self)
  @texml = Telnyx::Resources::Texml.new(client: self)
  @texml_applications = Telnyx::Resources::TexmlApplications.new(client: self)
  @text_to_speech = Telnyx::Resources::TextToSpeech.new(client: self)
  @usage_reports = Telnyx::Resources::UsageReports.new(client: self)
  @user_addresses = Telnyx::Resources::UserAddresses.new(client: self)
  @user_tags = Telnyx::Resources::UserTags.new(client: self)
  @verifications = Telnyx::Resources::Verifications.new(client: self)
  @verified_numbers = Telnyx::Resources::VerifiedNumbers.new(client: self)
  @verify_profiles = Telnyx::Resources::VerifyProfiles.new(client: self)
  @virtual_cross_connects = Telnyx::Resources::VirtualCrossConnects.new(client: self)
  @virtual_cross_connects_coverage = Telnyx::Resources::VirtualCrossConnectsCoverage.new(client: self)
  @webhook_deliveries = Telnyx::Resources::WebhookDeliveries.new(client: self)
  @wireguard_interfaces = Telnyx::Resources::WireguardInterfaces.new(client: self)
  @wireguard_peers = Telnyx::Resources::WireguardPeers.new(client: self)
  @wireless = Telnyx::Resources::Wireless.new(client: self)
  @wireless_blocklist_values = Telnyx::Resources::WirelessBlocklistValues.new(client: self)
  @wireless_blocklists = Telnyx::Resources::WirelessBlocklists.new(client: self)
  @well_known = Telnyx::Resources::WellKnown.new(client: self)
  @inexplicit_number_orders = Telnyx::Resources::InexplicitNumberOrders.new(client: self)
  @mobile_phone_numbers = Telnyx::Resources::MobilePhoneNumbers.new(client: self)
  @mobile_voice_connections = Telnyx::Resources::MobileVoiceConnections.new(client: self)
  @messaging_10dlc = Telnyx::Resources::Messaging10dlc.new(client: self)
  @organizations = Telnyx::Resources::Organizations.new(client: self)
  @alphanumeric_sender_ids = Telnyx::Resources::AlphanumericSenderIDs.new(client: self)
  @messaging_profile_metrics = Telnyx::Resources::MessagingProfileMetrics.new(client: self)
  @session_analysis = Telnyx::Resources::SessionAnalysis.new(client: self)
  @whatsapp = Telnyx::Resources::Whatsapp.new(client: self)
  @whatsapp_message_templates = Telnyx::Resources::WhatsappMessageTemplates.new(client: self)
  @x402 = Telnyx::Resources::X402.new(client: self)
  @voice_clones = Telnyx::Resources::VoiceClones.new(client: self)
  @voice_designs = Telnyx::Resources::VoiceDesigns.new(client: self)
  @traffic_policy_profiles = Telnyx::Resources::TrafficPolicyProfiles.new(client: self)
  @enterprises = Telnyx::Resources::Enterprises.new(client: self)
  @reputation = Telnyx::Resources::Reputation.new(client: self)
  @terms_of_service = Telnyx::Resources::TermsOfService.new(client: self)
  @pronunciation_dicts = Telnyx::Resources::PronunciationDicts.new(client: self)
  @uac_connections = Telnyx::Resources::UacConnections.new(client: self)
  @voice_sdk_call_reports = Telnyx::Resources::VoiceSDKCallReports.new(client: self)
  @sip_registration_status = Telnyx::Resources::SipRegistrationStatus.new(client: self)
  @call_reasons = Telnyx::Resources::CallReasons.new(client: self)
  @dir = Telnyx::Resources::Dir.new(client: self)
  @infringement_claims = Telnyx::Resources::InfringementClaims.new(client: self)
end

Instance Attribute Details

#access_ip_addressTelnyx::Resources::AccessIPAddress (readonly)

IP Address Operations



47
48
49
# File 'lib/telnyx/client.rb', line 47

def access_ip_address
  @access_ip_address
end

#access_ip_rangesTelnyx::Resources::AccessIPRanges (readonly)

IP Range Operations



51
52
53
# File 'lib/telnyx/client.rb', line 51

def access_ip_ranges
  @access_ip_ranges
end

#actionsTelnyx::Resources::Actions (readonly)



54
55
56
# File 'lib/telnyx/client.rb', line 54

def actions
  @actions
end

#addressesTelnyx::Resources::Addresses (readonly)

Operations to work with Address records. Address records are emergency-validated addresses meant to be associated with phone numbers. They are validated for emergency usage purposes at creation time, although you may validate them separately with a custom workflow using the ValidateAddress operation separately. Address records are not usable for physical orders, such as for Telnyx SIM cards, please use UserAddress for that. It is not possible to entirely skip emergency service validation for Address records; if an emergency provider for a phone number rejects the address then it cannot be used on a phone number. To prevent records from getting out of sync, Address records are immutable and cannot be altered once created. If you realize you need to alter an address, a new record must be created with the differing address.



68
69
70
# File 'lib/telnyx/client.rb', line 68

def addresses
  @addresses
end

#advanced_ordersTelnyx::Resources::AdvancedOrders (readonly)



71
72
73
# File 'lib/telnyx/client.rb', line 71

def advanced_orders
  @advanced_orders
end

#aiTelnyx::Resources::AI (readonly)



74
75
76
# File 'lib/telnyx/client.rb', line 74

def ai
  @ai
end

#alphanumeric_sender_idsTelnyx::Resources::AlphanumericSenderIDs (readonly)



617
618
619
# File 'lib/telnyx/client.rb', line 617

def alphanumeric_sender_ids
  @alphanumeric_sender_ids
end

#api_keyString? (readonly)

Returns:

  • (String, nil)


19
20
21
# File 'lib/telnyx/client.rb', line 19

def api_key
  @api_key
end

#audit_eventsTelnyx::Resources::AuditEvents (readonly)

Audit log operations.



78
79
80
# File 'lib/telnyx/client.rb', line 78

def audit_events
  @audit_events
end

#authentication_providersTelnyx::Resources::AuthenticationProviders (readonly)



81
82
83
# File 'lib/telnyx/client.rb', line 81

def authentication_providers
  @authentication_providers
end

#available_phone_number_blocksTelnyx::Resources::AvailablePhoneNumberBlocks (readonly)

Number search



85
86
87
# File 'lib/telnyx/client.rb', line 85

def available_phone_number_blocks
  @available_phone_number_blocks
end

#available_phone_numbersTelnyx::Resources::AvailablePhoneNumbers (readonly)

Number search



89
90
91
# File 'lib/telnyx/client.rb', line 89

def available_phone_numbers
  @available_phone_numbers
end

#balanceTelnyx::Resources::Balance (readonly)

Billing operations



93
94
95
# File 'lib/telnyx/client.rb', line 93

def balance
  @balance
end

#billing_groupsTelnyx::Resources::BillingGroups (readonly)

Billing groups operations



97
98
99
# File 'lib/telnyx/client.rb', line 97

def billing_groups
  @billing_groups
end

#bulk_sim_card_actionsTelnyx::Resources::BulkSimCardActions (readonly)

View SIM card actions, their progress and timestamps using the SIM Card Actions API



102
103
104
# File 'lib/telnyx/client.rb', line 102

def bulk_sim_card_actions
  @bulk_sim_card_actions
end

#bundle_pricingTelnyx::Resources::BundlePricing (readonly)



105
106
107
# File 'lib/telnyx/client.rb', line 105

def bundle_pricing
  @bundle_pricing
end

#call_control_applicationsTelnyx::Resources::CallControlApplications (readonly)

Call Control applications operations



109
110
111
# File 'lib/telnyx/client.rb', line 109

def call_control_applications
  @call_control_applications
end

#call_eventsTelnyx::Resources::CallEvents (readonly)

Call Control debugging



113
114
115
# File 'lib/telnyx/client.rb', line 113

def call_events
  @call_events
end

#call_reasonsTelnyx::Resources::CallReasons (readonly)

Static reference values the API accepts: call reasons, document types, rejection types.



683
684
685
# File 'lib/telnyx/client.rb', line 683

def call_reasons
  @call_reasons
end

#callsTelnyx::Resources::Calls (readonly)



116
117
118
# File 'lib/telnyx/client.rb', line 116

def calls
  @calls
end

#channel_zonesTelnyx::Resources::ChannelZones (readonly)

Voice Channels



120
121
122
# File 'lib/telnyx/client.rb', line 120

def channel_zones
  @channel_zones
end

#charges_breakdownTelnyx::Resources::ChargesBreakdown (readonly)



123
124
125
# File 'lib/telnyx/client.rb', line 123

def charges_breakdown
  @charges_breakdown
end

#charges_summaryTelnyx::Resources::ChargesSummary (readonly)



126
127
128
# File 'lib/telnyx/client.rb', line 126

def charges_summary
  @charges_summary
end

#client_idString? (readonly)

Returns:

  • (String, nil)


25
26
27
# File 'lib/telnyx/client.rb', line 25

def client_id
  @client_id
end

#client_secretString? (readonly)

Returns:

  • (String, nil)


28
29
30
# File 'lib/telnyx/client.rb', line 28

def client_secret
  @client_secret
end

#commentsTelnyx::Resources::Comments (readonly)

Number orders



130
131
132
# File 'lib/telnyx/client.rb', line 130

def comments
  @comments
end

#conferencesTelnyx::Resources::Conferences (readonly)

Conference command operations



134
135
136
# File 'lib/telnyx/client.rb', line 134

def conferences
  @conferences
end

#connectionsTelnyx::Resources::Connections (readonly)



137
138
139
# File 'lib/telnyx/client.rb', line 137

def connections
  @connections
end

#country_coverageTelnyx::Resources::CountryCoverage (readonly)

Country Coverage



141
142
143
# File 'lib/telnyx/client.rb', line 141

def country_coverage
  @country_coverage
end

#credential_connectionsTelnyx::Resources::CredentialConnections (readonly)

Credential connection operations



145
146
147
# File 'lib/telnyx/client.rb', line 145

def credential_connections
  @credential_connections
end

#custom_storage_credentialsTelnyx::Resources::CustomStorageCredentials (readonly)

Call Recordings operations.



149
150
151
# File 'lib/telnyx/client.rb', line 149

def custom_storage_credentials
  @custom_storage_credentials
end

#customer_service_recordsTelnyx::Resources::CustomerServiceRecords (readonly)

Customer Service Record operations



153
154
155
# File 'lib/telnyx/client.rb', line 153

def customer_service_records
  @customer_service_records
end

#detail_recordsTelnyx::Resources::DetailRecords (readonly)

Detail Records operations



157
158
159
# File 'lib/telnyx/client.rb', line 157

def detail_records
  @detail_records
end

#dialogflow_connectionsTelnyx::Resources::DialogflowConnections (readonly)

Dialogflow Connection Operations.



161
162
163
# File 'lib/telnyx/client.rb', line 161

def dialogflow_connections
  @dialogflow_connections
end

#dirTelnyx::Resources::Dir (readonly)



686
687
688
# File 'lib/telnyx/client.rb', line 686

def dir
  @dir
end

Documents



165
166
167
# File 'lib/telnyx/client.rb', line 165

def document_links
  @document_links
end

#documentsTelnyx::Resources::Documents (readonly)

Documents



169
170
171
# File 'lib/telnyx/client.rb', line 169

def documents
  @documents
end

#dynamic_emergency_addressesTelnyx::Resources::DynamicEmergencyAddresses (readonly)

Dynamic emergency address operations



173
174
175
# File 'lib/telnyx/client.rb', line 173

def dynamic_emergency_addresses
  @dynamic_emergency_addresses
end

#dynamic_emergency_endpointsTelnyx::Resources::DynamicEmergencyEndpoints (readonly)

Dynamic Emergency Endpoints



177
178
179
# File 'lib/telnyx/client.rb', line 177

def dynamic_emergency_endpoints
  @dynamic_emergency_endpoints
end

#enterprisesTelnyx::Resources::Enterprises (readonly)

Manage the legal-entity record that owns your DIRs and phone numbers.



651
652
653
# File 'lib/telnyx/client.rb', line 651

def enterprises
  @enterprises
end

#external_connectionsTelnyx::Resources::ExternalConnections (readonly)

External Connections operations



181
182
183
# File 'lib/telnyx/client.rb', line 181

def external_connections
  @external_connections
end

#fax_applicationsTelnyx::Resources::FaxApplications (readonly)

Fax Applications operations



185
186
187
# File 'lib/telnyx/client.rb', line 185

def fax_applications
  @fax_applications
end

#faxesTelnyx::Resources::Faxes (readonly)

Programmable fax command operations



189
190
191
# File 'lib/telnyx/client.rb', line 189

def faxes
  @faxes
end

#fqdn_connectionsTelnyx::Resources::FqdnConnections (readonly)

FQDN connection operations



193
194
195
# File 'lib/telnyx/client.rb', line 193

def fqdn_connections
  @fqdn_connections
end

#fqdnsTelnyx::Resources::Fqdns (readonly)

FQDN operations



197
198
199
# File 'lib/telnyx/client.rb', line 197

def fqdns
  @fqdns
end

#global_ip_allowed_portsTelnyx::Resources::GlobalIPAllowedPorts (readonly)

Global IPs



201
202
203
# File 'lib/telnyx/client.rb', line 201

def global_ip_allowed_ports
  @global_ip_allowed_ports
end

#global_ip_assignment_healthTelnyx::Resources::GlobalIPAssignmentHealth (readonly)

Global IPs



205
206
207
# File 'lib/telnyx/client.rb', line 205

def global_ip_assignment_health
  @global_ip_assignment_health
end

#global_ip_assignmentsTelnyx::Resources::GlobalIPAssignments (readonly)

Global IPs



209
210
211
# File 'lib/telnyx/client.rb', line 209

def global_ip_assignments
  @global_ip_assignments
end

#global_ip_assignments_usageTelnyx::Resources::GlobalIPAssignmentsUsage (readonly)

Global IPs



213
214
215
# File 'lib/telnyx/client.rb', line 213

def global_ip_assignments_usage
  @global_ip_assignments_usage
end

#global_ip_health_check_typesTelnyx::Resources::GlobalIPHealthCheckTypes (readonly)

Global IPs



217
218
219
# File 'lib/telnyx/client.rb', line 217

def global_ip_health_check_types
  @global_ip_health_check_types
end

#global_ip_health_checksTelnyx::Resources::GlobalIPHealthChecks (readonly)

Global IPs



221
222
223
# File 'lib/telnyx/client.rb', line 221

def global_ip_health_checks
  @global_ip_health_checks
end

#global_ip_latencyTelnyx::Resources::GlobalIPLatency (readonly)

Global IPs



225
226
227
# File 'lib/telnyx/client.rb', line 225

def global_ip_latency
  @global_ip_latency
end

#global_ip_protocolsTelnyx::Resources::GlobalIPProtocols (readonly)

Global IPs



229
230
231
# File 'lib/telnyx/client.rb', line 229

def global_ip_protocols
  @global_ip_protocols
end

#global_ip_usageTelnyx::Resources::GlobalIPUsage (readonly)

Global IPs



233
234
235
# File 'lib/telnyx/client.rb', line 233

def global_ip_usage
  @global_ip_usage
end

#global_ipsTelnyx::Resources::GlobalIPs (readonly)

Global IPs



237
238
239
# File 'lib/telnyx/client.rb', line 237

def global_ips
  @global_ips
end

#inbound_channelsTelnyx::Resources::InboundChannels (readonly)

Voice Channels



241
242
243
# File 'lib/telnyx/client.rb', line 241

def inbound_channels
  @inbound_channels
end

#inexplicit_number_ordersTelnyx::Resources::InexplicitNumberOrders (readonly)

Inexplicit number orders for bulk purchasing without specifying exact numbers



600
601
602
# File 'lib/telnyx/client.rb', line 600

def inexplicit_number_orders
  @inexplicit_number_orders
end

#infringement_claimsTelnyx::Resources::InfringementClaims (readonly)

Trademark or impersonation claims filed against your DIR. Customers may contest a claim with supporting evidence.



691
692
693
# File 'lib/telnyx/client.rb', line 691

def infringement_claims
  @infringement_claims
end

#integration_secretsTelnyx::Resources::IntegrationSecrets (readonly)

Store and retrieve integration secrets



245
246
247
# File 'lib/telnyx/client.rb', line 245

def integration_secrets
  @integration_secrets
end

#inventory_coverageTelnyx::Resources::InventoryCoverage (readonly)

Inventory Level



249
250
251
# File 'lib/telnyx/client.rb', line 249

def inventory_coverage
  @inventory_coverage
end

#invoicesTelnyx::Resources::Invoices (readonly)



252
253
254
# File 'lib/telnyx/client.rb', line 252

def invoices
  @invoices
end

#ip_connectionsTelnyx::Resources::IPConnections (readonly)

IP connection operations



256
257
258
# File 'lib/telnyx/client.rb', line 256

def ip_connections
  @ip_connections
end

#ipsTelnyx::Resources::IPs (readonly)

IP operations



260
261
262
# File 'lib/telnyx/client.rb', line 260

def ips
  @ips
end

#ledger_billing_group_reportsTelnyx::Resources::LedgerBillingGroupReports (readonly)

Ledger billing reports



264
265
266
# File 'lib/telnyx/client.rb', line 264

def ledger_billing_group_reports
  @ledger_billing_group_reports
end

#legacyTelnyx::Resources::Legacy (readonly)



31
32
33
# File 'lib/telnyx/client.rb', line 31

def legacy
  @legacy
end

#listTelnyx::Resources::List (readonly)

Voice Channels



268
269
270
# File 'lib/telnyx/client.rb', line 268

def list
  @list
end

#managed_accountsTelnyx::Resources::ManagedAccounts (readonly)

Managed Accounts operations



272
273
274
# File 'lib/telnyx/client.rb', line 272

def managed_accounts
  @managed_accounts
end

#mediaTelnyx::Resources::Media (readonly)

Media Storage operations



276
277
278
# File 'lib/telnyx/client.rb', line 276

def media
  @media
end

#messagesTelnyx::Resources::Messages (readonly)

Messages



280
281
282
# File 'lib/telnyx/client.rb', line 280

def messages
  @messages
end

#messagingTelnyx::Resources::Messaging (readonly)



283
284
285
# File 'lib/telnyx/client.rb', line 283

def messaging
  @messaging
end

#messaging_10dlcTelnyx::Resources::Messaging10dlc (readonly)



611
612
613
# File 'lib/telnyx/client.rb', line 611

def messaging_10dlc
  @messaging_10dlc
end

#messaging_hosted_number_ordersTelnyx::Resources::MessagingHostedNumberOrders (readonly)

Manage your messaging hosted numbers



287
288
289
# File 'lib/telnyx/client.rb', line 287

def messaging_hosted_number_orders
  @messaging_hosted_number_orders
end

#messaging_hosted_numbersTelnyx::Resources::MessagingHostedNumbers (readonly)



290
291
292
# File 'lib/telnyx/client.rb', line 290

def messaging_hosted_numbers
  @messaging_hosted_numbers
end

#messaging_numbers_bulk_updatesTelnyx::Resources::MessagingNumbersBulkUpdates (readonly)

Configure your phone numbers



294
295
296
# File 'lib/telnyx/client.rb', line 294

def messaging_numbers_bulk_updates
  @messaging_numbers_bulk_updates
end

#messaging_optoutsTelnyx::Resources::MessagingOptouts (readonly)

Opt-Out Management



298
299
300
# File 'lib/telnyx/client.rb', line 298

def messaging_optouts
  @messaging_optouts
end

#messaging_profile_metricsTelnyx::Resources::MessagingProfileMetrics (readonly)



620
621
622
# File 'lib/telnyx/client.rb', line 620

def messaging_profile_metrics
  @messaging_profile_metrics
end

#messaging_profilesTelnyx::Resources::MessagingProfiles (readonly)



301
302
303
# File 'lib/telnyx/client.rb', line 301

def messaging_profiles
  @messaging_profiles
end

#messaging_tollfreeTelnyx::Resources::MessagingTollfree (readonly)



304
305
306
# File 'lib/telnyx/client.rb', line 304

def messaging_tollfree
  @messaging_tollfree
end

#messaging_url_domainsTelnyx::Resources::MessagingURLDomains (readonly)

Messaging URL Domains



308
309
310
# File 'lib/telnyx/client.rb', line 308

def messaging_url_domains
  @messaging_url_domains
end

#mobile_network_operatorsTelnyx::Resources::MobileNetworkOperators (readonly)

Mobile network operators operations



312
313
314
# File 'lib/telnyx/client.rb', line 312

def mobile_network_operators
  @mobile_network_operators
end

#mobile_phone_numbersTelnyx::Resources::MobilePhoneNumbers (readonly)

Mobile phone number operations



604
605
606
# File 'lib/telnyx/client.rb', line 604

def mobile_phone_numbers
  @mobile_phone_numbers
end

#mobile_push_credentialsTelnyx::Resources::MobilePushCredentials (readonly)

Mobile push credential management



316
317
318
# File 'lib/telnyx/client.rb', line 316

def mobile_push_credentials
  @mobile_push_credentials
end

#mobile_voice_connectionsTelnyx::Resources::MobileVoiceConnections (readonly)

Mobile voice connection operations



608
609
610
# File 'lib/telnyx/client.rb', line 608

def mobile_voice_connections
  @mobile_voice_connections
end

#network_coverageTelnyx::Resources::NetworkCoverage (readonly)



319
320
321
# File 'lib/telnyx/client.rb', line 319

def network_coverage
  @network_coverage
end

#networksTelnyx::Resources::Networks (readonly)

Network operations



323
324
325
# File 'lib/telnyx/client.rb', line 323

def networks
  @networks
end

#notification_channelsTelnyx::Resources::NotificationChannels (readonly)

Notification settings operations



327
328
329
# File 'lib/telnyx/client.rb', line 327

def notification_channels
  @notification_channels
end

#notification_event_conditionsTelnyx::Resources::NotificationEventConditions (readonly)

Notification settings operations



331
332
333
# File 'lib/telnyx/client.rb', line 331

def notification_event_conditions
  @notification_event_conditions
end

#notification_eventsTelnyx::Resources::NotificationEvents (readonly)

Notification settings operations



335
336
337
# File 'lib/telnyx/client.rb', line 335

def notification_events
  @notification_events
end

#notification_profilesTelnyx::Resources::NotificationProfiles (readonly)

Notification settings operations



339
340
341
# File 'lib/telnyx/client.rb', line 339

def notification_profiles
  @notification_profiles
end

#notification_settingsTelnyx::Resources::NotificationSettings (readonly)

Notification settings operations



343
344
345
# File 'lib/telnyx/client.rb', line 343

def notification_settings
  @notification_settings
end

#number_block_ordersTelnyx::Resources::NumberBlockOrders (readonly)



346
347
348
# File 'lib/telnyx/client.rb', line 346

def number_block_orders
  @number_block_orders
end

#number_lookupTelnyx::Resources::NumberLookup (readonly)

Look up phone number data



350
351
352
# File 'lib/telnyx/client.rb', line 350

def number_lookup
  @number_lookup
end

#number_order_phone_numbersTelnyx::Resources::NumberOrderPhoneNumbers (readonly)



353
354
355
# File 'lib/telnyx/client.rb', line 353

def number_order_phone_numbers
  @number_order_phone_numbers
end

#number_ordersTelnyx::Resources::NumberOrders (readonly)

Number orders



357
358
359
# File 'lib/telnyx/client.rb', line 357

def number_orders
  @number_orders
end

#number_reservationsTelnyx::Resources::NumberReservations (readonly)

Number reservations



361
362
363
# File 'lib/telnyx/client.rb', line 361

def number_reservations
  @number_reservations
end

#numbers_featuresTelnyx::Resources::NumbersFeatures (readonly)



364
365
366
# File 'lib/telnyx/client.rb', line 364

def numbers_features
  @numbers_features
end

#oauthTelnyx::Resources::OAuth (readonly)



34
35
36
# File 'lib/telnyx/client.rb', line 34

def oauth
  @oauth
end

#oauth_client_auth_stateTelnyx::Internal::OAuth2ClientCredentials (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



711
712
713
# File 'lib/telnyx/client.rb', line 711

def oauth_client_auth_state
  @oauth_client_auth_state
end

#oauth_clientsTelnyx::Resources::OAuthClients (readonly)



37
38
39
# File 'lib/telnyx/client.rb', line 37

def oauth_clients
  @oauth_clients
end

#oauth_grantsTelnyx::Resources::OAuthGrants (readonly)



40
41
42
# File 'lib/telnyx/client.rb', line 40

def oauth_grants
  @oauth_grants
end

#operator_connectTelnyx::Resources::OperatorConnect (readonly)



367
368
369
# File 'lib/telnyx/client.rb', line 367

def operator_connect
  @operator_connect
end

#organizationsTelnyx::Resources::Organizations (readonly)



614
615
616
# File 'lib/telnyx/client.rb', line 614

def organizations
  @organizations
end

#ota_updatesTelnyx::Resources::OtaUpdates (readonly)

OTA updates operations



371
372
373
# File 'lib/telnyx/client.rb', line 371

def ota_updates
  @ota_updates
end

#outbound_voice_profilesTelnyx::Resources::OutboundVoiceProfiles (readonly)

Outbound voice profiles operations



375
376
377
# File 'lib/telnyx/client.rb', line 375

def outbound_voice_profiles
  @outbound_voice_profiles
end

#paymentTelnyx::Resources::Payment (readonly)

Operations for managing stored payment transactions.



379
380
381
# File 'lib/telnyx/client.rb', line 379

def payment
  @payment
end

#phone_number_blocksTelnyx::Resources::PhoneNumberBlocks (readonly)



382
383
384
# File 'lib/telnyx/client.rb', line 382

def phone_number_blocks
  @phone_number_blocks
end

#phone_numbersTelnyx::Resources::PhoneNumbers (readonly)

Configure your phone numbers



386
387
388
# File 'lib/telnyx/client.rb', line 386

def phone_numbers
  @phone_numbers
end

#phone_numbers_regulatory_requirementsTelnyx::Resources::PhoneNumbersRegulatoryRequirements (readonly)

Regulatory Requirements



390
391
392
# File 'lib/telnyx/client.rb', line 390

def phone_numbers_regulatory_requirements
  @phone_numbers_regulatory_requirements
end

#portability_checksTelnyx::Resources::PortabilityChecks (readonly)

Determining portability of phone numbers



394
395
396
# File 'lib/telnyx/client.rb', line 394

def portability_checks
  @portability_checks
end

#portingTelnyx::Resources::Porting (readonly)

Endpoints related to porting orders management.



398
399
400
# File 'lib/telnyx/client.rb', line 398

def porting
  @porting
end

#porting_ordersTelnyx::Resources::PortingOrders (readonly)

Endpoints related to porting orders management.



402
403
404
# File 'lib/telnyx/client.rb', line 402

def porting_orders
  @porting_orders
end

#porting_phone_numbersTelnyx::Resources::PortingPhoneNumbers (readonly)

Endpoints related to porting orders management.



406
407
408
# File 'lib/telnyx/client.rb', line 406

def porting_phone_numbers
  @porting_phone_numbers
end

#portoutsTelnyx::Resources::Portouts (readonly)

Number portout operations



410
411
412
# File 'lib/telnyx/client.rb', line 410

def portouts
  @portouts
end

#private_wireless_gatewaysTelnyx::Resources::PrivateWirelessGateways (readonly)

Private Wireless Gateways operations



414
415
416
# File 'lib/telnyx/client.rb', line 414

def private_wireless_gateways
  @private_wireless_gateways
end

#pronunciation_dictsTelnyx::Resources::PronunciationDicts (readonly)

Manage pronunciation dictionaries for text-to-speech synthesis. Dictionaries contain alias items (text replacement) and phoneme items (IPA pronunciation notation) that control how specific words are spoken.



665
666
667
# File 'lib/telnyx/client.rb', line 665

def pronunciation_dicts
  @pronunciation_dicts
end

#public_internet_gatewaysTelnyx::Resources::PublicInternetGateways (readonly)

Public Internet Gateway operations



418
419
420
# File 'lib/telnyx/client.rb', line 418

def public_internet_gateways
  @public_internet_gateways
end

#public_keyString? (readonly)

Returns:

  • (String, nil)


22
23
24
# File 'lib/telnyx/client.rb', line 22

def public_key
  @public_key
end

#queuesTelnyx::Resources::Queues (readonly)

Queue commands operations



422
423
424
# File 'lib/telnyx/client.rb', line 422

def queues
  @queues
end

#rcs_agentsTelnyx::Resources::RcsAgents (readonly)



425
426
427
# File 'lib/telnyx/client.rb', line 425

def rcs_agents
  @rcs_agents
end

#recording_transcriptionsTelnyx::Resources::RecordingTranscriptions (readonly)

Call Recordings operations.



429
430
431
# File 'lib/telnyx/client.rb', line 429

def recording_transcriptions
  @recording_transcriptions
end

#recordingsTelnyx::Resources::Recordings (readonly)

Call Recordings operations.



433
434
435
# File 'lib/telnyx/client.rb', line 433

def recordings
  @recordings
end

#regionsTelnyx::Resources::Regions (readonly)

Regions



437
438
439
# File 'lib/telnyx/client.rb', line 437

def regions
  @regions
end

#regulatory_requirementsTelnyx::Resources::RegulatoryRequirements (readonly)

Regulatory Requirements



441
442
443
# File 'lib/telnyx/client.rb', line 441

def regulatory_requirements
  @regulatory_requirements
end

#reportsTelnyx::Resources::Reports (readonly)



444
445
446
# File 'lib/telnyx/client.rb', line 444

def reports
  @reports
end

#reputationTelnyx::Resources::Reputation (readonly)



654
655
656
# File 'lib/telnyx/client.rb', line 654

def reputation
  @reputation
end

#requirement_groupsTelnyx::Resources::RequirementGroups (readonly)

Requirement Groups



451
452
453
# File 'lib/telnyx/client.rb', line 451

def requirement_groups
  @requirement_groups
end

#requirement_typesTelnyx::Resources::RequirementTypes (readonly)

Types of requirements for international numbers and porting orders



455
456
457
# File 'lib/telnyx/client.rb', line 455

def requirement_types
  @requirement_types
end

#requirementsTelnyx::Resources::Requirements (readonly)

Requirements for international numbers and porting orders



459
460
461
# File 'lib/telnyx/client.rb', line 459

def requirements
  @requirements
end

#room_compositionsTelnyx::Resources::RoomCompositions (readonly)

Rooms Compositions operations.



463
464
465
# File 'lib/telnyx/client.rb', line 463

def room_compositions
  @room_compositions
end

#room_participantsTelnyx::Resources::RoomParticipants (readonly)

Rooms Participants operations.



467
468
469
# File 'lib/telnyx/client.rb', line 467

def room_participants
  @room_participants
end

#room_recordingsTelnyx::Resources::RoomRecordings (readonly)

Rooms Recordings operations.



471
472
473
# File 'lib/telnyx/client.rb', line 471

def room_recordings
  @room_recordings
end

#roomsTelnyx::Resources::Rooms (readonly)

Rooms operations.



475
476
477
# File 'lib/telnyx/client.rb', line 475

def rooms
  @rooms
end

#session_analysisTelnyx::Resources::SessionAnalysis (readonly)

Analyze voice AI sessions, costs, and event hierarchies across Telnyx products.



624
625
626
# File 'lib/telnyx/client.rb', line 624

def session_analysis
  @session_analysis
end

#setiTelnyx::Resources::Seti (readonly)

Observability into Telnyx platform stability and performance.



479
480
481
# File 'lib/telnyx/client.rb', line 479

def seti
  @seti
end

#short_codesTelnyx::Resources::ShortCodes (readonly)

Short codes



483
484
485
# File 'lib/telnyx/client.rb', line 483

def short_codes
  @short_codes
end

#sim_card_data_usage_notificationsTelnyx::Resources::SimCardDataUsageNotifications (readonly)

SIM Cards operations



487
488
489
# File 'lib/telnyx/client.rb', line 487

def sim_card_data_usage_notifications
  @sim_card_data_usage_notifications
end

#sim_card_groupsTelnyx::Resources::SimCardGroups (readonly)

SIM Card Groups operations



491
492
493
# File 'lib/telnyx/client.rb', line 491

def sim_card_groups
  @sim_card_groups
end

#sim_card_order_previewTelnyx::Resources::SimCardOrderPreview (readonly)

SIM Card Orders operations



495
496
497
# File 'lib/telnyx/client.rb', line 495

def sim_card_order_preview
  @sim_card_order_preview
end

#sim_card_ordersTelnyx::Resources::SimCardOrders (readonly)

SIM Card Orders operations



499
500
501
# File 'lib/telnyx/client.rb', line 499

def sim_card_orders
  @sim_card_orders
end

#sim_cardsTelnyx::Resources::SimCards (readonly)

SIM Cards operations



503
504
505
# File 'lib/telnyx/client.rb', line 503

def sim_cards
  @sim_cards
end

#sip_registration_statusTelnyx::Resources::SipRegistrationStatus (readonly)

UAC connection operations



678
679
680
# File 'lib/telnyx/client.rb', line 678

def sip_registration_status
  @sip_registration_status
end

#siprec_connectorsTelnyx::Resources::SiprecConnectors (readonly)

SIPREC connectors configuration.



507
508
509
# File 'lib/telnyx/client.rb', line 507

def siprec_connectors
  @siprec_connectors
end

#speech_to_textTelnyx::Resources::SpeechToText (readonly)



447
448
449
# File 'lib/telnyx/client.rb', line 447

def speech_to_text
  @speech_to_text
end

#storageTelnyx::Resources::Storage (readonly)

Migrate data from an external provider into Telnyx Cloud Storage



511
512
513
# File 'lib/telnyx/client.rb', line 511

def storage
  @storage
end

#sub_number_ordersTelnyx::Resources::SubNumberOrders (readonly)



514
515
516
# File 'lib/telnyx/client.rb', line 514

def sub_number_orders
  @sub_number_orders
end

#sub_number_orders_reportTelnyx::Resources::SubNumberOrdersReport (readonly)

Number orders



518
519
520
# File 'lib/telnyx/client.rb', line 518

def sub_number_orders_report
  @sub_number_orders_report
end

#telephony_credentialsTelnyx::Resources::TelephonyCredentials (readonly)



521
522
523
# File 'lib/telnyx/client.rb', line 521

def telephony_credentials
  @telephony_credentials
end

#terms_of_serviceTelnyx::Resources::TermsOfService (readonly)

Accept and review the Branded Calling and Phone Number Reputation terms of service.



659
660
661
# File 'lib/telnyx/client.rb', line 659

def terms_of_service
  @terms_of_service
end

#texmlTelnyx::Resources::Texml (readonly)

TeXML REST Commands



525
526
527
# File 'lib/telnyx/client.rb', line 525

def texml
  @texml
end

#texml_applicationsTelnyx::Resources::TexmlApplications (readonly)

TeXML Applications operations



529
530
531
# File 'lib/telnyx/client.rb', line 529

def texml_applications
  @texml_applications
end

#text_to_speechTelnyx::Resources::TextToSpeech (readonly)

Text to speech streaming command operations



533
534
535
# File 'lib/telnyx/client.rb', line 533

def text_to_speech
  @text_to_speech
end

#traffic_policy_profilesTelnyx::Resources::TrafficPolicyProfiles (readonly)

Traffic Policy Profiles operations



647
648
649
# File 'lib/telnyx/client.rb', line 647

def traffic_policy_profiles
  @traffic_policy_profiles
end

#uac_connectionsTelnyx::Resources::UacConnections (readonly)

UAC connection operations



669
670
671
# File 'lib/telnyx/client.rb', line 669

def uac_connections
  @uac_connections
end

#usage_reportsTelnyx::Resources::UsageReports (readonly)

Usage data reporting across Telnyx products



537
538
539
# File 'lib/telnyx/client.rb', line 537

def usage_reports
  @usage_reports
end

#user_addressesTelnyx::Resources::UserAddresses (readonly)

Operations for working with UserAddress records. UserAddress records are stored addresses that users can use for non-emergency-calling purposes, such as for shipping addresses for orders of wireless SIMs (or other physical items). They cannot be used for emergency calling and are distinct from Address records, which are used on phone numbers.



545
546
547
# File 'lib/telnyx/client.rb', line 545

def user_addresses
  @user_addresses
end

#user_tagsTelnyx::Resources::UserTags (readonly)

User-defined tags for Telnyx resources



549
550
551
# File 'lib/telnyx/client.rb', line 549

def user_tags
  @user_tags
end

#verificationsTelnyx::Resources::Verifications (readonly)

Two factor authentication API



553
554
555
# File 'lib/telnyx/client.rb', line 553

def verifications
  @verifications
end

#verified_numbersTelnyx::Resources::VerifiedNumbers (readonly)

Verified Numbers operations



557
558
559
# File 'lib/telnyx/client.rb', line 557

def verified_numbers
  @verified_numbers
end

#verify_profilesTelnyx::Resources::VerifyProfiles (readonly)

Two factor authentication API



561
562
563
# File 'lib/telnyx/client.rb', line 561

def verify_profiles
  @verify_profiles
end

#virtual_cross_connectsTelnyx::Resources::VirtualCrossConnects (readonly)

Virtual Cross Connect operations



565
566
567
# File 'lib/telnyx/client.rb', line 565

def virtual_cross_connects
  @virtual_cross_connects
end

#virtual_cross_connects_coverageTelnyx::Resources::VirtualCrossConnectsCoverage (readonly)

Virtual Cross Connect operations



569
570
571
# File 'lib/telnyx/client.rb', line 569

def virtual_cross_connects_coverage
  @virtual_cross_connects_coverage
end

#voice_clonesTelnyx::Resources::VoiceClones (readonly)

Capture and manage voice identities as clones for use in text-to-speech synthesis.



639
640
641
# File 'lib/telnyx/client.rb', line 639

def voice_clones
  @voice_clones
end

#voice_designsTelnyx::Resources::VoiceDesigns (readonly)

Create and manage AI-generated voice designs using natural language prompts.



643
644
645
# File 'lib/telnyx/client.rb', line 643

def voice_designs
  @voice_designs
end

#voice_sdk_call_reportsTelnyx::Resources::VoiceSDKCallReports (readonly)

Retrieve raw Voice SDK call report stats payloads for WebRTC call troubleshooting.



674
675
676
# File 'lib/telnyx/client.rb', line 674

def voice_sdk_call_reports
  @voice_sdk_call_reports
end

#webhook_deliveriesTelnyx::Resources::WebhookDeliveries (readonly)

Webhooks operations



573
574
575
# File 'lib/telnyx/client.rb', line 573

def webhook_deliveries
  @webhook_deliveries
end

#webhooksTelnyx::Resources::Webhooks (readonly)



43
44
45
# File 'lib/telnyx/client.rb', line 43

def webhooks
  @webhooks
end

#well_knownTelnyx::Resources::WellKnown (readonly)



596
597
598
# File 'lib/telnyx/client.rb', line 596

def well_known
  @well_known
end

#whatsappTelnyx::Resources::Whatsapp (readonly)



627
628
629
# File 'lib/telnyx/client.rb', line 627

def whatsapp
  @whatsapp
end

#whatsapp_message_templatesTelnyx::Resources::WhatsappMessageTemplates (readonly)

Manage Whatsapp message templates



631
632
633
# File 'lib/telnyx/client.rb', line 631

def whatsapp_message_templates
  @whatsapp_message_templates
end

#wireguard_interfacesTelnyx::Resources::WireguardInterfaces (readonly)

WireGuard Interface operations



577
578
579
# File 'lib/telnyx/client.rb', line 577

def wireguard_interfaces
  @wireguard_interfaces
end

#wireguard_peersTelnyx::Resources::WireguardPeers (readonly)

WireGuard Interface operations



581
582
583
# File 'lib/telnyx/client.rb', line 581

def wireguard_peers
  @wireguard_peers
end

#wirelessTelnyx::Resources::Wireless (readonly)

Regions for wireless services



585
586
587
# File 'lib/telnyx/client.rb', line 585

def wireless
  @wireless
end

#wireless_blocklist_valuesTelnyx::Resources::WirelessBlocklistValues (readonly)

Wireless Blocklists operations



589
590
591
# File 'lib/telnyx/client.rb', line 589

def wireless_blocklist_values
  @wireless_blocklist_values
end

#wireless_blocklistsTelnyx::Resources::WirelessBlocklists (readonly)

Wireless Blocklists operations



593
594
595
# File 'lib/telnyx/client.rb', line 593

def wireless_blocklists
  @wireless_blocklists
end

#x402Telnyx::Resources::X402 (readonly)



634
635
636
# File 'lib/telnyx/client.rb', line 634

def x402
  @x402
end

Instance Method Details

#base_url_overridden?Boolean

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (Boolean)


737
# File 'lib/telnyx/client.rb', line 737

def base_url_overridden? = @base_url_overridden