Class: Telnyx::Models::AI::Assistant

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant.rb,
sig/telnyx/models/ai/assistant.rbs

Defined Under Namespace

Modules: Tool

Constant Summary collapse

Telnyx =

Returns:

  • (:BookAppointmentTool)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



31
# File 'sig/telnyx/models/ai/assistant.rbs', line 31

def initialize: (

Instance Attribute Details

#instructionsString?

The system instructions that the voice assistant uses during the gather command

Parameters:

  • (String)

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/ai/assistant.rb', line 11

optional :instructions, String

#modelString?

The model to be used by the voice assistant.

Parameters:

  • (String)

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/ai/assistant.rb', line 17

optional :model, String

#openai_api_key_refString?

This is necessary only if the model selected is from OpenAI. You would pass the identifier for an integration secret /v2/integration_secrets that refers to your OpenAI API Key. Warning: Free plans are unlikely to work with this integration.

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/ai/assistant.rb', line 27

optional :openai_api_key_ref, String

Instance Method Details

#to_hash{

Returns:

  • ({)


38
# File 'sig/telnyx/models/ai/assistant.rbs', line 38

def to_hash: -> {