Class: Telnyx::Models::AI::AssistantChatParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantChatParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/assistant_chat_params.rb
Overview
Instance Attribute Summary collapse
- #assistant_id ⇒ String
-
#content ⇒ String
The message content sent by the client to the assistant.
-
#conversation_id ⇒ String
A unique identifier for the conversation thread, used to maintain context.
-
#name ⇒ String?
The optional display name of the user sending the message.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(assistant_id:, content:, conversation_id:, name: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assistant_id:, content:, conversation_id:, name: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/ai/assistant_chat_params.rb', line 34
|
Instance Attribute Details
#assistant_id ⇒ String
14 |
# File 'lib/telnyx/models/ai/assistant_chat_params.rb', line 14 required :assistant_id, String |
#content ⇒ String
The message content sent by the client to the assistant
20 |
# File 'lib/telnyx/models/ai/assistant_chat_params.rb', line 20 required :content, String |
#conversation_id ⇒ String
A unique identifier for the conversation thread, used to maintain context
26 |
# File 'lib/telnyx/models/ai/assistant_chat_params.rb', line 26 required :conversation_id, String |
#name ⇒ String?
The optional display name of the user sending the message
32 |
# File 'lib/telnyx/models/ai/assistant_chat_params.rb', line 32 optional :name, String |