Class: Telnyx::Models::AI::AssistantChatResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_chat_response.rb,
sig/telnyx/models/ai/assistant_chat_response.rbs

Overview

See Also:

  • Telnyx::Resources::AI::Assistants#chat

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content:) ⇒ AssistantChatResponse

Returns a new instance of AssistantChatResponse.

Parameters:

  • content (String)

    The assistant's generated response based on the input message and context.

  • content: (String)


# File 'lib/telnyx/models/ai/assistant_chat_response.rb', line 14

Instance Attribute Details

#contentString

The assistant's generated response based on the input message and context.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/telnyx/models/ai/assistant_chat_response.rb', line 12

required :content, String

Instance Method Details

#to_hash{ content: String }

Returns:

  • ({ content: String })


11
# File 'sig/telnyx/models/ai/assistant_chat_response.rbs', line 11

def to_hash: -> { content: String }