Class: Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge
- Defined in:
- lib/telnyx/models/ai/assistant_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#condition ⇒ Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Condition::Llm, Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Condition::Expression
Condition that gates the transition.
-
#id ⇒ String
Caller-supplied unique identifier for this edge within the flow.
-
#start_node_id ⇒ String
ID of the node this edge transitions away from.
-
#target ⇒ Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Target::Node, Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Target::Assistant
Destination of the transition.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(value:, type: :bool_literal) ⇒ Object
constructor
Constant boolean value.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(value:, type: :bool_literal) ⇒ Object
Constant boolean value. Useful for unconditional (‘always’) edges.
|
|
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 669
|
Instance Attribute Details
#condition ⇒ Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Condition::Llm, Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Condition::Expression
Condition that gates the transition. Discriminated by ‘type`: `llm`, `expression`.
654 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 654 required :condition, union: -> { Telnyx::AI::AssistantCreateParams::ConversationFlow::Edge::Condition } |
#id ⇒ String
Caller-supplied unique identifier for this edge within the flow.
647 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 647 required :id, String |
#start_node_id ⇒ String
ID of the node this edge transitions away from.
660 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 660 required :start_node_id, String |
#target ⇒ Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Target::Node, Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Target::Assistant
Destination of the transition. Discriminated by ‘type`: `node` (jump to another node in this flow) or `assistant` (hand off to a different assistant).
667 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 667 required :target, union: -> { Telnyx::AI::AssistantCreateParams::ConversationFlow::Edge::Target } |
Class Method Details
.variants ⇒ Array(Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Condition::Llm, Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Condition::Expression)
|
|
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 883
|