Module: Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Target
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/ai/assistant_create_params.rb
Overview
Destination of the transition. Discriminated by ‘type`: `node` (jump to another node in this flow) or `assistant` (hand off to a different assistant).
Defined Under Namespace
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(node_id:, type: :node) ⇒ Object
Edge target referencing another node within the same flow.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Target::Node, Telnyx::Models::AI::AssistantCreateParams::ConversationFlow::Edge::Target::Assistant)
|
|
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 1037
|
Instance Method Details
#initialize(node_id:, type: :node) ⇒ Object
Edge target referencing another node within the same flow.
The runtime transitions the active node to ‘node_id` and continues processing within the current assistant’s flow.
|
|
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 928
|