Class: Telnyx::Models::AI::AssistantCreateParams::InterruptionSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantCreateParams::InterruptionSettings
- Defined in:
- lib/telnyx/models/ai/assistant_create_params.rb
Defined Under Namespace
Classes: StartSpeakingPlan
Instance Attribute Summary collapse
-
#enable ⇒ Boolean?
Whether users can interrupt the assistant while it is speaking.
-
#start_speaking_plan ⇒ Telnyx::Models::AI::AssistantCreateParams::InterruptionSettings::StartSpeakingPlan?
Controls when the assistant starts speaking after the user stops.
Instance Method Summary collapse
-
#initialize(enable: nil, start_speaking_plan: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see InterruptionSettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(enable: nil, start_speaking_plan: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantCreateParams::InterruptionSettings for more details.
Settings for interruptions and how the assistant decides the user has finished speaking. These timings are most relevant when using non turn-taking transcription models. For turn-taking models like ‘deepgram/flux`, end-of-turn behavior is controlled by the transcription end-of-turn settings under `transcription.settings` (`eot_threshold`, `eot_timeout_ms`, `eager_eot_threshold`).
|
|
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 512
|
Instance Attribute Details
#enable ⇒ Boolean?
Whether users can interrupt the assistant while it is speaking.
500 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 500 optional :enable, Telnyx::Internal::Type::Boolean |
#start_speaking_plan ⇒ Telnyx::Models::AI::AssistantCreateParams::InterruptionSettings::StartSpeakingPlan?
Controls when the assistant starts speaking after the user stops. These thresholds primarily apply to non turn-taking transcription models. For turn-taking models like ‘deepgram/flux`, end-of-turn detection is driven by the transcription end-of-turn settings under `transcription.settings` instead.
509 510 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 509 optional :start_speaking_plan, -> { Telnyx::AI::AssistantCreateParams::InterruptionSettings::StartSpeakingPlan } |