Class: Telnyx::Models::AI::AssistantCreateParams::InterruptionSettings::StartSpeakingPlan::TranscriptionEndpointingPlan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantCreateParams::InterruptionSettings::StartSpeakingPlan::TranscriptionEndpointingPlan
- Defined in:
- lib/telnyx/models/ai/assistant_create_params.rb
Overview
Instance Attribute Summary collapse
-
#on_no_punctuation_seconds ⇒ Float?
Seconds to wait after the transcript ends without punctuation.
-
#on_number_seconds ⇒ Float?
Seconds to wait after the transcript ends with a number.
-
#on_punctuation_seconds ⇒ Float?
Seconds to wait after the transcript ends with punctuation.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#on_no_punctuation_seconds ⇒ Float?
Seconds to wait after the transcript ends without punctuation.
566 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 566 optional :on_no_punctuation_seconds, Float |
#on_number_seconds ⇒ Float?
Seconds to wait after the transcript ends with a number.
572 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 572 optional :on_number_seconds, Float |
#on_punctuation_seconds ⇒ Float?
Seconds to wait after the transcript ends with punctuation.
578 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 578 optional :on_punctuation_seconds, Float |