Class: Telnyx::Models::AI::AssistantCreateParams::PostConversationSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enabled: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantCreateParams::PostConversationSettings for more details.

Configuration for post-conversation processing. When enabled, the assistant receives one additional LLM turn after the conversation ends, allowing it to execute tool calls such as logging to a CRM or sending a summary. The assistant can execute multiple parallel or sequential tools during this phase. Telephony-control tools (e.g. hangup, transfer) are unavailable post-conversation. Beta feature.

Parameters:

  • enabled (Boolean) (defaults to: nil)

    Whether post-conversation processing is enabled. When true, the assistant will b



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 187

class PostConversationSettings < Telnyx::Internal::Type::BaseModel
  # @!attribute enabled
  #   Whether post-conversation processing is enabled. When true, the assistant will
  #   be invoked after the conversation ends to perform any final tool calls. Defaults
  #   to false.
  #
  #   @return [Boolean, nil]
  optional :enabled, Telnyx::Internal::Type::Boolean

  # @!method initialize(enabled: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::AI::AssistantCreateParams::PostConversationSettings} for more
  #   details.
  #
  #   Configuration for post-conversation processing. When enabled, the assistant
  #   receives one additional LLM turn after the conversation ends, allowing it to
  #   execute tool calls such as logging to a CRM or sending a summary. The assistant
  #   can execute multiple parallel or sequential tools during this phase.
  #   Telephony-control tools (e.g. hangup, transfer) are unavailable
  #   post-conversation. Beta feature.
  #
  #   @param enabled [Boolean] Whether post-conversation processing is enabled. When true, the assistant will b
end

Instance Attribute Details

#enabledBoolean?

Whether post-conversation processing is enabled. When true, the assistant will be invoked after the conversation ends to perform any final tool calls. Defaults to false.

Returns:

  • (Boolean, nil)


194
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 194

optional :enabled, Telnyx::Internal::Type::Boolean