Class: Telnyx::Models::AI::AssistantRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/assistant_retrieve_params.rb
Overview
Instance Attribute Summary collapse
- #assistant_id ⇒ String
-
#call_control_id ⇒ String?
Filter results by call control id.
-
#fetch_dynamic_variables_from_webhook ⇒ Boolean?
Whether to fetch dynamic variables from the configured webhook.
-
#from ⇒ String?
Start of the filter range.
-
#to ⇒ String?
End of the filter range.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assistant_id:, call_control_id: nil, fetch_dynamic_variables_from_webhook: nil, from: nil, to: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/ai/assistant_retrieve_params.rb', line 40
|
Instance Attribute Details
#assistant_id ⇒ String
14 |
# File 'lib/telnyx/models/ai/assistant_retrieve_params.rb', line 14 required :assistant_id, String |
#call_control_id ⇒ String?
Filter results by call control id.
20 |
# File 'lib/telnyx/models/ai/assistant_retrieve_params.rb', line 20 optional :call_control_id, String |
#fetch_dynamic_variables_from_webhook ⇒ Boolean?
Whether to fetch dynamic variables from the configured webhook.
26 |
# File 'lib/telnyx/models/ai/assistant_retrieve_params.rb', line 26 optional :fetch_dynamic_variables_from_webhook, Telnyx::Internal::Type::Boolean |
#from ⇒ String?
Start of the filter range.
32 |
# File 'lib/telnyx/models/ai/assistant_retrieve_params.rb', line 32 optional :from, String |
#to ⇒ String?
End of the filter range.
38 |
# File 'lib/telnyx/models/ai/assistant_retrieve_params.rb', line 38 optional :to, String |