Module: Telnyx::Models::AI::AssistantTool

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs

Overview

The handoff tool allows the assistant to hand off control of the conversation to another AI assistant. By default, this will happen transparently to the end user.

Defined Under Namespace

Classes: ClientSideTool, Handoff, Invite, Pay, Refer, SendDtmf, SendMessage, SkipTurn, Transfer, UpdateDynamicVariables

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(pay:, type: :pay) ⇒ Object

(BETA) The pay tool allows the assistant to collect card payments from the caller via DTMF during the conversation. Recording is automatically paused while the pay tool is active and resumes when the payment flow completes. The connector_name must reference a pay connector configured in the Telnyx API.

Parameters:



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 981

#self?.variants::Array[Telnyx::Models::AI::assistant_tool]

Returns:

  • (::Array[Telnyx::Models::AI::assistant_tool])


962
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 962

def self?.variants: -> ::Array[Telnyx::Models::AI::assistant_tool]