Class: Telnyx::Models::AI::AssistantTool::ClientSideTool::ClientSideTool
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::ClientSideTool::ClientSideTool
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs
Overview
Defined Under Namespace
Classes: Parameters
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the tool.
-
#name ⇒ String
The name of the tool.
-
#parameters ⇒ Telnyx::Models::AI::AssistantTool::ClientSideTool::ClientSideTool::Parameters
The parameters the tool accepts, described as a JSON Schema object.
Instance Method Summary collapse
-
#initialize(description:, name:, parameters:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ClientSideTool for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description:, name:, parameters:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantTool::ClientSideTool::ClientSideTool for more details.
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 75
|
Instance Attribute Details
#description ⇒ String
The description of the tool.
59 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 59 required :description, String |
#name ⇒ String
The name of the tool.
65 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 65 required :name, String |
#parameters ⇒ Telnyx::Models::AI::AssistantTool::ClientSideTool::ClientSideTool::Parameters
The parameters the tool accepts, described as a JSON Schema object. See the JSON Schema reference for documentation about the format
73 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 73 required :parameters, -> { Telnyx::AI::AssistantTool::ClientSideTool::ClientSideTool::Parameters } |
Instance Method Details
#to_hash ⇒ {
61 |
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 61
def to_hash: -> {
|