Class: Telnyx::Models::AI::AssistantTool::Handoff

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs

Defined Under Namespace

Classes: Handoff

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(handoff:, type: :handoff) ⇒ Object

The handoff tool allows the assistant to hand off control of the conversation to another AI assistant. By default, this will happen transparently to the end user.

Parameters:



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 47

Instance Attribute Details

#handoffTelnyx::Models::AI::AssistantTool::Handoff::Handoff

Parameters:

  • value (Telnyx::AI::AssistantTool::Handoff::Handoff)

Returns:



40
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 40

required :handoff, -> { Telnyx::AI::AssistantTool::Handoff::Handoff }

#typeSymbol, :handoff

Parameters:

  • value (:handoff)

Returns:

  • (Symbol, :handoff)


45
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 45

required :type, const: :handoff

Instance Method Details

#to_hash{

Returns:

  • ({)


35
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 35

def to_hash: -> {