Class: Telnyx::Models::AI::AssistantTool::Handoff::Handoff
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::Handoff::Handoff
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs
Overview
Defined Under Namespace
Modules: VoiceMode Classes: AIAssistant
Instance Attribute Summary collapse
-
#ai_assistants ⇒ Array<Telnyx::Models::AI::AssistantTool::Handoff::Handoff::AIAssistant>
List of possible assistants that can receive a handoff.
-
#voice_mode ⇒ Symbol, ...
With the unified voice mode all assistants share the same voice, making the handoff transparent to the user.
Instance Method Summary collapse
- #initialize(id:, name:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:) ⇒ Object
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 193
|
Instance Attribute Details
#ai_assistants ⇒ Array<Telnyx::Models::AI::AssistantTool::Handoff::Handoff::AIAssistant>
List of possible assistants that can receive a handoff.
160 161 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 160 required :ai_assistants, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Handoff::Handoff::AIAssistant] } |
#voice_mode ⇒ Symbol, ...
With the unified voice mode all assistants share the same voice, making the handoff transparent to the user. With the distinct voice mode all assistants retain their voice configuration, providing the experience of a conference call with a team of assistants.
170 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 170 optional :voice_mode, enum: -> { Telnyx::AI::AssistantTool::Handoff::Handoff::VoiceMode } |
Instance Method Details
#to_hash ⇒ {
157 |
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 157
def to_hash: -> {
|