Module: Telnyx::Models::AI::AssistantTool::Invite::Invite::Targets

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs

Overview

The different possible targets of the invite. The assistant will be able to choose one of the targets to invite to the call. This can also be a dynamic variable string like {{ targets }} where targets is returned by the dynamic variables webhook and resolves to an array of target objects at runtime. If omitted or null, the invite tool can still be configured and targets may be supplied dynamically at runtime.

See Also:

  • Telnyx::Models::AI::AssistantTool::Invite::Invite#targets

Defined Under Namespace

Classes: TargetsList

Constant Summary collapse

TargetsListArray =
Telnyx::Internal::Type::ArrayOf[-> {
  Telnyx::AI::AssistantTool::Invite::Invite::Targets::TargetsList
}]

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(Array<Telnyx::Models::AI::AssistantTool::Invite::Invite::Targets::TargetsList>, String)



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 642

Instance Method Details

#initialize(to:, name: nil) ⇒ Object

Parameters:

  • to (String)

    The destination number or SIP URI of the call.

  • name (String) (defaults to: nil)

    The name of the target.



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 636

#self?.variants::Array[Telnyx::Models::AI::AssistantTool::Invite::Invite::targets]

Returns:

  • (::Array[Telnyx::Models::AI::AssistantTool::Invite::Invite::targets])


526
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 526

def self?.variants: -> ::Array[Telnyx::Models::AI::AssistantTool::Invite::Invite::targets]