Class: Telnyx::Models::AI::AssistantTool::Invite::InviteConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_tool.rb

Overview

See Also:

Defined Under Namespace

Modules: Targets Classes: CustomHeader, VoicemailDetection

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil, value: nil) ⇒ Object

Some parameter documentations has been truncated, see CustomHeader for more details.

Parameters:

  • name (String) (defaults to: nil)
  • value (String) (defaults to: nil)

    The value of the header. Note that we support mustache templating for the value.



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 589

Instance Attribute Details

#custom_headersArray<Telnyx::Models::AI::AssistantTool::Invite::InviteConfig::CustomHeader>?

Custom headers to be added to the SIP INVITE for the invite command.



531
532
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 531

optional :custom_headers,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Invite::InviteConfig::CustomHeader] }

#fromString?

Number or SIP URI placing the call.

Returns:

  • (String, nil)


538
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 538

optional :from, String

#targetsArray<Telnyx::Models::AI::AssistantTool::Invite::InviteConfig::Targets::UnionMember0>, ...

The different possible targets of the invite. The assistant will be able to choose one of the targets to invite to the call. This can also be a dynamic variable string like ‘targets }` where `targets` is returned by the dynamic variables webhook and resolves to an array of target objects at runtime. If omitted or null, the invite tool can still be configured and targets may be supplied dynamically at runtime.



549
550
551
552
553
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 549

optional :targets,
union: -> {
  Telnyx::AI::AssistantTool::Invite::InviteConfig::Targets
},
nil?: true

#voicemail_detectionTelnyx::Models::AI::AssistantTool::Invite::InviteConfig::VoicemailDetection?

Configuration for voicemail detection (AMD - Answering Machine Detection) on the invited call.



560
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 560

optional :voicemail_detection, -> { Telnyx::AI::AssistantTool::Invite::InviteConfig::VoicemailDetection }