Module: Telnyx::Models::AI::AssistantTool::Invite::InviteConfig::Targets

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/ai/assistant_tool.rb

Overview

The different possible targets of the invite. The assistant will be able to choose one of the targets to invite to the call. This can also be a dynamic variable string like ‘targets }` where `targets` is returned by the dynamic variables webhook and resolves to an array of target objects at runtime. If omitted or null, the invite tool can still be configured and targets may be supplied dynamically at runtime.

See Also:

Defined Under Namespace

Classes: UnionMember0

Constant Summary collapse

UnionMember0Array =
Telnyx::Internal::Type::ArrayOf[-> {
  Telnyx::AI::AssistantTool::Invite::InviteConfig::Targets::UnionMember0
}]

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(Array<Telnyx::Models::AI::AssistantTool::Invite::InviteConfig::Targets::UnionMember0>, String)



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 634

Instance Method Details

#initialize(to:, name: nil) ⇒ Object

Parameters:

  • to (String)

    The destination number or SIP URI of the call.

  • name (String) (defaults to: nil)

    The name of the target.



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 628