Class: Telnyx::Models::AI::AssistantTool::Refer::Refer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_tool.rb

Overview

See Also:

Defined Under Namespace

Classes: CustomHeader, SipHeader, Target

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil, value: nil) ⇒ Object

Some parameter documentations has been truncated, see CustomHeader for more details.

Parameters:

  • name (String) (defaults to: nil)
  • value (String) (defaults to: nil)

    The value of the header. Note that we support mustache templating for the value.



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 704

Instance Attribute Details

#custom_headersArray<Telnyx::Models::AI::AssistantTool::Refer::Refer::CustomHeader>?

Custom headers to be added to the SIP REFER.



658
659
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 658

optional :custom_headers,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Refer::Refer::CustomHeader] }

#sip_headersArray<Telnyx::Models::AI::AssistantTool::Refer::Refer::SipHeader>?

SIP headers to be added to the SIP REFER. Currently only User-to-User and Diversion headers are supported.



666
667
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 666

optional :sip_headers,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Refer::Refer::SipHeader] }

#targetsArray<Telnyx::Models::AI::AssistantTool::Refer::Refer::Target>

The different possible targets of the SIP refer. The assistant will be able to choose one of the targets to refer the call to.



652
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 652

required :targets, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Refer::Refer::Target] }