Class: Telnyx::Models::AI::AssistantTool::SendMessage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::SendMessage
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs
Defined Under Namespace
Classes: SendMessage
Instance Attribute Summary collapse
- #send_message ⇒ Telnyx::Models::AI::AssistantTool::SendMessage::SendMessage
- #type ⇒ Symbol, :send_message
Instance Method Summary collapse
-
#initialize(send_message:, type: :send_message) ⇒ Object
constructor
The send_message tool allows the assistant to send SMS or MMS messages to the end user.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(send_message:, type: :send_message) ⇒ Object
The send_message tool allows the assistant to send SMS or MMS messages to the end user. The 'to' and 'from' addresses are automatically determined from the conversation context, and the message text is generated by the assistant unless a message_template is provided for runtime variable substitution.
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 1101
|
Instance Attribute Details
#send_message ⇒ Telnyx::Models::AI::AssistantTool::SendMessage::SendMessage
1094 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 1094 required :send_message, -> { Telnyx::AI::AssistantTool::SendMessage::SendMessage } |
#type ⇒ Symbol, :send_message
1099 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 1099 required :type, const: :send_message |
Instance Method Details
#to_hash ⇒ {
941 |
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 941 def to_hash: -> { |