Class: Telnyx::Models::AI::AssistantTool::SendMessage::SendMessage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs

Overview

See Also:

  • Telnyx::Models::AI::AssistantTool::SendMessage#send_message

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeSendMessage

Returns a new instance of SendMessage.

Parameters:

  • message_template: (String, nil)


791
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 791

def initialize: (?message_template: String?) -> void

Instance Attribute Details

#message_templateString?

Optional message template with dynamic variable support using mustache syntax (e.g., {variable_name}). When set, the assistant will use this template for the SMS body instead of generating one. Dynamic variables like {telnyx_end_user_target}, {telnyx_agent_target}, and custom webhook-provided variables will be resolved at runtime.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


917
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 917

optional :message_template, String, nil?: true

Instance Method Details

#to_hash{ message_template: String? }

Returns:

  • ({ message_template: String? })


793
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 793

def to_hash: -> { message_template: String? }