Class: Telnyx::Models::AI::AssistantTool::Transfer::Transfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::Transfer::Transfer
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb
Overview
Defined Under Namespace
Modules: Targets Classes: CustomHeader, VoicemailDetection
Instance Attribute Summary collapse
-
#custom_headers ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::CustomHeader>?
Custom headers to be added to the SIP INVITE for the transfer command.
-
#description ⇒ String?
A description of the transfer tool.
-
#from ⇒ String
Number or SIP URI placing the call.
-
#targets ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::Targets::TargetsList>, String
The different possible targets of the transfer.
-
#voicemail_detection ⇒ Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection?
Configuration for voicemail detection (AMD - Answering Machine Detection) on the transferred call.
-
#warm_message_delay_ms ⇒ Integer?
Optional delay in milliseconds before playing the warm message audio when the transferred call is answered.
-
#warm_transfer_instructions ⇒ String?
Natural language instructions for your agent for how to provide context for the transfer recipient.
Instance Method Summary collapse
-
#initialize(name: nil, value: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomHeader for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil, value: nil) ⇒ Object
Some parameter documentations has been truncated, see CustomHeader for more details.
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 191
|
Instance Attribute Details
#custom_headers ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::CustomHeader>?
Custom headers to be added to the SIP INVITE for the transfer command.
154 155 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 154 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Transfer::Transfer::CustomHeader] } |
#description ⇒ String?
A description of the transfer tool. By default, Telnyx generates this automatically based on the configured targets. Typically only set when importing an assistant from another provider that allowed a custom description; in that case the provided value is preserved. Most users should leave this empty and let Telnyx manage it.
165 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 165 optional :description, String |
#from ⇒ String
Number or SIP URI placing the call.
139 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 139 required :from, String |
#targets ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::Targets::TargetsList>, String
The different possible targets of the transfer. The assistant will be able to choose one of the targets to transfer the call to. This can also be a dynamic variable string like ‘targets }` where `targets` is returned by the dynamic variables webhook and resolves to an array of target objects at runtime.
148 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 148 required :targets, union: -> { Telnyx::AI::AssistantTool::Transfer::Transfer::Targets } |
#voicemail_detection ⇒ Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection?
Configuration for voicemail detection (AMD - Answering Machine Detection) on the transferred call. Allows the assistant to detect when a voicemail system answers the transferred call and take appropriate action.
173 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 173 optional :voicemail_detection, -> { Telnyx::AI::AssistantTool::Transfer::Transfer::VoicemailDetection } |
#warm_message_delay_ms ⇒ Integer?
Optional delay in milliseconds before playing the warm message audio when the transferred call is answered. When set, the audio_url is not included in the dial command; instead, playback starts after the specified delay. When not set, existing behavior (audio_url in dial) is preserved.
182 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 182 optional :warm_message_delay_ms, Integer, nil?: true |
#warm_transfer_instructions ⇒ String?
Natural language instructions for your agent for how to provide context for the transfer recipient.
189 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 189 optional :warm_transfer_instructions, String |