Class: Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_tool.rb

Overview

Defined Under Namespace

Modules: DetectionMode Classes: DetectionConfig, OnVoicemailDetected

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after_greeting_silence_millis: nil, between_words_silence_millis: nil, greeting_duration_millis: nil, greeting_silence_duration_millis: nil, greeting_total_analysis_time_millis: nil, initial_silence_millis: nil, maximum_number_of_words: nil, maximum_word_length_millis: nil, min_word_length_millis: nil, silence_threshold: nil, total_analysis_time_millis: nil) ⇒ Object

Some parameter documentations has been truncated, see DetectionConfig for more details.

Advanced AMD detection configuration parameters. All values are optional - Telnyx will use defaults if not specified.

Parameters:

  • after_greeting_silence_millis (Integer) (defaults to: nil)

    Duration of silence after greeting detection before finalizing the result.

  • between_words_silence_millis (Integer) (defaults to: nil)

    Maximum silence duration between words during greeting.

  • greeting_duration_millis (Integer) (defaults to: nil)

    Expected duration of greeting speech.

  • greeting_silence_duration_millis (Integer) (defaults to: nil)

    Duration of silence after the greeting to wait before considering the greeting c

  • greeting_total_analysis_time_millis (Integer) (defaults to: nil)

    Maximum time to spend analyzing the greeting.

  • initial_silence_millis (Integer) (defaults to: nil)

    Maximum silence duration at the start of the call before speech.

  • maximum_number_of_words (Integer) (defaults to: nil)

    Maximum number of words expected in a human greeting.

  • maximum_word_length_millis (Integer) (defaults to: nil)

    Maximum duration of a single word.

  • min_word_length_millis (Integer) (defaults to: nil)

    Minimum duration for audio to be considered a word.

  • silence_threshold (Integer) (defaults to: nil)

    Audio level threshold for silence detection.

  • total_analysis_time_millis (Integer) (defaults to: nil)

    Total time allowed for AMD analysis.



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 265

Instance Attribute Details

#detection_configTelnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionConfig?

Advanced AMD detection configuration parameters. All values are optional - Telnyx will use defaults if not specified.



247
248
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 247

optional :detection_config,
-> { Telnyx::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionConfig }

#detection_modeSymbol, ...

The AMD detection mode to use. ‘premium’ enables premium answering machine detection. ‘disabled’ turns off AMD detection.



255
256
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 255

optional :detection_mode,
enum: -> { Telnyx::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionMode }

#on_voicemail_detectedTelnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::OnVoicemailDetected?

Action to take when voicemail is detected on the transferred call.



262
263
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 262

optional :on_voicemail_detected,
-> { Telnyx::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::OnVoicemailDetected }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ai/assistant_tool.rb', line 390