Class: Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs

Overview

See Also:

  • Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection#detection_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



406
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 406

def initialize: (

Instance Attribute Details

#after_greeting_silence_millisInteger?

Duration of silence after greeting detection before finalizing the result.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


422
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 422

optional :after_greeting_silence_millis, Integer

#between_words_silence_millisInteger?

Maximum silence duration between words during greeting.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


428
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 428

optional :between_words_silence_millis, Integer

#greeting_duration_millisInteger?

Expected duration of greeting speech.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


434
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 434

optional :greeting_duration_millis, Integer

#greeting_silence_duration_millisInteger?

Duration of silence after the greeting to wait before considering the greeting complete.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


441
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 441

optional :greeting_silence_duration_millis, Integer

#greeting_total_analysis_time_millisInteger?

Maximum time to spend analyzing the greeting.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


447
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 447

optional :greeting_total_analysis_time_millis, Integer

#initial_silence_millisInteger?

Maximum silence duration at the start of the call before speech.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


453
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 453

optional :initial_silence_millis, Integer

#maximum_number_of_wordsInteger?

Maximum number of words expected in a human greeting.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


459
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 459

optional :maximum_number_of_words, Integer

#maximum_word_length_millisInteger?

Maximum duration of a single word.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


465
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 465

optional :maximum_word_length_millis, Integer

#min_word_length_millisInteger?

Minimum duration for audio to be considered a word.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


471
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 471

optional :min_word_length_millis, Integer

#silence_thresholdInteger?

Audio level threshold for silence detection.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


477
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 477

optional :silence_threshold, Integer

#total_analysis_time_millisInteger?

Total time allowed for AMD analysis.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


483
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 483

optional :total_analysis_time_millis, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


420
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 420

def to_hash: -> {