Class: Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm
- Defined in:
- lib/telnyx/models/ai/assistant_update_params.rb
Defined Under Namespace
Modules: AuthenticationMethod
Instance Attribute Summary collapse
-
#authentication_method ⇒ Symbol, ...
Authentication method used when connecting to the external LLM endpoint.
-
#base_url ⇒ String
Base URL for the external LLM endpoint.
-
#certificate_ref ⇒ String?
Integration secret identifier for the client certificate used with certificate authentication.
-
#forward_metadata ⇒ Boolean?
When ‘true`, Telnyx forwards the assistant’s dynamic variables to the external LLM endpoint as a top-level ‘extra_metadata` object on the chat completion request body.
-
#llm_api_key_ref ⇒ String?
Integration secret identifier for the external LLM API key.
-
#model ⇒ String
Model identifier to use with the external LLM endpoint.
-
#token_retrieval_url ⇒ String?
URL used to retrieve an access token when certificate authentication is enabled.
Instance Method Summary collapse
-
#initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalLlm for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm for more details.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 290 class ExternalLlm < Telnyx::Internal::Type::BaseModel # @!attribute base_url # Base URL for the external LLM endpoint. # # @return [String] required :base_url, String # @!attribute model # Model identifier to use with the external LLM endpoint. # # @return [String] required :model, String # @!attribute authentication_method # Authentication method used when connecting to the external LLM endpoint. # # @return [Symbol, Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm::AuthenticationMethod, nil] optional :authentication_method, enum: -> { Telnyx::AI::AssistantUpdateParams::ExternalLlm::AuthenticationMethod } # @!attribute certificate_ref # Integration secret identifier for the client certificate used with certificate # authentication. # # @return [String, nil] optional :certificate_ref, String # @!attribute forward_metadata # When `true`, Telnyx forwards the assistant's dynamic variables to the external # LLM endpoint as a top-level `extra_metadata` object on the chat completion # request body. Defaults to `false`. Example payload sent to the external # endpoint: # `{"extra_metadata": {"customer_name": "Jane", "account_id": "acct_789", "telnyx_agent_target": "+13125550100", "telnyx_end_user_target": "+13125550123"}}`. # Distinct from OpenAI's native `metadata` field, which has its own size and type # limits. # # @return [Boolean, nil] optional :forward_metadata, Telnyx::Internal::Type::Boolean # @!attribute llm_api_key_ref # Integration secret identifier for the external LLM API key. # # @return [String, nil] optional :llm_api_key_ref, String # @!attribute token_retrieval_url # URL used to retrieve an access token when certificate authentication is enabled. # # @return [String, nil] optional :token_retrieval_url, String # @!method initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm} for more details. # # @param base_url [String] Base URL for the external LLM endpoint. # # @param model [String] Model identifier to use with the external LLM endpoint. # # @param authentication_method [Symbol, Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm::AuthenticationMethod] Authentication method used when connecting to the external LLM endpoint. # # @param certificate_ref [String] Integration secret identifier for the client certificate used with certificate a # # @param forward_metadata [Boolean] When `true`, Telnyx forwards the assistant's dynamic variables to the external L # # @param llm_api_key_ref [String] Integration secret identifier for the external LLM API key. # # @param token_retrieval_url [String] URL used to retrieve an access token when certificate authentication is enabled. # Authentication method used when connecting to the external LLM endpoint. # # @see Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm#authentication_method module AuthenticationMethod extend Telnyx::Internal::Type::Enum TOKEN = :token CERTIFICATE = :certificate # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#authentication_method ⇒ Symbol, ...
Authentication method used when connecting to the external LLM endpoint.
307 308 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 307 optional :authentication_method, enum: -> { Telnyx::AI::AssistantUpdateParams::ExternalLlm::AuthenticationMethod } |
#base_url ⇒ String
Base URL for the external LLM endpoint.
295 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 295 required :base_url, String |
#certificate_ref ⇒ String?
Integration secret identifier for the client certificate used with certificate authentication.
315 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 315 optional :certificate_ref, String |
#forward_metadata ⇒ Boolean?
When ‘true`, Telnyx forwards the assistant’s dynamic variables to the external LLM endpoint as a top-level ‘extra_metadata` object on the chat completion request body. Defaults to `false`. Example payload sent to the external endpoint: `{“customer_name”: “Jane”, “account_id”: “acct_789”, “telnyx_agent_target”: “+13125550100”, “telnyx_end_user_target”: “+13125550123”}`. Distinct from OpenAI’s native ‘metadata` field, which has its own size and type limits.
327 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 327 optional :forward_metadata, Telnyx::Internal::Type::Boolean |
#llm_api_key_ref ⇒ String?
Integration secret identifier for the external LLM API key.
333 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 333 optional :llm_api_key_ref, String |
#model ⇒ String
Model identifier to use with the external LLM endpoint.
301 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 301 required :model, String |
#token_retrieval_url ⇒ String?
URL used to retrieve an access token when certificate authentication is enabled.
339 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 339 optional :token_retrieval_url, String |