Class: Telnyx::Models::AI::Assistants::ScheduledEventCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb

Overview

Defined Under Namespace

Modules: ConversationMetadata

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#assistant_idString

Returns:

  • (String)


15
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 15

required :assistant_id, String

#conversation_metadataHash{Symbol=>String, Integer, Boolean}?

Metadata associated with the conversation. Telnyx provides several pieces of metadata, but customers can also add their own.

Returns:

  • (Hash{Symbol=>String, Integer, Boolean}, nil)


45
46
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 45

optional :conversation_metadata,
-> { Telnyx::Internal::Type::HashOf[union: Telnyx::AI::Assistants::ScheduledEventCreateParams::ConversationMetadata] }

#dynamic_variablesHash{Symbol=>String}?

A map of dynamic variable names to values. These variables can be referenced in the assistant’s instructions and messages using {variable_name} syntax.

Returns:

  • (Hash{Symbol=>String}, nil)


53
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 53

optional :dynamic_variables, Telnyx::Internal::Type::HashOf[String]

#scheduled_at_fixed_datetimeTime

The datetime at which the event should be scheduled. Formatted as ISO 8601.

Returns:

  • (Time)


21
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 21

required :scheduled_at_fixed_datetime, Time

#telnyx_agent_targetString

The phone number, SIP URI, to schedule the call or text from.

Returns:

  • (String)


27
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 27

required :telnyx_agent_target, String

#telnyx_conversation_channelSymbol, Telnyx::Models::AI::Assistants::ConversationChannelType



32
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 32

required :telnyx_conversation_channel, enum: -> { Telnyx::AI::Assistants::ConversationChannelType }

#telnyx_end_user_targetString

The phone number, SIP URI, to schedule the call or text to.

Returns:

  • (String)


38
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 38

required :telnyx_end_user_target, String

#textString?

Required for sms scheduled events. The text to be sent to the end user.

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 59

optional :text, String