Module: Telnyx::Models::AI::Assistants::ScheduledEventCreateParams::ConversationMetadata

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(String, Integer, Boolean)

Returns:

  • (Array(String, Integer, Boolean))


# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 92

Instance Method Details

#initialize(assistant_id:, scheduled_at_fixed_datetime:, telnyx_agent_target:, telnyx_conversation_channel:, telnyx_end_user_target:, conversation_metadata: nil, dynamic_variables: nil, text: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::Assistants::ScheduledEventCreateParams for more details.

Parameters:

  • assistant_id (String)
  • scheduled_at_fixed_datetime (Time)

    The datetime at which the event should be scheduled. Formatted as ISO 8601.

  • telnyx_agent_target (String)

    The phone number, SIP URI, to schedule the call or text from.

  • telnyx_conversation_channel (Symbol, Telnyx::Models::AI::Assistants::ConversationChannelType)
  • telnyx_end_user_target (String)

    The phone number, SIP URI, to schedule the call or text to.

  • conversation_metadata (Hash{Symbol=>String, Integer, Boolean}) (defaults to: nil)

    Metadata associated with the conversation. Telnyx provides several pieces of met

  • dynamic_variables (Hash{Symbol=>String}) (defaults to: nil)

    A map of dynamic variable names to values. These variables can be referenced in

  • text (String) (defaults to: nil)

    Required for sms scheduled events. The text to be sent to the end user.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 83

module ConversationMetadata
  extend Telnyx::Internal::Type::Union

  variant String

  variant Integer

  variant Telnyx::Internal::Type::Boolean

  # @!method self.variants
  #   @return [Array(String, Integer, Boolean)]
end