Class: Telnyx::Models::AI::Assistants::ScheduledPhoneCallEventResponse::CallSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistants/scheduled_phone_call_event_response.rb

Overview

See Also:

Defined Under Namespace

Modules: SipRegion

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(sip_region: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::Assistants::ScheduledPhoneCallEventResponse::CallSettings for more details.

Per-call telephony overrides applied when a scheduled phone-call event dispatches. Phone-call events only. New per-call dispatch options should be added here rather than as top-level event fields.

Parameters:



# File 'lib/telnyx/models/ai/assistants/scheduled_phone_call_event_response.rb', line 225

Instance Attribute Details

#sip_regionSymbol, ...

SIP region passed to Telnyx when initiating an outbound call. Values match the Telnyx TeXML ‘SipRegion` parameter exactly. Telnyx defaults to `US` when omitted.



222
223
# File 'lib/telnyx/models/ai/assistants/scheduled_phone_call_event_response.rb', line 222

optional :sip_region,
enum: -> { Telnyx::AI::Assistants::ScheduledPhoneCallEventResponse::CallSettings::SipRegion }