Class: Telnyx::Models::AI::Assistants::Tests::TestRunResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistants/tests/test_run_response.rb

Overview

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#completed_atTime?

Timestamp when the test run finished execution.

Returns:

  • (Time, nil)


51
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 51

optional :completed_at, Time

#conversation_idString?

Identifier of the conversation created during test execution.

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 57

optional :conversation_id, String

#conversation_insights_idString?

Identifier for conversation analysis and insights data.

Returns:

  • (String, nil)


63
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 63

optional :conversation_insights_id, String

#created_atTime

Timestamp when the test run was created and queued.

Returns:

  • (Time)


14
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 14

required :created_at, Time

#detail_statusArray<Telnyx::Models::AI::Assistants::Tests::TestRunDetailResult>?

Detailed evaluation results for each rubric criteria. Name is name of the criteria from the rubric and status is the result of the evaluation. This list will have a result for every criteria in the rubric section.



71
72
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 71

optional :detail_status,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::Assistants::Tests::TestRunDetailResult] }

#logsString?

Detailed execution logs and debug information.

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 78

optional :logs, String

#run_idString

Unique identifier for this specific test run execution.

Returns:

  • (String)


20
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 20

required :run_id, String

#statusSymbol, Telnyx::Models::AI::Assistants::Tests::TestStatus

Represents the lifecycle of a test:

  • ‘pending’: Test is waiting to be executed.

  • ‘starting’: Test execution is initializing.

  • ‘running’: Test is currently executing.

  • ‘passed’: Test completed successfully.

  • ‘failed’: Test executed but did not pass.

  • ‘error’: An error occurred during test execution.



33
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 33

required :status, enum: -> { Telnyx::AI::Assistants::Tests::TestStatus }

#test_idString

Identifier of the assistant test that was executed.

Returns:

  • (String)


39
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 39

required :test_id, String

#test_suite_run_idString?

Identifier linking this run to a test suite execution batch.

Returns:

  • (String, nil)


84
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 84

optional :test_suite_run_id, String

#triggered_byString

How this test run was initiated (manual, scheduled, or API).

Returns:

  • (String)


45
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 45

required :triggered_by, String

#updated_atTime?

Timestamp of the last update to this test run.

Returns:

  • (Time, nil)


90
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 90

optional :updated_at, Time