Class: Telnyx::Models::AI::Assistants::Tests::TestRunResponse::DetailStatus

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistants/tests/test_run_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at:, run_id:, status:, test_id:, triggered_by:, completed_at: nil, conversation_id: nil, conversation_insights_id: nil, detail_status: nil, logs: nil, test_suite_run_id: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::Assistants::Tests::TestRunResponse for more details.

Response model containing test run execution details and results.

Provides comprehensive information about a test execution including status, timing, logs, and detailed evaluation results.

Parameters:

  • created_at (Time)

    Timestamp when the test run was created and queued.

  • run_id (String)

    Unique identifier for this specific test run execution.

  • status (Symbol, Telnyx::Models::AI::Assistants::Tests::TestStatus)

    Represents the lifecycle of a test:

  • test_id (String)

    Identifier of the assistant test that was executed.

  • triggered_by (String)

    How this test run was initiated (manual, scheduled, or API).

  • completed_at (Time) (defaults to: nil)

    Timestamp when the test run finished execution.

  • conversation_id (String) (defaults to: nil)

    Identifier of the conversation created during test execution.

  • conversation_insights_id (String) (defaults to: nil)

    Identifier for conversation analysis and insights data.

  • detail_status (Array<Telnyx::Models::AI::Assistants::Tests::TestRunResponse::DetailStatus>) (defaults to: nil)

    Detailed evaluation results for each rubric criteria. Name is name of the criter

  • logs (String) (defaults to: nil)

    Detailed execution logs and debug information.

  • test_suite_run_id (String) (defaults to: nil)

    Identifier linking this run to a test suite execution batch.

  • updated_at (Time) (defaults to: nil)

    Timestamp of the last update to this test run.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 125

class DetailStatus < Telnyx::Internal::Type::BaseModel
  # @!attribute name
  #
  #   @return [String]
  required :name, String

  # @!attribute status
  #   Represents the lifecycle of a test:
  #
  #   - 'pending': Test is waiting to be executed.
  #   - 'starting': Test execution is initializing.
  #   - 'running': Test is currently executing.
  #   - 'passed': Test completed successfully.
  #   - 'failed': Test executed but did not pass.
  #   - 'error': An error occurred during test execution.
  #
  #   @return [Symbol, Telnyx::Models::AI::Assistants::Tests::TestStatus]
  required :status, enum: -> { Telnyx::AI::Assistants::Tests::TestStatus }

  # @!method initialize(name:, status:)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::AI::Assistants::Tests::TestRunResponse::DetailStatus} for more
  #   details.
  #
  #   @param name [String]
  #
  #   @param status [Symbol, Telnyx::Models::AI::Assistants::Tests::TestStatus] Represents the lifecycle of a test:
end

Instance Attribute Details

#nameString

Returns:

  • (String)


129
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 129

required :name, String

#statusSymbol, Telnyx::Models::AI::Assistants::Tests::TestStatus

Represents the lifecycle of a test:

  • ‘pending’: Test is waiting to be executed.

  • ‘starting’: Test execution is initializing.

  • ‘running’: Test is currently executing.

  • ‘passed’: Test completed successfully.

  • ‘failed’: Test executed but did not pass.

  • ‘error’: An error occurred during test execution.



142
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 142

required :status, enum: -> { Telnyx::AI::Assistants::Tests::TestStatus }