Class: Telnyx::Models::AI::Assistants::Tests::TestSuites::RunTriggerParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/ai/assistants/tests/test_suites/run_trigger_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(suite_name:, destination_version_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::Assistants::Tests::TestSuites::RunTriggerParams for more details.

Parameters:

  • suite_name (String)
  • destination_version_id (String) (defaults to: nil)

    Optional assistant version ID to use for all test runs in this suite. If provide

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/ai/assistants/tests/test_suites/run_trigger_params.rb', line 27

Instance Attribute Details

#destination_version_idString?

Optional assistant version ID to use for all test runs in this suite. If provided, the version must exist or a 400 error will be returned. If not provided, test will run on main version

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/ai/assistants/tests/test_suites/run_trigger_params.rb', line 25

optional :destination_version_id, String

#suite_nameString

Returns:

  • (String)


17
# File 'lib/telnyx/models/ai/assistants/tests/test_suites/run_trigger_params.rb', line 17

required :suite_name, String