Class: Telnyx::Models::AI::Assistants::ToolTestParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Assistants::ToolTestParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/assistants/tool_test_params.rb
Overview
Instance Attribute Summary collapse
-
#arguments ⇒ Hash{Symbol=>Object}?
Key-value arguments to use for the webhook test.
- #assistant_id ⇒ String
-
#dynamic_variables ⇒ Hash{Symbol=>Object}?
Key-value dynamic variables to use for the webhook test.
- #tool_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(assistant_id:, tool_id:, arguments: nil, dynamic_variables: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assistant_id:, tool_id:, arguments: nil, dynamic_variables: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/ai/assistants/tool_test_params.rb', line 34
|
Instance Attribute Details
#arguments ⇒ Hash{Symbol=>Object}?
Key-value arguments to use for the webhook test
26 |
# File 'lib/telnyx/models/ai/assistants/tool_test_params.rb', line 26 optional :arguments, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#assistant_id ⇒ String
15 |
# File 'lib/telnyx/models/ai/assistants/tool_test_params.rb', line 15 required :assistant_id, String |
#dynamic_variables ⇒ Hash{Symbol=>Object}?
Key-value dynamic variables to use for the webhook test
32 |
# File 'lib/telnyx/models/ai/assistants/tool_test_params.rb', line 32 optional :dynamic_variables, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#tool_id ⇒ String
20 |
# File 'lib/telnyx/models/ai/assistants/tool_test_params.rb', line 20 required :tool_id, String |