Class: Telnyx::Models::AI::Assistants::UpdateAssistant::Integration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistants/update_assistant.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(description: nil, dynamic_variables: nil, dynamic_variables_webhook_timeout_ms: nil, dynamic_variables_webhook_url: nil, enabled_features: nil, external_llm: nil, fallback_config: nil, greeting: nil, insight_settings: nil, instructions: nil, integrations: nil, interruption_settings: nil, llm_api_key_ref: nil, mcp_servers: nil, messaging_settings: nil, model: nil, name: nil, observability_settings: nil, post_conversation_settings: nil, privacy_settings: nil, tags: nil, telephony_settings: nil, tool_ids: nil, tools: nil, transcription: nil, version_name: nil, voice_settings: nil, widget_settings: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::Assistants::UpdateAssistant for more details.

Parameters:



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 269

class Integration < Telnyx::Internal::Type::BaseModel
  # @!attribute integration_id
  #   Catalog integration ID to attach. This is the `id` from the integrations catalog
  #   at `/ai/integrations` (the same value also appears as `integration_id` on
  #   entries returned by `/ai/integrations/connections`). It is **not** the
  #   connection-level `id` from `/ai/integrations/connections`.
  #
  #   @return [String]
  required :integration_id, String

  # @!attribute allowed_list
  #   Optional per-assistant allowlist of integration tool names. When omitted or
  #   empty, all tools allowed by the connected integration are available to the
  #   assistant.
  #
  #   @return [Array<String>, nil]
  optional :allowed_list, Telnyx::Internal::Type::ArrayOf[String]

  # @!method initialize(integration_id:, allowed_list: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::AI::Assistants::UpdateAssistant::Integration} for more details.
  #
  #   Reference to a connected integration attached to an assistant. Discover
  #   available integrations with `/ai/integrations` and connected integrations with
  #   `/ai/integrations/connections`.
  #
  #   @param integration_id [String] Catalog integration ID to attach. This is the `id` from the integrations catalog
  #
  #   @param allowed_list [Array<String>] Optional per-assistant allowlist of integration tool names. When omitted or empt
end

Instance Attribute Details

#allowed_listArray<String>?

Optional per-assistant allowlist of integration tool names. When omitted or empty, all tools allowed by the connected integration are available to the assistant.

Returns:

  • (Array<String>, nil)


285
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 285

optional :allowed_list, Telnyx::Internal::Type::ArrayOf[String]

#integration_idString

Catalog integration ID to attach. This is the ‘id` from the integrations catalog at `/ai/integrations` (the same value also appears as `integration_id` on entries returned by `/ai/integrations/connections`). It is not the connection-level `id` from `/ai/integrations/connections`.

Returns:

  • (String)


277
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 277

required :integration_id, String