Class: Telnyx::Models::AI::Assistants::UpdateAssistant::InterruptionSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistants/update_assistant.rb

Overview

Defined Under Namespace

Classes: StartSpeakingPlan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enable: nil, start_speaking_plan: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::Assistants::UpdateAssistant::InterruptionSettings for more details.

Settings for interruptions and how the assistant decides the user has finished speaking. These timings are most relevant when using non turn-taking transcription models. For turn-taking models like ‘deepgram/flux`, end-of-turn behavior is controlled by the transcription end-of-turn settings under `transcription.settings` (`eot_threshold`, `eot_timeout_ms`, `eager_eot_threshold`).

Parameters:



# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 520

Instance Attribute Details

#enableBoolean?

Whether users can interrupt the assistant while it is speaking.

Returns:

  • (Boolean, nil)


508
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 508

optional :enable, Telnyx::Internal::Type::Boolean

#start_speaking_planTelnyx::Models::AI::Assistants::UpdateAssistant::InterruptionSettings::StartSpeakingPlan?

Controls when the assistant starts speaking after the user stops. These thresholds primarily apply to non turn-taking transcription models. For turn-taking models like ‘deepgram/flux`, end-of-turn detection is driven by the transcription end-of-turn settings under `transcription.settings` instead.



517
518
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 517

optional :start_speaking_plan,
-> { Telnyx::AI::Assistants::UpdateAssistant::InterruptionSettings::StartSpeakingPlan }