Class: Telnyx::Models::AI::AudioTranscribeResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AudioTranscribeResponse
- Defined in:
- lib/telnyx/models/ai/audio_transcribe_response.rb,
sig/telnyx/models/ai/audio_transcribe_response.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#duration ⇒ Float?
The duration of the audio file in seconds.
-
#segments ⇒ Array<Telnyx::Models::AI::AudioTranscribeResponse::Segment>?
Segments of the transcribed text and their corresponding details.
-
#text ⇒ String
The transcribed text for the audio file.
-
#words ⇒ Array<Telnyx::Models::AI::AudioTranscribeResponse::Word>?
Word-level timestamps and optional speaker labels.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, end_:, start:, text:) ⇒ Object
|
|
# File 'lib/telnyx/models/ai/audio_transcribe_response.rb', line 81
|
Instance Attribute Details
#duration ⇒ Float?
The duration of the audio file in seconds. Returned by
distil-whisper/distil-large-v2 and deepgram/nova-3 when response_format is
verbose_json. Not returned by openai/whisper-large-v3-turbo.
20 |
# File 'lib/telnyx/models/ai/audio_transcribe_response.rb', line 20 optional :duration, Float |
#segments ⇒ Array<Telnyx::Models::AI::AudioTranscribeResponse::Segment>?
Segments of the transcribed text and their corresponding details. Returned by
distil-whisper/distil-large-v2 when response_format is verbose_json. Not
returned by openai/whisper-large-v3-turbo.
28 29 |
# File 'lib/telnyx/models/ai/audio_transcribe_response.rb', line 28 optional :segments, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AI::AudioTranscribeResponse::Segment] } |
#text ⇒ String
The transcribed text for the audio file.
12 |
# File 'lib/telnyx/models/ai/audio_transcribe_response.rb', line 12 required :text, String |
#words ⇒ Array<Telnyx::Models::AI::AudioTranscribeResponse::Word>?
Word-level timestamps and optional speaker labels. Only returned by
deepgram/nova-3 when word-level output is enabled via model_config.
36 |
# File 'lib/telnyx/models/ai/audio_transcribe_response.rb', line 36 optional :words, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AI::AudioTranscribeResponse::Word] } |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/telnyx/models/ai/audio_transcribe_response.rbs', line 38
def to_hash: -> {
|