Class: Telnyx::Models::AI::BucketIDs

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/bucket_ids.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bucket_ids:, max_num_results: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::BucketIDs for more details.

Parameters:

  • bucket_ids (Array<String>)

    List of [embedded storage buckets](developers.telnyx.com/api-reference/e

  • max_num_results (Integer) (defaults to: nil)

    The maximum number of results to retrieve as context for the language model.



# File 'lib/telnyx/models/ai/bucket_ids.rb', line 21

Instance Attribute Details

#bucket_idsArray<String>

List of [embedded storage buckets](developers.telnyx.com/api-reference/embeddings/embed-documents) to use for retrieval-augmented generation.

Returns:

  • (Array<String>)


13
# File 'lib/telnyx/models/ai/bucket_ids.rb', line 13

required :bucket_ids, Telnyx::Internal::Type::ArrayOf[String]

#max_num_resultsInteger?

The maximum number of results to retrieve as context for the language model.

Returns:

  • (Integer, nil)


19
# File 'lib/telnyx/models/ai/bucket_ids.rb', line 19

optional :max_num_results, Integer