Class: Telnyx::Models::AI::ChatCreateCompletionParams::ResponseFormat
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::ChatCreateCompletionParams::ResponseFormat
- Defined in:
- lib/telnyx/models/ai/chat_create_completion_params.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(type:) ⇒ Object
constructor
Use this is you want to guarantee a JSON output without defining a schema.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:) ⇒ Object
Use this is you want to guarantee a JSON output without defining a schema. For control over the schema, use ‘guided_json`.
|
|
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 322
|
Instance Attribute Details
#type ⇒ Symbol, Telnyx::Models::AI::ChatCreateCompletionParams::ResponseFormat::Type
320 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 320 required :type, enum: -> { Telnyx::AI::ChatCreateCompletionParams::ResponseFormat::Type } |