Class: Telnyx::Models::AI::ClusterComputeParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/ai/cluster_compute_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bucket:, files: nil, min_cluster_size: nil, min_subcluster_size: nil, prefix: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::ClusterComputeParams for more details.

Parameters:

  • bucket (String)

    The embedded storage bucket to compute the clusters from. The bucket must alread

  • files (Array<String>) (defaults to: nil)

    Array of files to filter which are included.

  • min_cluster_size (Integer) (defaults to: nil)

    Smallest number of related text chunks to qualify as a cluster. Top-level cluste

  • min_subcluster_size (Integer) (defaults to: nil)

    Smallest number of related text chunks to qualify as a sub-cluster. Sub-clusters

  • prefix (String) (defaults to: nil)

    Prefix to filter whcih files in the buckets are included.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 45

Instance Attribute Details

#bucketString

The embedded storage bucket to compute the clusters from. The bucket must already be [embedded](developers.telnyx.com/api-reference/embeddings/embed-documents).

Returns:

  • (String)


17
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 17

required :bucket, String

#filesArray<String>?

Array of files to filter which are included.

Returns:

  • (Array<String>, nil)


23
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 23

optional :files, Telnyx::Internal::Type::ArrayOf[String]

#min_cluster_sizeInteger?

Smallest number of related text chunks to qualify as a cluster. Top-level clusters should be thought of as identifying broad themes in your data.

Returns:

  • (Integer, nil)


30
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 30

optional :min_cluster_size, Integer

#min_subcluster_sizeInteger?

Smallest number of related text chunks to qualify as a sub-cluster. Sub-clusters should be thought of as identifying more specific topics within a broader theme.

Returns:

  • (Integer, nil)


37
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 37

optional :min_subcluster_size, Integer

#prefixString?

Prefix to filter whcih files in the buckets are included.

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 43

optional :prefix, String