Class: Telnyx::Models::AI::ClusterRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::ClusterRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/cluster_retrieve_params.rb
Overview
Instance Attribute Summary collapse
-
#show_subclusters ⇒ Boolean?
Whether or not to include subclusters and their nodes in the response.
- #task_id ⇒ String
-
#top_n_nodes ⇒ Integer?
The number of nodes in the cluster to return in the response.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(task_id:, show_subclusters: nil, top_n_nodes: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ClusterRetrieveParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(task_id:, show_subclusters: nil, top_n_nodes: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::ClusterRetrieveParams for more details.
|
|
# File 'lib/telnyx/models/ai/cluster_retrieve_params.rb', line 29
|
Instance Attribute Details
#show_subclusters ⇒ Boolean?
Whether or not to include subclusters and their nodes in the response.
20 |
# File 'lib/telnyx/models/ai/cluster_retrieve_params.rb', line 20 optional :show_subclusters, Telnyx::Internal::Type::Boolean |
#task_id ⇒ String
14 |
# File 'lib/telnyx/models/ai/cluster_retrieve_params.rb', line 14 required :task_id, String |
#top_n_nodes ⇒ Integer?
The number of nodes in the cluster to return in the response. Nodes will be sorted by their centrality within the cluster.
27 |
# File 'lib/telnyx/models/ai/cluster_retrieve_params.rb', line 27 optional :top_n_nodes, Integer |