Class: Telnyx::Models::AI::CollectionRetrieveDocumentsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/collection_retrieve_documents_response.rb,
sig/telnyx/models/ai/collection_retrieve_documents_response.rbs

Overview

See Also:

  • Telnyx::Resources::AI::Collections#retrieve_documents

Defined Under Namespace

Classes: Data, Meta

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, chunk_index: nil, chunk_total: nil, ingested_at: nil, metadata: nil, organization_id: nil, record_created_at: nil, record_id: nil, record_type: nil, region: nil, score: nil, text: nil, user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Data for more details.

Parameters:

  • id (String) (defaults to: nil)
  • chunk_index (Integer) (defaults to: nil)
  • chunk_total (Integer) (defaults to: nil)
  • ingested_at (Time) (defaults to: nil)
  • metadata (Hash{Symbol=>Object}) (defaults to: nil)
  • organization_id (String) (defaults to: nil)
  • record_created_at (Time) (defaults to: nil)
  • record_id (String) (defaults to: nil)
  • record_type (String) (defaults to: nil)

    The source record kind this chunk came from (e.g. voice, meeting_bot, `messa

  • region (String) (defaults to: nil)
  • score (Float) (defaults to: nil)

    Relevance score (higher = more relevant) for ranked search. 0.0 for plain cata

  • text (String) (defaults to: nil)
  • user_id (String) (defaults to: nil)


# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 93

Instance Attribute Details

#dataArray<Telnyx::Models::AI::CollectionRetrieveDocumentsResponse::Data>?



11
12
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 11

optional :data,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AI::CollectionRetrieveDocumentsResponse::Data] }

#metaTelnyx::Models::AI::CollectionRetrieveDocumentsResponse::Meta?



17
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 17

optional :meta, -> { Telnyx::Models::AI::CollectionRetrieveDocumentsResponse::Meta }

Instance Method Details

#to_hash{

Returns:

  • ({)


28
# File 'sig/telnyx/models/ai/collection_retrieve_documents_response.rbs', line 28

def to_hash: -> {