Class: Telnyx::Models::AI::CollectionRetrieveDocumentsResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/collection_retrieve_documents_response.rb,
sig/telnyx/models/ai/collection_retrieve_documents_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data: nil, meta: nil) ⇒ Object



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 23

class Data < Telnyx::Internal::Type::BaseModel
  # @!attribute id
  #
  #   @return [String, nil]
  optional :id, String

  # @!attribute chunk_index
  #
  #   @return [Integer, nil]
  optional :chunk_index, Integer

  # @!attribute chunk_total
  #
  #   @return [Integer, nil]
  optional :chunk_total, Integer

  # @!attribute ingested_at
  #
  #   @return [Time, nil]
  optional :ingested_at, Time

  # @!attribute metadata
  #
  #   @return [Hash{Symbol=>Object}, nil]
  optional :metadata, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

  # @!attribute organization_id
  #
  #   @return [String, nil]
  optional :organization_id, String

  # @!attribute record_created_at
  #
  #   @return [Time, nil]
  optional :record_created_at, Time

  # @!attribute record_id
  #
  #   @return [String, nil]
  optional :record_id, String

  # @!attribute record_type
  #   The source record kind this chunk came from (e.g. `voice`, `meeting_bot`,
  #   `message`).
  #
  #   @return [String, nil]
  optional :record_type, String

  # @!attribute region
  #
  #   @return [String, nil]
  optional :region, String

  # @!attribute score
  #   Relevance score (higher = more relevant) for ranked search. `0.0` for plain
  #   catalog listings (when `query` is omitted).
  #
  #   @return [Float, nil]
  optional :score, Float

  # @!attribute text
  #
  #   @return [String, nil]
  optional :text, String

  # @!attribute user_id
  #
  #   @return [String, nil]
  optional :user_id, String

  # @!method initialize(id: nil, chunk_index: nil, chunk_total: nil, ingested_at: nil, metadata: nil, organization_id: nil, record_created_at: nil, record_id: nil, record_type: nil, region: nil, score: nil, text: nil, user_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::AI::CollectionRetrieveDocumentsResponse::Data} for more
  #   details.
  #
  #   @param id [String]
  #
  #   @param chunk_index [Integer]
  #
  #   @param chunk_total [Integer]
  #
  #   @param ingested_at [Time]
  #
  #   @param metadata [Hash{Symbol=>Object}]
  #
  #   @param organization_id [String]
  #
  #   @param record_created_at [Time]
  #
  #   @param record_id [String]
  #
  #   @param record_type [String] The source record kind this chunk came from (e.g. `voice`, `meeting_bot`, `messa
  #
  #   @param region [String]
  #
  #   @param score [Float] Relevance score (higher = more relevant) for ranked search. `0.0` for plain cata
  #
  #   @param text [String]
  #
  #   @param user_id [String]
end

Instance Attribute Details

#chunk_indexInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


32
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 32

optional :chunk_index, Integer

#chunk_totalInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


37
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 37

optional :chunk_total, Integer

#idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 27

optional :id, String

#ingested_atTime?

Parameters:

  • (Time)

Returns:

  • (Time, nil)


42
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 42

optional :ingested_at, Time

#metadataHash{Symbol=>Object}?

Parameters:

  • (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object}, nil)


47
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 47

optional :metadata, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#organization_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


52
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 52

optional :organization_id, String

#record_created_atTime?

Parameters:

  • (Time)

Returns:

  • (Time, nil)


57
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 57

optional :record_created_at, Time

#record_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 62

optional :record_id, String

#record_typeString?

The source record kind this chunk came from (e.g. voice, meeting_bot, message).

Parameters:

  • (String)

Returns:

  • (String, nil)


69
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 69

optional :record_type, String

#regionString?

Parameters:

  • (String)

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 74

optional :region, String

#scoreFloat?

Relevance score (higher = more relevant) for ranked search. 0.0 for plain catalog listings (when query is omitted).

Parameters:

  • (Float)

Returns:

  • (Float, nil)


81
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 81

optional :score, Float

#textString?

Parameters:

  • (String)

Returns:

  • (String, nil)


86
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 86

optional :text, String

#user_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


91
# File 'lib/telnyx/models/ai/collection_retrieve_documents_response.rb', line 91

optional :user_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


119
# File 'sig/telnyx/models/ai/collection_retrieve_documents_response.rbs', line 119

def to_hash: -> {