Class: Telnyx::Models::AI::Collections::Source

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/collections/source.rb,
sig/telnyx/models/ai/collections/source.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, bucket_id: nil, collection_id: nil, record_type: nil, source_type: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::Collections::Source for more details.

Parameters:

  • id (String) (defaults to: nil)
  • bucket_id (String) (defaults to: nil)

    The Telnyx Storage bucket name. Present only for bucket sources.

  • collection_id (String) (defaults to: nil)
  • record_type (String) (defaults to: nil)

    Identifies the record type. Always ai_collection_source.

  • source_type (Symbol, Telnyx::Models::AI::Collections::SourceType) (defaults to: nil)

    The type of Telnyx data attached as a source. bucket requires an additional `b

  • status (String) (defaults to: nil)


# File 'lib/telnyx/models/ai/collections/source.rb', line 43

Instance Attribute Details

#bucket_idString?

The Telnyx Storage bucket name. Present only for bucket sources.

Parameters:

  • (String)

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/ai/collections/source.rb', line 17

optional :bucket_id, String

#collection_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/ai/collections/source.rb', line 22

optional :collection_id, String

#idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/ai/collections/source.rb', line 11

optional :id, String

#record_typeString?

Identifies the record type. Always ai_collection_source.

Parameters:

  • (String)

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/ai/collections/source.rb', line 28

optional :record_type, String

#source_typeSymbol, ...

The type of Telnyx data attached as a source. bucket requires an additional bucket_id. Only voice is searchable today; meeting_bot, message, and bucket attach but are not yet searchable (Coming soon).



36
# File 'lib/telnyx/models/ai/collections/source.rb', line 36

optional :source_type, enum: -> { Telnyx::AI::Collections::SourceType }

#statusString?

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/ai/collections/source.rb', line 41

optional :status, String

Instance Method Details

#to_hash{

Returns:

  • ({)


51
# File 'sig/telnyx/models/ai/collections/source.rbs', line 51

def to_hash: -> {