Class: Telnyx::Models::AI::Collections::SourceReplaceResponse::Meta
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Collections::SourceReplaceResponse::Meta
- Defined in:
- lib/telnyx/models/ai/collections/source_replace_response.rb,
sig/telnyx/models/ai/collections/source_replace_response.rbs
Overview
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(added: nil, removed: nil, retained: nil) ⇒ Object
constructor
Reports which source IDs were added, retained, and removed by a replace operation.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(added: nil, removed: nil, retained: nil) ⇒ Object
Reports which source IDs were added, retained, and removed by a replace operation.
|
|
# File 'lib/telnyx/models/ai/collections/source_replace_response.rb', line 46
|
Instance Attribute Details
#added ⇒ Array<String>?
34 |
# File 'lib/telnyx/models/ai/collections/source_replace_response.rb', line 34 optional :added, Telnyx::Internal::Type::ArrayOf[String] |
#removed ⇒ Array<String>?
39 |
# File 'lib/telnyx/models/ai/collections/source_replace_response.rb', line 39 optional :removed, Telnyx::Internal::Type::ArrayOf[String] |
#retained ⇒ Array<String>?
44 |
# File 'lib/telnyx/models/ai/collections/source_replace_response.rb', line 44 optional :retained, Telnyx::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
60 |
# File 'sig/telnyx/models/ai/collections/source_replace_response.rbs', line 60
def to_hash: -> {
|