Class: Telnyx::Models::AI::Collections::SourceRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/collections/source_request.rb,
sig/telnyx/models/ai/collections/source_request.rbs

Direct Known Subclasses

SourceCreateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(source_type:, bucket_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::Collections::SourceRequest for more details.

Parameters:

  • source_type (Symbol, Telnyx::Models::AI::Collections::SourceType)

    The type of Telnyx data attached as a source. bucket requires an additional `b

  • bucket_id (String) (defaults to: nil)

    The Telnyx Storage bucket name. Required when source_type is bucket; ignored



# File 'lib/telnyx/models/ai/collections/source_request.rb', line 23

Instance Attribute Details

#bucket_idString?

The Telnyx Storage bucket name. Required when source_type is bucket; ignored otherwise.

Parameters:

  • (String)

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/ai/collections/source_request.rb', line 21

optional :bucket_id, String

#source_typeSymbol, Telnyx::Models::AI::Collections::SourceType

The type of Telnyx data attached as a source. bucket requires an additional bucket_id. Only voice is searchable today; meeting_bot, message, and bucket attach but are not yet searchable (Coming soon).

Parameters:

  • value (Telnyx::Models::AI::Collections::source_type)

Returns:



14
# File 'lib/telnyx/models/ai/collections/source_request.rb', line 14

required :source_type, enum: -> { Telnyx::AI::Collections::SourceType }

Instance Method Details

#to_hash{

Returns:

  • ({)


23
# File 'sig/telnyx/models/ai/collections/source_request.rbs', line 23

def to_hash: -> {