Module: Telnyx::Models::AI::Collections::SourceType

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/ai/collections/source_type.rb,
sig/telnyx/models/ai/collections/source_type.rbs

Overview

The type of Telnyx data attached as a source. bucket requires an additional bucket_id. Only voice is searchable today; meeting_bot, message, and bucket attach but are not yet searchable (Coming soon).

Constant Summary collapse

VOICE =

Returns:

  • (:voice)
:voice
MEETING_BOT =

Returns:

  • (:meeting_bot)
:meeting_bot
MESSAGE =

Returns:

  • (:message)
:message
BUCKET =

Returns:

  • (:bucket)
:bucket

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ai/collections/source_type.rb', line 18

Instance Method Details

#self?.values::Array[Telnyx::Models::AI::Collections::source_type]

Returns:

  • (::Array[Telnyx::Models::AI::Collections::source_type])


15
# File 'sig/telnyx/models/ai/collections/source_type.rbs', line 15

def self?.values: -> ::Array[Telnyx::Models::AI::Collections::source_type]