Class: Telnyx::Models::AI::ConversationListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::ConversationListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/conversation_list_params.rb,
sig/telnyx/models/ai/conversation_list_params.rbs
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ String?
Filter by creation datetime (e.g.,
created_at=gte.2025-01-01). -
#id ⇒ String?
Filter by conversation ID (e.g. id=eq.123).
-
#last_message_at ⇒ String?
Filter by last message datetime (e.g.,
last_message_at=lte.2025-06-01). -
#limit ⇒ Integer?
Limit the number of returned conversations (e.g.,
limit=10). -
#metadata_assistant_id ⇒ String?
Filter by assistant ID (e.g.,
metadata->assistant_id=eq.assistant-123). -
#metadata_call_control_id ⇒ String?
Filter by call control ID (e.g.,
metadata->call_control_id=eq.v3:123). -
#metadata_telnyx_agent_target ⇒ String?
Filter by the phone number, SIP URI, or other identifier for the agent (e.g.,
metadata->telnyx_agent_target=eq.+13128675309). -
#metadata_telnyx_conversation_channel ⇒ String?
Filter by conversation channel (e.g.,
metadata->telnyx_conversation_channel=eq.phone_call). -
#metadata_telnyx_end_user_target ⇒ String?
Filter by the phone number, SIP URI, or other identifier for the end user (e.g.,
metadata->telnyx_end_user_target=eq.+13128675309). -
#name ⇒ String?
Filter by conversation Name (e.g.
name=like.Voice%). -
#or_ ⇒ String?
Apply OR conditions using PostgREST syntax (e.g.,
or=(created_at.gte.2025-04-01,last_message_at.gte.2025-04-01)). -
#order ⇒ String?
Order the results by specific fields (e.g.,
order=created_at.descororder=last_message_at.asc).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id: nil, created_at: nil, last_message_at: nil, limit: nil, metadata_assistant_id: nil, metadata_call_control_id: nil, metadata_telnyx_agent_target: nil, metadata_telnyx_conversation_channel: nil, metadata_telnyx_end_user_target: nil, name: nil, or_: nil, order: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConversationListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, last_message_at: nil, limit: nil, metadata_assistant_id: nil, metadata_call_control_id: nil, metadata_telnyx_agent_target: nil, metadata_telnyx_conversation_channel: nil, metadata_telnyx_end_user_target: nil, name: nil, or_: nil, order: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::ConversationListParams for more details.
|
|
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 88
|
Instance Attribute Details
#created_at ⇒ String?
Filter by creation datetime (e.g., created_at=gte.2025-01-01)
21 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 21 optional :created_at, String |
#id ⇒ String?
Filter by conversation ID (e.g. id=eq.123)
15 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 15 optional :id, String |
#last_message_at ⇒ String?
Filter by last message datetime (e.g., last_message_at=lte.2025-06-01)
27 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 27 optional :last_message_at, String |
#limit ⇒ Integer?
Limit the number of returned conversations (e.g., limit=10)
33 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 33 optional :limit, Integer |
#metadata_assistant_id ⇒ String?
Filter by assistant ID (e.g., metadata->assistant_id=eq.assistant-123)
39 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 39 optional :metadata_assistant_id, String |
#metadata_call_control_id ⇒ String?
Filter by call control ID (e.g., metadata->call_control_id=eq.v3:123)
45 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 45 optional :metadata_call_control_id, String |
#metadata_telnyx_agent_target ⇒ String?
Filter by the phone number, SIP URI, or other identifier for the agent (e.g.,
metadata->telnyx_agent_target=eq.+13128675309)
52 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 52 optional :metadata_telnyx_agent_target, String |
#metadata_telnyx_conversation_channel ⇒ String?
Filter by conversation channel (e.g.,
metadata->telnyx_conversation_channel=eq.phone_call)
59 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 59 optional :metadata_telnyx_conversation_channel, String |
#metadata_telnyx_end_user_target ⇒ String?
Filter by the phone number, SIP URI, or other identifier for the end user (e.g.,
metadata->telnyx_end_user_target=eq.+13128675309)
66 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 66 optional :metadata_telnyx_end_user_target, String |
#name ⇒ String?
Filter by conversation Name (e.g. name=like.Voice%)
72 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 72 optional :name, String |
#or_ ⇒ String?
Apply OR conditions using PostgREST syntax (e.g.,
or=(created_at.gte.2025-04-01,last_message_at.gte.2025-04-01))
79 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 79 optional :or_, String |
#order ⇒ String?
Order the results by specific fields (e.g., order=created_at.desc or
order=last_message_at.asc)
86 |
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 86 optional :order, String |
Instance Method Details
#to_hash ⇒ {
89 |
# File 'sig/telnyx/models/ai/conversation_list_params.rbs', line 89
def to_hash: -> {
|