Class: Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/conversation_retrieve_conversations_insights_response.rb

Defined Under Namespace

Modules: Status Classes: ConversationInsight

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(insight_id:, result:) ⇒ Object

Some parameter documentations has been truncated, see ConversationInsight for more details.

Parameters:

  • insight_id (String)

    Unique identifier for the insight configuration.

  • result (String)

    Insight result from the conversation. If the insight has a JSON schema, this wil



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/telnyx/models/ai/conversation_retrieve_conversations_insights_response.rb', line 23

class Data < Telnyx::Internal::Type::BaseModel
  # @!attribute id
  #   Unique identifier for the conversation insight.
  #
  #   @return [String]
  required :id, String

  # @!attribute conversation_insights
  #   List of insights extracted from the conversation.
  #
  #   @return [Array<Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::ConversationInsight>]
  required :conversation_insights,
           -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::ConversationInsight] }

  # @!attribute created_at
  #   Timestamp of when the object was created.
  #
  #   @return [Time]
  required :created_at, Time

  # @!attribute status
  #   Current status of the insight generation for the conversation.
  #
  #   @return [Symbol, Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::Status]
  required :status,
           enum: -> { Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::Status }

  # @!method initialize(id:, conversation_insights:, created_at:, status:)
  #   @param id [String] Unique identifier for the conversation insight.
  #
  #   @param conversation_insights [Array<Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::ConversationInsight>] List of insights extracted from the conversation.
  #
  #   @param created_at [Time] Timestamp of when the object was created.
  #
  #   @param status [Symbol, Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::Status] Current status of the insight generation for the conversation.

  class ConversationInsight < Telnyx::Internal::Type::BaseModel
    # @!attribute insight_id
    #   Unique identifier for the insight configuration.
    #
    #   @return [String]
    required :insight_id, String

    # @!attribute result
    #   Insight result from the conversation. If the insight has a JSON schema, this
    #   will be stringified JSON object.
    #
    #   @return [String]
    required :result, String

    # @!method initialize(insight_id:, result:)
    #   Some parameter documentations has been truncated, see
    #   {Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::ConversationInsight}
    #   for more details.
    #
    #   @param insight_id [String] Unique identifier for the insight configuration.
    #
    #   @param result [String] Insight result from the conversation. If the insight has a JSON schema, this wil
  end

  # Current status of the insight generation for the conversation.
  #
  # @see Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data#status
  module Status
    extend Telnyx::Internal::Type::Enum

    PENDING = :pending
    IN_PROGRESS = :in_progress
    COMPLETED = :completed
    FAILED = :failed

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#conversation_insightsArray<Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::ConversationInsight>

List of insights extracted from the conversation.



34
35
# File 'lib/telnyx/models/ai/conversation_retrieve_conversations_insights_response.rb', line 34

required :conversation_insights,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::ConversationInsight] }

#created_atTime

Timestamp of when the object was created.

Returns:

  • (Time)


41
# File 'lib/telnyx/models/ai/conversation_retrieve_conversations_insights_response.rb', line 41

required :created_at, Time

#idString

Unique identifier for the conversation insight.

Returns:

  • (String)


28
# File 'lib/telnyx/models/ai/conversation_retrieve_conversations_insights_response.rb', line 28

required :id, String

#statusSymbol, Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::Status

Current status of the insight generation for the conversation.



47
48
# File 'lib/telnyx/models/ai/conversation_retrieve_conversations_insights_response.rb', line 47

required :status,
enum: -> { Telnyx::Models::AI::ConversationRetrieveConversationsInsightsResponse::Data::Status }