Module: Telnyx::Models::AI::EnabledFeatures

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/ai/enabled_features.rb,
sig/telnyx/models/ai/enabled_features.rbs

Overview

If telephony is enabled, the assistant will be able to make and receive calls. If messaging is enabled, the assistant will be able to send and receive messages.

Constant Summary collapse

TELEPHONY =

Returns:

  • (:telephony)
:telephony
MESSAGING =

Returns:

  • (:messaging)
:messaging

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ai/enabled_features.rb', line 15

Instance Method Details

#self?.values::Array[Telnyx::Models::AI::enabled_features]

Returns:

  • (::Array[Telnyx::Models::AI::enabled_features])


12
# File 'sig/telnyx/models/ai/enabled_features.rbs', line 12

def self?.values: -> ::Array[Telnyx::Models::AI::enabled_features]