Class: Telnyx::Models::AI::Expression::Variable
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Expression::Variable
- Defined in:
- lib/telnyx/models/ai/expression.rb,
sig/telnyx/models/ai/expression.rbs
Instance Attribute Summary collapse
-
#name ⇒ String
Variable name to look up in the runtime context.
- #type ⇒ Symbol, :variable
Instance Method Summary collapse
-
#initialize ⇒ Variable
constructor
A new instance of Variable.
- #to_hash ⇒ { name: String, type: :variable }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Variable
Returns a new instance of Variable.
23 |
# File 'sig/telnyx/models/ai/expression.rbs', line 23
def initialize: (name: String, ?type: :variable) -> void
|
Instance Attribute Details
#name ⇒ String
Variable name to look up in the runtime context.
55 |
# File 'lib/telnyx/models/ai/expression.rb', line 55 required :name, String |
#type ⇒ Symbol, :variable
60 |
# File 'lib/telnyx/models/ai/expression.rb', line 60 required :type, const: :variable |
Instance Method Details
#to_hash ⇒ { name: String, type: :variable }
25 |
# File 'sig/telnyx/models/ai/expression.rbs', line 25
def to_hash: -> { name: String, type: :variable }
|