Class: Telnyx::Models::AI::FineTuning::FineTuningJob::Hyperparameters

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb,
sig/telnyx/models/ai/fine_tuning/fine_tuning_job.rbs

Overview

See Also:

  • Telnyx::Models::AI::FineTuning::FineTuningJob#hyperparameters

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeHyperparameters

Returns a new instance of Hyperparameters.

Parameters:

  • n_epochs: (Integer)


68
# File 'sig/telnyx/models/ai/fine_tuning/fine_tuning_job.rbs', line 68

def initialize: (n_epochs: Integer) -> void

Instance Attribute Details

#n_epochsInteger

The number of epochs to train the model for. An epoch refers to one full cycle through the training dataset.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


97
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 97

required :n_epochs, Integer

Instance Method Details

#to_hash{ n_epochs: Integer }

Returns:

  • ({ n_epochs: Integer })


70
# File 'sig/telnyx/models/ai/fine_tuning/fine_tuning_job.rbs', line 70

def to_hash: -> { n_epochs: Integer }