Class: Telnyx::Models::AI::FineTuning::JobCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::FineTuning::JobCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/fine_tuning/job_create_params.rb,
sig/telnyx/models/ai/fine_tuning/job_create_params.rbs
Overview
Defined Under Namespace
Classes: Hyperparameters
Instance Attribute Summary collapse
-
#hyperparameters ⇒ Telnyx::Models::AI::FineTuning::JobCreateParams::Hyperparameters?
The hyperparameters used for the fine-tuning job.
-
#model ⇒ String
The base model that is being fine-tuned.
-
#suffix ⇒ String?
Optional suffix to append to the fine tuned model's name.
-
#training_file ⇒ String
The storage bucket or object used for training.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
32 |
# File 'sig/telnyx/models/ai/fine_tuning/job_create_params.rbs', line 32
def initialize: (
|
Instance Attribute Details
#hyperparameters ⇒ Telnyx::Models::AI::FineTuning::JobCreateParams::Hyperparameters?
The hyperparameters used for the fine-tuning job.
28 |
# File 'lib/telnyx/models/ai/fine_tuning/job_create_params.rb', line 28 optional :hyperparameters, -> { Telnyx::AI::FineTuning::JobCreateParams::Hyperparameters } |
#model ⇒ String
The base model that is being fine-tuned.
16 |
# File 'lib/telnyx/models/ai/fine_tuning/job_create_params.rb', line 16 required :model, String |
#suffix ⇒ String?
Optional suffix to append to the fine tuned model's name.
34 |
# File 'lib/telnyx/models/ai/fine_tuning/job_create_params.rb', line 34 optional :suffix, String |
#training_file ⇒ String
The storage bucket or object used for training.
22 |
# File 'lib/telnyx/models/ai/fine_tuning/job_create_params.rb', line 22 required :training_file, String |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/telnyx/models/ai/fine_tuning/job_create_params.rbs', line 40
def to_hash: -> {
|