Class: Telnyx::Models::AI::FineTuning::JobCreateParams::Hyperparameters

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/fine_tuning/job_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(n_epochs: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::FineTuning::JobCreateParams::Hyperparameters for more details.

The hyperparameters used for the fine-tuning job.

Parameters:

  • n_epochs (Integer) (defaults to: nil)

    The number of epochs to train the model for. An epoch refers to one full cycle t



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/telnyx/models/ai/fine_tuning/job_create_params.rb', line 47

class Hyperparameters < Telnyx::Internal::Type::BaseModel
  # @!attribute n_epochs
  #   The number of epochs to train the model for. An epoch refers to one full cycle
  #   through the training dataset. 'auto' decides the optimal number of epochs based
  #   on the size of the dataset. If setting the number manually, we support any
  #   number between 1 and 50 epochs.
  #
  #   @return [Integer, nil]
  optional :n_epochs, Integer

  # @!method initialize(n_epochs: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::AI::FineTuning::JobCreateParams::Hyperparameters} for more
  #   details.
  #
  #   The hyperparameters used for the fine-tuning job.
  #
  #   @param n_epochs [Integer] The number of epochs to train the model for. An epoch refers to one full cycle t
end

Instance Attribute Details

#n_epochsInteger?

The number of epochs to train the model for. An epoch refers to one full cycle through the training dataset. ‘auto’ decides the optimal number of epochs based on the size of the dataset. If setting the number manually, we support any number between 1 and 50 epochs.

Returns:

  • (Integer, nil)


55
# File 'lib/telnyx/models/ai/fine_tuning/job_create_params.rb', line 55

optional :n_epochs, Integer