Module: Telnyx::Models::AI::FlowEdge::Target
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/ai/flow_edge.rb,
sig/telnyx/models/ai/flow_edge.rbs
Overview
Destination of the transition. Discriminated by type: node (jump to another
node in this flow) or assistant (hand off to a different assistant).
Defined Under Namespace
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(node_id:, type: :node) ⇒ Object
Edge target referencing another node within the same flow.
- #self?.variants ⇒ ::Array[Telnyx::Models::AI::FlowEdge::target]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Telnyx::Models::AI::FlowEdge::Target::Node, Telnyx::Models::AI::FlowEdge::Target::Assistant)
|
|
# File 'lib/telnyx/models/ai/flow_edge.rb', line 279
|
Instance Method Details
#initialize(node_id:, type: :node) ⇒ Object
Edge target referencing another node within the same flow.
The runtime transitions the active node to node_id and continues processing
within the current assistant's flow.
|
|
# File 'lib/telnyx/models/ai/flow_edge.rb', line 199
|
#self?.variants ⇒ ::Array[Telnyx::Models::AI::FlowEdge::target]
150 |
# File 'sig/telnyx/models/ai/flow_edge.rbs', line 150
def self?.variants: -> ::Array[Telnyx::Models::AI::FlowEdge::target]
|