Class: Telnyx::Models::AI::InferenceEmbedding
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::InferenceEmbedding
- Defined in:
- lib/telnyx/models/ai/inference_embedding.rb,
sig/telnyx/models/ai/inference_embedding.rbs
Overview
Defined Under Namespace
Classes: ConversationFlow
Instance Attribute Summary collapse
-
#conversation_flow ⇒ Telnyx::Models::AI::InferenceEmbedding::ConversationFlow?
Conversation flow as returned by the API.
- #created_at ⇒ Time
- #description ⇒ String?
-
#dynamic_variables ⇒ Hash{Symbol=>Object}?
Map of dynamic variables and their values.
-
#dynamic_variables_webhook_timeout_ms ⇒ Integer?
Timeout in milliseconds for the dynamic variables webhook.
-
#dynamic_variables_webhook_url ⇒ String?
If
dynamic_variables_webhook_urlis set, Telnyx sends a POST request to this URL at the start of the conversation to resolve dynamic variables. - #enabled_features ⇒ Array<Symbol, Telnyx::Models::AI::EnabledFeatures>?
- #external_llm ⇒ Telnyx::Models::AI::ExternalLlm?
- #fallback_config ⇒ Telnyx::Models::AI::FallbackConfig?
-
#greeting ⇒ String?
Text that the assistant will use to start the conversation.
- #id ⇒ String
- #import_metadata ⇒ Telnyx::Models::AI::ImportMetadata?
- #insight_settings ⇒ Telnyx::Models::AI::InsightSettings?
-
#instructions ⇒ String
System instructions for the assistant.
-
#integrations ⇒ Array<Telnyx::Models::AI::AssistantIntegration>?
Connected integrations attached to the assistant.
-
#interruption_settings ⇒ Telnyx::Models::AI::InferenceEmbeddingInterruptionSettings?
Settings for interruptions and how the assistant decides the user has finished speaking.
-
#llm_api_key_ref ⇒ String?
This is only needed when using third-party inference providers selected by
model. -
#mcp_servers ⇒ Array<Telnyx::Models::AI::AssistantMcpServer>?
MCP servers attached to the assistant.
- #messaging_settings ⇒ Telnyx::Models::AI::MessagingSettings?
-
#model ⇒ String
ID of the model to use when
external_llmis not set. - #name ⇒ String
- #observability_settings ⇒ Telnyx::Models::AI::Observability?
-
#post_conversation_settings ⇒ Telnyx::Models::AI::PostConversationSettings?
Configuration for post-conversation processing.
- #privacy_settings ⇒ Telnyx::Models::AI::PrivacySettings?
-
#related_mission_ids ⇒ Array<String>?
IDs of missions related to this assistant.
-
#tags ⇒ Array<String>?
Tags associated with the assistant.
- #telephony_settings ⇒ Telnyx::Models::AI::TelephonySettings?
-
#tools ⇒ Array<Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams, Telnyx::Models::AI::RetrievalTool, Telnyx::Models::AI::AssistantTool::Handoff, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::AssistantTool::Transfer, Telnyx::Models::AI::AssistantTool::Invite, Telnyx::Models::AI::AssistantTool::Refer, Telnyx::Models::AI::AssistantTool::SendDtmf, Telnyx::Models::AI::AssistantTool::SendMessage, Telnyx::Models::AI::AssistantTool::SkipTurn>?
Deprecated for new integrations.
- #transcription ⇒ Telnyx::Models::AI::TranscriptionSettings?
-
#version_created_at ⇒ Time?
Timestamp when this assistant version was created.
-
#version_id ⇒ String?
Identifier for the assistant version returned by version-aware assistant endpoints.
-
#version_name ⇒ String?
Human-readable name for the assistant version.
- #voice_settings ⇒ Telnyx::Models::AI::VoiceSettings?
-
#widget_settings ⇒ Telnyx::Models::AI::WidgetSettings?
Configuration settings for the assistant's web widget.
Instance Method Summary collapse
-
#initialize(id:, created_at:, instructions:, model:, name:, conversation_flow: nil, description: nil, dynamic_variables: nil, dynamic_variables_webhook_timeout_ms: nil, dynamic_variables_webhook_url: nil, enabled_features: nil, external_llm: nil, fallback_config: nil, greeting: nil, import_metadata: nil, insight_settings: nil, integrations: nil, interruption_settings: nil, llm_api_key_ref: nil, mcp_servers: nil, messaging_settings: nil, observability_settings: nil, post_conversation_settings: nil, privacy_settings: nil, related_mission_ids: nil, tags: nil, telephony_settings: nil, tools: nil, transcription: nil, version_created_at: nil, version_id: nil, version_name: nil, voice_settings: nil, widget_settings: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see InferenceEmbedding for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, instructions:, model:, name:, conversation_flow: nil, description: nil, dynamic_variables: nil, dynamic_variables_webhook_timeout_ms: nil, dynamic_variables_webhook_url: nil, enabled_features: nil, external_llm: nil, fallback_config: nil, greeting: nil, import_metadata: nil, insight_settings: nil, integrations: nil, interruption_settings: nil, llm_api_key_ref: nil, mcp_servers: nil, messaging_settings: nil, observability_settings: nil, post_conversation_settings: nil, privacy_settings: nil, related_mission_ids: nil, tags: nil, telephony_settings: nil, tools: nil, transcription: nil, version_created_at: nil, version_id: nil, version_name: nil, voice_settings: nil, widget_settings: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::InferenceEmbedding for more details.
|
|
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 240
|
Instance Attribute Details
#conversation_flow ⇒ Telnyx::Models::AI::InferenceEmbedding::ConversationFlow?
Conversation flow as returned by the API.
44 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 44 optional :conversation_flow, -> { Telnyx::AI::InferenceEmbedding::ConversationFlow } |
#created_at ⇒ Time
16 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 16 required :created_at, Time |
#description ⇒ String?
49 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 49 optional :description, String |
#dynamic_variables ⇒ Hash{Symbol=>Object}?
Map of dynamic variables and their values
55 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 55 optional :dynamic_variables, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#dynamic_variables_webhook_timeout_ms ⇒ Integer?
Timeout in milliseconds for the dynamic variables webhook. Must be between 1 and 10000 ms. If the webhook does not respond within this timeout, the call proceeds with default values. See the dynamic variables guide.
64 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 64 optional :dynamic_variables_webhook_timeout_ms, Integer |
#dynamic_variables_webhook_url ⇒ String?
If dynamic_variables_webhook_url is set, Telnyx sends a POST request to this
URL at the start of the conversation to resolve dynamic variables. Gotcha:
the webhook response must wrap variables under a top-level dynamic_variables
object, e.g. {"dynamic_variables": {"customer_name": "Jane"}}. Returning a
flat object will be ignored and variables will fall back to their defaults. See
the
dynamic variables guide
for the full request/response format and timeout behavior.
77 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 77 optional :dynamic_variables_webhook_url, String |
#enabled_features ⇒ Array<Symbol, Telnyx::Models::AI::EnabledFeatures>?
82 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 82 optional :enabled_features, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::AI::EnabledFeatures] } |
#external_llm ⇒ Telnyx::Models::AI::ExternalLlm?
87 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 87 optional :external_llm, -> { Telnyx::AI::ExternalLlm } |
#fallback_config ⇒ Telnyx::Models::AI::FallbackConfig?
92 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 92 optional :fallback_config, -> { Telnyx::AI::FallbackConfig } |
#greeting ⇒ String?
Text that the assistant will use to start the conversation. This may be
templated with
dynamic variables.
Use an empty string to have the assistant wait for the user to speak first. Use
the special value <assistant-speaks-first-with-model-generated-message> to
have the assistant generate the greeting based on the system instructions.
103 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 103 optional :greeting, String |
#id ⇒ String
11 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 11 required :id, String |
#import_metadata ⇒ Telnyx::Models::AI::ImportMetadata?
108 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 108 optional :import_metadata, -> { Telnyx::AI::ImportMetadata } |
#insight_settings ⇒ Telnyx::Models::AI::InsightSettings?
113 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 113 optional :insight_settings, -> { Telnyx::AI::InsightSettings } |
#instructions ⇒ String
System instructions for the assistant. These may be templated with dynamic variables
23 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 23 required :instructions, String |
#integrations ⇒ Array<Telnyx::Models::AI::AssistantIntegration>?
Connected integrations attached to the assistant. The catalog of available
integrations is at /ai/integrations; the user's connected integrations are at
/ai/integrations/connections. Each item references a catalog integration by
integration_id.
122 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 122 optional :integrations, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantIntegration] } |
#interruption_settings ⇒ Telnyx::Models::AI::InferenceEmbeddingInterruptionSettings?
Settings for interruptions and how the assistant decides the user has finished
speaking. These timings are most relevant when using non turn-taking
transcription models. For turn-taking models like deepgram/flux, end-of-turn
behavior is controlled by the transcription end-of-turn settings under
transcription.settings (eot_threshold, eot_timeout_ms,
eager_eot_threshold).
133 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 133 optional :interruption_settings, -> { Telnyx::AI::InferenceEmbeddingInterruptionSettings } |
#llm_api_key_ref ⇒ String?
This is only needed when using third-party inference providers selected by
model. The identifier for an integration secret
/v2/integration_secrets
that refers to your LLM provider's API key. For bring-your-own endpoint
authentication, use external_llm.llm_api_key_ref instead. Warning: Free plans
are unlikely to work with this integration.
144 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 144 optional :llm_api_key_ref, String |
#mcp_servers ⇒ Array<Telnyx::Models::AI::AssistantMcpServer>?
MCP servers attached to the assistant. Create MCP servers with
/ai/mcp_servers, then reference them by id here.
151 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 151 optional :mcp_servers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantMcpServer] } |
#messaging_settings ⇒ Telnyx::Models::AI::MessagingSettings?
156 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 156 optional :messaging_settings, -> { Telnyx::AI::MessagingSettings } |
#model ⇒ String
ID of the model to use when external_llm is not set. You can use the
Get models API
to see available models. If external_llm is provided, the assistant uses
external_llm instead of this field. If neither model nor external_llm is
provided, Telnyx applies the default model.
33 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 33 required :model, String |
#name ⇒ String
38 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 38 required :name, String |
#observability_settings ⇒ Telnyx::Models::AI::Observability?
161 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 161 optional :observability_settings, -> { Telnyx::AI::Observability } |
#post_conversation_settings ⇒ Telnyx::Models::AI::PostConversationSettings?
Configuration for post-conversation processing. When enabled, the assistant receives one additional LLM turn after the conversation ends, allowing it to execute tool calls such as logging to a CRM or sending a summary. The assistant can execute multiple parallel or sequential tools during this phase. Telephony-control tools (e.g. hangup, transfer) are unavailable post-conversation. Beta feature.
172 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 172 optional :post_conversation_settings, -> { Telnyx::AI::PostConversationSettings } |
#privacy_settings ⇒ Telnyx::Models::AI::PrivacySettings?
177 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 177 optional :privacy_settings, -> { Telnyx::AI::PrivacySettings } |
#related_mission_ids ⇒ Array<String>?
IDs of missions related to this assistant.
183 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 183 optional :related_mission_ids, Telnyx::Internal::Type::ArrayOf[String] |
#tags ⇒ Array<String>?
Tags associated with the assistant. Tags can also be managed with the assistant tag endpoints.
190 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 190 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#telephony_settings ⇒ Telnyx::Models::AI::TelephonySettings?
195 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 195 optional :telephony_settings, -> { Telnyx::AI::TelephonySettings } |
#tools ⇒ Array<Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams, Telnyx::Models::AI::RetrievalTool, Telnyx::Models::AI::AssistantTool::Handoff, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::AssistantTool::Transfer, Telnyx::Models::AI::AssistantTool::Invite, Telnyx::Models::AI::AssistantTool::Refer, Telnyx::Models::AI::AssistantTool::SendDtmf, Telnyx::Models::AI::AssistantTool::SendMessage, Telnyx::Models::AI::AssistantTool::SkipTurn>?
Deprecated for new integrations. Inline tool definitions available to the
assistant. Prefer tool_ids to attach shared tools created with the AI Tools
endpoints.
203 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 203 optional :tools, -> { Telnyx::Internal::Type::ArrayOf[union: Telnyx::AI::AssistantTool] } |
#transcription ⇒ Telnyx::Models::AI::TranscriptionSettings?
208 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 208 optional :transcription, -> { Telnyx::AI::TranscriptionSettings } |
#version_created_at ⇒ Time?
Timestamp when this assistant version was created.
214 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 214 optional :version_created_at, Time |
#version_id ⇒ String?
Identifier for the assistant version returned by version-aware assistant endpoints.
221 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 221 optional :version_id, String |
#version_name ⇒ String?
Human-readable name for the assistant version.
227 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 227 optional :version_name, String |
#voice_settings ⇒ Telnyx::Models::AI::VoiceSettings?
232 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 232 optional :voice_settings, -> { Telnyx::AI::VoiceSettings } |
#widget_settings ⇒ Telnyx::Models::AI::WidgetSettings?
Configuration settings for the assistant's web widget.
238 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 238 optional :widget_settings, -> { Telnyx::AI::WidgetSettings } |
Instance Method Details
#to_hash ⇒ {
240 |
# File 'sig/telnyx/models/ai/inference_embedding.rbs', line 240
def to_hash: -> {
|