Class: Telnyx::Models::AI::InferenceEmbedding::FallbackConfig::ExternalLlm
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::InferenceEmbedding::FallbackConfig::ExternalLlm
- Defined in:
- lib/telnyx/models/ai/inference_embedding.rb
Overview
Defined Under Namespace
Modules: AuthenticationMethod
Instance Attribute Summary collapse
-
#authentication_method ⇒ Symbol, ...
Authentication method used when connecting to the external LLM endpoint.
-
#base_url ⇒ String
Base URL for the external LLM endpoint.
-
#certificate_ref ⇒ String?
Integration secret identifier for the client certificate used with certificate authentication.
-
#forward_metadata ⇒ Boolean?
When ‘true`, Telnyx forwards the assistant’s dynamic variables to the external LLM endpoint as a top-level ‘extra_metadata` object on the chat completion request body.
-
#llm_api_key_ref ⇒ String?
Integration secret identifier for the external LLM API key.
-
#model ⇒ String
Model identifier to use with the external LLM endpoint.
-
#token_retrieval_url ⇒ String?
URL used to retrieve an access token when certificate authentication is enabled.
Instance Method Summary collapse
-
#initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalLlm for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::InferenceEmbedding::FallbackConfig::ExternalLlm for more details.
|
|
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 471
|
Instance Attribute Details
#authentication_method ⇒ Symbol, ...
Authentication method used when connecting to the external LLM endpoint.
437 438 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 437 optional :authentication_method, enum: -> { Telnyx::AI::InferenceEmbedding::FallbackConfig::ExternalLlm::AuthenticationMethod } |
#base_url ⇒ String
Base URL for the external LLM endpoint.
425 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 425 required :base_url, String |
#certificate_ref ⇒ String?
Integration secret identifier for the client certificate used with certificate authentication.
445 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 445 optional :certificate_ref, String |
#forward_metadata ⇒ Boolean?
When ‘true`, Telnyx forwards the assistant’s dynamic variables to the external LLM endpoint as a top-level ‘extra_metadata` object on the chat completion request body. Defaults to `false`. Example payload sent to the external endpoint: `{“customer_name”: “Jane”, “account_id”: “acct_789”, “telnyx_agent_target”: “+13125550100”, “telnyx_end_user_target”: “+13125550123”}`. Distinct from OpenAI’s native ‘metadata` field, which has its own size and type limits.
457 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 457 optional :forward_metadata, Telnyx::Internal::Type::Boolean |
#llm_api_key_ref ⇒ String?
Integration secret identifier for the external LLM API key.
463 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 463 optional :llm_api_key_ref, String |
#model ⇒ String
Model identifier to use with the external LLM endpoint.
431 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 431 required :model, String |
#token_retrieval_url ⇒ String?
URL used to retrieve an access token when certificate authentication is enabled.
469 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 469 optional :token_retrieval_url, String |