Class: Telnyx::Models::AI::InferenceEmbeddingInterruptionSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::InferenceEmbeddingInterruptionSettings
- Defined in:
- lib/telnyx/models/ai/inference_embedding_interruption_settings.rb,
sig/telnyx/models/ai/inference_embedding_interruption_settings.rbs
Instance Attribute Summary collapse
-
#disable_greeting_interruption ⇒ Boolean?
When true, disables user interruptions while the assistant greeting is playing.
-
#enable ⇒ Boolean?
Whether users can interrupt the assistant while it is speaking.
-
#start_speaking_plan ⇒ Telnyx::Models::AI::StartSpeakingPlan?
Controls when the assistant starts speaking after the user stops.
Instance Method Summary collapse
-
#initialize(disable_greeting_interruption: nil, enable: nil, start_speaking_plan: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see InferenceEmbeddingInterruptionSettings for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(disable_greeting_interruption: nil, enable: nil, start_speaking_plan: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::InferenceEmbeddingInterruptionSettings for more details.
Settings for interruptions and how the assistant decides the user has finished
speaking. These timings are most relevant when using non turn-taking
transcription models. For turn-taking models like deepgram/flux, end-of-turn
behavior is controlled by the transcription end-of-turn settings under
transcription.settings (eot_threshold, eot_timeout_ms,
eager_eot_threshold).
|
|
# File 'lib/telnyx/models/ai/inference_embedding_interruption_settings.rb', line 28
|
Instance Attribute Details
#disable_greeting_interruption ⇒ Boolean?
When true, disables user interruptions while the assistant greeting is playing.
11 |
# File 'lib/telnyx/models/ai/inference_embedding_interruption_settings.rb', line 11 optional :disable_greeting_interruption, Telnyx::Internal::Type::Boolean |
#enable ⇒ Boolean?
Whether users can interrupt the assistant while it is speaking.
17 |
# File 'lib/telnyx/models/ai/inference_embedding_interruption_settings.rb', line 17 optional :enable, Telnyx::Internal::Type::Boolean |
#start_speaking_plan ⇒ Telnyx::Models::AI::StartSpeakingPlan?
Controls when the assistant starts speaking after the user stops. These
thresholds primarily apply to non turn-taking transcription models. For
turn-taking models like deepgram/flux, end-of-turn detection is driven by the
transcription end-of-turn settings under transcription.settings instead.
26 |
# File 'lib/telnyx/models/ai/inference_embedding_interruption_settings.rb', line 26 optional :start_speaking_plan, -> { Telnyx::AI::StartSpeakingPlan } |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/telnyx/models/ai/inference_embedding_interruption_settings.rbs', line 32
def to_hash: -> {
|