Class: Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::Header

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb,
sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeHeader

Returns a new instance of Header.

Parameters:

  • name: (String)
  • value: (String)


192
# File 'sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs', line 192

def initialize: (?name: String, ?value: String) -> void

Instance Attribute Details

#nameString?

Parameters:

  • (String)

Returns:

  • (String, nil)


206
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 206

optional :name, String

#valueString?

The value of the header. Note that we support mustache templating for the value. For example you can use Bearer {{#integration_secret}}test-secret{{/integration_secret}} to pass the value of the integration secret as the bearer token. Telnyx signature headers will be automatically added to the request.

Parameters:

  • (String)

Returns:

  • (String, nil)


217
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 217

optional :value, String

Instance Method Details

#to_hash{ name: String, value: String }

Returns:

  • ({ name: String, value: String })


194
# File 'sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs', line 194

def to_hash: -> { name: String, value: String }