Class: Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::Message::WebhookToolRequestResponseDelayedMessage

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb,
sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



252
# File 'sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs', line 252

def initialize: (

Instance Attribute Details

#contentString

The text the assistant speaks.

Parameters:

  • value (String)

Returns:

  • (String)


281
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 281

required :content, String

#timing_msInteger

The delay in milliseconds from the start of the webhook request.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


287
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 287

required :timing_ms, Integer

#typeSymbol, :request_response_delayed

Speak the filler message after the configured delay if the webhook response is still pending.

Parameters:

  • value (:request_response_delayed)

Returns:

  • (Symbol, :request_response_delayed)


294
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 294

required :type, const: :request_response_delayed

Instance Method Details

#to_hash{

Returns:

  • ({)


258
# File 'sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs', line 258

def to_hash: -> {