Class: Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::Message::WebhookToolRequestStartMessage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::Message::WebhookToolRequestStartMessage
- Defined in:
- lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb,
sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs
Instance Attribute Summary collapse
-
#content ⇒ String
The text the assistant speaks.
-
#timing_ms ⇒ Integer?
An optional delay value.
-
#type ⇒ Symbol, :request_start
Speak the filler message immediately when the webhook request begins.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
225 |
# File 'sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs', line 225
def initialize: (
|
Instance Attribute Details
#content ⇒ String
The text the assistant speaks.
254 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 254 required :content, String |
#timing_ms ⇒ Integer?
An optional delay value. This value is ignored for request_start messages.
266 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 266 optional :timing_ms, Integer |
#type ⇒ Symbol, :request_start
Speak the filler message immediately when the webhook request begins.
260 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 260 required :type, const: :request_start |
Instance Method Details
#to_hash ⇒ {
231 |
# File 'sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs', line 231
def to_hash: -> {
|