Class: Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::PathParameters

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb

Overview

See Also:

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(properties: nil, required: nil, type: nil) ⇒ Object

The path parameters the webhook tool accepts, described as a JSON Schema object. These parameters will be passed to the webhook as the path of the request if the URL contains a placeholder for a value. See the [JSON Schema reference](json-schema.org/understanding-json-schema) for documentation about the format

Parameters:



# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 255

Instance Attribute Details

#propertiesHash{Symbol=>Object}?

The properties of the path parameters.

Returns:

  • (Hash{Symbol=>Object}, nil)


241
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 241

optional :properties, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#requiredArray<String>?

The required properties of the path parameters.

Returns:

  • (Array<String>, nil)


247
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 247

optional :required, Telnyx::Internal::Type::ArrayOf[String]

#typeSymbol, ...



252
253
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 252

optional :type,
enum: -> { Telnyx::AI::InferenceEmbeddingWebhookToolParams::Webhook::PathParameters::Type }