Class: Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::StoreFieldsAsVariable
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::StoreFieldsAsVariable
- Defined in:
- lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb,
sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the dynamic variable to store the extracted value in.
-
#value_path ⇒ String
A dot-notation path to the value in the webhook response body (e.g. 'customer.name' or 'id').
Instance Method Summary collapse
-
#initialize(name:, value_path:) ⇒ StoreFieldsAsVariable
constructor
Some parameter documentations has been truncated, see StoreFieldsAsVariable for more details.
- #to_hash ⇒ { name: String, value_path: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, value_path:) ⇒ StoreFieldsAsVariable
Some parameter documentations has been truncated, see Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::StoreFieldsAsVariable for more details.
|
|
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 347
|
Instance Attribute Details
#name ⇒ String
The name of the dynamic variable to store the extracted value in.
338 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 338 required :name, String |
#value_path ⇒ String
A dot-notation path to the value in the webhook response body (e.g. 'customer.name' or 'id').
345 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 345 required :value_path, String |
Instance Method Details
#to_hash ⇒ { name: String, value_path: String }
310 |
# File 'sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs', line 310
def to_hash: -> { name: String, value_path: String }
|