Class: Telnyx::Models::AI::MessagingSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/messaging_settings.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(conversation_inactivity_minutes: nil, default_messaging_profile_id: nil, delivery_status_webhook_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::MessagingSettings for more details.

Parameters:

  • conversation_inactivity_minutes (Integer) (defaults to: nil)

    If more than this many minutes have passed since the last message, the assistant

  • default_messaging_profile_id (String) (defaults to: nil)

    Default Messaging Profile used for messaging exchanges with your assistant. This

  • delivery_status_webhook_url (String) (defaults to: nil)

    The URL where webhooks related to delivery statused for assistant messages will



# File 'lib/telnyx/models/ai/messaging_settings.rb', line 28

Instance Attribute Details

#conversation_inactivity_minutesInteger?

If more than this many minutes have passed since the last message, the assistant will start a new conversation instead of continuing the existing one.

Returns:

  • (Integer, nil)


12
# File 'lib/telnyx/models/ai/messaging_settings.rb', line 12

optional :conversation_inactivity_minutes, Integer

#default_messaging_profile_idString?

Default Messaging Profile used for messaging exchanges with your assistant. This will be created automatically on assistant creation.

Returns:

  • (String, nil)


19
# File 'lib/telnyx/models/ai/messaging_settings.rb', line 19

optional :default_messaging_profile_id, String

#delivery_status_webhook_urlString?

The URL where webhooks related to delivery statused for assistant messages will be sent.

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/ai/messaging_settings.rb', line 26

optional :delivery_status_webhook_url, String