Class: Telnyx::Models::AI::OpenAI::EmbeddingCreateEmbeddingsResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/openai/embedding_create_embeddings_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data:, model:, object:, usage:) ⇒ Object

Parameters:



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/telnyx/models/ai/openai/embedding_create_embeddings_response.rb', line 42

class Data < Telnyx::Internal::Type::BaseModel
  # @!attribute embedding
  #   The embedding vector
  #
  #   @return [Array<Float>]
  required :embedding, Telnyx::Internal::Type::ArrayOf[Float]

  # @!attribute index
  #   The index of the embedding in the list of embeddings
  #
  #   @return [Integer]
  required :index, Integer

  # @!attribute object
  #   The object type, always 'embedding'
  #
  #   @return [String]
  required :object, String

  # @!method initialize(embedding:, index:, object:)
  #   @param embedding [Array<Float>] The embedding vector
  #
  #   @param index [Integer] The index of the embedding in the list of embeddings
  #
  #   @param object [String] The object type, always 'embedding'
end

Instance Attribute Details

#embeddingArray<Float>

The embedding vector

Returns:

  • (Array<Float>)


47
# File 'lib/telnyx/models/ai/openai/embedding_create_embeddings_response.rb', line 47

required :embedding, Telnyx::Internal::Type::ArrayOf[Float]

#indexInteger

The index of the embedding in the list of embeddings

Returns:

  • (Integer)


53
# File 'lib/telnyx/models/ai/openai/embedding_create_embeddings_response.rb', line 53

required :index, Integer

#objectString

The object type, always ‘embedding’

Returns:

  • (String)


59
# File 'lib/telnyx/models/ai/openai/embedding_create_embeddings_response.rb', line 59

required :object, String