Class: Telnyx::Models::AI::OpenAICreateResponseParams::Reasoning

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/openai_create_response_params.rb,
sig/telnyx/models/ai/openai_create_response_params.rbs

Defined Under Namespace

Modules: Effort

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(effort: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::OpenAICreateResponseParams::Reasoning for more details.

Parameters:



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/telnyx/models/ai/openai_create_response_params.rb', line 81

class Reasoning < Telnyx::Internal::Type::BaseModel
  # @!attribute effort
  #   Controls the reasoning effort for models that support it. Same values and
  #   semantics as reasoning_effort on Chat Completions.
  #
  #   @return [Symbol, Telnyx::Models::AI::OpenAICreateResponseParams::Reasoning::Effort, nil]
  optional :effort, enum: -> { Telnyx::AI::OpenAICreateResponseParams::Reasoning::Effort }

  # @!method initialize(effort: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::AI::OpenAICreateResponseParams::Reasoning} for more details.
  #
  #   @param effort [Symbol, Telnyx::Models::AI::OpenAICreateResponseParams::Reasoning::Effort] Controls the reasoning effort for models that support it. Same values and semant

  # Controls the reasoning effort for models that support it. Same values and
  # semantics as reasoning_effort on Chat Completions.
  #
  # @see Telnyx::Models::AI::OpenAICreateResponseParams::Reasoning#effort
  module Effort
    extend Telnyx::Internal::Type::Enum

    NONE = :none
    MINIMAL = :minimal
    LOW = :low
    MEDIUM = :medium
    HIGH = :high
    XHIGH = :xhigh
    MAX = :max

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#effortSymbol, ...

Controls the reasoning effort for models that support it. Same values and semantics as reasoning_effort on Chat Completions.



87
# File 'lib/telnyx/models/ai/openai_create_response_params.rb', line 87

optional :effort, enum: -> { Telnyx::AI::OpenAICreateResponseParams::Reasoning::Effort }

Instance Method Details

#to_hash{

Returns:

  • ({)


88
# File 'sig/telnyx/models/ai/openai_create_response_params.rbs', line 88

def to_hash: -> {