Class: Telnyx::Models::AI::PayToolParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/pay_tool_params.rb,
sig/telnyx/models/ai/pay_tool_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(connector_name:, currency: nil, description: nil, payment_method: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::PayToolParams for more details.

Parameters:

  • connector_name (String)

    The name of the pay connector configured in the Telnyx API. Must reference an ex

  • currency (String) (defaults to: nil)

    Default currency for payments processed by this tool.

  • description (String, nil) (defaults to: nil)

    Optional description of the pay tool that will be passed to the assistant.

  • payment_method (String) (defaults to: nil)

    Default payment method for payments processed by this tool.



# File 'lib/telnyx/models/ai/pay_tool_params.rb', line 32

Instance Attribute Details

#connector_nameString

The name of the pay connector configured in the Telnyx API. Must reference an existing pay connector for this organization.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/telnyx/models/ai/pay_tool_params.rb', line 12

required :connector_name, String

#currencyString?

Default currency for payments processed by this tool.

Parameters:

  • (String)

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/ai/pay_tool_params.rb', line 18

optional :currency, String

#descriptionString?

Optional description of the pay tool that will be passed to the assistant.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/ai/pay_tool_params.rb', line 24

optional :description, String, nil?: true

#payment_methodString?

Default payment method for payments processed by this tool.

Parameters:

  • (String)

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/ai/pay_tool_params.rb', line 30

optional :payment_method, String

Instance Method Details

#to_hash{

Returns:

  • ({)


32
# File 'sig/telnyx/models/ai/pay_tool_params.rbs', line 32

def to_hash: -> {