Class: Telnyx::Models::AI::StartSpeakingPlan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::StartSpeakingPlan
- Defined in:
- lib/telnyx/models/ai/start_speaking_plan.rb,
sig/telnyx/models/ai/start_speaking_plan.rbs
Instance Attribute Summary collapse
-
#transcription_endpointing_plan ⇒ Telnyx::Models::AI::TranscriptionEndpointingPlan?
Endpointing thresholds used to decide when the user has finished speaking.
-
#wait_seconds ⇒ Float?
Minimum seconds to wait before the assistant starts speaking.
Instance Method Summary collapse
-
#initialize(transcription_endpointing_plan: nil, wait_seconds: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see StartSpeakingPlan for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transcription_endpointing_plan: nil, wait_seconds: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::StartSpeakingPlan for more details.
Controls when the assistant starts speaking after the user stops. These
thresholds primarily apply to non turn-taking transcription models. For
turn-taking models like deepgram/flux, end-of-turn detection is driven by the
transcription end-of-turn settings under transcription.settings instead.
|
|
# File 'lib/telnyx/models/ai/start_speaking_plan.rb', line 22
|
Instance Attribute Details
#transcription_endpointing_plan ⇒ Telnyx::Models::AI::TranscriptionEndpointingPlan?
Endpointing thresholds used to decide when the user has finished speaking.
Applies to non turn-taking transcription models. For deepgram/flux, use
transcription.settings.eot_threshold / eot_timeout_ms /
eager_eot_threshold.
14 |
# File 'lib/telnyx/models/ai/start_speaking_plan.rb', line 14 optional :transcription_endpointing_plan, -> { Telnyx::AI::TranscriptionEndpointingPlan } |
#wait_seconds ⇒ Float?
Minimum seconds to wait before the assistant starts speaking.
20 |
# File 'lib/telnyx/models/ai/start_speaking_plan.rb', line 20 optional :wait_seconds, Float |
Instance Method Details
#to_hash ⇒ {
26 |
# File 'sig/telnyx/models/ai/start_speaking_plan.rbs', line 26
def to_hash: -> {
|