Class: Telnyx::Models::AI::TelephonySettings::RecordingSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/telephony_settings.rb,
sig/telnyx/models/ai/telephony_settings.rbs

Overview

See Also:

  • Telnyx::Models::AI::TelephonySettings#recording_settings

Defined Under Namespace

Modules: Channels, Format

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channels: nil, enabled: nil, file_format: nil, stop_on_conversation_end: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::TelephonySettings::RecordingSettings for more details.

Configuration for call recording format and channel settings.

Parameters:



# File 'lib/telnyx/models/ai/telephony_settings.rb', line 207

Instance Attribute Details

#channelsSymbol, ...

The number of channels for the recording. 'single' for mono, 'dual' for stereo.



182
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 182

optional :channels, enum: -> { Telnyx::AI::TelephonySettings::RecordingSettings::Channels }

#enabledBoolean?

Whether call recording is enabled. When set to false, calls will not be recorded regardless of other recording configuration.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


189
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 189

optional :enabled, Telnyx::Internal::Type::Boolean

#file_formatSymbol, ...

The format of the recording file.



195
196
197
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 195

optional :file_format,
enum: -> { Telnyx::AI::TelephonySettings::RecordingSettings::Format },
api_name: :format

#stop_on_conversation_endBoolean?

When enabled, the call recording will stop when the conversation ends (for example, when the assistant hangs up or the call is transferred). When disabled, recording continues until the call itself ends.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


205
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 205

optional :stop_on_conversation_end, Telnyx::Internal::Type::Boolean

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ai/telephony_settings.rb', line 230

Instance Method Details

#to_hash{

Returns:

  • ({)


186
# File 'sig/telnyx/models/ai/telephony_settings.rbs', line 186

def to_hash: -> {