Class: Telnyx::Models::AI::TelephonySettings::VoicemailDetection::OnVoicemailDetected::VoicemailMessage

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/telnyx/models/ai/telephony_settings.rb

Overview

See Also:

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(message: nil, prompt: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::TelephonySettings::VoicemailDetection::OnVoicemailDetected::VoicemailMessage for more details.

Configuration for the voicemail message to leave. Only applicable when action is ‘leave_message_and_stop_assistant’.

Parameters:



# File 'lib/telnyx/models/ai/telephony_settings.rb', line 288

Instance Attribute Details

#messageString?

The specific message to leave as voicemail. Only applicable when type is ‘message’.

Returns:

  • (String, nil)


271
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 271

optional :message, String

#promptString?

The prompt to use for generating the voicemail message. Only applicable when type is ‘prompt’.

Returns:

  • (String, nil)


278
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 278

optional :prompt, String

#typeSymbol, ...

The type of voicemail message. Use ‘prompt’ to have the assistant generate a message based on a prompt, or ‘message’ to leave a specific message.



285
286
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 285

optional :type,
enum: -> { Telnyx::AI::TelephonySettings::VoicemailDetection::OnVoicemailDetected::VoicemailMessage::Type }