Class: Telnyx::Models::AI::TranscriptionEndpointingPlan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::TranscriptionEndpointingPlan
- Defined in:
- lib/telnyx/models/ai/transcription_endpointing_plan.rb
Instance Attribute Summary collapse
-
#on_no_punctuation_seconds ⇒ Float?
Seconds to wait after the transcript ends without punctuation.
-
#on_number_seconds ⇒ Float?
Seconds to wait after the transcript ends with a number.
-
#on_punctuation_seconds ⇒ Float?
Seconds to wait after the transcript ends with punctuation.
Instance Method Summary collapse
-
#initialize(on_no_punctuation_seconds: nil, on_number_seconds: nil, on_punctuation_seconds: nil) ⇒ Object
constructor
Endpointing thresholds used to decide when the user has finished speaking.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(on_no_punctuation_seconds: nil, on_number_seconds: nil, on_punctuation_seconds: nil) ⇒ Object
Endpointing thresholds used to decide when the user has finished speaking. Applies to non turn-taking transcription models. For ‘deepgram/flux`, use `transcription.settings.eot_threshold` / `eot_timeout_ms` / `eager_eot_threshold`.
|
|
# File 'lib/telnyx/models/ai/transcription_endpointing_plan.rb', line 25
|
Instance Attribute Details
#on_no_punctuation_seconds ⇒ Float?
Seconds to wait after the transcript ends without punctuation.
11 |
# File 'lib/telnyx/models/ai/transcription_endpointing_plan.rb', line 11 optional :on_no_punctuation_seconds, Float |
#on_number_seconds ⇒ Float?
Seconds to wait after the transcript ends with a number.
17 |
# File 'lib/telnyx/models/ai/transcription_endpointing_plan.rb', line 17 optional :on_number_seconds, Float |
#on_punctuation_seconds ⇒ Float?
Seconds to wait after the transcript ends with punctuation.
23 |
# File 'lib/telnyx/models/ai/transcription_endpointing_plan.rb', line 23 optional :on_punctuation_seconds, Float |