Module: Telnyx::Models::AI::TranscriptionSettings::Model

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/ai/transcription_settings.rb,
sig/telnyx/models/ai/transcription_settings.rbs

Overview

The speech to text model to be used by the voice assistant. All Deepgram models are run on-premise.

  • deepgram/flux is optimized for turn-taking with multilingual language hints.
  • deepgram/nova-3 is multilingual with automatic language detection.
  • deepgram/nova-2 is Deepgram's previous-generation multilingual model.
  • azure/fast is a multilingual Azure transcription model.
  • assemblyai/universal-streaming is a multilingual streaming model with configurable turn detection.
  • xai/grok-stt is a multilingual Grok STT model.
  • soniox/stt-rt-v4 and soniox/stt-rt-v5 are multilingual streaming models with automatic language detection, configurable endpointing, term biasing (context), and language_hints.
  • nvidia/parakeet-v3 is a multilingual transcription model with automatic language detection.
  • humain/realtime is a streaming model with native Arabic and Arabic/English code-switching support.
  • reson8/turns is a turn-based streaming model covering 10 European languages with automatic language detection.
  • cohere/ar-stt is a non-streaming Arabic and English transcription model.

See Also:

  • Telnyx::Models::AI::TranscriptionSettings#model

Constant Summary collapse

DEEPGRAM_FLUX =

Returns:

:"deepgram/flux"
DEEPGRAM_NOVA_3 =

Returns:

:"deepgram/nova-3"
DEEPGRAM_NOVA_2 =

Returns:

:"deepgram/nova-2"
AZURE_FAST =

Returns:

:"azure/fast"
ASSEMBLYAI_UNIVERSAL_STREAMING =

Returns:

:"assemblyai/universal-streaming"
XAI_GROK_STT =

Returns:

:"xai/grok-stt"
SONIOX_STT_RT_V4 =

Returns:

:"soniox/stt-rt-v4"
SONIOX_STT_RT_V5 =

Returns:

:"soniox/stt-rt-v5"
NVIDIA_PARAKEET_V3 =

Returns:

:"nvidia/parakeet-v3"
HUMAIN_REALTIME =

Returns:

:"humain/realtime"
RESON8_TURNS =

Returns:

:"reson8/turns"
COHERE_AR_STT =

Returns:

:"cohere/ar-stt"
DISTIL_WHISPER_DISTIL_LARGE_V2 =

Returns:

:"distil-whisper/distil-large-v2"
OPENAI_WHISPER_LARGE_V3_TURBO =

Returns:

:"openai/whisper-large-v3-turbo"

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/telnyx/models/ai/transcription_settings.rb', line 127


Instance Method Details

#self?.values::Array[Telnyx::Models::AI::TranscriptionSettings::model]

Returns:



88
# File 'sig/telnyx/models/ai/transcription_settings.rbs', line 88

def self?.values: -> ::Array[Telnyx::Models::AI::TranscriptionSettings::model]