Class: Telnyx::Models::AI::TransferTool::Transfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::TransferTool::Transfer
- Defined in:
- lib/telnyx/models/ai/transfer_tool.rb
Overview
Defined Under Namespace
Modules: Targets
Instance Attribute Summary collapse
-
#from ⇒ String
Number or SIP URI placing the call.
-
#targets ⇒ Array<Telnyx::Models::AI::TransferTool::Transfer::Targets::UnionMember0>, String
The different possible targets of the transfer.
Instance Method Summary collapse
-
#initialize(from:, targets:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Transfer for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(from:, targets:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::TransferTool::Transfer for more details.
|
|
# File 'lib/telnyx/models/ai/transfer_tool.rb', line 38
|
Instance Attribute Details
#from ⇒ String
Number or SIP URI placing the call.
27 |
# File 'lib/telnyx/models/ai/transfer_tool.rb', line 27 required :from, String |
#targets ⇒ Array<Telnyx::Models::AI::TransferTool::Transfer::Targets::UnionMember0>, String
The different possible targets of the transfer. The assistant will be able to choose one of the targets to transfer the call to. This can also be a dynamic variable string like ‘targets }` where `targets` is returned by the dynamic variables webhook and resolves to an array of target objects at runtime.
36 |
# File 'lib/telnyx/models/ai/transfer_tool.rb', line 36 required :targets, union: -> { Telnyx::AI::TransferTool::Transfer::Targets } |