Module: Telnyx::Models::AI::TransferTool::Transfer::Targets
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/ai/transfer_tool.rb,
sig/telnyx/models/ai/transfer_tool.rbs
Overview
The different possible targets of the transfer. The assistant will be able to
choose one of the targets to transfer the call to. This can also be a dynamic
variable string like {{ targets }} where targets is returned by the dynamic
variables webhook and resolves to an array of target objects at runtime.
Defined Under Namespace
Classes: TargetsList
Constant Summary collapse
- TargetsListArray =
Telnyx::Internal::Type::ArrayOf[-> { Telnyx::AI::TransferTool::Transfer::Targets::TargetsList }]
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(to:, name: nil) ⇒ Object
- #self?.variants ⇒ ::Array[Telnyx::Models::AI::TransferTool::Transfer::targets]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Array<Telnyx::Models::AI::TransferTool::Transfer::Targets::TargetsList>, String)
|
|
# File 'lib/telnyx/models/ai/transfer_tool.rb', line 79
|
Instance Method Details
#initialize(to:, name: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/ai/transfer_tool.rb', line 73
|
#self?.variants ⇒ ::Array[Telnyx::Models::AI::TransferTool::Transfer::targets]
67 |
# File 'sig/telnyx/models/ai/transfer_tool.rbs', line 67
def self?.variants: -> ::Array[Telnyx::Models::AI::TransferTool::Transfer::targets]
|