Class: Telnyx::Models::AI::UpdateDynamicVariablesToolParams::UpdatableVariable

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/update_dynamic_variables_tool_params.rb,
sig/telnyx/models/ai/update_dynamic_variables_tool_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, description: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::UpdateDynamicVariablesToolParams::UpdatableVariable for more details.

Parameters:

  • name (String)

    The dynamic-variable key to update. Must match ^[a-zA-Z0-9._-]+$ and may not s

  • description (String) (defaults to: nil)

    Optional description of the variable, guiding the assistant on what value to cap

  • type (String) (defaults to: nil)

    Optional hint for the variable's value type (e.g. string).



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/telnyx/models/ai/update_dynamic_variables_tool_params.rb', line 42

class UpdatableVariable < Telnyx::Internal::Type::BaseModel
  # @!attribute name
  #   The dynamic-variable key to update. Must match `^[a-zA-Z0-9._-]+$` and may not
  #   start with the reserved `telnyx_` prefix (reserved for system variables). The
  #   `pattern` encodes both rules via a negative lookahead.
  #
  #   @return [String]
  required :name, String

  # @!attribute description
  #   Optional description of the variable, guiding the assistant on what value to
  #   capture.
  #
  #   @return [String, nil]
  optional :description, String

  # @!attribute type
  #   Optional hint for the variable's value type (e.g. `string`).
  #
  #   @return [String, nil]
  optional :type, String

  # @!method initialize(name:, description: nil, type: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::AI::UpdateDynamicVariablesToolParams::UpdatableVariable} for
  #   more details.
  #
  #   @param name [String] The dynamic-variable key to update. Must match `^[a-zA-Z0-9._-]+$` and may not s
  #
  #   @param description [String] Optional description of the variable, guiding the assistant on what value to cap
  #
  #   @param type [String] Optional hint for the variable's value type (e.g. `string`).
end

Instance Attribute Details

#descriptionString?

Optional description of the variable, guiding the assistant on what value to capture.

Parameters:

  • (String)

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/ai/update_dynamic_variables_tool_params.rb', line 56

optional :description, String

#nameString

The dynamic-variable key to update. Must match ^[a-zA-Z0-9._-]+$ and may not start with the reserved telnyx_ prefix (reserved for system variables). The pattern encodes both rules via a negative lookahead.

Parameters:

  • value (String)

Returns:

  • (String)


49
# File 'lib/telnyx/models/ai/update_dynamic_variables_tool_params.rb', line 49

required :name, String

#typeString?

Optional hint for the variable's value type (e.g. string).

Parameters:

  • (String)

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/ai/update_dynamic_variables_tool_params.rb', line 62

optional :type, String

Instance Method Details

#to_hash{ name: String, description: String, type: String }

Returns:

  • ({ name: String, description: String, type: String })


50
# File 'sig/telnyx/models/ai/update_dynamic_variables_tool_params.rbs', line 50

def to_hash: -> { name: String, description: String, type: String }