Class: Telnyx::Models::AI::VoiceSettings::BackgroundAudio::MediaName

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/voice_settings.rb,
sig/telnyx/models/ai/voice_settings.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeMediaName

Returns a new instance of MediaName.

Parameters:

  • value: (String)
  • type: (:media_name)


157
# File 'sig/telnyx/models/ai/voice_settings.rbs', line 157

def initialize: (value: String, ?type: :media_name) -> void

Instance Attribute Details

#typeSymbol, :media_name

Reference a previously uploaded media by its name from Telnyx Media Storage.

Parameters:

  • value (:media_name)

Returns:

  • (Symbol, :media_name)


212
# File 'lib/telnyx/models/ai/voice_settings.rb', line 212

required :type, const: :media_name

#valueString

The name of a media asset created via Media Storage API. The audio will loop during the call.

Parameters:

  • value (String)

Returns:

  • (String)


220
# File 'lib/telnyx/models/ai/voice_settings.rb', line 220

required :value, String

Instance Method Details

#to_hash{ type: :media_name, value: String }

Returns:

  • ({ type: :media_name, value: String })


159
# File 'sig/telnyx/models/ai/voice_settings.rbs', line 159

def to_hash: -> { type: :media_name, value: String }