Class: Telnyx::Models::AI::WidgetSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::WidgetSettings
- Defined in:
- lib/telnyx/models/ai/widget_settings.rb
Defined Under Namespace
Modules: DefaultState, Position, Theme
Instance Attribute Summary collapse
-
#agent_thinking_text ⇒ String?
Text displayed while the agent is processing.
- #audio_visualizer_config ⇒ Telnyx::Models::AI::AudioVisualizerConfig?
-
#default_state ⇒ Symbol, ...
The default state of the widget.
-
#give_feedback_url ⇒ String?
URL for users to give feedback.
-
#logo_icon_url ⇒ String?
URL to a custom logo icon for the widget.
-
#position ⇒ Symbol, ...
The positioning style for the widget.
-
#report_issue_url ⇒ String?
URL for users to report issues.
-
#speak_to_interrupt_text ⇒ String?
Text prompting users to speak to interrupt.
-
#start_call_text ⇒ String?
Custom text displayed on the start call button.
-
#theme ⇒ Symbol, ...
The visual theme for the widget.
-
#view_history_url ⇒ String?
URL to view conversation history.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(agent_thinking_text: nil, audio_visualizer_config: nil, default_state: nil, give_feedback_url: nil, logo_icon_url: nil, position: nil, report_issue_url: nil, speak_to_interrupt_text: nil, start_call_text: nil, theme: nil, view_history_url: nil) ⇒ Object
constructor
Configuration settings for the assistant’s web widget.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_thinking_text: nil, audio_visualizer_config: nil, default_state: nil, give_feedback_url: nil, logo_icon_url: nil, position: nil, report_issue_url: nil, speak_to_interrupt_text: nil, start_call_text: nil, theme: nil, view_history_url: nil) ⇒ Object
Configuration settings for the assistant’s web widget.
|
|
# File 'lib/telnyx/models/ai/widget_settings.rb', line 72
|
Instance Attribute Details
#agent_thinking_text ⇒ String?
Text displayed while the agent is processing.
11 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 11 optional :agent_thinking_text, String |
#audio_visualizer_config ⇒ Telnyx::Models::AI::AudioVisualizerConfig?
16 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 16 optional :audio_visualizer_config, -> { Telnyx::AI::AudioVisualizerConfig } |
#default_state ⇒ Symbol, ...
The default state of the widget.
22 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 22 optional :default_state, enum: -> { Telnyx::AI::WidgetSettings::DefaultState } |
#give_feedback_url ⇒ String?
URL for users to give feedback.
28 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 28 optional :give_feedback_url, String, nil?: true |
#logo_icon_url ⇒ String?
URL to a custom logo icon for the widget.
34 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 34 optional :logo_icon_url, String, nil?: true |
#position ⇒ Symbol, ...
The positioning style for the widget.
40 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 40 optional :position, enum: -> { Telnyx::AI::WidgetSettings::Position } |
#report_issue_url ⇒ String?
URL for users to report issues.
46 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 46 optional :report_issue_url, String, nil?: true |
#speak_to_interrupt_text ⇒ String?
Text prompting users to speak to interrupt.
52 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 52 optional :speak_to_interrupt_text, String |
#start_call_text ⇒ String?
Custom text displayed on the start call button.
58 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 58 optional :start_call_text, String |
#theme ⇒ Symbol, ...
The visual theme for the widget.
64 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 64 optional :theme, enum: -> { Telnyx::AI::WidgetSettings::Theme } |
#view_history_url ⇒ String?
URL to view conversation history.
70 |
# File 'lib/telnyx/models/ai/widget_settings.rb', line 70 optional :view_history_url, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/widget_settings.rb', line 106
|