Class: Telnyx::Models::AIRetrieveConversationHistoriesParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/ai_retrieve_conversation_histories_params.rb,
sig/telnyx/models/ai_retrieve_conversation_histories_params.rbs

Overview

See Also:

  • Telnyx::Resources::AI#retrieve_conversation_histories

Defined Under Namespace

Modules: Region

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(q:, filter_ingested_at_gte: nil, filter_ingested_at_lte: nil, filter_record_created_at_gte: nil, filter_record_created_at_lte: nil, filter_record_id: nil, filter_region_in: nil, filter_retention: nil, filter_user_id: nil, min_score: nil, page_number: nil, page_size: nil, region: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AIRetrieveConversationHistoriesParams for more details.

Parameters:

  • q (String)

    Natural language search query. The text is embedded into a 1024-dimensional vect

  • filter_ingested_at_gte (Time) (defaults to: nil)

    Only include records ingested (chunked, embedded, and indexed) on or after this

  • filter_ingested_at_lte (Time) (defaults to: nil)

    Only include records ingested (chunked, embedded, and indexed) on or before this

  • filter_record_created_at_gte (Time) (defaults to: nil)

    Only include records whose original creation time is on or after this ISO 8601 t

  • filter_record_created_at_lte (Time) (defaults to: nil)

    Only include records whose original creation time is on or before this ISO 8601

  • filter_record_id (String) (defaults to: nil)

    Filter to chunks belonging to a specific parent record (exact match).

  • filter_region_in (String) (defaults to: nil)

    Filter by the region stored on the record. Comma-separated to match multiple reg

  • filter_retention (String) (defaults to: nil)

    Filter by retention policy (exact match). Filter-only: not returned in the respo

  • filter_user_id (String) (defaults to: nil)

    Filter to records owned by a specific user (exact match).

  • min_score (Float) (defaults to: nil)

    Minimum cosine similarity score threshold (0.0 to 1.0). Results below this thres

  • page_number (Integer) (defaults to: nil)

    Page number to return (1-based). Defaults to 1.

  • page_size (Integer) (defaults to: nil)

    Number of results per page. Defaults to 20, maximum 100.

  • region (Symbol, Telnyx::Models::AIRetrieveConversationHistoriesParams::Region) (defaults to: nil)

    Restrict search to a specific region. When omitted, all regions are queried in p

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 98

Instance Attribute Details

#filter_ingested_at_gteTime?

Only include records ingested (chunked, embedded, and indexed) on or after this ISO 8601 timestamp.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


22
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 22

optional :filter_ingested_at_gte, Time

#filter_ingested_at_lteTime?

Only include records ingested (chunked, embedded, and indexed) on or before this ISO 8601 timestamp.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


29
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 29

optional :filter_ingested_at_lte, Time

#filter_record_created_at_gteTime?

Only include records whose original creation time is on or after this ISO 8601 timestamp.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


36
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 36

optional :filter_record_created_at_gte, Time

#filter_record_created_at_lteTime?

Only include records whose original creation time is on or before this ISO 8601 timestamp.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


43
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 43

optional :filter_record_created_at_lte, Time

#filter_record_idString?

Filter to chunks belonging to a specific parent record (exact match).

Parameters:

  • (String)

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 49

optional :filter_record_id, String

#filter_region_inString?

Filter by the region stored on the record. Comma-separated to match multiple regions (USA, DEU, AUS, UAE). Distinct from the region parameter, which selects which cluster(s) are queried.

Parameters:

  • (String)

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 57

optional :filter_region_in, String

#filter_retentionString?

Filter by retention policy (exact match). Filter-only: not returned in the response body.

Parameters:

  • (String)

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 64

optional :filter_retention, String

#filter_user_idString?

Filter to records owned by a specific user (exact match).

Parameters:

  • (String)

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 70

optional :filter_user_id, String

#min_scoreFloat?

Minimum cosine similarity score threshold (0.0 to 1.0). Results below this threshold are excluded.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


77
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 77

optional :min_score, Float

#page_numberInteger?

Page number to return (1-based). Defaults to 1.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


83
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 83

optional :page_number, Integer

#page_sizeInteger?

Number of results per page. Defaults to 20, maximum 100.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


89
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 89

optional :page_size, Integer

#qString

Natural language search query. The text is embedded into a 1024-dimensional vector and compared against indexed record chunks using semantic similarity.

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 15

required :q, String

#regionSymbol, ...

Restrict search to a specific region. When omitted, all regions are queried in parallel (fan-out) and results are merged by similarity score.



96
# File 'lib/telnyx/models/ai_retrieve_conversation_histories_params.rb', line 96

optional :region, enum: -> { Telnyx::AIRetrieveConversationHistoriesParams::Region }

Instance Method Details

#to_hash{

Returns:

  • ({)


94
# File 'sig/telnyx/models/ai_retrieve_conversation_histories_params.rbs', line 94

def to_hash: -> {