Class: Telnyx::Models::AISearchConversationHistoriesParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/ai_search_conversation_histories_params.rb

Overview

Defined Under Namespace

Modules: RecordType, Region

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(q:, record_type:, filter_document_id: nil, filter_ingested_at_gte: nil, filter_ingested_at_lte: nil, filter_record_created_at_gte: nil, filter_record_created_at_lte: nil, filter_record_id: nil, filter_region_in: nil, filter_retention: nil, filter_user_id: nil, min_score: nil, region: nil, top_k: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AISearchConversationHistoriesParams for more details.

Parameters:

  • q (String)

    Natural language search query. The text is embedded into a 1024-dimensional vect

  • record_type (Symbol, Telnyx::Models::AISearchConversationHistoriesParams::RecordType)

    The type of records to search. Each record type is stored in a separate vector i

  • filter_document_id (String) (defaults to: nil)

    Filter by document identifier (exact match). Populated for knowledge_base record

  • filter_ingested_at_gte (Time) (defaults to: nil)

    Only include records ingested (chunked, embedded, and indexed) on or after this

  • filter_ingested_at_lte (Time) (defaults to: nil)

    Only include records ingested (chunked, embedded, and indexed) on or before this

  • filter_record_created_at_gte (Time) (defaults to: nil)

    Only include records whose original creation time is on or after this ISO 8601 t

  • filter_record_created_at_lte (Time) (defaults to: nil)

    Only include records whose original creation time is on or before this ISO 8601

  • filter_record_id (String) (defaults to: nil)

    Filter to chunks belonging to a specific parent record (exact match).

  • filter_region_in (String) (defaults to: nil)

    Filter by the region stored on the record. Comma-separated to match multiple reg

  • filter_retention (String) (defaults to: nil)

    Filter by retention policy (exact match). Filter-only: not returned in the respo

  • filter_user_id (String) (defaults to: nil)

    Filter to records owned by a specific user (exact match).

  • min_score (Float) (defaults to: nil)

    Minimum cosine similarity score threshold (0.0 to 1.0). Results below this thres

  • region (Symbol, Telnyx::Models::AISearchConversationHistoriesParams::Region) (defaults to: nil)

    Restrict search to a specific region’s OpenSearch cluster. When omitted, all reg

  • top_k (Integer) (defaults to: nil)

    Maximum number of results to return. Defaults to 20, maximum 100.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 107

Instance Attribute Details

#filter_document_idString?

Filter by document identifier (exact match). Populated for knowledge_base records.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 29

optional :filter_document_id, String

#filter_ingested_at_gteTime?

Only include records ingested (chunked, embedded, and indexed) on or after this ISO 8601 timestamp.

Returns:

  • (Time, nil)


36
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 36

optional :filter_ingested_at_gte, Time

#filter_ingested_at_lteTime?

Only include records ingested (chunked, embedded, and indexed) on or before this ISO 8601 timestamp.

Returns:

  • (Time, nil)


43
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 43

optional :filter_ingested_at_lte, Time

#filter_record_created_at_gteTime?

Only include records whose original creation time is on or after this ISO 8601 timestamp.

Returns:

  • (Time, nil)


50
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 50

optional :filter_record_created_at_gte, Time

#filter_record_created_at_lteTime?

Only include records whose original creation time is on or before this ISO 8601 timestamp.

Returns:

  • (Time, nil)


57
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 57

optional :filter_record_created_at_lte, Time

#filter_record_idString?

Filter to chunks belonging to a specific parent record (exact match).

Returns:

  • (String, nil)


63
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 63

optional :filter_record_id, String

#filter_region_inString?

Filter by the region stored on the record. Comma-separated to match multiple regions (USA, DEU, AUS, UAE). Distinct from the ‘region` parameter, which selects which cluster(s) are queried.

Returns:

  • (String, nil)


71
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 71

optional :filter_region_in, String

#filter_retentionString?

Filter by retention policy (exact match). Filter-only: not returned in the response body.

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 78

optional :filter_retention, String

#filter_user_idString?

Filter to records owned by a specific user (exact match).

Returns:

  • (String, nil)


84
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 84

optional :filter_user_id, String

#min_scoreFloat?

Minimum cosine similarity score threshold (0.0 to 1.0). Results below this threshold are excluded.

Returns:

  • (Float, nil)


91
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 91

optional :min_score, Float

#qString

Natural language search query. The text is embedded into a 1024-dimensional vector and compared against indexed record chunks using kNN cosine similarity.

Returns:

  • (String)


15
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 15

required :q, String

#record_typeSymbol, Telnyx::Models::AISearchConversationHistoriesParams::RecordType

The type of records to search. Each record type is stored in a separate vector index.



22
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 22

required :record_type, enum: -> { Telnyx::AISearchConversationHistoriesParams::RecordType }

#regionSymbol, ...

Restrict search to a specific region’s OpenSearch cluster. When omitted, all regions are queried in parallel (fan-out) and results are merged by cosine similarity score.



99
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 99

optional :region, enum: -> { Telnyx::AISearchConversationHistoriesParams::Region }

#top_kInteger?

Maximum number of results to return. Defaults to 20, maximum 100.

Returns:

  • (Integer, nil)


105
# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 105

optional :top_k, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ai_search_conversation_histories_params.rb', line 151