Class: Telnyx::Models::Actions::PurchaseCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/actions/purchase_create_params.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, product: nil, sim_card_group_id: nil, status: nil, tags: nil, whitelabel_name: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Actions::PurchaseCreateParams for more details.

Parameters:

  • amount (Integer)

    The amount of eSIMs to be purchased.

  • product (String) (defaults to: nil)

    Type of product to be purchased, specify “whitelabel” to use a custom SPN

  • sim_card_group_id (String) (defaults to: nil)

    The group SIMCardGroup identification. This attribute can be null w

  • status (Symbol, Telnyx::Models::Actions::PurchaseCreateParams::Status) (defaults to: nil)

    Status on which the SIM cards will be set after being successfully registered.

  • tags (Array<String>) (defaults to: nil)

    Searchable tags associated with the SIM cards

  • whitelabel_name (String) (defaults to: nil)

    Service Provider Name (SPN) for the Whitelabel eSIM product. It will be displaye

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 50

Instance Attribute Details

#amountInteger

The amount of eSIMs to be purchased.

Returns:

  • (Integer)


15
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 15

required :amount, Integer

#productString?

Type of product to be purchased, specify “whitelabel” to use a custom SPN

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 21

optional :product, String

#sim_card_group_idString?

The group SIMCardGroup identification. This attribute can be null when it’s present in an associated resource.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 28

optional :sim_card_group_id, String

#statusSymbol, ...

Status on which the SIM cards will be set after being successfully registered.



34
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 34

optional :status, enum: -> { Telnyx::Actions::PurchaseCreateParams::Status }

#tagsArray<String>?

Searchable tags associated with the SIM cards

Returns:

  • (Array<String>, nil)


40
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 40

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#whitelabel_nameString?

Service Provider Name (SPN) for the Whitelabel eSIM product. It will be displayed as the mobile service name by operating systems of smartphones. This parameter must only contain letters, numbers and whitespaces.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 48

optional :whitelabel_name, String