Class: Telnyx::Models::Address

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/address.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, address_book: nil, administrative_area: nil, borough: nil, business_name: nil, country_code: nil, created_at: nil, customer_reference: nil, extended_address: nil, first_name: nil, last_name: nil, locality: nil, neighborhood: nil, phone_number: nil, postal_code: nil, record_type: nil, street_address: nil, updated_at: nil, validate_address: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Address for more details.

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the address.

  • address_book (Boolean) (defaults to: nil)

    Indicates whether or not the address should be considered part of your list of a

  • administrative_area (String) (defaults to: nil)

    The locality of the address. For US addresses, this corresponds to the state of

  • borough (String) (defaults to: nil)

    The borough of the address. This field is not used for addresses in the US but i

  • business_name (String) (defaults to: nil)

    The business name associated with the address. An address must have either a fir

  • country_code (String) (defaults to: nil)

    The two-character (ISO 3166-1 alpha-2) country code of the address.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • extended_address (String) (defaults to: nil)

    Additional street address information about the address such as, but not limited

  • first_name (String) (defaults to: nil)

    The first name associated with the address. An address must have either a first

  • last_name (String) (defaults to: nil)

    The last name associated with the address. An address must have either a first l

  • locality (String) (defaults to: nil)

    The locality of the address. For US addresses, this corresponds to the city of t

  • neighborhood (String) (defaults to: nil)

    The neighborhood of the address. This field is not used for addresses in the US

  • phone_number (String) (defaults to: nil)

    The phone number associated with the address.

  • postal_code (String) (defaults to: nil)

    The postal code of the address.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • street_address (String) (defaults to: nil)

    The primary street address information about the address.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.

  • validate_address (Boolean) (defaults to: nil)

    Indicates whether or not the address should be validated for emergency use upon



# File 'lib/telnyx/models/address.rb', line 135

Instance Attribute Details

#address_bookBoolean?

Indicates whether or not the address should be considered part of your list of addresses that appear for regular use.

Returns:

  • (Boolean, nil)


18
# File 'lib/telnyx/models/address.rb', line 18

optional :address_book, Telnyx::Internal::Type::Boolean

#administrative_areaString?

The locality of the address. For US addresses, this corresponds to the state of the address.

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/address.rb', line 25

optional :administrative_area, String

#boroughString?

The borough of the address. This field is not used for addresses in the US but is used for some international addresses.

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/address.rb', line 32

optional :borough, String

#business_nameString?

The business name associated with the address. An address must have either a first last name or a business name.

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/address.rb', line 39

optional :business_name, String

#country_codeString?

The two-character (ISO 3166-1 alpha-2) country code of the address.

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/address.rb', line 45

optional :country_code, String

#created_atString?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/address.rb', line 51

optional :created_at, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/address.rb', line 57

optional :customer_reference, String

#extended_addressString?

Additional street address information about the address such as, but not limited to, unit number or apartment number.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/address.rb', line 64

optional :extended_address, String

#first_nameString?

The first name associated with the address. An address must have either a first last name or a business name.

Returns:

  • (String, nil)


71
# File 'lib/telnyx/models/address.rb', line 71

optional :first_name, String

#idString?

Uniquely identifies the address.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/address.rb', line 11

optional :id, String

#last_nameString?

The last name associated with the address. An address must have either a first last name or a business name.

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/address.rb', line 78

optional :last_name, String

#localityString?

The locality of the address. For US addresses, this corresponds to the city of the address.

Returns:

  • (String, nil)


85
# File 'lib/telnyx/models/address.rb', line 85

optional :locality, String

#neighborhoodString?

The neighborhood of the address. This field is not used for addresses in the US but is used for some international addresses.

Returns:

  • (String, nil)


92
# File 'lib/telnyx/models/address.rb', line 92

optional :neighborhood, String

#phone_numberString?

The phone number associated with the address.

Returns:

  • (String, nil)


98
# File 'lib/telnyx/models/address.rb', line 98

optional :phone_number, String

#postal_codeString?

The postal code of the address.

Returns:

  • (String, nil)


104
# File 'lib/telnyx/models/address.rb', line 104

optional :postal_code, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


110
# File 'lib/telnyx/models/address.rb', line 110

optional :record_type, String

#street_addressString?

The primary street address information about the address.

Returns:

  • (String, nil)


116
# File 'lib/telnyx/models/address.rb', line 116

optional :street_address, String

#updated_atString?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (String, nil)


122
# File 'lib/telnyx/models/address.rb', line 122

optional :updated_at, String

#validate_addressBoolean?

Indicates whether or not the address should be validated for emergency use upon creation or not. This should be left with the default value of ‘true` unless you have used the `/addresses/actions/validate` endpoint to validate the address separately prior to creation. If an address is not validated for emergency use upon creation and it is not valid, it will not be able to be used for emergency services.

Returns:

  • (Boolean, nil)


133
# File 'lib/telnyx/models/address.rb', line 133

optional :validate_address, Telnyx::Internal::Type::Boolean