Class: Telnyx::Models::AddressCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/address_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(business_name:, country_code:, first_name:, last_name:, locality:, street_address:, address_book: nil, administrative_area: nil, borough: nil, customer_reference: nil, extended_address: nil, neighborhood: nil, phone_number: nil, postal_code: nil, validate_address: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AddressCreateParams for more details.

Parameters:

  • business_name (String)

    The business name associated with the address. An address must have either a fir

  • country_code (String)

    The two-character (ISO 3166-1 alpha-2) country code of the address.

  • first_name (String)

    The first name associated with the address. An address must have either a first

  • last_name (String)

    The last name associated with the address. An address must have either a first l

  • locality (String)

    The locality of the address. For US addresses, this corresponds to the city of t

  • street_address (String)

    The primary street address information about the address.

  • address_book (Boolean) (defaults to: nil)

    Indicates whether or not the address should be considered part of your list of a

  • administrative_area (String) (defaults to: nil)

    The locality of the address. For US addresses, this corresponds to the state of

  • borough (String) (defaults to: nil)

    The borough of the address. This field is not used for addresses in the US but i

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • extended_address (String) (defaults to: nil)

    Additional street address information about the address such as, but not limited

  • neighborhood (String) (defaults to: nil)

    The neighborhood of the address. This field is not used for addresses in the US

  • phone_number (String) (defaults to: nil)

    The phone number associated with the address.

  • postal_code (String) (defaults to: nil)

    The postal code of the address.

  • validate_address (Boolean) (defaults to: nil)

    Indicates whether or not the address should be validated for emergency use upon

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/address_create_params.rb', line 114

Instance Attribute Details

#address_bookBoolean?

Indicates whether or not the address should be considered part of your list of addresses that appear for regular use.

Returns:

  • (Boolean, nil)


55
# File 'lib/telnyx/models/address_create_params.rb', line 55

optional :address_book, Telnyx::Internal::Type::Boolean

#administrative_areaString?

The locality of the address. For US addresses, this corresponds to the state of the address.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/address_create_params.rb', line 62

optional :administrative_area, String

#boroughString?

The borough of the address. This field is not used for addresses in the US but is used for some international addresses.

Returns:

  • (String, nil)


69
# File 'lib/telnyx/models/address_create_params.rb', line 69

optional :borough, String

#business_nameString

The business name associated with the address. An address must have either a first last name or a business name.

Returns:

  • (String)


15
# File 'lib/telnyx/models/address_create_params.rb', line 15

required :business_name, String

#country_codeString

The two-character (ISO 3166-1 alpha-2) country code of the address.

Returns:

  • (String)


21
# File 'lib/telnyx/models/address_create_params.rb', line 21

required :country_code, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


75
# File 'lib/telnyx/models/address_create_params.rb', line 75

optional :customer_reference, String

#extended_addressString?

Additional street address information about the address such as, but not limited to, unit number or apartment number.

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/address_create_params.rb', line 82

optional :extended_address, String

#first_nameString

The first name associated with the address. An address must have either a first last name or a business name.

Returns:

  • (String)


28
# File 'lib/telnyx/models/address_create_params.rb', line 28

required :first_name, String

#last_nameString

The last name associated with the address. An address must have either a first last name or a business name.

Returns:

  • (String)


35
# File 'lib/telnyx/models/address_create_params.rb', line 35

required :last_name, String

#localityString

The locality of the address. For US addresses, this corresponds to the city of the address.

Returns:

  • (String)


42
# File 'lib/telnyx/models/address_create_params.rb', line 42

required :locality, String

#neighborhoodString?

The neighborhood of the address. This field is not used for addresses in the US but is used for some international addresses.

Returns:

  • (String, nil)


89
# File 'lib/telnyx/models/address_create_params.rb', line 89

optional :neighborhood, String

#phone_numberString?

The phone number associated with the address.

Returns:

  • (String, nil)


95
# File 'lib/telnyx/models/address_create_params.rb', line 95

optional :phone_number, String

#postal_codeString?

The postal code of the address.

Returns:

  • (String, nil)


101
# File 'lib/telnyx/models/address_create_params.rb', line 101

optional :postal_code, String

#street_addressString

The primary street address information about the address.

Returns:

  • (String)


48
# File 'lib/telnyx/models/address_create_params.rb', line 48

required :street_address, String

#validate_addressBoolean?

Indicates whether or not the address should be validated for emergency use upon creation or not. This should be left with the default value of ‘true` unless you have used the `/addresses/actions/validate` endpoint to validate the address separately prior to creation. If an address is not validated for emergency use upon creation and it is not valid, it will not be able to be used for emergency services.

Returns:

  • (Boolean, nil)


112
# File 'lib/telnyx/models/address_create_params.rb', line 112

optional :validate_address, Telnyx::Internal::Type::Boolean