Class: Telnyx::Models::AddressListParams::Filter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/address_list_params.rb,
sig/telnyx/models/address_list_params.rbs

Defined Under Namespace

Modules: CustomerReference Classes: AddressBook, StreetAddress

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(contains: nil, eq: nil) ⇒ Object

Parameters:

  • contains (String) (defaults to: nil)

    Partial match for customer_reference. Matching is not case-sensitive.

  • eq (String) (defaults to: nil)

    Exact match for customer_reference.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/telnyx/models/address_list_params.rb', line 62

class Filter < Telnyx::Internal::Type::BaseModel
  # @!attribute address_book
  #
  #   @return [Telnyx::Models::AddressListParams::Filter::AddressBook, nil]
  optional :address_book, -> { Telnyx::AddressListParams::Filter::AddressBook }

  # @!attribute customer_reference
  #   If present, addresses with <code>customer_reference</code> containing the given
  #   value will be returned. Matching is not case-sensitive.
  #
  #   @return [String, Telnyx::Models::AddressListParams::Filter::CustomerReference::CustomerReferenceMatcher, nil]
  optional :customer_reference, union: -> { Telnyx::AddressListParams::Filter::CustomerReference }

  # @!attribute street_address
  #
  #   @return [Telnyx::Models::AddressListParams::Filter::StreetAddress, nil]
  optional :street_address, -> { Telnyx::AddressListParams::Filter::StreetAddress }

  # @!attribute used_as_emergency
  #   If set as 'true', only addresses used as the emergency address for at least one
  #   active phone-number will be returned. When set to 'false', the opposite happens:
  #   only addresses not used as the emergency address from phone-numbers will be
  #   returned.
  #
  #   @return [String, nil]
  optional :used_as_emergency, String

  # @!method initialize(address_book: nil, customer_reference: nil, street_address: nil, used_as_emergency: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::AddressListParams::Filter} for more details.
  #
  #   Consolidated filter parameter (deepObject style). Originally:
  #   filter[customer_reference][eq], filter[customer_reference][contains],
  #   filter[used_as_emergency], filter[street_address][contains],
  #   filter[address_book][eq]
  #
  #   @param address_book [Telnyx::Models::AddressListParams::Filter::AddressBook]
  #
  #   @param customer_reference [String, Telnyx::Models::AddressListParams::Filter::CustomerReference::CustomerReferenceMatcher] If present, addresses with <code>customer_reference</code> containing the given
  #
  #   @param street_address [Telnyx::Models::AddressListParams::Filter::StreetAddress]
  #
  #   @param used_as_emergency [String] If set as 'true', only addresses used as the emergency address for at least one

  # @see Telnyx::Models::AddressListParams::Filter#address_book
  class AddressBook < Telnyx::Internal::Type::BaseModel
    # @!attribute eq
    #   If present, only returns results with the <code>address_book</code> flag equal
    #   to the given value.
    #
    #   @return [String, nil]
    optional :eq, String

    # @!method initialize(eq: nil)
    #   Some parameter documentations has been truncated, see
    #   {Telnyx::Models::AddressListParams::Filter::AddressBook} for more details.
    #
    #   @param eq [String] If present, only returns results with the <code>address_book</code> flag equal t
  end

  # If present, addresses with <code>customer_reference</code> containing the given
  # value will be returned. Matching is not case-sensitive.
  #
  # @see Telnyx::Models::AddressListParams::Filter#customer_reference
  module CustomerReference
    extend Telnyx::Internal::Type::Union

    # If present, addresses with <code>customer_reference</code> containing the given value will be returned. Matching is not case-sensitive.
    variant String

    variant -> { Telnyx::AddressListParams::Filter::CustomerReference::CustomerReferenceMatcher }

    class CustomerReferenceMatcher < Telnyx::Internal::Type::BaseModel
      # @!attribute contains
      #   Partial match for customer_reference. Matching is not case-sensitive.
      #
      #   @return [String, nil]
      optional :contains, String

      # @!attribute eq
      #   Exact match for customer_reference.
      #
      #   @return [String, nil]
      optional :eq, String

      # @!method initialize(contains: nil, eq: nil)
      #   @param contains [String] Partial match for customer_reference. Matching is not case-sensitive.
      #
      #   @param eq [String] Exact match for customer_reference.
    end

    # @!method self.variants
    #   @return [Array(String, Telnyx::Models::AddressListParams::Filter::CustomerReference::CustomerReferenceMatcher)]
  end

  # @see Telnyx::Models::AddressListParams::Filter#street_address
  class StreetAddress < Telnyx::Internal::Type::BaseModel
    # @!attribute contains
    #   If present, addresses with <code>street_address</code> containing the given
    #   value will be returned. Matching is not case-sensitive. Requires at least three
    #   characters.
    #
    #   @return [String, nil]
    optional :contains, String

    # @!method initialize(contains: nil)
    #   Some parameter documentations has been truncated, see
    #   {Telnyx::Models::AddressListParams::Filter::StreetAddress} for more details.
    #
    #   @param contains [String] If present, addresses with <code>street_address</code> containing the given valu
  end
end

Instance Attribute Details

#address_bookTelnyx::Models::AddressListParams::Filter::AddressBook?



66
# File 'lib/telnyx/models/address_list_params.rb', line 66

optional :address_book, -> { Telnyx::AddressListParams::Filter::AddressBook }

#customer_referenceString, ...

If present, addresses with customer_reference containing the given value will be returned. Matching is not case-sensitive.



73
# File 'lib/telnyx/models/address_list_params.rb', line 73

optional :customer_reference, union: -> { Telnyx::AddressListParams::Filter::CustomerReference }

#street_addressTelnyx::Models::AddressListParams::Filter::StreetAddress?



78
# File 'lib/telnyx/models/address_list_params.rb', line 78

optional :street_address, -> { Telnyx::AddressListParams::Filter::StreetAddress }

#used_as_emergencyString?

If set as 'true', only addresses used as the emergency address for at least one active phone-number will be returned. When set to 'false', the opposite happens: only addresses not used as the emergency address from phone-numbers will be returned.

Parameters:

  • (String)

Returns:

  • (String, nil)


87
# File 'lib/telnyx/models/address_list_params.rb', line 87

optional :used_as_emergency, String

Class Method Details

.variantsArray(String, Telnyx::Models::AddressListParams::Filter::CustomerReference::CustomerReferenceMatcher)



# File 'lib/telnyx/models/address_list_params.rb', line 153


Instance Method Details

#to_hash{

Returns:

  • ({)


90
# File 'sig/telnyx/models/address_list_params.rbs', line 90

def to_hash: -> {