Class: Telnyx::Models::Addresses::ActionValidateResponse::Data::Suggested

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/addresses/action_validate_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(administrative_area: nil, country_code: nil, extended_address: nil, locality: nil, postal_code: nil, street_address: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Addresses::ActionValidateResponse::Data::Suggested for more details.

Provides normalized address when available.

Parameters:

  • administrative_area (String) (defaults to: nil)

    The locality of the address. For US addresses, this corresponds to the state of

  • country_code (String) (defaults to: nil)

    The two-character (ISO 3166-1 alpha-2) country code of the address.

  • extended_address (String) (defaults to: nil)

    Additional street address information about the address such as, but not limited

  • locality (String) (defaults to: nil)

    The locality of the address. For US addresses, this corresponds to the city of t

  • postal_code (String) (defaults to: nil)

    The postal code of the address.

  • street_address (String) (defaults to: nil)

    The primary street address information about the address.



# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 104

Instance Attribute Details

#administrative_areaString?

The locality of the address. For US addresses, this corresponds to the state of the address.

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 70

optional :administrative_area, String

#country_codeString?

The two-character (ISO 3166-1 alpha-2) country code of the address.

Returns:

  • (String, nil)


76
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 76

optional :country_code, String

#extended_addressString?

Additional street address information about the address such as, but not limited to, unit number or apartment number.

Returns:

  • (String, nil)


83
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 83

optional :extended_address, String

#localityString?

The locality of the address. For US addresses, this corresponds to the city of the address.

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 90

optional :locality, String

#postal_codeString?

The postal code of the address.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 96

optional :postal_code, String

#street_addressString?

The primary street address information about the address.

Returns:

  • (String, nil)


102
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 102

optional :street_address, String