Class: Telnyx::Models::AdvancedOrderRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AdvancedOrderRetrieveResponse
- Defined in:
- lib/telnyx/models/advanced_order_retrieve_response.rb
Overview
Defined Under Namespace
Modules: Feature, PhoneNumberType, Status
Instance Attribute Summary collapse
- #area_code ⇒ String?
- #comments ⇒ String?
- #country_code ⇒ String?
- #customer_reference ⇒ String?
- #features ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderRetrieveResponse::Feature>?
- #id ⇒ String?
- #orders ⇒ Array<String>?
- #phone_number_type ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderRetrieveResponse::PhoneNumberType>?
- #quantity ⇒ Integer?
-
#requirement_group_id ⇒ String?
The ID of the requirement group associated with this advanced order.
- #status ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderRetrieveResponse::Status>?
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#area_code ⇒ String?
15 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 15 optional :area_code, String |
#comments ⇒ String?
20 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 20 optional :comments, String |
#country_code ⇒ String?
25 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 25 optional :country_code, String |
#customer_reference ⇒ String?
30 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 30 optional :customer_reference, String |
#features ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderRetrieveResponse::Feature>?
35 36 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 35 optional :features, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::AdvancedOrderRetrieveResponse::Feature] } |
#id ⇒ String?
10 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 10 optional :id, String |
#orders ⇒ Array<String>?
41 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 41 optional :orders, Telnyx::Internal::Type::ArrayOf[String] |
#phone_number_type ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderRetrieveResponse::PhoneNumberType>?
46 47 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 46 optional :phone_number_type, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::AdvancedOrderRetrieveResponse::PhoneNumberType] } |
#quantity ⇒ Integer?
52 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 52 optional :quantity, Integer |
#requirement_group_id ⇒ String?
The ID of the requirement group associated with this advanced order
58 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 58 optional :requirement_group_id, String |
#status ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderRetrieveResponse::Status>?
63 64 |
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 63 optional :status, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::AdvancedOrderRetrieveResponse::Status] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/advanced_order_retrieve_response.rb', line 98
|