Class: Telnyx::Models::AdvancedOrderUpdateRequirementGroupParams
- Inherits:
-
AdvancedOrderRequest
- Object
- Internal::Type::BaseModel
- AdvancedOrderRequest
- Telnyx::Models::AdvancedOrderUpdateRequirementGroupParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/advanced_order_update_requirement_group_params.rb
Overview
Defined Under Namespace
Modules: Feature, PhoneNumberType
Instance Attribute Summary collapse
- #advanced_order_id ⇒ String
- #area_code ⇒ String?
- #comments ⇒ String?
- #country_code ⇒ String?
- #customer_reference ⇒ String?
- #features ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderUpdateRequirementGroupParams::Feature>?
- #phone_number_type ⇒ Symbol, ...
- #quantity ⇒ Integer?
-
#requirement_group_id ⇒ String?
The ID of the requirement group to associate with this advanced order.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#advanced_order_id ⇒ String
13 |
# File 'lib/telnyx/models/advanced_order_update_requirement_group_params.rb', line 13 required :advanced_order_id, String |
#area_code ⇒ String?
18 |
# File 'lib/telnyx/models/advanced_order_update_requirement_group_params.rb', line 18 optional :area_code, String |
#comments ⇒ String?
23 |
# File 'lib/telnyx/models/advanced_order_update_requirement_group_params.rb', line 23 optional :comments, String |
#country_code ⇒ String?
28 |
# File 'lib/telnyx/models/advanced_order_update_requirement_group_params.rb', line 28 optional :country_code, String |
#customer_reference ⇒ String?
33 |
# File 'lib/telnyx/models/advanced_order_update_requirement_group_params.rb', line 33 optional :customer_reference, String |
#features ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderUpdateRequirementGroupParams::Feature>?
38 39 |
# File 'lib/telnyx/models/advanced_order_update_requirement_group_params.rb', line 38 optional :features, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::AdvancedOrderUpdateRequirementGroupParams::Feature] } |
#phone_number_type ⇒ Symbol, ...
44 45 |
# File 'lib/telnyx/models/advanced_order_update_requirement_group_params.rb', line 44 optional :phone_number_type, enum: -> { Telnyx::AdvancedOrderUpdateRequirementGroupParams::PhoneNumberType } |
#quantity ⇒ Integer?
50 |
# File 'lib/telnyx/models/advanced_order_update_requirement_group_params.rb', line 50 optional :quantity, Integer |
#requirement_group_id ⇒ String?
The ID of the requirement group to associate with this advanced order
56 |
# File 'lib/telnyx/models/advanced_order_update_requirement_group_params.rb', line 56 optional :requirement_group_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/advanced_order_update_requirement_group_params.rb', line 88
|