Class: Telnyx::Models::AlphanumericSenderID

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/alphanumeric_sender_id.rb

Overview

Defined Under Namespace

Modules: RecordType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, alphanumeric_sender_id: nil, messaging_profile_id: nil, organization_id: nil, record_type: nil, us_long_code_fallback: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the alphanumeric sender ID resource.

  • alphanumeric_sender_id (String) (defaults to: nil)

    The alphanumeric sender ID string.

  • messaging_profile_id (String) (defaults to: nil)

    The messaging profile this sender ID belongs to.

  • organization_id (String) (defaults to: nil)

    The organization that owns this sender ID.

  • record_type (Symbol, Telnyx::Models::AlphanumericSenderID::RecordType) (defaults to: nil)
  • us_long_code_fallback (String) (defaults to: nil)

    A US long code number to use as fallback when sending to US destinations.



# File 'lib/telnyx/models/alphanumeric_sender_id.rb', line 42

Instance Attribute Details

#alphanumeric_sender_idString?

The alphanumeric sender ID string.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/alphanumeric_sender_id.rb', line 17

optional :alphanumeric_sender_id, String

#idString?

Uniquely identifies the alphanumeric sender ID resource.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/alphanumeric_sender_id.rb', line 11

optional :id, String

#messaging_profile_idString?

The messaging profile this sender ID belongs to.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/alphanumeric_sender_id.rb', line 23

optional :messaging_profile_id, String

#organization_idString?

The organization that owns this sender ID.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/alphanumeric_sender_id.rb', line 29

optional :organization_id, String

#record_typeSymbol, ...



34
# File 'lib/telnyx/models/alphanumeric_sender_id.rb', line 34

optional :record_type, enum: -> { Telnyx::AlphanumericSenderID::RecordType }

#us_long_code_fallbackString?

A US long code number to use as fallback when sending to US destinations.

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/alphanumeric_sender_id.rb', line 40

optional :us_long_code_fallback, String