Class: Telnyx::Models::AuditEventListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/audit_event_list_response.rb

Overview

Defined Under Namespace

Modules: ChangeMadeBy Classes: Change

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, alternate_resource_id: nil, change_made_by: nil, change_type: nil, changes: nil, created_at: nil, organization_id: nil, record_type: nil, resource_id: nil, user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AuditEventListResponse for more details.

Parameters:

  • id (String) (defaults to: nil)

    Unique identifier for the audit log entry.

  • alternate_resource_id (String, nil) (defaults to: nil)

    An alternate identifier for a resource which may be considered unique enough to

  • change_made_by (Symbol, Telnyx::Models::AuditEventListResponse::ChangeMadeBy) (defaults to: nil)

    Indicates if the change was made by Telnyx on your behalf, the organization owne

  • change_type (String) (defaults to: nil)

    The type of change that occurred.

  • changes (Array<Telnyx::Models::AuditEventListResponse::Change>, nil) (defaults to: nil)

    Details of the changes made to the resource.

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the change occurred.

  • organization_id (String) (defaults to: nil)

    Unique identifier for the organization that owns the resource.

  • record_type (String) (defaults to: nil)

    The type of the resource being audited.

  • resource_id (String) (defaults to: nil)

    Unique identifier for the resource that was changed.

  • user_id (String) (defaults to: nil)

    Unique identifier for the user who made the change.



# File 'lib/telnyx/models/audit_event_list_response.rb', line 74

Instance Attribute Details

#alternate_resource_idString?

An alternate identifier for a resource which may be considered unique enough to identify the resource but is not the primary identifier for the resource. For example, this field could be used to store the phone number value for a phone number when the primary database identifier is a separate distinct value.

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/audit_event_list_response.rb', line 20

optional :alternate_resource_id, String, nil?: true

#change_made_bySymbol, ...

Indicates if the change was made by Telnyx on your behalf, the organization owner, a member of your organization, or in the case of managed accounts, the account manager.



28
# File 'lib/telnyx/models/audit_event_list_response.rb', line 28

optional :change_made_by, enum: -> { Telnyx::Models::AuditEventListResponse::ChangeMadeBy }

#change_typeString?

The type of change that occurred.

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/audit_event_list_response.rb', line 34

optional :change_type, String

#changesArray<Telnyx::Models::AuditEventListResponse::Change>?

Details of the changes made to the resource.



40
41
42
# File 'lib/telnyx/models/audit_event_list_response.rb', line 40

optional :changes,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AuditEventListResponse::Change] },
nil?: true

#created_atTime?

ISO 8601 formatted date indicating when the change occurred.

Returns:

  • (Time, nil)


48
# File 'lib/telnyx/models/audit_event_list_response.rb', line 48

optional :created_at, Time

#idString?

Unique identifier for the audit log entry.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/audit_event_list_response.rb', line 11

optional :id, String

#organization_idString?

Unique identifier for the organization that owns the resource.

Returns:

  • (String, nil)


54
# File 'lib/telnyx/models/audit_event_list_response.rb', line 54

optional :organization_id, String

#record_typeString?

The type of the resource being audited.

Returns:

  • (String, nil)


60
# File 'lib/telnyx/models/audit_event_list_response.rb', line 60

optional :record_type, String

#resource_idString?

Unique identifier for the resource that was changed.

Returns:

  • (String, nil)


66
# File 'lib/telnyx/models/audit_event_list_response.rb', line 66

optional :resource_id, String

#user_idString?

Unique identifier for the user who made the change.

Returns:

  • (String, nil)


72
# File 'lib/telnyx/models/audit_event_list_response.rb', line 72

optional :user_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/audit_event_list_response.rb', line 111