Class: Telnyx::Models::AuditEventListResponse::Change
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AuditEventListResponse::Change
- Defined in:
- lib/telnyx/models/audit_event_list_response.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#field ⇒ String?
The name of the field that was changed.
-
#from ⇒ String, ...
The previous value of the field.
-
#to ⇒ String, ...
The new value of the field.
Instance Method Summary collapse
-
#initialize(field: nil, from: nil, to: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Change for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field: nil, from: nil, to: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AuditEventListResponse::Change for more details.
Details of the changes made to a resource.
|
|
# File 'lib/telnyx/models/audit_event_list_response.rb', line 135
|
Instance Attribute Details
#field ⇒ String?
The name of the field that was changed. May use the dot notation to indicate nested fields.
121 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 121 optional :field, String |
#from ⇒ String, ...
The previous value of the field. Can be any JSON type.
127 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 127 optional :from, union: -> { Telnyx::Models::AuditEventListResponse::Change::From }, nil?: true |
#to ⇒ String, ...
The new value of the field. Can be any JSON type.
133 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 133 optional :to, union: -> { Telnyx::Models::AuditEventListResponse::Change::To }, nil?: true |