Class: Telnyx::Models::AuthenticationProvider

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/authentication_provider.rb

Overview

Defined Under Namespace

Classes: Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, activated_at: nil, active: nil, created_at: nil, name: nil, organization_id: nil, record_type: nil, settings: nil, short_name: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AuthenticationProvider for more details.

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the authentication provider.

  • activated_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the authentication provider was activate

  • active (Boolean) (defaults to: nil)

    The active status of the authentication provider

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • name (String) (defaults to: nil)

    The name associated with the authentication provider.

  • organization_id (String) (defaults to: nil)

    The id from the Organization the authentication provider belongs to.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • settings (Telnyx::Models::AuthenticationProvider::Settings) (defaults to: nil)

    The settings associated with the authentication provider.

  • short_name (String) (defaults to: nil)

    The short name associated with the authentication provider. This must be unique

  • updated_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/authentication_provider.rb', line 69

Instance Attribute Details

#activated_atTime?

ISO 8601 formatted date indicating when the authentication provider was activated.

Returns:

  • (Time, nil)


18
# File 'lib/telnyx/models/authentication_provider.rb', line 18

optional :activated_at, Time

#activeBoolean?

The active status of the authentication provider

Returns:

  • (Boolean, nil)


24
# File 'lib/telnyx/models/authentication_provider.rb', line 24

optional :active, Telnyx::Internal::Type::Boolean

#created_atTime?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (Time, nil)


30
# File 'lib/telnyx/models/authentication_provider.rb', line 30

optional :created_at, Time

#idString?

Uniquely identifies the authentication provider.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/authentication_provider.rb', line 11

optional :id, String

#nameString?

The name associated with the authentication provider.

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/authentication_provider.rb', line 36

optional :name, String

#organization_idString?

The id from the Organization the authentication provider belongs to.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/authentication_provider.rb', line 42

optional :organization_id, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/authentication_provider.rb', line 48

optional :record_type, String

#settingsTelnyx::Models::AuthenticationProvider::Settings?

The settings associated with the authentication provider.



54
# File 'lib/telnyx/models/authentication_provider.rb', line 54

optional :settings, -> { Telnyx::AuthenticationProvider::Settings }

#short_nameString?

The short name associated with the authentication provider. This must be unique and URL-friendly, as it’s going to be part of the login URL.

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/authentication_provider.rb', line 61

optional :short_name, String

#updated_atTime?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (Time, nil)


67
# File 'lib/telnyx/models/authentication_provider.rb', line 67

optional :updated_at, Time