Class: Telnyx::Models::AuthenticationProvider::Settings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/authentication_provider.rb

Overview

See Also:

Defined Under Namespace

Modules: IdpCertFingerprintAlgorithm

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(assertion_consumer_service_url: nil, idp_attribute_names: nil, idp_cert_fingerprint: nil, idp_cert_fingerprint_algorithm: nil, idp_certificate: nil, idp_entity_id: nil, idp_slo_target_url: nil, idp_sso_target_url: nil, name_identifier_format: nil, provision_groups: nil, service_provider_entity_id: nil, service_provider_login_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AuthenticationProvider::Settings for more details.

The settings associated with the authentication provider.

Parameters:

  • assertion_consumer_service_url (String) (defaults to: nil)

    The Assertion Consumer Service URL for the service provider (Telnyx).

  • idp_attribute_names (Hash{Symbol=>Object}) (defaults to: nil)

    Mapping of SAML attribute names used by the identity provider (IdP).

  • idp_cert_fingerprint (String) (defaults to: nil)

    The certificate fingerprint for the identity provider (IdP)

  • idp_cert_fingerprint_algorithm (Symbol, Telnyx::Models::AuthenticationProvider::Settings::IdpCertFingerprintAlgorithm) (defaults to: nil)

    The algorithm used to generate the identity provider’s (IdP) certificate fingerp

  • idp_certificate (String) (defaults to: nil)

    The full X.509 certificate for the identity provider (IdP).

  • idp_entity_id (String) (defaults to: nil)

    The Entity ID for the identity provider (IdP).

  • idp_slo_target_url (String) (defaults to: nil)

    The Single Logout (SLO) target URL for the identity provider (IdP).

  • idp_sso_target_url (String) (defaults to: nil)

    The SSO target url for the identity provider (IdP).

  • name_identifier_format (String) (defaults to: nil)

    The name identifier format associated with the authentication provider. This mus

  • provision_groups (Boolean) (defaults to: nil)

    Whether group provisioning is enabled for this authentication provider.

  • service_provider_entity_id (String) (defaults to: nil)

    The Entity ID for the service provider (Telnyx).

  • service_provider_login_url (String) (defaults to: nil)

    The login URL for the service provider (Telnyx). Users navigate to this URL to i



# File 'lib/telnyx/models/authentication_provider.rb', line 172

Instance Attribute Details

#assertion_consumer_service_urlString?

The Assertion Consumer Service URL for the service provider (Telnyx).

Returns:

  • (String, nil)


99
# File 'lib/telnyx/models/authentication_provider.rb', line 99

optional :assertion_consumer_service_url, String

#idp_attribute_namesHash{Symbol=>Object}?

Mapping of SAML attribute names used by the identity provider (IdP).

Returns:

  • (Hash{Symbol=>Object}, nil)


105
# File 'lib/telnyx/models/authentication_provider.rb', line 105

optional :idp_attribute_names, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#idp_cert_fingerprintString?

The certificate fingerprint for the identity provider (IdP)

Returns:

  • (String, nil)


111
# File 'lib/telnyx/models/authentication_provider.rb', line 111

optional :idp_cert_fingerprint, String

#idp_cert_fingerprint_algorithmSymbol, ...

The algorithm used to generate the identity provider’s (IdP) certificate fingerprint



118
119
# File 'lib/telnyx/models/authentication_provider.rb', line 118

optional :idp_cert_fingerprint_algorithm,
enum: -> { Telnyx::AuthenticationProvider::Settings::IdpCertFingerprintAlgorithm }

#idp_certificateString?

The full X.509 certificate for the identity provider (IdP).

Returns:

  • (String, nil)


125
# File 'lib/telnyx/models/authentication_provider.rb', line 125

optional :idp_certificate, String

#idp_entity_idString?

The Entity ID for the identity provider (IdP).

Returns:

  • (String, nil)


131
# File 'lib/telnyx/models/authentication_provider.rb', line 131

optional :idp_entity_id, String

#idp_slo_target_urlString?

The Single Logout (SLO) target URL for the identity provider (IdP).

Returns:

  • (String, nil)


137
# File 'lib/telnyx/models/authentication_provider.rb', line 137

optional :idp_slo_target_url, String

#idp_sso_target_urlString?

The SSO target url for the identity provider (IdP).

Returns:

  • (String, nil)


143
# File 'lib/telnyx/models/authentication_provider.rb', line 143

optional :idp_sso_target_url, String

#name_identifier_formatString?

The name identifier format associated with the authentication provider. This must be the same for both the Identity Provider (IdP) and the service provider (Telnyx).

Returns:

  • (String, nil)


151
# File 'lib/telnyx/models/authentication_provider.rb', line 151

optional :name_identifier_format, String

#provision_groupsBoolean?

Whether group provisioning is enabled for this authentication provider.

Returns:

  • (Boolean, nil)


157
# File 'lib/telnyx/models/authentication_provider.rb', line 157

optional :provision_groups, Telnyx::Internal::Type::Boolean

#service_provider_entity_idString?

The Entity ID for the service provider (Telnyx).

Returns:

  • (String, nil)


163
# File 'lib/telnyx/models/authentication_provider.rb', line 163

optional :service_provider_entity_id, String

#service_provider_login_urlString?

The login URL for the service provider (Telnyx). Users navigate to this URL to initiate SSO login.

Returns:

  • (String, nil)


170
# File 'lib/telnyx/models/authentication_provider.rb', line 170

optional :service_provider_login_url, String