Module: Telnyx::Models::AuthenticationProviderListParams::Sort

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/authentication_provider_list_params.rb,
sig/telnyx/models/authentication_provider_list_params.rbs

Overview

Specifies the sort order for results. By default sorting direction is ascending. To have the results sorted in descending order add the - prefix.

That is:

  • name: sorts the result by the name field in ascending order.
  • -name: sorts the result by the name field in descending order.

If not given, results are sorted by created_at in descending order.

Constant Summary collapse

NAME =

Returns:

  • (:name)
:name
NAME_DESC =

Returns:

  • (:"-name")
:"-name"
SHORT_NAME =

Returns:

  • (:short_name)
:short_name
SHORT_NAME_DESC =

Returns:

  • (:"-short_name")
:"-short_name"
ACTIVE =

Returns:

  • (:active)
:active
ACTIVE_DESC =

Returns:

  • (:"-active")
:"-active"
CREATED_AT =

Returns:

  • (:created_at)
:created_at
CREATED_AT_DESC =

Returns:

  • (:"-created_at")
:"-created_at"
UPDATED_AT =

Returns:

  • (:updated_at)
:updated_at
UPDATED_AT_DESC =

Returns:

  • (:"-updated_at")
:"-updated_at"

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/authentication_provider_list_params.rb', line 77

Instance Method Details

#self?.values::Array[Telnyx::Models::AuthenticationProviderListParams::sort]

Returns:

  • (::Array[Telnyx::Models::AuthenticationProviderListParams::sort])


69
# File 'sig/telnyx/models/authentication_provider_list_params.rbs', line 69

def self?.values: -> ::Array[Telnyx::Models::AuthenticationProviderListParams::sort]