Class: Telnyx::Models::AuthenticationProviderUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AuthenticationProviderUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/authentication_provider_update_params.rb
Overview
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
The active status of the authentication provider.
- #id ⇒ String
-
#name ⇒ String?
The name associated with the authentication provider.
-
#settings ⇒ Telnyx::Models::Settings?
The settings associated with the authentication provider.
-
#settings_url ⇒ String?
The URL for the identity provider metadata file to populate the settings automatically.
-
#short_name ⇒ String?
The short name associated with the authentication provider.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, active: nil, name: nil, settings: nil, settings_url: nil, short_name: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AuthenticationProviderUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, active: nil, name: nil, settings: nil, settings_url: nil, short_name: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AuthenticationProviderUpdateParams for more details.
|
|
# File 'lib/telnyx/models/authentication_provider_update_params.rb', line 47
|
Instance Attribute Details
#active ⇒ Boolean?
The active status of the authentication provider
19 |
# File 'lib/telnyx/models/authentication_provider_update_params.rb', line 19 optional :active, Telnyx::Internal::Type::Boolean |
#id ⇒ String
13 |
# File 'lib/telnyx/models/authentication_provider_update_params.rb', line 13 required :id, String |
#name ⇒ String?
The name associated with the authentication provider.
25 |
# File 'lib/telnyx/models/authentication_provider_update_params.rb', line 25 optional :name, String |
#settings ⇒ Telnyx::Models::Settings?
The settings associated with the authentication provider.
31 |
# File 'lib/telnyx/models/authentication_provider_update_params.rb', line 31 optional :settings, -> { Telnyx::Settings } |
#settings_url ⇒ String?
The URL for the identity provider metadata file to populate the settings automatically. If the settings attribute is provided, that will be used instead.
38 |
# File 'lib/telnyx/models/authentication_provider_update_params.rb', line 38 optional :settings_url, String |
#short_name ⇒ String?
The short name associated with the authentication provider. This must be unique and URL-friendly, as it’s going to be part of the login URL.
45 |
# File 'lib/telnyx/models/authentication_provider_update_params.rb', line 45 optional :short_name, String |