Class: Telnyx::Models::AzureConfigurationData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/azure_configuration_data.rb

Defined Under Namespace

Modules: Backend

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(backend:, account_key: nil, account_name: nil, bucket: nil) ⇒ Object

Parameters:

  • backend (Symbol, Telnyx::Models::AzureConfigurationData::Backend)

    Storage backend type

  • account_key (String) (defaults to: nil)

    Azure Blob Storage account key.

  • account_name (String) (defaults to: nil)

    Azure Blob Storage account name.

  • bucket (String) (defaults to: nil)

    Name of the bucket to be used to store recording files.



# File 'lib/telnyx/models/azure_configuration_data.rb', line 30

Instance Attribute Details

#account_keyString?

Azure Blob Storage account key.

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/azure_configuration_data.rb', line 16

optional :account_key, String

#account_nameString?

Azure Blob Storage account name.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/azure_configuration_data.rb', line 22

optional :account_name, String

#backendSymbol, Telnyx::Models::AzureConfigurationData::Backend

Storage backend type



10
# File 'lib/telnyx/models/azure_configuration_data.rb', line 10

required :backend, enum: -> { Telnyx::AzureConfigurationData::Backend }

#bucketString?

Name of the bucket to be used to store recording files.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/azure_configuration_data.rb', line 28

optional :bucket, String