Class: Telnyx::Models::AzureVoiceSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/azure_voice_settings.rb

Defined Under Namespace

Modules: Effect, Gender, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, api_key_ref: nil, deployment_id: nil, effect: nil, gender: nil, region: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AzureVoiceSettings for more details.

Parameters:

  • type (Symbol, Telnyx::Models::AzureVoiceSettings::Type)

    Voice settings provider type

  • api_key_ref (String) (defaults to: nil)

    The ‘identifier` for an integration secret that refers to your Azure Speech API

  • deployment_id (String) (defaults to: nil)

    The deployment ID for a custom Azure neural voice.

  • effect (Symbol, Telnyx::Models::AzureVoiceSettings::Effect) (defaults to: nil)

    Audio effect to apply.

  • gender (Symbol, Telnyx::Models::AzureVoiceSettings::Gender) (defaults to: nil)

    Voice gender filter.

  • region (String) (defaults to: nil)

    The Azure region for the Speech service (e.g., ‘eastus`, `westeurope`). Required



# File 'lib/telnyx/models/azure_voice_settings.rb', line 44

Instance Attribute Details

#api_key_refString?

The ‘identifier` for an integration secret that refers to your Azure Speech API key.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/azure_voice_settings.rb', line 17

optional :api_key_ref, String

#deployment_idString?

The deployment ID for a custom Azure neural voice.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/azure_voice_settings.rb', line 23

optional :deployment_id, String

#effectSymbol, ...

Audio effect to apply.



29
# File 'lib/telnyx/models/azure_voice_settings.rb', line 29

optional :effect, enum: -> { Telnyx::AzureVoiceSettings::Effect }

#genderSymbol, ...

Voice gender filter.



35
# File 'lib/telnyx/models/azure_voice_settings.rb', line 35

optional :gender, enum: -> { Telnyx::AzureVoiceSettings::Gender }

#regionString?

The Azure region for the Speech service (e.g., ‘eastus`, `westeurope`). Required when using a custom API key.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/azure_voice_settings.rb', line 42

optional :region, String

#typeSymbol, Telnyx::Models::AzureVoiceSettings::Type

Voice settings provider type



10
# File 'lib/telnyx/models/azure_voice_settings.rb', line 10

required :type, enum: -> { Telnyx::AzureVoiceSettings::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/azure_voice_settings.rb', line 68