Class: Telnyx::Models::BookAppointmentToolParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/book_appointment_tool_params.rb,
sig/telnyx/models/book_appointment_tool_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_key_ref:, event_type_id:, attendee_name: nil, attendee_timezone: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::BookAppointmentToolParams for more details.

Parameters:



# File 'lib/telnyx/models/book_appointment_tool_params.rb', line 38

Instance Attribute Details

#api_key_refString

Reference to an integration secret that contains your Cal.com API key. You would pass the identifier for an integration secret /v2/integration_secrets that refers to your Cal.com API key.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/telnyx/models/book_appointment_tool_params.rb', line 13

required :api_key_ref, String

#attendee_nameString?

The name of the attendee cal.com. If not provided, the assistant will ask for the attendee's name.

Parameters:

  • (String)

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/book_appointment_tool_params.rb', line 28

optional :attendee_name, String

#attendee_timezoneString?

The timezone of the attendee cal.com. If not provided, the assistant will ask for the attendee's timezone.

Parameters:

  • (String)

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/book_appointment_tool_params.rb', line 36

optional :attendee_timezone, String

#event_type_idInteger

Event Type ID for which slots are being fetched. cal.com

Parameters:

  • value (Integer)

Returns:

  • (Integer)


20
# File 'lib/telnyx/models/book_appointment_tool_params.rb', line 20

required :event_type_id, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


31
# File 'sig/telnyx/models/book_appointment_tool_params.rbs', line 31

def to_hash: -> {