Class: Telnyx::Models::BundlePricing::BillingBundleRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bundle_id:, authorization_bearer: nil, request_options: {}) ⇒ Object

Parameters:

  • bundle_id (String)

    Billing bundle’s ID, this is used to identify the billing bundle in the API.

  • authorization_bearer (String) (defaults to: nil)

    Authenticates the request with your Telnyx API V2 KEY

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_params.rb', line 23

Instance Attribute Details

#authorization_bearerString?

Authenticates the request with your Telnyx API V2 KEY

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_params.rb', line 21

optional :authorization_bearer, String

#bundle_idString

Billing bundle’s ID, this is used to identify the billing bundle in the API.

Returns:

  • (String)


15
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_params.rb', line 15

required :bundle_id, String