Class: Telnyx::Models::BundlePricing::BillingBundleRetrieveResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rb,
sig/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rbs

Overview

See Also:

  • Telnyx::Models::BundlePricing::BillingBundleRetrieveResponse#data

Defined Under Namespace

Classes: BundleLimit

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



51
# File 'sig/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rbs', line 51

def initialize: (

Instance Attribute Details

#activeBoolean

If that bundle is active or not.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


28
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rb', line 28

required :active, Telnyx::Internal::Type::Boolean

#bundle_limitsArray<Telnyx::Models::BundlePricing::BillingBundleRetrieveResponse::Data::BundleLimit>



33
34
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rb', line 33

required :bundle_limits,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::BundlePricing::BillingBundleRetrieveResponse::Data::BundleLimit] }

#cost_codeString

Bundle's cost code, this is used to identify the bundle in the billing system.

Parameters:

  • value (String)

Returns:

  • (String)


40
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rb', line 40

required :cost_code, String

#created_atDate

Date the bundle was created.

Parameters:

  • value (Date)

Returns:

  • (Date)


46
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rb', line 46

required :created_at, Date

#idString

Bundle's ID, this is used to identify the bundle in the API.

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rb', line 22

required :id, String

#is_publicBoolean

Available to all customers or only to specific customers.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


52
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rb', line 52

required :is_public, Telnyx::Internal::Type::Boolean

#nameString

Bundle's name, this is used to identify the bundle in the UI.

Parameters:

  • value (String)

Returns:

  • (String)


58
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rb', line 58

required :name, String

#slugString?

Slugified version of the bundle's name.

Parameters:

  • (String)

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rb', line 64

optional :slug, String

Instance Method Details

#to_hash{

Returns:

  • ({)


62
# File 'sig/telnyx/models/bundle_pricing/billing_bundle_retrieve_response.rbs', line 62

def to_hash: -> {