Class: Telnyx::Models::BundlePricing::BillingBundleSummary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, cost_code:, created_at:, is_public:, name:, currency: nil, mrc_price: nil, slug: nil, specs: nil) ⇒ Object

Parameters:

  • id (String)

    Bundle’s ID, this is used to identify the bundle in the API.

  • cost_code (String)

    Bundle’s cost code, this is used to identify the bundle in the billing system.

  • created_at (Date)

    Date the bundle was created.

  • is_public (Boolean)

    Available to all customers or only to specific customers.

  • name (String)

    Bundle’s name, this is used to identify the bundle in the UI.

  • currency (String) (defaults to: nil)

    Bundle’s currency code.

  • mrc_price (Float) (defaults to: nil)

    Monthly recurring charge price.

  • slug (String) (defaults to: nil)

    Slugified version of the bundle’s name.

  • specs (Array<String>) (defaults to: nil)


# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 61

Instance Attribute Details

#cost_codeString

Bundle’s cost code, this is used to identify the bundle in the billing system.

Returns:

  • (String)


18
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 18

required :cost_code, String

#created_atDate

Date the bundle was created.

Returns:

  • (Date)


24
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 24

required :created_at, Date

#currencyString?

Bundle’s currency code.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 42

optional :currency, String

#idString

Bundle’s ID, this is used to identify the bundle in the API.

Returns:

  • (String)


12
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 12

required :id, String

#is_publicBoolean

Available to all customers or only to specific customers.

Returns:

  • (Boolean)


30
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 30

required :is_public, Telnyx::Internal::Type::Boolean

#mrc_priceFloat?

Monthly recurring charge price.

Returns:

  • (Float, nil)


48
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 48

optional :mrc_price, Float

#nameString

Bundle’s name, this is used to identify the bundle in the UI.

Returns:

  • (String)


36
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 36

required :name, String

#slugString?

Slugified version of the bundle’s name.

Returns:

  • (String, nil)


54
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 54

optional :slug, String

#specsArray<String>?

Returns:

  • (Array<String>, nil)


59
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 59

optional :specs, Telnyx::Internal::Type::ArrayOf[String]