Class: Telnyx::Models::BundlePricing::UserBundle
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::BundlePricing::UserBundle
- Defined in:
- lib/telnyx/models/bundle_pricing/user_bundle.rb
Overview
Instance Attribute Summary collapse
-
#active ⇒ Boolean
Status of the user bundle.
- #billing_bundle ⇒ Telnyx::Models::BundlePricing::BillingBundleSummary
-
#created_at ⇒ Date
Date the user bundle was created.
-
#id ⇒ String
User bundle’s ID, this is used to identify the user bundle in the API.
- #resources ⇒ Array<Telnyx::Models::BundlePricing::UserBundleResource>
-
#updated_at ⇒ Date?
Date the user bundle was last updated.
-
#user_id ⇒ String
The customer’s ID that owns this user bundle.
Instance Method Summary collapse
- #initialize(id:, active:, billing_bundle:, created_at:, resources:, user_id:, updated_at: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, active:, billing_bundle:, created_at:, resources:, user_id:, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/bundle_pricing/user_bundle.rb', line 48
|
Instance Attribute Details
#active ⇒ Boolean
Status of the user bundle.
18 |
# File 'lib/telnyx/models/bundle_pricing/user_bundle.rb', line 18 required :active, Telnyx::Internal::Type::Boolean |
#billing_bundle ⇒ Telnyx::Models::BundlePricing::BillingBundleSummary
23 |
# File 'lib/telnyx/models/bundle_pricing/user_bundle.rb', line 23 required :billing_bundle, -> { Telnyx::BundlePricing::BillingBundleSummary } |
#created_at ⇒ Date
Date the user bundle was created.
29 |
# File 'lib/telnyx/models/bundle_pricing/user_bundle.rb', line 29 required :created_at, Date |
#id ⇒ String
User bundle’s ID, this is used to identify the user bundle in the API.
12 |
# File 'lib/telnyx/models/bundle_pricing/user_bundle.rb', line 12 required :id, String |
#resources ⇒ Array<Telnyx::Models::BundlePricing::UserBundleResource>
34 |
# File 'lib/telnyx/models/bundle_pricing/user_bundle.rb', line 34 required :resources, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::BundlePricing::UserBundleResource] } |
#updated_at ⇒ Date?
Date the user bundle was last updated.
46 |
# File 'lib/telnyx/models/bundle_pricing/user_bundle.rb', line 46 optional :updated_at, Date, nil?: true |
#user_id ⇒ String
The customer’s ID that owns this user bundle.
40 |
# File 'lib/telnyx/models/bundle_pricing/user_bundle.rb', line 40 required :user_id, String |