Class: Telnyx::Models::CallAIGatherEndedWebhookEvent::Data::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallAIGatherEndedWebhookEvent::Data::Payload
- Defined in:
- lib/telnyx/models/call_ai_gather_ended_webhook_event.rb
Overview
Defined Under Namespace
Modules: Status Classes: MessageHistory
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Telnyx connection ID used in the call.
-
#from ⇒ String?
Number or SIP URI placing the call.
-
#message_history ⇒ Array<Telnyx::Models::CallAIGatherEndedWebhookEvent::Data::Payload::MessageHistory>?
The history of the messages exchanged during the AI gather.
-
#result ⇒ Hash{Symbol=>Object}?
The result of the AI gather, its type depends of the ‘parameters` provided in the command.
-
#status ⇒ Symbol, ...
Reflects how command ended.
-
#to ⇒ String?
Destination number or SIP URI of the call.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
74 |
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 74 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
80 |
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 80 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
88 |
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 88 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command.
94 |
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 94 optional :client_state, String |
#connection_id ⇒ String?
Telnyx connection ID used in the call.
100 |
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 100 optional :connection_id, String |
#from ⇒ String?
Number or SIP URI placing the call.
106 |
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 106 optional :from, String |
#message_history ⇒ Array<Telnyx::Models::CallAIGatherEndedWebhookEvent::Data::Payload::MessageHistory>?
The history of the messages exchanged during the AI gather
112 113 |
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 112 optional :message_history, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CallAIGatherEndedWebhookEvent::Data::Payload::MessageHistory] } |
#result ⇒ Hash{Symbol=>Object}?
The result of the AI gather, its type depends of the ‘parameters` provided in the command
120 |
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 120 optional :result, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#status ⇒ Symbol, ...
Reflects how command ended.
126 |
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 126 optional :status, enum: -> { Telnyx::CallAIGatherEndedWebhookEvent::Data::Payload::Status } |
#to ⇒ String?
Destination number or SIP URI of the call.
132 |
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 132 optional :to, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/call_ai_gather_ended_webhook_event.rb', line 185
|