Class: Telnyx::Models::CallAIGatherMessageHistoryUpdatedWebhookEvent::Data::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallAIGatherMessageHistoryUpdatedWebhookEvent::Data::Payload
- Defined in:
- lib/telnyx/models/call_ai_gather_message_history_updated_webhook_event.rb
Overview
Defined Under Namespace
Classes: MessageHistory
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Telnyx connection ID used in the call.
-
#from ⇒ String?
Number or SIP URI placing the call.
-
#message_history ⇒ Array<Telnyx::Models::CallAIGatherMessageHistoryUpdatedWebhookEvent::Data::Payload::MessageHistory>?
The history of the messages exchanged during the AI gather.
-
#to ⇒ String?
Destination number or SIP URI of the call.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
75 |
# File 'lib/telnyx/models/call_ai_gather_message_history_updated_webhook_event.rb', line 75 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
81 |
# File 'lib/telnyx/models/call_ai_gather_message_history_updated_webhook_event.rb', line 81 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
89 |
# File 'lib/telnyx/models/call_ai_gather_message_history_updated_webhook_event.rb', line 89 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command.
95 |
# File 'lib/telnyx/models/call_ai_gather_message_history_updated_webhook_event.rb', line 95 optional :client_state, String |
#connection_id ⇒ String?
Telnyx connection ID used in the call.
101 |
# File 'lib/telnyx/models/call_ai_gather_message_history_updated_webhook_event.rb', line 101 optional :connection_id, String |
#from ⇒ String?
Number or SIP URI placing the call.
107 |
# File 'lib/telnyx/models/call_ai_gather_message_history_updated_webhook_event.rb', line 107 optional :from, String |
#message_history ⇒ Array<Telnyx::Models::CallAIGatherMessageHistoryUpdatedWebhookEvent::Data::Payload::MessageHistory>?
The history of the messages exchanged during the AI gather
113 114 |
# File 'lib/telnyx/models/call_ai_gather_message_history_updated_webhook_event.rb', line 113 optional :message_history, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CallAIGatherMessageHistoryUpdatedWebhookEvent::Data::Payload::MessageHistory] } |
#to ⇒ String?
Destination number or SIP URI of the call.
120 |
# File 'lib/telnyx/models/call_ai_gather_message_history_updated_webhook_event.rb', line 120 optional :to, String |