Module: Telnyx::Models::CallAssistantRequest::DynamicVariable

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/call_assistant_request.rb

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id:, dynamic_variables: nil, external_llm: nil, fallback_config: nil, greeting: nil, instructions: nil, llm_api_key_ref: nil, mcp_servers: nil, model: nil, name: nil, observability_settings: nil, openai_api_key_ref: nil, tools: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallAssistantRequest for more details.

AI Assistant configuration. All fields except ‘id` are optional — the assistant’s stored configuration will be used as fallback for any omitted fields.

Parameters:

  • id (String)

    The identifier of the AI assistant to use.

  • dynamic_variables (Hash{Symbol=>String, Float, Boolean}) (defaults to: nil)

    Map of dynamic variables and their default values. Dynamic variables can be refe

  • external_llm (Hash{Symbol=>Object}) (defaults to: nil)

    External LLM configuration for bringing your own LLM endpoint.

  • fallback_config (Hash{Symbol=>Object}) (defaults to: nil)

    Fallback LLM configuration used when the primary LLM provider is unavailable.

  • greeting (String) (defaults to: nil)

    Initial greeting text spoken when the assistant starts. Can be plain text for an

  • instructions (String) (defaults to: nil)

    System instructions for the voice assistant. Can be templated with [dynamic vari

  • llm_api_key_ref (String) (defaults to: nil)

    Integration secret identifier for the LLM provider API key. Use this field to re

  • mcp_servers (Array<Hash{Symbol=>Object}>) (defaults to: nil)

    MCP (Model Context Protocol) server configurations for extending the assistant’s

  • model (String) (defaults to: nil)

    LLM model override for this call. If omitted, the assistant’s configured model i

  • name (String) (defaults to: nil)

    Assistant name override for this call.

  • observability_settings (Hash{Symbol=>Object}) (defaults to: nil)

    Observability configuration for the assistant session, including Langfuse integr

  • openai_api_key_ref (String) (defaults to: nil)

    Deprecated — use ‘llm_api_key_ref` instead. Integration secret identifier for th

  • tools (Array<Telnyx::Models::BookAppointmentTool, Telnyx::Models::CheckAvailabilityTool, Telnyx::Models::AI::WebhookTool, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::TransferTool, Telnyx::Models::CallControlRetrievalTool>) (defaults to: nil)

    Inline tool definitions available to the assistant (webhook, retrieval, transfer



141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/telnyx/models/call_assistant_request.rb', line 141

module DynamicVariable
  extend Telnyx::Internal::Type::Union

  variant String

  variant Float

  variant Telnyx::Internal::Type::Boolean

  # @!method self.variants
  #   @return [Array(String, Float, Boolean)]
end