Class: Telnyx::Models::CallAssistantRequest::FallbackConfig::ExternalLlm

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_assistant_request.rb

Overview

See Also:

Defined Under Namespace

Modules: AuthenticationMethod

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authentication_method: nil, base_url: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, model: nil, token_retrieval_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallAssistantRequest::FallbackConfig::ExternalLlm for more details.

External LLM fallback configuration.

Parameters:

  • authentication_method (Symbol, Telnyx::Models::CallAssistantRequest::FallbackConfig::ExternalLlm::AuthenticationMethod) (defaults to: nil)

    Authentication method used when connecting to the external LLM endpoint.

  • base_url (String) (defaults to: nil)

    Base URL for the external LLM endpoint.

  • certificate_ref (String) (defaults to: nil)

    Integration secret identifier for the client certificate used with certificate a

  • forward_metadata (Boolean) (defaults to: nil)

    When enabled, Telnyx forwards conversation metadata and dynamic variables to the

  • llm_api_key_ref (String) (defaults to: nil)

    Integration secret identifier for the external LLM API key.

  • model (String) (defaults to: nil)

    Model identifier to use with the external LLM endpoint.

  • token_retrieval_url (String) (defaults to: nil)

    URL used to retrieve an access token when certificate authentication is enabled.



# File 'lib/telnyx/models/call_assistant_request.rb', line 321

Instance Attribute Details

#authentication_methodSymbol, ...

Authentication method used when connecting to the external LLM endpoint.



277
278
# File 'lib/telnyx/models/call_assistant_request.rb', line 277

optional :authentication_method,
enum: -> { Telnyx::CallAssistantRequest::FallbackConfig::ExternalLlm::AuthenticationMethod }

#base_urlString?

Base URL for the external LLM endpoint.

Returns:

  • (String, nil)


284
# File 'lib/telnyx/models/call_assistant_request.rb', line 284

optional :base_url, String

#certificate_refString?

Integration secret identifier for the client certificate used with certificate authentication.

Returns:

  • (String, nil)


291
# File 'lib/telnyx/models/call_assistant_request.rb', line 291

optional :certificate_ref, String

#forward_metadataBoolean?

When enabled, Telnyx forwards conversation metadata and dynamic variables to the external LLM endpoint. Defaults to false. The external endpoint receives the standard chat completions payload with top-level ‘metadata` and `dynamic_variables` objects when values are available. For example: `“metadata”:{“conversation_id”:“conv_123”,“assistant_id”:“assistant_456”,“call_control_id”:“v3:abc123”,“telnyx_conversation_channel”:“phone_call”,“dynamic_variables”:“customer_name”:“Jane”,“account_id”:“acct_789”,“telnyx_agent_target”:“+13125550100”,“telnyx_end_user_target”:“+13125550123”}`.

Returns:

  • (Boolean, nil)


301
# File 'lib/telnyx/models/call_assistant_request.rb', line 301

optional :forward_metadata, Telnyx::Internal::Type::Boolean

#llm_api_key_refString?

Integration secret identifier for the external LLM API key.

Returns:

  • (String, nil)


307
# File 'lib/telnyx/models/call_assistant_request.rb', line 307

optional :llm_api_key_ref, String

#modelString?

Model identifier to use with the external LLM endpoint.

Returns:

  • (String, nil)


313
# File 'lib/telnyx/models/call_assistant_request.rb', line 313

optional :model, String

#token_retrieval_urlString?

URL used to retrieve an access token when certificate authentication is enabled.

Returns:

  • (String, nil)


319
# File 'lib/telnyx/models/call_assistant_request.rb', line 319

optional :token_retrieval_url, String