Class: Telnyx::Models::CallControlApplication

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_control_application.rb

Overview

Defined Under Namespace

Modules: AnchorsiteOverride, DtmfType, RecordType, WebhookAPIVersion

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, active: nil, anchorsite_override: nil, application_name: nil, call_cost_in_webhooks: nil, created_at: nil, dtmf_type: nil, first_command_timeout: nil, first_command_timeout_secs: nil, inbound: nil, outbound: nil, record_type: nil, redact_dtmf_debug_logging: nil, tags: nil, updated_at: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallControlApplication for more details.

Parameters:

  • id (String) (defaults to: nil)
  • active (Boolean) (defaults to: nil)

    Specifies whether the connection can be used.

  • anchorsite_override (Symbol, Telnyx::Models::CallControlApplication::AnchorsiteOverride) (defaults to: nil)

    Latency directs Telnyx to route media through the site with the low

  • application_name (String) (defaults to: nil)

    A user-assigned name to help manage the application.

  • call_cost_in_webhooks (Boolean) (defaults to: nil)

    Specifies if call cost webhooks should be sent for this Call Control Application

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the resource was created

  • dtmf_type (Symbol, Telnyx::Models::CallControlApplication::DtmfType) (defaults to: nil)

    Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF

  • first_command_timeout (Boolean) (defaults to: nil)

    Specifies whether calls to phone numbers associated with this connection should

  • first_command_timeout_secs (Integer) (defaults to: nil)

    Specifies how many seconds to wait before timing out a dial command.

  • inbound (Telnyx::Models::CallControlApplicationInbound) (defaults to: nil)
  • outbound (Telnyx::Models::CallControlApplicationOutbound) (defaults to: nil)
  • record_type (Symbol, Telnyx::Models::CallControlApplication::RecordType) (defaults to: nil)
  • redact_dtmf_debug_logging (Boolean) (defaults to: nil)

    When enabled, DTMF digits entered by users will be redacted in debug logs to pro

  • tags (Array<String>) (defaults to: nil)

    Tags assigned to the Call Control Application.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the resource was last updated

  • webhook_api_version (Symbol, Telnyx::Models::CallControlApplication::WebhookAPIVersion) (defaults to: nil)

    Determines which webhook format will be used, Telnyx API v1 or v2.

  • webhook_event_failover_url (String, nil) (defaults to: nil)

    The failover URL where webhooks related to this connection will be sent if sendi

  • webhook_event_url (String) (defaults to: nil)

    The URL where webhooks related to this connection will be sent. Must include a s

  • webhook_timeout_secs (Integer, nil) (defaults to: nil)


# File 'lib/telnyx/models/call_control_application.rb', line 125

Instance Attribute Details

#activeBoolean?

Specifies whether the connection can be used.

Returns:

  • (Boolean, nil)


16
# File 'lib/telnyx/models/call_control_application.rb', line 16

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

Latency directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.



25
# File 'lib/telnyx/models/call_control_application.rb', line 25

optional :anchorsite_override, enum: -> { Telnyx::CallControlApplication::AnchorsiteOverride }

#application_nameString?

A user-assigned name to help manage the application.

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/call_control_application.rb', line 31

optional :application_name, String

#call_cost_in_webhooksBoolean?

Specifies if call cost webhooks should be sent for this Call Control Application.

Returns:

  • (Boolean, nil)


38
# File 'lib/telnyx/models/call_control_application.rb', line 38

optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean

#created_atString?

ISO 8601 formatted date of when the resource was created

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/call_control_application.rb', line 44

optional :created_at, String

#dtmf_typeSymbol, ...

Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.



51
# File 'lib/telnyx/models/call_control_application.rb', line 51

optional :dtmf_type, enum: -> { Telnyx::CallControlApplication::DtmfType }

#first_command_timeoutBoolean?

Specifies whether calls to phone numbers associated with this connection should hangup after timing out.

Returns:

  • (Boolean, nil)


58
# File 'lib/telnyx/models/call_control_application.rb', line 58

optional :first_command_timeout, Telnyx::Internal::Type::Boolean

#first_command_timeout_secsInteger?

Specifies how many seconds to wait before timing out a dial command.

Returns:

  • (Integer, nil)


64
# File 'lib/telnyx/models/call_control_application.rb', line 64

optional :first_command_timeout_secs, Integer

#idString?

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/call_control_application.rb', line 10

optional :id, String

#inboundTelnyx::Models::CallControlApplicationInbound?



69
# File 'lib/telnyx/models/call_control_application.rb', line 69

optional :inbound, -> { Telnyx::CallControlApplicationInbound }

#outboundTelnyx::Models::CallControlApplicationOutbound?



74
# File 'lib/telnyx/models/call_control_application.rb', line 74

optional :outbound, -> { Telnyx::CallControlApplicationOutbound }

#record_typeSymbol, ...



79
# File 'lib/telnyx/models/call_control_application.rb', line 79

optional :record_type, enum: -> { Telnyx::CallControlApplication::RecordType }

#redact_dtmf_debug_loggingBoolean?

When enabled, DTMF digits entered by users will be redacted in debug logs to protect PII data entered through IVR interactions.

Returns:

  • (Boolean, nil)


86
# File 'lib/telnyx/models/call_control_application.rb', line 86

optional :redact_dtmf_debug_logging, Telnyx::Internal::Type::Boolean

#tagsArray<String>?

Tags assigned to the Call Control Application.

Returns:

  • (Array<String>, nil)


92
# File 'lib/telnyx/models/call_control_application.rb', line 92

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#updated_atString?

ISO 8601 formatted date of when the resource was last updated

Returns:

  • (String, nil)


98
# File 'lib/telnyx/models/call_control_application.rb', line 98

optional :updated_at, String

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1 or v2.



104
# File 'lib/telnyx/models/call_control_application.rb', line 104

optional :webhook_api_version, enum: -> { Telnyx::CallControlApplication::WebhookAPIVersion }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https`.

Returns:

  • (String, nil)


111
# File 'lib/telnyx/models/call_control_application.rb', line 111

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https`.

Returns:

  • (String, nil)


118
# File 'lib/telnyx/models/call_control_application.rb', line 118

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Returns:

  • (Integer, nil)


123
# File 'lib/telnyx/models/call_control_application.rb', line 123

optional :webhook_timeout_secs, Integer, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_control_application.rb', line 186