Module: Telnyx::Models::CallControlApplication::AnchorsiteOverride

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/call_control_application.rb,
sig/telnyx/models/call_control_application.rbs

Overview

Latency directs Telnyx to route media through the site with the lowest round-trip time to the user's connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

See Also:

  • Telnyx::Models::CallControlApplication#anchorsite_override

Constant Summary collapse

LATENCY =

Returns:

  • (:Latency)
:Latency
CHICAGO_IL =

Returns:

  • (:"Chicago, IL")
:"Chicago, IL"
ASHBURN_VA =

Returns:

  • (:"Ashburn, VA")
:"Ashburn, VA"
SAN_JOSE_CA =

Returns:

  • (:"San Jose, CA")
:"San Jose, CA"
LONDON_UK =

Returns:

  • (:"London, UK")
:"London, UK"
CHENNAI_IN =

Returns:

  • (:"Chennai, IN")
:"Chennai, IN"
AMSTERDAM_NETHERLANDS =

Returns:

  • (:"Amsterdam, Netherlands")
:"Amsterdam, Netherlands"
TORONTO_CANADA =

Returns:

  • (:"Toronto, Canada")
:"Toronto, Canada"
SYDNEY_AUSTRALIA =

Returns:

  • (:"Sydney, Australia")
:"Sydney, Australia"

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Telnyx::Models::CallControlApplication::anchorsite_override]

Returns:

  • (::Array[Telnyx::Models::CallControlApplication::anchorsite_override])


179
# File 'sig/telnyx/models/call_control_application.rbs', line 179

def self?.values: -> ::Array[Telnyx::Models::CallControlApplication::anchorsite_override]