Module: Telnyx::Models::CallControlApplicationCreateParams::AnchorsiteOverride

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/call_control_application_create_params.rb

Overview

Latency directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Constant Summary collapse

LATENCY =
:Latency
CHICAGO_IL =
:"Chicago, IL"
ASHBURN_VA =
:"Ashburn, VA"
SAN_JOSE_CA =
:"San Jose, CA"
LONDON_UK =
:"London, UK"
CHENNAI_IN =
:"Chennai, IN"
AMSTERDAM_NETHERLANDS =
:"Amsterdam, Netherlands"
TORONTO_CANADA =
:"Toronto, Canada"
SYDNEY_AUSTRALIA =
:"Sydney, Australia"

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info