Class: Telnyx::Models::CallControlApplicationInbound
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallControlApplicationInbound
- Defined in:
- lib/telnyx/models/call_control_application_inbound.rb
Defined Under Namespace
Modules: SipSubdomainReceiveSettings
Instance Attribute Summary collapse
-
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
-
#shaken_stir_enabled ⇒ Boolean?
When enabled Telnyx will include Shaken/Stir data in the Webhook for new inbound calls.
-
#sip_subdomain ⇒ String?
Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint.
-
#sip_subdomain_receive_settings ⇒ Symbol, ...
This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).
Instance Method Summary collapse
-
#initialize(channel_limit: nil, shaken_stir_enabled: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallControlApplicationInbound for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channel_limit: nil, shaken_stir_enabled: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallControlApplicationInbound for more details.
|
|
# File 'lib/telnyx/models/call_control_application_inbound.rb', line 40
|
Instance Attribute Details
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
11 |
# File 'lib/telnyx/models/call_control_application_inbound.rb', line 11 optional :channel_limit, Integer |
#shaken_stir_enabled ⇒ Boolean?
When enabled Telnyx will include Shaken/Stir data in the Webhook for new inbound calls.
18 |
# File 'lib/telnyx/models/call_control_application_inbound.rb', line 18 optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean |
#sip_subdomain ⇒ String?
Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint. Example: the subdomain “example.sip.telnyx.com” can be called from any SIP endpoint by using the SIP URI “sip:@example.sip.telnyx.com” where the user part can be any alphanumeric value. Please note TLS encrypted calls are not allowed for subdomain calls.
29 |
# File 'lib/telnyx/models/call_control_application_inbound.rb', line 29 optional :sip_subdomain, String |
#sip_subdomain_receive_settings ⇒ Symbol, ...
This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).
37 38 |
# File 'lib/telnyx/models/call_control_application_inbound.rb', line 37 optional :sip_subdomain_receive_settings, enum: -> { Telnyx::CallControlApplicationInbound::SipSubdomainReceiveSettings } |