Class: Telnyx::Models::CallControlApplicationListParams::Filter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_control_application_list_params.rb,
sig/telnyx/models/call_control_application_list_params.rbs

Defined Under Namespace

Modules: Product, Status, Type Classes: ApplicationName, OccurredAt

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(eq: nil, gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Object

Event occurred_at filters

Parameters:

  • eq (String) (defaults to: nil)

    Event occurred_at: equal

  • gt (String) (defaults to: nil)

    Event occurred_at: greater than

  • gte (String) (defaults to: nil)

    Event occurred_at: greater than or equal

  • lt (String) (defaults to: nil)

    Event occurred_at: lower than

  • lte (String) (defaults to: nil)

    Event occurred_at: lower than or equal



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 63

class Filter < Telnyx::Internal::Type::BaseModel
  # @!attribute application_name
  #   Application name filters
  #
  #   @return [Telnyx::Models::CallControlApplicationListParams::Filter::ApplicationName, nil]
  optional :application_name, -> { Telnyx::CallControlApplicationListParams::Filter::ApplicationName }

  # @!attribute application_session_id
  #   The unique identifier of the call session. A session may include multiple call
  #   leg events.
  #
  #   @return [String, nil]
  optional :application_session_id, String

  # @!attribute connection_id
  #   The unique identifier of the conection.
  #
  #   @return [String, nil]
  optional :connection_id, String

  # @!attribute failed
  #   Delivery failed or not.
  #
  #   @return [Boolean, nil]
  optional :failed, Telnyx::Internal::Type::Boolean

  # @!attribute from
  #   Filter by From number.
  #
  #   @return [String, nil]
  optional :from, String

  # @!attribute leg_id
  #   The unique identifier of an individual call leg.
  #
  #   @return [String, nil]
  optional :leg_id, String

  # @!attribute name
  #   If present, conferences will be filtered to those with a matching `name`
  #   attribute. Matching is case-sensitive
  #
  #   @return [String, nil]
  optional :name, String

  # @!attribute occurred_at
  #   Event occurred_at filters
  #
  #   @return [Telnyx::Models::CallControlApplicationListParams::Filter::OccurredAt, nil]
  optional :occurred_at, -> { Telnyx::CallControlApplicationListParams::Filter::OccurredAt }

  # @!attribute outbound_outbound_voice_profile_id
  #   Identifies the associated outbound voice profile.
  #
  #   @return [String, nil]
  optional :outbound_outbound_voice_profile_id, String, api_name: :"outbound.outbound_voice_profile_id"

  # @!attribute product
  #   Filter by product.
  #
  #   @return [Symbol, Telnyx::Models::CallControlApplicationListParams::Filter::Product, nil]
  optional :product, enum: -> { Telnyx::CallControlApplicationListParams::Filter::Product }

  # @!attribute status
  #   If present, conferences will be filtered by status.
  #
  #   @return [Symbol, Telnyx::Models::CallControlApplicationListParams::Filter::Status, nil]
  optional :status, enum: -> { Telnyx::CallControlApplicationListParams::Filter::Status }

  # @!attribute to
  #   Filter by To number.
  #
  #   @return [String, nil]
  optional :to, String

  # @!attribute type
  #   Event type
  #
  #   @return [Symbol, Telnyx::Models::CallControlApplicationListParams::Filter::Type, nil]
  optional :type, enum: -> { Telnyx::CallControlApplicationListParams::Filter::Type }

  # @!method initialize(application_name: nil, application_session_id: nil, connection_id: nil, failed: nil, from: nil, leg_id: nil, name: nil, occurred_at: nil, outbound_outbound_voice_profile_id: nil, product: nil, status: nil, to: nil, type: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::CallControlApplicationListParams::Filter} for more details.
  #
  #   Consolidated filter parameter (deepObject style). Originally:
  #   filter[application_name][contains], filter[outbound.outbound_voice_profile_id],
  #   filter[leg_id], filter[application_session_id], filter[connection_id],
  #   filter[product], filter[failed], filter[from], filter[to], filter[name],
  #   filter[type], filter[occurred_at][eq/gt/gte/lt/lte], filter[status]
  #
  #   @param application_name [Telnyx::Models::CallControlApplicationListParams::Filter::ApplicationName] Application name filters
  #
  #   @param application_session_id [String] The unique identifier of the call session. A session may include multiple call l
  #
  #   @param connection_id [String] The unique identifier of the conection.
  #
  #   @param failed [Boolean] Delivery failed or not.
  #
  #   @param from [String] Filter by From number.
  #
  #   @param leg_id [String] The unique identifier of an individual call leg.
  #
  #   @param name [String] If present, conferences will be filtered to those with a matching `name` attribu
  #
  #   @param occurred_at [Telnyx::Models::CallControlApplicationListParams::Filter::OccurredAt] Event occurred_at filters
  #
  #   @param outbound_outbound_voice_profile_id [String] Identifies the associated outbound voice profile.
  #
  #   @param product [Symbol, Telnyx::Models::CallControlApplicationListParams::Filter::Product] Filter by product.
  #
  #   @param status [Symbol, Telnyx::Models::CallControlApplicationListParams::Filter::Status] If present, conferences will be filtered by status.
  #
  #   @param to [String] Filter by To number.
  #
  #   @param type [Symbol, Telnyx::Models::CallControlApplicationListParams::Filter::Type] Event type

  # @see Telnyx::Models::CallControlApplicationListParams::Filter#application_name
  class ApplicationName < Telnyx::Internal::Type::BaseModel
    # @!attribute contains
    #   If present, applications with <code>application_name</code> containing the given
    #   value will be returned. Matching is not case-sensitive. Requires at least three
    #   characters.
    #
    #   @return [String, nil]
    optional :contains, String

    # @!method initialize(contains: nil)
    #   Some parameter documentations has been truncated, see
    #   {Telnyx::Models::CallControlApplicationListParams::Filter::ApplicationName} for
    #   more details.
    #
    #   Application name filters
    #
    #   @param contains [String] If present, applications with <code>application_name</code> containing the given
  end

  # @see Telnyx::Models::CallControlApplicationListParams::Filter#occurred_at
  class OccurredAt < Telnyx::Internal::Type::BaseModel
    # @!attribute eq
    #   Event occurred_at: equal
    #
    #   @return [String, nil]
    optional :eq, String

    # @!attribute gt
    #   Event occurred_at: greater than
    #
    #   @return [String, nil]
    optional :gt, String

    # @!attribute gte
    #   Event occurred_at: greater than or equal
    #
    #   @return [String, nil]
    optional :gte, String

    # @!attribute lt
    #   Event occurred_at: lower than
    #
    #   @return [String, nil]
    optional :lt, String

    # @!attribute lte
    #   Event occurred_at: lower than or equal
    #
    #   @return [String, nil]
    optional :lte, String

    # @!method initialize(eq: nil, gt: nil, gte: nil, lt: nil, lte: nil)
    #   Event occurred_at filters
    #
    #   @param eq [String] Event occurred_at: equal
    #
    #   @param gt [String] Event occurred_at: greater than
    #
    #   @param gte [String] Event occurred_at: greater than or equal
    #
    #   @param lt [String] Event occurred_at: lower than
    #
    #   @param lte [String] Event occurred_at: lower than or equal
  end

  # Filter by product.
  #
  # @see Telnyx::Models::CallControlApplicationListParams::Filter#product
  module Product
    extend Telnyx::Internal::Type::Enum

    CALL_CONTROL = :call_control
    FAX = :fax
    TEXML = :texml

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # If present, conferences will be filtered by status.
  #
  # @see Telnyx::Models::CallControlApplicationListParams::Filter#status
  module Status
    extend Telnyx::Internal::Type::Enum

    INIT = :init
    IN_PROGRESS = :in_progress
    COMPLETED = :completed

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # Event type
  #
  # @see Telnyx::Models::CallControlApplicationListParams::Filter#type
  module Type
    extend Telnyx::Internal::Type::Enum

    COMMAND = :command
    WEBHOOK = :webhook

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#application_nameTelnyx::Models::CallControlApplicationListParams::Filter::ApplicationName?

Application name filters



68
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 68

optional :application_name, -> { Telnyx::CallControlApplicationListParams::Filter::ApplicationName }

#application_session_idString?

The unique identifier of the call session. A session may include multiple call leg events.

Parameters:

  • (String)

Returns:

  • (String, nil)


75
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 75

optional :application_session_id, String

#connection_idString?

The unique identifier of the conection.

Parameters:

  • (String)

Returns:

  • (String, nil)


81
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 81

optional :connection_id, String

#failedBoolean?

Delivery failed or not.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


87
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 87

optional :failed, Telnyx::Internal::Type::Boolean

#fromString?

Filter by From number.

Parameters:

  • (String)

Returns:

  • (String, nil)


93
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 93

optional :from, String

#leg_idString?

The unique identifier of an individual call leg.

Parameters:

  • (String)

Returns:

  • (String, nil)


99
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 99

optional :leg_id, String

#nameString?

If present, conferences will be filtered to those with a matching name attribute. Matching is case-sensitive

Parameters:

  • (String)

Returns:

  • (String, nil)


106
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 106

optional :name, String

#occurred_atTelnyx::Models::CallControlApplicationListParams::Filter::OccurredAt?

Event occurred_at filters



112
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 112

optional :occurred_at, -> { Telnyx::CallControlApplicationListParams::Filter::OccurredAt }

#outbound_outbound_voice_profile_idString?

Identifies the associated outbound voice profile.

Parameters:

  • (String)

Returns:

  • (String, nil)


118
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 118

optional :outbound_outbound_voice_profile_id, String, api_name: :"outbound.outbound_voice_profile_id"

#productSymbol, ...

Filter by product.



124
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 124

optional :product, enum: -> { Telnyx::CallControlApplicationListParams::Filter::Product }

#statusSymbol, ...

If present, conferences will be filtered by status.



130
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 130

optional :status, enum: -> { Telnyx::CallControlApplicationListParams::Filter::Status }

#toString?

Filter by To number.

Parameters:

  • (String)

Returns:

  • (String, nil)


136
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 136

optional :to, String

#typeSymbol, ...

Event type



142
# File 'lib/telnyx/models/call_control_application_list_params.rb', line 142

optional :type, enum: -> { Telnyx::CallControlApplicationListParams::Filter::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_control_application_list_params.rb', line 256

Instance Method Details

#to_hash{

Returns:

  • ({)


148
# File 'sig/telnyx/models/call_control_application_list_params.rbs', line 148

def to_hash: -> {