Class: Telnyx::Models::CallControlBucketIDs
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallControlBucketIDs
- Defined in:
- lib/telnyx/models/call_control_bucket_ids.rb
Instance Attribute Summary collapse
- #bucket_ids ⇒ Array<String>
-
#max_num_results ⇒ Integer?
The maximum number of results to retrieve as context for the language model.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bucket_ids:, max_num_results: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/call_control_bucket_ids.rb', line 17
|
Instance Attribute Details
#bucket_ids ⇒ Array<String>
9 |
# File 'lib/telnyx/models/call_control_bucket_ids.rb', line 9 required :bucket_ids, Telnyx::Internal::Type::ArrayOf[String] |
#max_num_results ⇒ Integer?
The maximum number of results to retrieve as context for the language model.
15 |
# File 'lib/telnyx/models/call_control_bucket_ids.rb', line 15 optional :max_num_results, Integer |