Class: Telnyx::Models::CallConversationEnded::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_conversation_ended.rb

Overview

See Also:

Defined Under Namespace

Modules: CallingPartyType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(assistant_id: nil, call_control_id: nil, call_leg_id: nil, call_session_id: nil, calling_party_type: nil, client_state: nil, connection_id: nil, conversation_id: nil, duration_sec: nil, from: nil, llm_model: nil, stt_model: nil, to: nil, tts_model_id: nil, tts_provider: nil, tts_voice_id: nil) ⇒ Object

Parameters:

  • assistant_id (String) (defaults to: nil)

    Unique identifier of the assistant involved in the call.

  • call_control_id (String) (defaults to: nil)

    Call ID used to issue commands via Call Control API.

  • call_leg_id (String) (defaults to: nil)

    ID that is unique to the call leg.

  • call_session_id (String) (defaults to: nil)

    ID that is unique to the call session (group of related call legs).

  • calling_party_type (Symbol, Telnyx::Models::CallConversationEnded::Payload::CallingPartyType) (defaults to: nil)

    The type of calling party connection.

  • client_state (String) (defaults to: nil)

    Base64-encoded state received from a command.

  • connection_id (String) (defaults to: nil)

    Call Control App ID (formerly Telnyx connection ID) used in the call.

  • conversation_id (String) (defaults to: nil)

    ID unique to the conversation or insight group generated for the call.

  • duration_sec (Integer) (defaults to: nil)

    Duration of the conversation in seconds.

  • from (String) (defaults to: nil)

    The caller’s number or identifier.

  • llm_model (String) (defaults to: nil)

    The large language model used during the conversation.

  • stt_model (String) (defaults to: nil)

    The speech-to-text model used in the conversation.

  • to (String) (defaults to: nil)

    The callee’s number or SIP address.

  • tts_model_id (String) (defaults to: nil)

    The model ID used for text-to-speech synthesis.

  • tts_provider (String) (defaults to: nil)

    The text-to-speech provider used in the call.

  • tts_voice_id (String) (defaults to: nil)

    Voice ID used for TTS.



# File 'lib/telnyx/models/call_conversation_ended.rb', line 164

Instance Attribute Details

#assistant_idString?

Unique identifier of the assistant involved in the call.

Returns:

  • (String, nil)


72
# File 'lib/telnyx/models/call_conversation_ended.rb', line 72

optional :assistant_id, String

#call_control_idString?

Call ID used to issue commands via Call Control API.

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/call_conversation_ended.rb', line 78

optional :call_control_id, String

#call_leg_idString?

ID that is unique to the call leg.

Returns:

  • (String, nil)


84
# File 'lib/telnyx/models/call_conversation_ended.rb', line 84

optional :call_leg_id, String

#call_session_idString?

ID that is unique to the call session (group of related call legs).

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/call_conversation_ended.rb', line 90

optional :call_session_id, String

#calling_party_typeSymbol, ...

The type of calling party connection.



96
# File 'lib/telnyx/models/call_conversation_ended.rb', line 96

optional :calling_party_type, enum: -> { Telnyx::CallConversationEnded::Payload::CallingPartyType }

#client_stateString?

Base64-encoded state received from a command.

Returns:

  • (String, nil)


102
# File 'lib/telnyx/models/call_conversation_ended.rb', line 102

optional :client_state, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


108
# File 'lib/telnyx/models/call_conversation_ended.rb', line 108

optional :connection_id, String

#conversation_idString?

ID unique to the conversation or insight group generated for the call.

Returns:

  • (String, nil)


114
# File 'lib/telnyx/models/call_conversation_ended.rb', line 114

optional :conversation_id, String

#duration_secInteger?

Duration of the conversation in seconds.

Returns:

  • (Integer, nil)


120
# File 'lib/telnyx/models/call_conversation_ended.rb', line 120

optional :duration_sec, Integer

#fromString?

The caller’s number or identifier.

Returns:

  • (String, nil)


126
# File 'lib/telnyx/models/call_conversation_ended.rb', line 126

optional :from, String

#llm_modelString?

The large language model used during the conversation.

Returns:

  • (String, nil)


132
# File 'lib/telnyx/models/call_conversation_ended.rb', line 132

optional :llm_model, String

#stt_modelString?

The speech-to-text model used in the conversation.

Returns:

  • (String, nil)


138
# File 'lib/telnyx/models/call_conversation_ended.rb', line 138

optional :stt_model, String

#toString?

The callee’s number or SIP address.

Returns:

  • (String, nil)


144
# File 'lib/telnyx/models/call_conversation_ended.rb', line 144

optional :to, String

#tts_model_idString?

The model ID used for text-to-speech synthesis.

Returns:

  • (String, nil)


150
# File 'lib/telnyx/models/call_conversation_ended.rb', line 150

optional :tts_model_id, String

#tts_providerString?

The text-to-speech provider used in the call.

Returns:

  • (String, nil)


156
# File 'lib/telnyx/models/call_conversation_ended.rb', line 156

optional :tts_provider, String

#tts_voice_idString?

Voice ID used for TTS.

Returns:

  • (String, nil)


162
# File 'lib/telnyx/models/call_conversation_ended.rb', line 162

optional :tts_voice_id, String