Class: Telnyx::Models::CallConversationInsightsGenerated::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_conversation_insights_generated.rb

Overview

See Also:

Defined Under Namespace

Modules: CallingPartyType Classes: Result

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, calling_party_type: nil, client_state: nil, connection_id: nil, insight_group_id: nil, results: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallConversationInsightsGenerated::Payload for more details.

Parameters:

  • call_control_id (String) (defaults to: nil)

    Call ID used to issue commands via Call Control API.

  • call_leg_id (String) (defaults to: nil)

    ID that is unique to the call and can be used to correlate webhook events.

  • call_session_id (String) (defaults to: nil)

    ID that is unique to the call session and can be used to correlate webhook event

  • calling_party_type (Symbol, Telnyx::Models::CallConversationInsightsGenerated::Payload::CallingPartyType) (defaults to: nil)

    The type of calling party connection.

  • client_state (String) (defaults to: nil)

    State received from a command.

  • connection_id (String) (defaults to: nil)

    Call Control App ID (formerly Telnyx connection ID) used in the call.

  • insight_group_id (String) (defaults to: nil)

    ID that is unique to the insight group being generated for the call.

  • results (Array<Telnyx::Models::CallConversationInsightsGenerated::Payload::Result>) (defaults to: nil)

    Array of insight results being generated for the call.



# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 112

Instance Attribute Details

#call_control_idString?

Call ID used to issue commands via Call Control API.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 64

optional :call_control_id, String

#call_leg_idString?

ID that is unique to the call and can be used to correlate webhook events.

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 70

optional :call_leg_id, String

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 78

optional :call_session_id, String

#calling_party_typeSymbol, ...

The type of calling party connection.



84
85
# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 84

optional :calling_party_type,
enum: -> { Telnyx::CallConversationInsightsGenerated::Payload::CallingPartyType }

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


91
# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 91

optional :client_state, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


97
# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 97

optional :connection_id, String

#insight_group_idString?

ID that is unique to the insight group being generated for the call.

Returns:

  • (String, nil)


103
# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 103

optional :insight_group_id, String

#resultsArray<Telnyx::Models::CallConversationInsightsGenerated::Payload::Result>?

Array of insight results being generated for the call.



109
110
# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 109

optional :results,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::CallConversationInsightsGenerated::Payload::Result] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 141