Class: Telnyx::Models::CallConversationInsightsGenerated::Payload::Result

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_conversation_insights_generated.rb

Defined Under Namespace

Modules: Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(insight_id: nil, result: nil) ⇒ Object

Parameters:

  • insight_id (String) (defaults to: nil)

    ID that is unique to the insight result being generated for the call.

  • result (Hash{Symbol=>Object}, String) (defaults to: nil)

    The result of the insight.



# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 158

Instance Attribute Details

#insight_idString?

ID that is unique to the insight result being generated for the call.

Returns:

  • (String, nil)


150
# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 150

optional :insight_id, String

#resultHash{Symbol=>Object}, ...

The result of the insight.

Returns:

  • (Hash{Symbol=>Object}, String, nil)


156
# File 'lib/telnyx/models/call_conversation_insights_generated.rb', line 156

optional :result, union: -> { Telnyx::CallConversationInsightsGenerated::Payload::Result::Result }