Class: Telnyx::Models::CallDialParams::AnsweringMachineDetectionConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_dial_params.rb,
sig/telnyx/models/call_dial_params.rbs

Defined Under Namespace

Modules: BeepDetectionProfile

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after_greeting_silence_millis: nil, beep_detection_profile: nil, between_words_silence_millis: nil, greeting_duration_millis: nil, greeting_silence_duration_millis: nil, greeting_total_analysis_time_millis: nil, initial_silence_millis: nil, maximum_number_of_words: nil, maximum_word_length_millis: nil, silence_threshold: nil, total_analysis_time_millis: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallDialParams::AnsweringMachineDetectionConfig for more details.

Optional configuration parameters to modify 'answering_machine_detection' performance. Only total_analysis_time_millis and greeting_duration_millis parameters are applicable when premium is selected as answering_machine_detection.

Parameters:

  • after_greeting_silence_millis (Integer) (defaults to: nil)

    Silence duration threshold after a greeting message or voice for it be considere

  • beep_detection_profile (Symbol, Telnyx::Models::CallDialParams::AnsweringMachineDetectionConfig::BeepDetectionProfile) (defaults to: nil)

    Selects which detectors must validate a beep. both requires the amplitude and

  • between_words_silence_millis (Integer) (defaults to: nil)

    Maximum threshold for silence between words.

  • greeting_duration_millis (Integer) (defaults to: nil)

    Maximum threshold of a human greeting. If greeting longer than this value, consi

  • greeting_silence_duration_millis (Integer) (defaults to: nil)

    If machine already detected, maximum threshold for silence between words. If exc

  • greeting_total_analysis_time_millis (Integer) (defaults to: nil)

    If machine already detected, maximum timeout threshold to determine the end of t

  • initial_silence_millis (Integer) (defaults to: nil)

    If initial silence duration is greater than this value, consider it a machine.

  • maximum_number_of_words (Integer) (defaults to: nil)

    If number of detected words is greater than this value, consder it a machine.

  • maximum_word_length_millis (Integer) (defaults to: nil)

    If a single word lasts longer than this threshold, consider it a machine.

  • silence_threshold (Integer) (defaults to: nil)

    Minimum noise threshold for any analysis.

  • total_analysis_time_millis (Integer) (defaults to: nil)

    Maximum timeout threshold for overall detection.



# File 'lib/telnyx/models/call_dial_params.rb', line 775

Instance Attribute Details

#after_greeting_silence_millisInteger?

Silence duration threshold after a greeting message or voice for it be considered human.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


707
# File 'lib/telnyx/models/call_dial_params.rb', line 707

optional :after_greeting_silence_millis, Integer

#beep_detection_profileSymbol, ...

Selects which detectors must validate a beep. both requires the amplitude and frequency detectors to agree. freq_only uses the frequency detector alone, for beeps whose volume is too unsteady for the default profile.



715
716
# File 'lib/telnyx/models/call_dial_params.rb', line 715

optional :beep_detection_profile,
enum: -> { Telnyx::CallDialParams::AnsweringMachineDetectionConfig::BeepDetectionProfile }

#between_words_silence_millisInteger?

Maximum threshold for silence between words.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


722
# File 'lib/telnyx/models/call_dial_params.rb', line 722

optional :between_words_silence_millis, Integer

#greeting_duration_millisInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


729
# File 'lib/telnyx/models/call_dial_params.rb', line 729

optional :greeting_duration_millis, Integer

#greeting_silence_duration_millisInteger?

If machine already detected, maximum threshold for silence between words. If exceeded, the greeting is considered ended.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


736
# File 'lib/telnyx/models/call_dial_params.rb', line 736

optional :greeting_silence_duration_millis, Integer

#greeting_total_analysis_time_millisInteger?

If machine already detected, maximum timeout threshold to determine the end of the machine greeting.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


743
# File 'lib/telnyx/models/call_dial_params.rb', line 743

optional :greeting_total_analysis_time_millis, Integer

#initial_silence_millisInteger?

If initial silence duration is greater than this value, consider it a machine.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


749
# File 'lib/telnyx/models/call_dial_params.rb', line 749

optional :initial_silence_millis, Integer

#maximum_number_of_wordsInteger?

If number of detected words is greater than this value, consder it a machine.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


755
# File 'lib/telnyx/models/call_dial_params.rb', line 755

optional :maximum_number_of_words, Integer

#maximum_word_length_millisInteger?

If a single word lasts longer than this threshold, consider it a machine.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


761
# File 'lib/telnyx/models/call_dial_params.rb', line 761

optional :maximum_word_length_millis, Integer

#silence_thresholdInteger?

Minimum noise threshold for any analysis.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


767
# File 'lib/telnyx/models/call_dial_params.rb', line 767

optional :silence_threshold, Integer

#total_analysis_time_millisInteger?

Maximum timeout threshold for overall detection.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


773
# File 'lib/telnyx/models/call_dial_params.rb', line 773

optional :total_analysis_time_millis, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


631
# File 'sig/telnyx/models/call_dial_params.rbs', line 631

def to_hash: -> {