Class: Telnyx::Models::CallDialParams::DeepfakeDetection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_dial_params.rb,
sig/telnyx/models/call_dial_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



775
# File 'sig/telnyx/models/call_dial_params.rbs', line 775

def initialize: (

Instance Attribute Details

#enabledBoolean

Whether deepfake detection is enabled.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


958
# File 'lib/telnyx/models/call_dial_params.rb', line 958

required :enabled, Telnyx::Internal::Type::Boolean

#rtp_timeoutInteger?

Maximum time in seconds to wait for RTP audio before timing out. If no audio is received within this window, detection stops with an error.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


965
# File 'lib/telnyx/models/call_dial_params.rb', line 965

optional :rtp_timeout, Integer

#timeoutInteger?

Maximum time in seconds to wait for a detection result before timing out.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


971
# File 'lib/telnyx/models/call_dial_params.rb', line 971

optional :timeout, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


781
# File 'sig/telnyx/models/call_dial_params.rbs', line 781

def to_hash: -> {