Class: Telnyx::Models::CallDialResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_dial_response.rb

Overview

See Also:

Defined Under Namespace

Modules: RecordType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, call_leg_id:, call_session_id:, is_alive:, record_type:, call_duration: nil, client_state: nil, end_time: nil, recording_id: nil, start_time: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallDialResponse::Data for more details.

Parameters:

  • call_control_id (String)

    Unique identifier and token for controlling the call.

  • call_leg_id (String)

    ID that is unique to the call and can be used to correlate webhook events

  • call_session_id (String)

    ID that is unique to the call session and can be used to correlate webhook event

  • is_alive (Boolean)

    Indicates whether the call is alive or not. For Dial command it will always be ‘

  • record_type (Symbol, Telnyx::Models::CallDialResponse::Data::RecordType)
  • call_duration (Integer) (defaults to: nil)

    Indicates the duration of the call in seconds

  • client_state (String) (defaults to: nil)

    State received from a command.

  • end_time (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the call ended. Only present when the ca

  • recording_id (String) (defaults to: nil)

    The ID of the recording. Only present when the record parameter is set to record

  • start_time (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the call started



# File 'lib/telnyx/models/call_dial_response.rb', line 81

Instance Attribute Details

#call_control_idString

Unique identifier and token for controlling the call.

Returns:

  • (String)


21
# File 'lib/telnyx/models/call_dial_response.rb', line 21

required :call_control_id, String

#call_durationInteger?

Indicates the duration of the call in seconds

Returns:

  • (Integer, nil)


53
# File 'lib/telnyx/models/call_dial_response.rb', line 53

optional :call_duration, Integer

#call_leg_idString

ID that is unique to the call and can be used to correlate webhook events

Returns:

  • (String)


27
# File 'lib/telnyx/models/call_dial_response.rb', line 27

required :call_leg_id, String

#call_session_idString

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call

Returns:

  • (String)


35
# File 'lib/telnyx/models/call_dial_response.rb', line 35

required :call_session_id, String

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/call_dial_response.rb', line 59

optional :client_state, String

#end_timeString?

ISO 8601 formatted date indicating when the call ended. Only present when the call is not alive

Returns:

  • (String, nil)


66
# File 'lib/telnyx/models/call_dial_response.rb', line 66

optional :end_time, String

#is_aliveBoolean

Indicates whether the call is alive or not. For Dial command it will always be ‘false` (dialing is asynchronous).

Returns:

  • (Boolean)


42
# File 'lib/telnyx/models/call_dial_response.rb', line 42

required :is_alive, Telnyx::Internal::Type::Boolean

#record_typeSymbol, Telnyx::Models::CallDialResponse::Data::RecordType



47
# File 'lib/telnyx/models/call_dial_response.rb', line 47

required :record_type, enum: -> { Telnyx::Models::CallDialResponse::Data::RecordType }

#recording_idString?

The ID of the recording. Only present when the record parameter is set to record-from-answer.

Returns:

  • (String, nil)


73
# File 'lib/telnyx/models/call_dial_response.rb', line 73

optional :recording_id, String

#start_timeString?

ISO 8601 formatted date indicating when the call started

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/call_dial_response.rb', line 79

optional :start_time, String