Class: Telnyx::Models::CallEventListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_event_list_response.rb

Overview

Defined Under Namespace

Modules: RecordType, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_leg_id:, call_session_id:, event_timestamp:, metadata:, name:, record_type:, type:) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallEventListResponse for more details.

Parameters:

  • call_leg_id (String)

    Uniquely identifies an individual call leg.

  • call_session_id (String)

    Uniquely identifies the call control session. A session may include multiple cal

  • event_timestamp (String)

    Event timestamp

  • metadata (Hash{Symbol=>Object})

    Event metadata, which includes raw event, and extra information based on event t

  • name (String)

    Event name

  • record_type (Symbol, Telnyx::Models::CallEventListResponse::RecordType)
  • type (Symbol, Telnyx::Models::CallEventListResponse::Type)

    Event type



# File 'lib/telnyx/models/call_event_list_response.rb', line 50

Instance Attribute Details

#call_leg_idString

Uniquely identifies an individual call leg.

Returns:

  • (String)


11
# File 'lib/telnyx/models/call_event_list_response.rb', line 11

required :call_leg_id, String

#call_session_idString

Uniquely identifies the call control session. A session may include multiple call leg events.

Returns:

  • (String)


18
# File 'lib/telnyx/models/call_event_list_response.rb', line 18

required :call_session_id, String

#event_timestampString

Event timestamp

Returns:

  • (String)


24
# File 'lib/telnyx/models/call_event_list_response.rb', line 24

required :event_timestamp, String

#metadataHash{Symbol=>Object}

Event metadata, which includes raw event, and extra information based on event type

Returns:

  • (Hash{Symbol=>Object})


31
# File 'lib/telnyx/models/call_event_list_response.rb', line 31

required :metadata, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#nameString

Event name

Returns:

  • (String)


37
# File 'lib/telnyx/models/call_event_list_response.rb', line 37

required :name, String

#record_typeSymbol, Telnyx::Models::CallEventListResponse::RecordType



42
# File 'lib/telnyx/models/call_event_list_response.rb', line 42

required :record_type, enum: -> { Telnyx::Models::CallEventListResponse::RecordType }

#typeSymbol, Telnyx::Models::CallEventListResponse::Type

Event type



48
# File 'lib/telnyx/models/call_event_list_response.rb', line 48

required :type, enum: -> { Telnyx::Models::CallEventListResponse::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_event_list_response.rb', line 74