Class: Telnyx::Models::CallGatherEnded::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_gather_ended.rb

Overview

See Also:

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, digits: nil, from: nil, status: nil, to: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallGatherEnded::Payload for more details.

Parameters:

  • call_control_id (String) (defaults to: nil)

    Call ID used to issue commands via Call Control API.

  • call_leg_id (String) (defaults to: nil)

    ID that is unique to the call and can be used to correlate webhook events.

  • call_session_id (String) (defaults to: nil)

    ID that is unique to the call session and can be used to correlate webhook event

  • client_state (String) (defaults to: nil)

    State received from a command.

  • connection_id (String) (defaults to: nil)

    Call Control App ID (formerly Telnyx connection ID) used in the call.

  • digits (String) (defaults to: nil)

    The received DTMF digit or symbol.

  • from (String) (defaults to: nil)

    Number or SIP URI placing the call.

  • status (Symbol, Telnyx::Models::CallGatherEnded::Payload::Status) (defaults to: nil)

    Reflects how command ended.

  • to (String) (defaults to: nil)

    Destination number or SIP URI of the call.



# File 'lib/telnyx/models/call_gather_ended.rb', line 116

Instance Attribute Details

#call_control_idString?

Call ID used to issue commands via Call Control API.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/call_gather_ended.rb', line 64

optional :call_control_id, String

#call_leg_idString?

ID that is unique to the call and can be used to correlate webhook events.

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/call_gather_ended.rb', line 70

optional :call_leg_id, String

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/call_gather_ended.rb', line 78

optional :call_session_id, String

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


84
# File 'lib/telnyx/models/call_gather_ended.rb', line 84

optional :client_state, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/call_gather_ended.rb', line 90

optional :connection_id, String

#digitsString?

The received DTMF digit or symbol.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/call_gather_ended.rb', line 96

optional :digits, String

#fromString?

Number or SIP URI placing the call.

Returns:

  • (String, nil)


102
# File 'lib/telnyx/models/call_gather_ended.rb', line 102

optional :from, String

#statusSymbol, ...

Reflects how command ended.



108
# File 'lib/telnyx/models/call_gather_ended.rb', line 108

optional :status, enum: -> { Telnyx::CallGatherEnded::Payload::Status }

#toString?

Destination number or SIP URI of the call.

Returns:

  • (String, nil)


114
# File 'lib/telnyx/models/call_gather_ended.rb', line 114

optional :to, String