Class: Telnyx::Models::CallHangup::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_hangup.rb

Overview

See Also:

Defined Under Namespace

Modules: HangupCause, HangupSource, State Classes: CallQualityStats

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(packet_count: nil, skip_packet_count: nil) ⇒ Object

Outbound call quality statistics.

Parameters:

  • packet_count (String) (defaults to: nil)

    Total number of outbound audio packets.

  • skip_packet_count (String) (defaults to: nil)

    Number of skipped outbound packets (packet loss).



# File 'lib/telnyx/models/call_hangup.rb', line 163

Instance Attribute Details

#call_control_idString?

Call ID used to issue commands via Call Control API.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/call_hangup.rb', line 64

optional :call_control_id, String

#call_leg_idString?

ID that is unique to the call and can be used to correlate webhook events.

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/call_hangup.rb', line 70

optional :call_leg_id, String

#call_quality_statsTelnyx::Models::CallHangup::Payload::CallQualityStats?

Call quality statistics aggregated from the CHANNEL_HANGUP_COMPLETE event. Only includes metrics that are available (filters out nil values). Returns nil if no metrics are available.



78
# File 'lib/telnyx/models/call_hangup.rb', line 78

optional :call_quality_stats, -> { Telnyx::CallHangup::Payload::CallQualityStats }, nil?: true

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


86
# File 'lib/telnyx/models/call_hangup.rb', line 86

optional :call_session_id, String

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


92
# File 'lib/telnyx/models/call_hangup.rb', line 92

optional :client_state, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


98
# File 'lib/telnyx/models/call_hangup.rb', line 98

optional :connection_id, String

#custom_headersArray<Telnyx::Models::CustomSipHeader>?

Custom headers set on answer command

Returns:



104
# File 'lib/telnyx/models/call_hangup.rb', line 104

optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] }

#fromString?

Number or SIP URI placing the call.

Returns:

  • (String, nil)


110
# File 'lib/telnyx/models/call_hangup.rb', line 110

optional :from, String

#hangup_causeSymbol, ...

The reason the call was ended (‘call_rejected`, `normal_clearing`, `originator_cancel`, `timeout`, `time_limit`, `user_busy`, `not_found`, `no_answer` or `unspecified`).



118
# File 'lib/telnyx/models/call_hangup.rb', line 118

optional :hangup_cause, enum: -> { Telnyx::CallHangup::Payload::HangupCause }

#hangup_sourceSymbol, ...

The party who ended the call (‘callee`, `caller`, `unknown`).



124
# File 'lib/telnyx/models/call_hangup.rb', line 124

optional :hangup_source, enum: -> { Telnyx::CallHangup::Payload::HangupSource }

#sip_hangup_causeString?

The reason the call was ended (SIP response code). If the SIP response is unavailable (in inbound calls for example) this is set to ‘unspecified`.

Returns:

  • (String, nil)


131
# File 'lib/telnyx/models/call_hangup.rb', line 131

optional :sip_hangup_cause, String

#sip_headersArray<Telnyx::Models::SipHeader>?

User-to-User and Diversion headers from sip invite.

Returns:



137
# File 'lib/telnyx/models/call_hangup.rb', line 137

optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] }

#start_timeTime?

ISO 8601 datetime of when the call started.

Returns:

  • (Time, nil)


143
# File 'lib/telnyx/models/call_hangup.rb', line 143

optional :start_time, Time

#stateSymbol, ...

State received from a command.



149
# File 'lib/telnyx/models/call_hangup.rb', line 149

optional :state, enum: -> { Telnyx::CallHangup::Payload::State }

#tagsArray<String>?

Array of tags associated to number.

Returns:

  • (Array<String>, nil)


155
# File 'lib/telnyx/models/call_hangup.rb', line 155

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#toString?

Destination number or SIP URI of the call.

Returns:

  • (String, nil)


161
# File 'lib/telnyx/models/call_hangup.rb', line 161

optional :to, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_hangup.rb', line 309