Class: Telnyx::Models::CallHangupWebhookEvent::Data::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_hangup_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Modules: HangupCause, HangupSource, State Classes: CallQualityStats

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(packet_count: nil, skip_packet_count: nil) ⇒ Object

Outbound call quality statistics.

Parameters:

  • packet_count (String) (defaults to: nil)

    Total number of outbound audio packets.

  • skip_packet_count (String) (defaults to: nil)

    Number of skipped outbound packets (packet loss).



# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 175

Instance Attribute Details

#call_control_idString?

Call ID used to issue commands via Call Control API.

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 74

optional :call_control_id, String

#call_leg_idString?

ID that is unique to the call and can be used to correlate webhook events.

Returns:

  • (String, nil)


80
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 80

optional :call_leg_id, String

#call_quality_statsTelnyx::Models::CallHangupWebhookEvent::Data::Payload::CallQualityStats?

Call quality statistics aggregated from the CHANNEL_HANGUP_COMPLETE event. Only includes metrics that are available (filters out nil values). Returns nil if no metrics are available.



88
89
90
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 88

optional :call_quality_stats,
-> { Telnyx::CallHangupWebhookEvent::Data::Payload::CallQualityStats },
nil?: true

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


98
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 98

optional :call_session_id, String

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


104
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 104

optional :client_state, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


110
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 110

optional :connection_id, String

#custom_headersArray<Telnyx::Models::CustomSipHeader>?

Custom headers set on answer command

Returns:



116
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 116

optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] }

#fromString?

Number or SIP URI placing the call.

Returns:

  • (String, nil)


122
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 122

optional :from, String

#hangup_causeSymbol, ...

The reason the call was ended (‘call_rejected`, `normal_clearing`, `originator_cancel`, `timeout`, `time_limit`, `user_busy`, `not_found`, `no_answer` or `unspecified`).



130
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 130

optional :hangup_cause, enum: -> { Telnyx::CallHangupWebhookEvent::Data::Payload::HangupCause }

#hangup_sourceSymbol, ...

The party who ended the call (‘callee`, `caller`, `unknown`).



136
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 136

optional :hangup_source, enum: -> { Telnyx::CallHangupWebhookEvent::Data::Payload::HangupSource }

#sip_hangup_causeString?

The reason the call was ended (SIP response code). If the SIP response is unavailable (in inbound calls for example) this is set to ‘unspecified`.

Returns:

  • (String, nil)


143
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 143

optional :sip_hangup_cause, String

#sip_headersArray<Telnyx::Models::SipHeader>?

User-to-User and Diversion headers from sip invite.

Returns:



149
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 149

optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] }

#start_timeTime?

ISO 8601 datetime of when the call started.

Returns:

  • (Time, nil)


155
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 155

optional :start_time, Time

#stateSymbol, ...

State received from a command.



161
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 161

optional :state, enum: -> { Telnyx::CallHangupWebhookEvent::Data::Payload::State }

#tagsArray<String>?

Array of tags associated to number.

Returns:

  • (Array<String>, nil)


167
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 167

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#toString?

Destination number or SIP URI of the call.

Returns:

  • (String, nil)


173
# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 173

optional :to, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_hangup_webhook_event.rb', line 321