Class: Telnyx::Models::CallInitiated::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_initiated.rb

Overview

See Also:

Defined Under Namespace

Modules: Direction, State

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id: nil, call_leg_id: nil, call_screening_result: nil, call_session_id: nil, caller_id_name: nil, client_state: nil, connection_codecs: nil, connection_id: nil, custom_headers: nil, direction: nil, from: nil, offered_codecs: nil, shaken_stir_attestation: nil, shaken_stir_validated: nil, sip_headers: nil, start_time: nil, state: nil, tags: nil, to: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallInitiated::Payload for more details.

Parameters:

  • call_control_id (String) (defaults to: nil)

    Call ID used to issue commands via Call Control API.

  • call_leg_id (String) (defaults to: nil)

    ID that is unique to the call and can be used to correlate webhook events.

  • call_screening_result (String) (defaults to: nil)

    Call screening result.

  • call_session_id (String) (defaults to: nil)

    ID that is unique to the call session and can be used to correlate webhook event

  • caller_id_name (String) (defaults to: nil)

    Caller id.

  • client_state (String) (defaults to: nil)

    State received from a command.

  • connection_codecs (String) (defaults to: nil)

    The list of comma-separated codecs enabled for the connection.

  • connection_id (String) (defaults to: nil)

    Call Control App ID (formerly Telnyx connection ID) used in the call.

  • custom_headers (Array<Telnyx::Models::CustomSipHeader>) (defaults to: nil)

    Custom headers from sip invite

  • direction (Symbol, Telnyx::Models::CallInitiated::Payload::Direction) (defaults to: nil)

    Whether the call is ‘incoming` or `outgoing`.

  • from (String) (defaults to: nil)

    Number or SIP URI placing the call.

  • offered_codecs (String) (defaults to: nil)

    The list of comma-separated codecs offered by caller.

  • shaken_stir_attestation (String) (defaults to: nil)

    SHAKEN/STIR attestation level.

  • shaken_stir_validated (Boolean) (defaults to: nil)

    Whether attestation was successfully validated or not.

  • sip_headers (Array<Telnyx::Models::SipHeader>) (defaults to: nil)

    User-to-User and Diversion headers from sip invite.

  • start_time (Time) (defaults to: nil)

    ISO 8601 datetime of when the call started.

  • state (Symbol, Telnyx::Models::CallInitiated::Payload::State) (defaults to: nil)

    State received from a command.

  • tags (Array<String>) (defaults to: nil)

    Array of tags associated to number.

  • to (String) (defaults to: nil)

    Destination number or SIP URI of the call.



# File 'lib/telnyx/models/call_initiated.rb', line 176

Instance Attribute Details

#call_control_idString?

Call ID used to issue commands via Call Control API.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/call_initiated.rb', line 64

optional :call_control_id, String

#call_leg_idString?

ID that is unique to the call and can be used to correlate webhook events.

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/call_initiated.rb', line 70

optional :call_leg_id, String

#call_screening_resultString?

Call screening result.

Returns:

  • (String, nil)


76
# File 'lib/telnyx/models/call_initiated.rb', line 76

optional :call_screening_result, String

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


84
# File 'lib/telnyx/models/call_initiated.rb', line 84

optional :call_session_id, String

#caller_id_nameString?

Caller id.

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/call_initiated.rb', line 90

optional :caller_id_name, String

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/call_initiated.rb', line 96

optional :client_state, String

#connection_codecsString?

The list of comma-separated codecs enabled for the connection.

Returns:

  • (String, nil)


102
# File 'lib/telnyx/models/call_initiated.rb', line 102

optional :connection_codecs, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


108
# File 'lib/telnyx/models/call_initiated.rb', line 108

optional :connection_id, String

#custom_headersArray<Telnyx::Models::CustomSipHeader>?

Custom headers from sip invite

Returns:



114
# File 'lib/telnyx/models/call_initiated.rb', line 114

optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] }

#directionSymbol, ...

Whether the call is ‘incoming` or `outgoing`.



120
# File 'lib/telnyx/models/call_initiated.rb', line 120

optional :direction, enum: -> { Telnyx::CallInitiated::Payload::Direction }

#fromString?

Number or SIP URI placing the call.

Returns:

  • (String, nil)


126
# File 'lib/telnyx/models/call_initiated.rb', line 126

optional :from, String

#offered_codecsString?

The list of comma-separated codecs offered by caller.

Returns:

  • (String, nil)


132
# File 'lib/telnyx/models/call_initiated.rb', line 132

optional :offered_codecs, String

#shaken_stir_attestationString?

SHAKEN/STIR attestation level.

Returns:

  • (String, nil)


138
# File 'lib/telnyx/models/call_initiated.rb', line 138

optional :shaken_stir_attestation, String

#shaken_stir_validatedBoolean?

Whether attestation was successfully validated or not.

Returns:

  • (Boolean, nil)


144
# File 'lib/telnyx/models/call_initiated.rb', line 144

optional :shaken_stir_validated, Telnyx::Internal::Type::Boolean

#sip_headersArray<Telnyx::Models::SipHeader>?

User-to-User and Diversion headers from sip invite.

Returns:



150
# File 'lib/telnyx/models/call_initiated.rb', line 150

optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] }

#start_timeTime?

ISO 8601 datetime of when the call started.

Returns:

  • (Time, nil)


156
# File 'lib/telnyx/models/call_initiated.rb', line 156

optional :start_time, Time

#stateSymbol, ...

State received from a command.



162
# File 'lib/telnyx/models/call_initiated.rb', line 162

optional :state, enum: -> { Telnyx::CallInitiated::Payload::State }

#tagsArray<String>?

Array of tags associated to number.

Returns:

  • (Array<String>, nil)


168
# File 'lib/telnyx/models/call_initiated.rb', line 168

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#toString?

Destination number or SIP URI of the call.

Returns:

  • (String, nil)


174
# File 'lib/telnyx/models/call_initiated.rb', line 174

optional :to, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_initiated.rb', line 227