Class: Telnyx::Models::CallMachinePremiumGreetingEnded::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallMachinePremiumGreetingEnded::Payload
- Defined in:
- lib/telnyx/models/call_machine_premium_greeting_ended.rb
Overview
Defined Under Namespace
Modules: Result
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#from ⇒ String?
Number or SIP URI placing the call.
-
#result ⇒ Symbol, ...
Premium Answering Machine Greeting Ended result.
-
#to ⇒ String?
Destination number or SIP URI of the call.
Instance Method Summary collapse
-
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, from: nil, result: nil, to: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, from: nil, result: nil, to: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallMachinePremiumGreetingEnded::Payload for more details.
|
|
# File 'lib/telnyx/models/call_machine_premium_greeting_ended.rb', line 110
|
Instance Attribute Details
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
64 |
# File 'lib/telnyx/models/call_machine_premium_greeting_ended.rb', line 64 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
70 |
# File 'lib/telnyx/models/call_machine_premium_greeting_ended.rb', line 70 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
78 |
# File 'lib/telnyx/models/call_machine_premium_greeting_ended.rb', line 78 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command.
84 |
# File 'lib/telnyx/models/call_machine_premium_greeting_ended.rb', line 84 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
90 |
# File 'lib/telnyx/models/call_machine_premium_greeting_ended.rb', line 90 optional :connection_id, String |
#from ⇒ String?
Number or SIP URI placing the call.
96 |
# File 'lib/telnyx/models/call_machine_premium_greeting_ended.rb', line 96 optional :from, String |
#result ⇒ Symbol, ...
Premium Answering Machine Greeting Ended result.
102 |
# File 'lib/telnyx/models/call_machine_premium_greeting_ended.rb', line 102 optional :result, enum: -> { Telnyx::CallMachinePremiumGreetingEnded::Payload::Result } |
#to ⇒ String?
Destination number or SIP URI of the call.
108 |
# File 'lib/telnyx/models/call_machine_premium_greeting_ended.rb', line 108 optional :to, String |