Class: Telnyx::Models::CallReasonValidateResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_reason_validate_response.rb,
sig/telnyx/models/call_reason_validate_response.rbs

Overview

See Also:

  • Telnyx::Models::CallReasonValidateResponse#data

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(all_pre_approved:, non_approved_reasons:, requires_manual_vetting:) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallReasonValidateResponse::Data for more details.

Parameters:

  • all_pre_approved (Boolean)

    true when every supplied reason matches a pre-vetted entry in the call-reason

  • non_approved_reasons (Array<String>)

    Subset of the input that does NOT match the pre-vetted library. The DIR can stil

  • requires_manual_vetting (Boolean)

    true when at least one supplied reason is in non_approved_reasons. Equivalen



# File 'lib/telnyx/models/call_reason_validate_response.rb', line 40

Instance Attribute Details

#all_pre_approvedBoolean

true when every supplied reason matches a pre-vetted entry in the call-reason library. When true, the DIR will sail through the call-reasons portion of vetting.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


23
# File 'lib/telnyx/models/call_reason_validate_response.rb', line 23

required :all_pre_approved, Telnyx::Internal::Type::Boolean

#non_approved_reasonsArray<String>

Subset of the input that does NOT match the pre-vetted library. The DIR can still be submitted with these - they will go through manual review.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


30
# File 'lib/telnyx/models/call_reason_validate_response.rb', line 30

required :non_approved_reasons, Telnyx::Internal::Type::ArrayOf[String]

#requires_manual_vettingBoolean

true when at least one supplied reason is in non_approved_reasons. Equivalent to non_approved_reasons.length > 0 and the inverse of all_pre_approved.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


38
# File 'lib/telnyx/models/call_reason_validate_response.rb', line 38

required :requires_manual_vetting, Telnyx::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


35
# File 'sig/telnyx/models/call_reason_validate_response.rbs', line 35

def to_hash: -> {