Class: Telnyx::Models::CallRecordingSavedWebhookEvent::Data::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_recording_saved_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Modules: Channels Classes: PublicRecordingURLs, RecordingURLs

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mp3: nil, wav: nil) ⇒ Object

Recording URLs in requested format. The URL is valid for as long as the file exists. For security purposes, this feature is activated on a per request basis. Please contact customer support with your Account ID to request activation.

Parameters:

  • mp3 (String, nil) (defaults to: nil)

    Recording URL in requested ‘mp3` format.

  • wav (String, nil) (defaults to: nil)

    Recording URL in requested ‘wav` format.



# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 131

Instance Attribute Details

#call_leg_idString?

ID that is unique to the call and can be used to correlate webhook events.

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 74

optional :call_leg_id, String

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 82

optional :call_session_id, String

#channelsSymbol, ...

Whether recording was recorded in ‘single` or `dual` channel.



88
# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 88

optional :channels, enum: -> { Telnyx::CallRecordingSavedWebhookEvent::Data::Payload::Channels }

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


94
# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 94

optional :client_state, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


100
# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 100

optional :connection_id, String

#public_recording_urlsTelnyx::Models::CallRecordingSavedWebhookEvent::Data::Payload::PublicRecordingURLs?

Recording URLs in requested format. The URL is valid for as long as the file exists. For security purposes, this feature is activated on a per request basis. Please contact customer support with your Account ID to request activation.



108
109
# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 108

optional :public_recording_urls,
-> { Telnyx::CallRecordingSavedWebhookEvent::Data::Payload::PublicRecordingURLs }

#recording_ended_atTime?

ISO 8601 datetime of when recording ended.

Returns:

  • (Time, nil)


115
# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 115

optional :recording_ended_at, Time

#recording_started_atTime?

ISO 8601 datetime of when recording started.

Returns:

  • (Time, nil)


121
# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 121

optional :recording_started_at, Time

#recording_urlsTelnyx::Models::CallRecordingSavedWebhookEvent::Data::Payload::RecordingURLs?

Recording URLs in requested format. These URLs are valid for 10 minutes. After 10 minutes, you may retrieve recordings via API using Reports -> Call Recordings documentation, or via Mission Control under Reporting -> Recordings.



129
# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 129

optional :recording_urls, -> { Telnyx::CallRecordingSavedWebhookEvent::Data::Payload::RecordingURLs }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_recording_saved_webhook_event.rb', line 163