Class: Telnyx::Models::CallRecordingTranscriptionSaved::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallRecordingTranscriptionSaved::Payload
- Defined in:
- lib/telnyx/models/call_recording_transcription_saved.rb
Overview
Defined Under Namespace
Modules: CallingPartyType, Status
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#calling_party_type ⇒ Symbol, ...
The type of calling party connection.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#recording_id ⇒ String?
ID that is unique to the recording session and can be used to correlate webhook events.
-
#recording_transcription_id ⇒ String?
ID that is unique to the transcription process and can be used to correlate webhook events.
-
#status ⇒ Symbol, ...
The transcription status.
-
#transcription_text ⇒ String?
The transcribed text.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, calling_party_type: nil, client_state: nil, connection_id: nil, recording_id: nil, recording_transcription_id: nil, status: nil, transcription_text: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, calling_party_type: nil, client_state: nil, connection_id: nil, recording_id: nil, recording_transcription_id: nil, status: nil, transcription_text: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallRecordingTranscriptionSaved::Payload for more details.
|
|
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 125
|
Instance Attribute Details
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
64 |
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 64 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
70 |
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 70 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
78 |
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 78 optional :call_session_id, String |
#calling_party_type ⇒ Symbol, ...
The type of calling party connection.
84 85 |
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 84 optional :calling_party_type, enum: -> { Telnyx::CallRecordingTranscriptionSaved::Payload::CallingPartyType } |
#client_state ⇒ String?
State received from a command.
91 |
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 91 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
97 |
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 97 optional :connection_id, String |
#recording_id ⇒ String?
ID that is unique to the recording session and can be used to correlate webhook events.
104 |
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 104 optional :recording_id, String |
#recording_transcription_id ⇒ String?
ID that is unique to the transcription process and can be used to correlate webhook events.
111 |
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 111 optional :recording_transcription_id, String |
#status ⇒ Symbol, ...
The transcription status.
117 |
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 117 optional :status, enum: -> { Telnyx::CallRecordingTranscriptionSaved::Payload::Status } |
#transcription_text ⇒ String?
The transcribed text
123 |
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 123 optional :transcription_text, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/call_recording_transcription_saved.rb', line 158
|