Class: Telnyx::Models::CallRecordingTranscriptionSavedWebhookEvent::Data::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Modules: CallingPartyType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, calling_party_type: nil, client_state: nil, connection_id: nil, recording_id: nil, recording_transcription_id: nil, status: nil, transcription_text: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallRecordingTranscriptionSavedWebhookEvent::Data::Payload for more details.

Parameters:

  • call_control_id (String) (defaults to: nil)

    Call ID used to issue commands via Call Control API.

  • call_leg_id (String) (defaults to: nil)

    ID that is unique to the call and can be used to correlate webhook events.

  • call_session_id (String) (defaults to: nil)

    ID that is unique to the call session and can be used to correlate webhook event

  • calling_party_type (Symbol, Telnyx::Models::CallRecordingTranscriptionSavedWebhookEvent::Data::Payload::CallingPartyType) (defaults to: nil)

    The type of calling party connection.

  • client_state (String) (defaults to: nil)

    State received from a command.

  • connection_id (String) (defaults to: nil)

    Call Control App ID (formerly Telnyx connection ID) used in the call.

  • recording_id (String) (defaults to: nil)

    ID that is unique to the recording session and can be used to correlate webhook

  • recording_transcription_id (String) (defaults to: nil)

    ID that is unique to the transcription process and can be used to correlate webh

  • status (Symbol, Telnyx::Models::CallRecordingTranscriptionSavedWebhookEvent::Data::Payload::Status) (defaults to: nil)

    The transcription status.

  • transcription_text (String) (defaults to: nil)

    The transcribed text



# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 135

Instance Attribute Details

#call_control_idString?

Call ID used to issue commands via Call Control API.

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 74

optional :call_control_id, String

#call_leg_idString?

ID that is unique to the call and can be used to correlate webhook events.

Returns:

  • (String, nil)


80
# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 80

optional :call_leg_id, String

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 88

optional :call_session_id, String

#calling_party_typeSymbol, ...

The type of calling party connection.



94
95
# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 94

optional :calling_party_type,
enum: -> { Telnyx::CallRecordingTranscriptionSavedWebhookEvent::Data::Payload::CallingPartyType }

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


101
# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 101

optional :client_state, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


107
# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 107

optional :connection_id, String

#recording_idString?

ID that is unique to the recording session and can be used to correlate webhook events.

Returns:

  • (String, nil)


114
# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 114

optional :recording_id, String

#recording_transcription_idString?

ID that is unique to the transcription process and can be used to correlate webhook events.

Returns:

  • (String, nil)


121
# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 121

optional :recording_transcription_id, String

#statusSymbol, ...

The transcription status.



127
# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 127

optional :status, enum: -> { Telnyx::CallRecordingTranscriptionSavedWebhookEvent::Data::Payload::Status }

#transcription_textString?

The transcribed text

Returns:

  • (String, nil)


133
# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 133

optional :transcription_text, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_recording_transcription_saved_webhook_event.rb', line 169