Class: Telnyx::Models::CallReferCompleted::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_refer_completed.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#call_control_idString?

Unique ID for controlling the call.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/call_refer_completed.rb', line 64

optional :call_control_id, String

#call_leg_idString?

ID that is unique to the call and can be used to correlate webhook events.

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/call_refer_completed.rb', line 70

optional :call_leg_id, String

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/call_refer_completed.rb', line 78

optional :call_session_id, String

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


84
# File 'lib/telnyx/models/call_refer_completed.rb', line 84

optional :client_state, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/call_refer_completed.rb', line 90

optional :connection_id, String

#fromString?

Number or SIP URI placing the call.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/call_refer_completed.rb', line 96

optional :from, String

#sip_notify_responseInteger?

SIP NOTIFY event status for tracking the REFER attempt.

Returns:

  • (Integer, nil)


102
# File 'lib/telnyx/models/call_refer_completed.rb', line 102

optional :sip_notify_response, Integer

#toString?

Destination number or SIP URI of the call.

Returns:

  • (String, nil)


108
# File 'lib/telnyx/models/call_refer_completed.rb', line 108

optional :to, String