Class: Telnyx::Models::CallReferFailed::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallReferFailed::Payload
- Defined in:
- lib/telnyx/models/call_refer_failed.rb
Overview
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Unique ID for controlling the call.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#from ⇒ String?
Number or SIP URI placing the call.
-
#sip_notify_response ⇒ Integer?
SIP NOTIFY event status for tracking the REFER attempt.
-
#to ⇒ String?
Destination number or SIP URI of the call.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#call_control_id ⇒ String?
Unique ID for controlling the call.
64 |
# File 'lib/telnyx/models/call_refer_failed.rb', line 64 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
70 |
# File 'lib/telnyx/models/call_refer_failed.rb', line 70 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
78 |
# File 'lib/telnyx/models/call_refer_failed.rb', line 78 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command.
84 |
# File 'lib/telnyx/models/call_refer_failed.rb', line 84 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
90 |
# File 'lib/telnyx/models/call_refer_failed.rb', line 90 optional :connection_id, String |
#from ⇒ String?
Number or SIP URI placing the call.
96 |
# File 'lib/telnyx/models/call_refer_failed.rb', line 96 optional :from, String |
#sip_notify_response ⇒ Integer?
SIP NOTIFY event status for tracking the REFER attempt.
102 |
# File 'lib/telnyx/models/call_refer_failed.rb', line 102 optional :sip_notify_response, Integer |
#to ⇒ String?
Destination number or SIP URI of the call.
108 |
# File 'lib/telnyx/models/call_refer_failed.rb', line 108 optional :to, String |