Class: Telnyx::Models::CallSiprecStopped

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_siprec_stopped.rb

Defined Under Namespace

Modules: EventType, RecordType Classes: Payload

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, hangup_cause: nil) ⇒ Object

Some parameter documentations has been truncated, see Payload for more details.

Parameters:

  • call_control_id (String) (defaults to: nil)

    Call ID used to issue commands via Call Control API.

  • call_leg_id (String) (defaults to: nil)

    ID that is unique to the call and can be used to correlate webhook events.

  • call_session_id (String) (defaults to: nil)

    ID that is unique to the call session and can be used to correlate webhook event

  • client_state (String) (defaults to: nil)

    State received from a command.

  • connection_id (String) (defaults to: nil)

    Call Control App ID (formerly Telnyx connection ID) used in the call.

  • hangup_cause (String) (defaults to: nil)

    Q850 reason why the SIPREC session was stopped.



# File 'lib/telnyx/models/call_siprec_stopped.rb', line 35

Instance Attribute Details

#event_typeSymbol, ...

The type of event being delivered.



16
# File 'lib/telnyx/models/call_siprec_stopped.rb', line 16

optional :event_type, enum: -> { Telnyx::CallSiprecStopped::EventType }

#idString?

Identifies the type of resource.

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/call_siprec_stopped.rb', line 10

optional :id, String

#occurred_atTime?

ISO 8601 datetime of when the event occurred.

Returns:

  • (Time, nil)


22
# File 'lib/telnyx/models/call_siprec_stopped.rb', line 22

optional :occurred_at, Time

#payloadTelnyx::Models::CallSiprecStopped::Payload?



27
# File 'lib/telnyx/models/call_siprec_stopped.rb', line 27

optional :payload, -> { Telnyx::CallSiprecStopped::Payload }

#record_typeSymbol, ...

Identifies the type of the resource.



33
# File 'lib/telnyx/models/call_siprec_stopped.rb', line 33

optional :record_type, enum: -> { Telnyx::CallSiprecStopped::RecordType }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_siprec_stopped.rb', line 54