Class: Telnyx::Models::CallStreamingFailed::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallStreamingFailed::Payload
- Defined in:
- lib/telnyx/models/call_streaming_failed.rb
Overview
Defined Under Namespace
Modules: StreamType Classes: StreamParams
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#failure_reason ⇒ String?
A short description explaning why the media streaming failed.
-
#stream_id ⇒ String?
Identifies the streaming.
-
#stream_params ⇒ Telnyx::Models::CallStreamingFailed::Payload::StreamParams?
Streaming parameters as they were originally given to the Call Control API.
-
#stream_type ⇒ Symbol, ...
The type of stream connection the stream is performing.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, failure_reason: nil, stream_id: nil, stream_params: nil, stream_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, failure_reason: nil, stream_id: nil, stream_params: nil, stream_type: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallStreamingFailed::Payload for more details.
|
|
# File 'lib/telnyx/models/call_streaming_failed.rb', line 116
|
Instance Attribute Details
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
64 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 64 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
70 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 70 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
78 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 78 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command.
84 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 84 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
90 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 90 optional :connection_id, String |
#failure_reason ⇒ String?
A short description explaning why the media streaming failed.
96 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 96 optional :failure_reason, String |
#stream_id ⇒ String?
Identifies the streaming.
102 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 102 optional :stream_id, String |
#stream_params ⇒ Telnyx::Models::CallStreamingFailed::Payload::StreamParams?
Streaming parameters as they were originally given to the Call Control API.
108 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 108 optional :stream_params, -> { Telnyx::CallStreamingFailed::Payload::StreamParams } |
#stream_type ⇒ Symbol, ...
The type of stream connection the stream is performing.
114 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 114 optional :stream_type, enum: -> { Telnyx::CallStreamingFailed::Payload::StreamType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/call_streaming_failed.rb', line 169
|