Class: Telnyx::Models::CallStreamingFailed::Payload::StreamParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallStreamingFailed::Payload::StreamParams
- Defined in:
- lib/telnyx/models/call_streaming_failed.rb
Overview
Defined Under Namespace
Modules: Track
Instance Attribute Summary collapse
-
#stream_url ⇒ String?
The destination WebSocket address where the stream is going to be delivered.
-
#track ⇒ Symbol, ...
Specifies which track should be streamed.
Instance Method Summary collapse
-
#initialize(stream_url: nil, track: nil) ⇒ Object
constructor
Streaming parameters as they were originally given to the Call Control API.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(stream_url: nil, track: nil) ⇒ Object
Streaming parameters as they were originally given to the Call Control API.
|
|
# File 'lib/telnyx/models/call_streaming_failed.rb', line 152
|
Instance Attribute Details
#stream_url ⇒ String?
The destination WebSocket address where the stream is going to be delivered.
144 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 144 optional :stream_url, String |
#track ⇒ Symbol, ...
Specifies which track should be streamed.
150 |
# File 'lib/telnyx/models/call_streaming_failed.rb', line 150 optional :track, enum: -> { Telnyx::CallStreamingFailed::Payload::StreamParams::Track } |