Class: Telnyx::Models::Calls::ActionAddAIAssistantMessagesParams::Message::Assistant
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionAddAIAssistantMessagesParams::Message::Assistant
- Defined in:
- lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb
Defined Under Namespace
Classes: ToolCall
Instance Attribute Summary collapse
-
#content ⇒ String?
The contents of the assistant message.
-
#metadata ⇒ Hash{Symbol=>Object}?
Metadata to add to the message.
-
#role ⇒ Symbol, :assistant
The role of the messages author, in this case ‘assistant`.
-
#tool_calls ⇒ Array<Telnyx::Models::Calls::ActionAddAIAssistantMessagesParams::Message::Assistant::ToolCall>?
The tool calls generated by the model, such as function calls.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#content ⇒ String?
The contents of the assistant message. Required unless ‘tool_calls`
111 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 111 optional :content, String |
#metadata ⇒ Hash{Symbol=>Object}?
Metadata to add to the message
117 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 117 optional :metadata, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#role ⇒ Symbol, :assistant
The role of the messages author, in this case ‘assistant`.
105 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 105 required :role, const: :assistant |
#tool_calls ⇒ Array<Telnyx::Models::Calls::ActionAddAIAssistantMessagesParams::Message::Assistant::ToolCall>?
The tool calls generated by the model, such as function calls.
123 124 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 123 optional :tool_calls, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Calls::ActionAddAIAssistantMessagesParams::Message::Assistant::ToolCall] } |