Class: Telnyx::Models::Calls::ActionAddAIAssistantMessagesParams::Message::Developer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content:, metadata: nil, role: :developer) ⇒ Object

Developer-provided instructions that the model should follow, regardless of messages sent by the user.

Parameters:

  • content (String)

    The contents of the developer message.

  • metadata (Hash{Symbol=>Object}) (defaults to: nil)

    Metadata to add to the message

  • role (Symbol, :developer) (defaults to: :developer)

    The role of the messages author, in this case developer.



# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 279

Instance Attribute Details

#contentString

The contents of the developer message.

Returns:

  • (String)


265
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 265

required :content, String

#metadataHash{Symbol=>Object}?

Metadata to add to the message

Returns:

  • (Hash{Symbol=>Object}, nil)


277
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 277

optional :metadata, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#roleSymbol, :developer

The role of the messages author, in this case developer.

Returns:

  • (Symbol, :developer)


271
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 271

required :role, const: :developer