Class: Telnyx::Models::Calls::ActionAddAIAssistantMessagesParams::Message::Tool
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionAddAIAssistantMessagesParams::Message::Tool
- Defined in:
- lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb
Instance Attribute Summary collapse
-
#content ⇒ String
The contents of the tool message.
-
#metadata ⇒ Hash{Symbol=>Object}?
Metadata to add to the message.
-
#role ⇒ Symbol, :tool
The role of the messages author, in this case ‘tool`.
-
#tool_call_id ⇒ String
Tool call that this message is responding to.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#content ⇒ String
The contents of the tool message.
200 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 200 required :content, String |
#metadata ⇒ Hash{Symbol=>Object}?
Metadata to add to the message
218 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 218 optional :metadata, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#role ⇒ Symbol, :tool
The role of the messages author, in this case ‘tool`.
206 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 206 required :role, const: :tool |
#tool_call_id ⇒ String
Tool call that this message is responding to.
212 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 212 required :tool_call_id, String |