Class: Telnyx::Models::Calls::ActionAnswerParams::ConversationRelayConfig::Language

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/action_answer_params.rb

Defined Under Namespace

Modules: TranscriptionEngine, VoiceSettings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(language:, speech_model: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_provider: nil, tts_provider: nil, voice: nil, voice_settings: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionAnswerParams::ConversationRelayConfig::Language for more details.

Language-specific TTS and transcription settings for Conversation Relay.

Parameters:



# File 'lib/telnyx/models/calls/action_answer_params.rb', line 699

Instance Attribute Details

#languageString

BCP 47 language tag for this language configuration.

Returns:

  • (String)


643
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 643

required :language, String

#speech_modelString?

Conversation Relay speech model. Prefer ‘transcription_engine_config.transcription_model` when configuring speech-to-text.

Returns:

  • (String, nil)


651
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 651

optional :speech_model, String

#transcription_engineSymbol, ...

Engine to use for speech recognition. Legacy values ‘A` - `Google`, `B` - `Telnyx` are supported for backward compatibility. When provided in a Conversation Relay language entry, Telnyx derives `transcription_provider` and `speech_model` for that language.



660
661
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 660

optional :transcription_engine,
enum: -> { Telnyx::Calls::ActionAnswerParams::ConversationRelayConfig::Language::TranscriptionEngine }

#transcription_engine_configHash{Symbol=>Object}?

Engine-specific transcription settings for Conversation Relay. This accepts the same provider-specific options used by the Call Transcription Start command, such as ‘transcription_model`, without requiring the engine discriminator to be repeated inside this object.

Returns:

  • (Hash{Symbol=>Object}, nil)


670
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 670

optional :transcription_engine_config, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#transcription_providerString?

Conversation Relay transcription provider name. Prefer ‘transcription_engine` when configuring speech-to-text.

Returns:

  • (String, nil)


677
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 677

optional :transcription_provider, String

#tts_providerString?

Text-to-speech provider for this language. If omitted and ‘voice` is provided, Telnyx derives the provider from the voice identifier.

Returns:

  • (String, nil)


684
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 684

optional :tts_provider, String

#voiceString?

Voice identifier for this language.

Returns:

  • (String, nil)


690
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 690

optional :voice, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_answer_params.rb', line 742