Class: Telnyx::Models::Calls::ActionAnswerResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/action_answer_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(recording_id: nil, result: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionAnswerResponse::Data for more details.

Parameters:

  • recording_id (String) (defaults to: nil)

    The ID of the recording. Only present when the record parameter is set to record

  • result (String) (defaults to: nil)


# File 'lib/telnyx/models/calls/action_answer_response.rb', line 30

Instance Attribute Details

#recording_idString?

The ID of the recording. Only present when the record parameter is set to record-from-answer.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/calls/action_answer_response.rb', line 23

optional :recording_id, String

#resultString?

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/calls/action_answer_response.rb', line 28

optional :result, String