Class: Telnyx::Models::Calls::ActionBridgeParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_bridge_params.rb

Overview

Defined Under Namespace

Modules: MuteDtmf, Record, RecordChannels, RecordFormat, RecordTrack, RecordTrim, Ringtone

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id_to_bridge:, call_control_id_to_bridge_with:, client_state: nil, command_id: nil, hold_after_unbridge: nil, mute_dtmf: nil, park_after_unbridge: nil, play_ringtone: nil, prevent_double_bridge: nil, queue: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, ringtone: nil, video_room_context: nil, video_room_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionBridgeParams for more details.

call_

Parameters:

  • call_control_id_to_bridge (String)
  • call_control_id_to_bridge_with (String)

    The Call Control ID of the call you want to bridge with, can’t be used together

  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. It must be a valid Base

  • command_id (String) (defaults to: nil)

    Use this field to avoid duplicate commands. Telnyx will ignore any command with

  • hold_after_unbridge (Boolean) (defaults to: nil)

    Specifies behavior after the bridge ends. If set to ‘true`, the current leg will

  • mute_dtmf (Symbol, Telnyx::Models::Calls::ActionBridgeParams::MuteDtmf) (defaults to: nil)

    When enabled, DTMF tones are not passed to the call participant. The webhooks co

  • park_after_unbridge (String) (defaults to: nil)

    Specifies behavior after the bridge ends (i.e. the opposite leg either hangs up

  • play_ringtone (Boolean) (defaults to: nil)

    Specifies whether to play a ringtone if the call you want to bridge with has not

  • prevent_double_bridge (Boolean) (defaults to: nil)

    When set to ‘true`, it prevents bridging if the target call is already bridged t

  • queue (String) (defaults to: nil)

    The name of the queue you want to bridge with, can’t be used together with

  • record (Symbol, Telnyx::Models::Calls::ActionBridgeParams::Record) (defaults to: nil)

    Start recording automatically after an event. Disabled by default.

  • record_channels (Symbol, Telnyx::Models::Calls::ActionBridgeParams::RecordChannels) (defaults to: nil)

    Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is s

  • record_custom_file_name (String) (defaults to: nil)

    The custom recording file name to be used instead of the default ‘call_leg_id`.

  • record_format (Symbol, Telnyx::Models::Calls::ActionBridgeParams::RecordFormat) (defaults to: nil)

    Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.

  • record_max_length (Integer) (defaults to: nil)

    Defines the maximum length for the recording in seconds when ‘record` is specifi

  • record_timeout_secs (Integer) (defaults to: nil)

    The number of seconds that Telnyx will wait for the recording to be stopped if s

  • record_track (Symbol, Telnyx::Models::Calls::ActionBridgeParams::RecordTrack) (defaults to: nil)

    The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. I

  • record_trim (Symbol, Telnyx::Models::Calls::ActionBridgeParams::RecordTrim) (defaults to: nil)

    When set to ‘trim-silence`, silence will be removed from the beginning and end o

  • ringtone (Symbol, Telnyx::Models::Calls::ActionBridgeParams::Ringtone) (defaults to: nil)

    Specifies which country ringtone to play when ‘play_ringtone` is set to `true`.

  • video_room_context (String) (defaults to: nil)

    The additional parameter that will be passed to the video conference. It is a te

  • video_room_id (String) (defaults to: nil)

    The ID of the video room you want to bridge with, can’t be used together with ca

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 165

Instance Attribute Details

#call_control_id_to_bridgeString

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 14

required :call_control_id_to_bridge, String

#call_control_id_to_bridge_withString

The Call Control ID of the call you want to bridge with, can’t be used together with queue parameter or video_room_id parameter.

Returns:

  • (String)


21
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 21

required :call_control_id_to_bridge_with, String, api_name: :call_control_id

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 28

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 35

optional :command_id, String

#hold_after_unbridgeBoolean?

Specifies behavior after the bridge ends. If set to ‘true`, the current leg will be put on hold after unbridge instead of being hung up.

Returns:

  • (Boolean, nil)


42
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 42

optional :hold_after_unbridge, Telnyx::Internal::Type::Boolean

#mute_dtmfSymbol, ...

When enabled, DTMF tones are not passed to the call participant. The webhooks containing the DTMF information will be sent.



49
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 49

optional :mute_dtmf, enum: -> { Telnyx::Calls::ActionBridgeParams::MuteDtmf }

#park_after_unbridgeString?

Specifies behavior after the bridge ends (i.e. the opposite leg either hangs up or is transferred). If supplied with the value ‘self`, the current leg will be parked after unbridge. If not set, the default behavior is to hang up the leg.

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 57

optional :park_after_unbridge, String

#play_ringtoneBoolean?

Specifies whether to play a ringtone if the call you want to bridge with has not yet been answered.

Returns:

  • (Boolean, nil)


64
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 64

optional :play_ringtone, Telnyx::Internal::Type::Boolean

#prevent_double_bridgeBoolean?

When set to ‘true`, it prevents bridging if the target call is already bridged to another call. Disabled by default.

Returns:

  • (Boolean, nil)


71
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 71

optional :prevent_double_bridge, Telnyx::Internal::Type::Boolean

#queueString?

The name of the queue you want to bridge with, can’t be used together with call_control_id parameter or video_room_id parameter. Bridging with a queue means bridging with the first call in the queue. The call will always be removed from the queue regardless of whether bridging succeeds. Returns an error when the queue is empty.

Returns:

  • (String, nil)


81
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 81

optional :queue, String

#recordSymbol, ...

Start recording automatically after an event. Disabled by default.



87
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 87

optional :record, enum: -> { Telnyx::Calls::ActionBridgeParams::Record }

#record_channelsSymbol, ...

Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.



94
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 94

optional :record_channels, enum: -> { Telnyx::Calls::ActionBridgeParams::RecordChannels }

#record_custom_file_nameString?

The custom recording file name to be used instead of the default ‘call_leg_id`. Telnyx will still add a Unix timestamp suffix.

Returns:

  • (String, nil)


101
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 101

optional :record_custom_file_name, String

#record_formatSymbol, ...

Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.



107
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 107

optional :record_format, enum: -> { Telnyx::Calls::ActionBridgeParams::RecordFormat }

#record_max_lengthInteger?

Defines the maximum length for the recording in seconds when ‘record` is specified. The minimum value is 0. The maximum value is 43200. The default value is 0 (infinite).

Returns:

  • (Integer, nil)


115
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 115

optional :record_max_length, Integer

#record_timeout_secsInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified. The timer only starts when the speech is detected. Please note that call transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite).

Returns:

  • (Integer, nil)


125
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 125

optional :record_timeout_secs, Integer

#record_trackSymbol, ...

The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. If only single track is specified (`inbound`, `outbound`), `channels` configuration is ignored and it will be recorded as mono (single channel).



133
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 133

optional :record_track, enum: -> { Telnyx::Calls::ActionBridgeParams::RecordTrack }

#record_trimSymbol, ...

When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.



140
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 140

optional :record_trim, enum: -> { Telnyx::Calls::ActionBridgeParams::RecordTrim }

#ringtoneSymbol, ...

Specifies which country ringtone to play when ‘play_ringtone` is set to `true`. If not set, the US ringtone will be played.



147
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 147

optional :ringtone, enum: -> { Telnyx::Calls::ActionBridgeParams::Ringtone }

#video_room_contextString?

The additional parameter that will be passed to the video conference. It is a text field and the user can decide how to use it. For example, you can set the participant name or pass JSON text. It can be used only with video_room_id parameter.

Returns:

  • (String, nil)


156
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 156

optional :video_room_context, String

#video_room_idString?

The ID of the video room you want to bridge with, can’t be used together with call_control_id parameter or queue parameter.

Returns:

  • (String, nil)


163
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 163

optional :video_room_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 224