Class: Telnyx::Models::Calls::ActionEnqueueParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_enqueue_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, queue_name:, client_state: nil, command_id: nil, keep_after_hangup: nil, max_size: nil, max_wait_time_secs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionEnqueueParams for more details.

Parameters:

  • call_control_id (String)
  • queue_name (String)

    The name of the queue the call should be put in. If a queue with a given name do

  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. It must be a valid Base

  • command_id (String) (defaults to: nil)

    Use this field to avoid duplicate commands. Telnyx will ignore any command with

  • keep_after_hangup (Boolean) (defaults to: nil)

    If set to true, the call will remain in the queue after hangup. In this case bri

  • max_size (Integer) (defaults to: nil)

    The maximum number of calls allowed in the queue at a given time. Can’t be modif

  • max_wait_time_secs (Integer) (defaults to: nil)

    The number of seconds after which the call will be removed from the queue.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/calls/action_enqueue_params.rb', line 58

Instance Attribute Details

#call_control_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_enqueue_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/calls/action_enqueue_params.rb', line 28

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/calls/action_enqueue_params.rb', line 35

optional :command_id, String

#keep_after_hangupBoolean?

If set to true, the call will remain in the queue after hangup. In this case bridging to such call will fail with necessary information needed to re-establish the call.

Returns:

  • (Boolean, nil)


43
# File 'lib/telnyx/models/calls/action_enqueue_params.rb', line 43

optional :keep_after_hangup, Telnyx::Internal::Type::Boolean

#max_sizeInteger?

The maximum number of calls allowed in the queue at a given time. Can’t be modified for an existing queue.

Returns:

  • (Integer, nil)


50
# File 'lib/telnyx/models/calls/action_enqueue_params.rb', line 50

optional :max_size, Integer

#max_wait_time_secsInteger?

The number of seconds after which the call will be removed from the queue.

Returns:

  • (Integer, nil)


56
# File 'lib/telnyx/models/calls/action_enqueue_params.rb', line 56

optional :max_wait_time_secs, Integer

#queue_nameString

The name of the queue the call should be put in. If a queue with a given name doesn’t exist yet it will be created.

Returns:

  • (String)


21
# File 'lib/telnyx/models/calls/action_enqueue_params.rb', line 21

required :queue_name, String