Class: Telnyx::Models::Calls::ActionGatherUsingAudioParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_gather_using_audio_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, audio_url: nil, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_audio_url: nil, invalid_media_name: nil, maximum_digits: nil, maximum_tries: nil, media_name: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionGatherUsingAudioParams for more details.

Parameters:

  • call_control_id (String)
  • audio_url (String) (defaults to: nil)

    The URL of a file to be played back at the beginning of each prompt. The URL can

  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. It must be a valid Base

  • command_id (String) (defaults to: nil)

    Use this field to avoid duplicate commands. Telnyx will ignore any command with

  • inter_digit_timeout_millis (Integer) (defaults to: nil)

    The number of milliseconds to wait for input between digits.

  • invalid_audio_url (String) (defaults to: nil)

    The URL of a file to play when digits don’t match the ‘valid_digits` parameter o

  • invalid_media_name (String) (defaults to: nil)

    The media_name of a file to be played back when digits don’t match the ‘valid_di

  • maximum_digits (Integer) (defaults to: nil)

    The maximum number of digits to fetch. This parameter has a maximum value of 128

  • maximum_tries (Integer) (defaults to: nil)

    The maximum number of times the file should be played if there is no input from

  • media_name (String) (defaults to: nil)

    The media_name of a file to be played back at the beginning of each prompt. The

  • minimum_digits (Integer) (defaults to: nil)

    The minimum number of digits to fetch. This parameter has a minimum value of 1.

  • terminating_digit (String) (defaults to: nil)

    The digit used to terminate input if fewer than ‘maximum_digits` digits have bee

  • timeout_millis (Integer) (defaults to: nil)

    The number of milliseconds to wait for a DTMF response after file playback ends

  • valid_digits (String) (defaults to: nil)

    A list of all digits accepted as valid.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 111

Instance Attribute Details

#audio_urlString?

The URL of a file to be played back at the beginning of each prompt. The URL can point to either a WAV or MP3 file. media_name and audio_url cannot be used together in one request.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 22

optional :audio_url, String

#call_control_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 29

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 36

optional :command_id, String

#inter_digit_timeout_millisInteger?

The number of milliseconds to wait for input between digits.

Returns:

  • (Integer, nil)


42
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 42

optional :inter_digit_timeout_millis, Integer

#invalid_audio_urlString?

The URL of a file to play when digits don’t match the ‘valid_digits` parameter or the number of digits is not between `min` and `max`. The URL can point to either a WAV or MP3 file. invalid_media_name and invalid_audio_url cannot be used together in one request.

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 51

optional :invalid_audio_url, String

#invalid_media_nameString?

The media_name of a file to be played back when digits don’t match the ‘valid_digits` parameter or the number of digits is not between `min` and `max`. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file.

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 61

optional :invalid_media_name, String

#maximum_digitsInteger?

The maximum number of digits to fetch. This parameter has a maximum value of 128.

Returns:

  • (Integer, nil)


68
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 68

optional :maximum_digits, Integer

#maximum_triesInteger?

The maximum number of times the file should be played if there is no input from the user on the call.

Returns:

  • (Integer, nil)


75
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 75

optional :maximum_tries, Integer

#media_nameString?

The media_name of a file to be played back at the beginning of each prompt. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file.

Returns:

  • (String, nil)


83
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 83

optional :media_name, String

#minimum_digitsInteger?

The minimum number of digits to fetch. This parameter has a minimum value of 1.

Returns:

  • (Integer, nil)


89
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 89

optional :minimum_digits, Integer

#terminating_digitString?

The digit used to terminate input if fewer than ‘maximum_digits` digits have been gathered.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 96

optional :terminating_digit, String

#timeout_millisInteger?

The number of milliseconds to wait for a DTMF response after file playback ends before a replaying the sound file.

Returns:

  • (Integer, nil)


103
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 103

optional :timeout_millis, Integer

#valid_digitsString?

A list of all digits accepted as valid.

Returns:

  • (String, nil)


109
# File 'lib/telnyx/models/calls/action_gather_using_audio_params.rb', line 109

optional :valid_digits, String