Class: Telnyx::Models::Calls::ActionJoinAIAssistantParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_join_ai_assistant_params.rb

Overview

Defined Under Namespace

Classes: Participant

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#call_control_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 32

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 39

optional :command_id, String

#conversation_idString

The ID of the AI assistant conversation to join.

Returns:

  • (String)


20
# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 20

required :conversation_id, String

#participantTelnyx::Models::Calls::ActionJoinAIAssistantParams::Participant



25
# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 25

required :participant, -> { Telnyx::Calls::ActionJoinAIAssistantParams::Participant }