Class: Telnyx::Models::Calls::ActionJoinAIAssistantParams::Participant

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/action_join_ai_assistant_params.rb

Defined Under Namespace

Modules: OnHangup, Role

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, role:, name: nil, on_hangup: nil) ⇒ Object

Parameters:



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 57

class Participant < Telnyx::Internal::Type::BaseModel
  # @!attribute id
  #   The call_control_id of the participant to add to the conversation.
  #
  #   @return [String]
  required :id, String

  # @!attribute role
  #   The role of the participant in the conversation.
  #
  #   @return [Symbol, Telnyx::Models::Calls::ActionJoinAIAssistantParams::Participant::Role]
  required :role, enum: -> { Telnyx::Calls::ActionJoinAIAssistantParams::Participant::Role }

  # @!attribute name
  #   Display name for the participant.
  #
  #   @return [String, nil]
  optional :name, String

  # @!attribute on_hangup
  #   Determines what happens to the conversation when this participant hangs up.
  #
  #   @return [Symbol, Telnyx::Models::Calls::ActionJoinAIAssistantParams::Participant::OnHangup, nil]
  optional :on_hangup, enum: -> { Telnyx::Calls::ActionJoinAIAssistantParams::Participant::OnHangup }

  # @!method initialize(id:, role:, name: nil, on_hangup: nil)
  #   @param id [String] The call_control_id of the participant to add to the conversation.
  #
  #   @param role [Symbol, Telnyx::Models::Calls::ActionJoinAIAssistantParams::Participant::Role] The role of the participant in the conversation.
  #
  #   @param name [String] Display name for the participant.
  #
  #   @param on_hangup [Symbol, Telnyx::Models::Calls::ActionJoinAIAssistantParams::Participant::OnHangup] Determines what happens to the conversation when this participant hangs up.

  # The role of the participant in the conversation.
  #
  # @see Telnyx::Models::Calls::ActionJoinAIAssistantParams::Participant#role
  module Role
    extend Telnyx::Internal::Type::Enum

    USER = :user

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # Determines what happens to the conversation when this participant hangs up.
  #
  # @see Telnyx::Models::Calls::ActionJoinAIAssistantParams::Participant#on_hangup
  module OnHangup
    extend Telnyx::Internal::Type::Enum

    CONTINUE_CONVERSATION = :continue_conversation
    END_CONVERSATION = :end_conversation

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#idString

The call_control_id of the participant to add to the conversation.

Returns:

  • (String)


62
# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 62

required :id, String

#nameString?

Display name for the participant.

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 74

optional :name, String

#on_hangupSymbol, ...

Determines what happens to the conversation when this participant hangs up.



80
# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 80

optional :on_hangup, enum: -> { Telnyx::Calls::ActionJoinAIAssistantParams::Participant::OnHangup }

#roleSymbol, Telnyx::Models::Calls::ActionJoinAIAssistantParams::Participant::Role

The role of the participant in the conversation.



68
# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 68

required :role, enum: -> { Telnyx::Calls::ActionJoinAIAssistantParams::Participant::Role }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_join_ai_assistant_params.rb', line 99