Class: Telnyx::Models::Calls::ActionPayParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_pay_params.rb,
sig/telnyx/models/calls/action_pay_params.rbs

Overview

See Also:

  • Telnyx::Resources::Calls::Actions#pay

Defined Under Namespace

Modules: Currency, PaymentMethod, TransactionType Classes: Prompts

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bank_account_number: nil, bank_routing_number: nil, expiration_date: nil, payment_card_number: nil, postal_code: nil, security_code: nil) ⇒ Object

Custom text-to-speech prompts keyed by payment collection step.

Parameters:



# File 'lib/telnyx/models/calls/action_pay_params.rb', line 129

Instance Attribute Details

#amountFloat?

Amount to charge. Required when transaction_type is charge.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


20
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 20

optional :amount, Float

#call_control_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 14

required :call_control_id, String

#client_stateString?

Base64-encoded state included in subsequent webhooks.

Parameters:

  • (String)

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 26

optional :client_state, String

#command_idString?

Idempotency key for the command. Telnyx ignores a duplicate command with the same command_id for the same call_control_id.

Parameters:

  • (String)

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 33

optional :command_id, String

#connector_nameString?

Name of the Pay connector used to process the transaction.

Parameters:

  • (String)

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 39

optional :connector_name, String

#currencySymbol, ...

Currency used for the transaction. Pay currently supports USD only.



45
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 45

optional :currency, enum: -> { Telnyx::Calls::ActionPayParams::Currency }

#descriptionString?

Optional description forwarded with the payment transaction.

Parameters:

  • (String)

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 51

optional :description, String

#inter_digit_timeout_millisInteger?

Time in milliseconds to wait between consecutive DTMF digits.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


57
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 57

optional :inter_digit_timeout_millis, Integer

#languageString?

Language used for payment prompts.

Parameters:

  • (String)

Returns:

  • (String, nil)


63
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 63

optional :language, String

#max_attemptsInteger?

Maximum number of attempts for each payment collection step.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


69
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 69

optional :max_attempts, Integer

#metadataHash{Symbol=>Object}?

Metadata forwarded to the Pay connector.

Parameters:

  • (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object}, nil)


75
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 75

optional :metadata, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#parametersHash{Symbol=>Object}?

Additional parameters forwarded to the Pay connector.

Parameters:

  • (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object}, nil)


81
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 81

optional :parameters, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#payment_methodSymbol, ...

Payment method to collect.



87
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 87

optional :payment_method, enum: -> { Telnyx::Calls::ActionPayParams::PaymentMethod }

#payment_tokenString?

Existing payment token. When supplied, payment-detail collection is skipped.

Parameters:

  • (String)

Returns:

  • (String, nil)


93
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 93

optional :payment_token, String

#promptsTelnyx::Models::Calls::ActionPayParams::Prompts?

Custom text-to-speech prompts keyed by payment collection step.



99
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 99

optional :prompts, -> { Telnyx::Calls::ActionPayParams::Prompts }

#service_levelString?

Speech synthesis service level used for payment prompts. Pay defaults to premium.

Parameters:

  • (String)

Returns:

  • (String, nil)


106
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 106

optional :service_level, String

#timeout_millisInteger?

Time in milliseconds to wait for DTMF input for each collection step.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


112
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 112

optional :timeout_millis, Integer

#transaction_typeSymbol, ...

Transaction to perform. If omitted, Pay infers tokenize when amount is absent or zero and charge when amount is positive.



119
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 119

optional :transaction_type, enum: -> { Telnyx::Calls::ActionPayParams::TransactionType }

#voiceString?

Voice used for payment prompts. Accepts male, female, or a provider voice in <Provider>.<Model>.<VoiceId> format, for example AWS.Polly.Joanna or Telnyx.KokoroTTS.af.

Parameters:

  • (String)

Returns:

  • (String, nil)


127
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 127

optional :voice, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_pay_params.rb', line 180

Instance Method Details

#to_hash{

Returns:

  • ({)


137
# File 'sig/telnyx/models/calls/action_pay_params.rbs', line 137

def to_hash: -> {