Class: Telnyx::Models::Calls::ActionPayParams::Prompts

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/action_pay_params.rb,
sig/telnyx/models/calls/action_pay_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



238
# File 'sig/telnyx/models/calls/action_pay_params.rbs', line 238

def initialize: (

Instance Attribute Details

#bank_account_numberString, ...

A default prompt string or an ordered list of qualified prompts.



212
213
214
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 212

optional :bank_account_number,
union: -> { Telnyx::Calls::PayPromptValue },
api_name: :"bank-account-number"

#bank_routing_numberString, ...

A default prompt string or an ordered list of qualified prompts.



220
221
222
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 220

optional :bank_routing_number,
union: -> { Telnyx::Calls::PayPromptValue },
api_name: :"bank-routing-number"

#expiration_dateString, ...

A default prompt string or an ordered list of qualified prompts.



228
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 228

optional :expiration_date, union: -> { Telnyx::Calls::PayPromptValue }, api_name: :"expiration-date"

#payment_card_numberString, ...

A default prompt string or an ordered list of qualified prompts.



234
235
236
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 234

optional :payment_card_number,
union: -> { Telnyx::Calls::PayPromptValue },
api_name: :"payment-card-number"

#postal_codeString, ...

A default prompt string or an ordered list of qualified prompts.



242
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 242

optional :postal_code, union: -> { Telnyx::Calls::PayPromptValue }, api_name: :"postal-code"

#security_codeString, ...

A default prompt string or an ordered list of qualified prompts.



248
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 248

optional :security_code, union: -> { Telnyx::Calls::PayPromptValue }, api_name: :"security-code"

Instance Method Details

#to_hash{

Returns:

  • ({)


247
# File 'sig/telnyx/models/calls/action_pay_params.rbs', line 247

def to_hash: -> {