Class: Telnyx::Models::Calls::ActionReferParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_refer_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, sip_address:, client_state: nil, command_id: nil, custom_headers: nil, sip_auth_password: nil, sip_auth_username: nil, sip_headers: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionReferParams for more details.

Parameters:

  • call_control_id (String)
  • sip_address (String)

    The SIP URI to which the call will be referred to.

  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. It must be a valid Base

  • command_id (String) (defaults to: nil)

    Use this field to avoid execution of duplicate commands. Telnyx will ignore subs

  • custom_headers (Array<Telnyx::Models::CustomSipHeader>) (defaults to: nil)

    Custom headers to be added to the SIP INVITE.

  • sip_auth_password (String) (defaults to: nil)

    SIP Authentication password used for SIP challenges.

  • sip_auth_username (String) (defaults to: nil)

    SIP Authentication username used for SIP challenges.

  • sip_headers (Array<Telnyx::Models::SipHeader>) (defaults to: nil)

    SIP headers to be added to the request. Currently only User-to-User header is su

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/calls/action_refer_params.rb', line 62

Instance Attribute Details

#call_control_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_refer_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/calls/action_refer_params.rb', line 27

optional :client_state, String

#command_idString?

Use this field to avoid execution of duplicate commands. Telnyx will ignore subsequent commands with the same ‘command_id` as one that has already been executed.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/calls/action_refer_params.rb', line 35

optional :command_id, String

#custom_headersArray<Telnyx::Models::CustomSipHeader>?

Custom headers to be added to the SIP INVITE.

Returns:



41
# File 'lib/telnyx/models/calls/action_refer_params.rb', line 41

optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] }

#sip_addressString

The SIP URI to which the call will be referred to.

Returns:

  • (String)


20
# File 'lib/telnyx/models/calls/action_refer_params.rb', line 20

required :sip_address, String

#sip_auth_passwordString?

SIP Authentication password used for SIP challenges.

Returns:

  • (String, nil)


47
# File 'lib/telnyx/models/calls/action_refer_params.rb', line 47

optional :sip_auth_password, String

#sip_auth_usernameString?

SIP Authentication username used for SIP challenges.

Returns:

  • (String, nil)


53
# File 'lib/telnyx/models/calls/action_refer_params.rb', line 53

optional :sip_auth_username, String

#sip_headersArray<Telnyx::Models::SipHeader>?

SIP headers to be added to the request. Currently only User-to-User header is supported.

Returns:



60
# File 'lib/telnyx/models/calls/action_refer_params.rb', line 60

optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] }