Class: Telnyx::Models::Calls::ActionRejectParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionRejectParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_reject_params.rb
Overview
Defined Under Namespace
Modules: Cause
Instance Attribute Summary collapse
- #call_control_id ⇒ String
-
#cause ⇒ Symbol, Telnyx::Models::Calls::ActionRejectParams::Cause
Cause for call rejection.
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(call_control_id:, cause:, client_state: nil, command_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionRejectParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id:, cause:, client_state: nil, command_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionRejectParams for more details.
|
|
# File 'lib/telnyx/models/calls/action_reject_params.rb', line 36
|
Instance Attribute Details
#call_control_id ⇒ String
14 |
# File 'lib/telnyx/models/calls/action_reject_params.rb', line 14 required :call_control_id, String |
#cause ⇒ Symbol, Telnyx::Models::Calls::ActionRejectParams::Cause
Cause for call rejection.
20 |
# File 'lib/telnyx/models/calls/action_reject_params.rb', line 20 required :cause, enum: -> { Telnyx::Calls::ActionRejectParams::Cause } |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
27 |
# File 'lib/telnyx/models/calls/action_reject_params.rb', line 27 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
34 |
# File 'lib/telnyx/models/calls/action_reject_params.rb', line 34 optional :command_id, String |