Class: Telnyx::Models::Calls::ActionSendDtmfParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionSendDtmfParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_send_dtmf_params.rb
Overview
Instance Attribute Summary collapse
- #call_control_id ⇒ String
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#digits ⇒ String
DTMF digits to send.
-
#duration_millis ⇒ Integer?
Specifies for how many milliseconds each digit will be played in the audio stream.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(call_control_id:, digits:, client_state: nil, command_id: nil, duration_millis: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionSendDtmfParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id:, digits:, client_state: nil, command_id: nil, duration_millis: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionSendDtmfParams for more details.
us
|
|
# File 'lib/telnyx/models/calls/action_send_dtmf_params.rb', line 44
|
Instance Attribute Details
#call_control_id ⇒ String
14 |
# File 'lib/telnyx/models/calls/action_send_dtmf_params.rb', line 14 required :call_control_id, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
28 |
# File 'lib/telnyx/models/calls/action_send_dtmf_params.rb', line 28 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
35 |
# File 'lib/telnyx/models/calls/action_send_dtmf_params.rb', line 35 optional :command_id, String |
#digits ⇒ String
DTMF digits to send. Valid digits are 0-9, A-D, *, and #. Pauses can be added using w (0.5s) and W (1s).
21 |
# File 'lib/telnyx/models/calls/action_send_dtmf_params.rb', line 21 required :digits, String |
#duration_millis ⇒ Integer?
Specifies for how many milliseconds each digit will be played in the audio stream. Ranges from 100 to 500ms
42 |
# File 'lib/telnyx/models/calls/action_send_dtmf_params.rb', line 42 optional :duration_millis, Integer |