Class: Telnyx::Models::Calls::ActionSendSipInfoParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_send_sip_info_params.rb,
sig/telnyx/models/calls/action_send_sip_info_params.rbs

Overview

See Also:

  • Telnyx::Resources::Calls::Actions#send_sip_info

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, body:, content_type:, client_state: nil, command_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionSendSipInfoParams for more details.



# File 'lib/telnyx/models/calls/action_send_sip_info_params.rb', line 43


Instance Attribute Details

#bodyString

Content of the SIP INFO



20
# File 'lib/telnyx/models/calls/action_send_sip_info_params.rb', line 20

required :body, String

#call_control_idString



14
# File 'lib/telnyx/models/calls/action_send_sip_info_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.



34
# File 'lib/telnyx/models/calls/action_send_sip_info_params.rb', line 34

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same command_id for the same call_control_id.



41
# File 'lib/telnyx/models/calls/action_send_sip_info_params.rb', line 41

optional :command_id, String

#content_typeString

Content type of the INFO body. Must be MIME type compliant. There is a 1,400 bytes limit



27
# File 'lib/telnyx/models/calls/action_send_sip_info_params.rb', line 27

required :content_type, String

Instance Method Details

#to_hash{



41
# File 'sig/telnyx/models/calls/action_send_sip_info_params.rbs', line 41

def to_hash: -> {