Class: Telnyx::Models::Calls::ActionSpeakParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_speak_params.rb,
sig/telnyx/models/calls/action_speak_params.rbs

Overview

See Also:

  • Telnyx::Resources::Calls::Actions#speak

Defined Under Namespace

Modules: Language, PayloadType, ServiceLevel, TargetLegs, VoiceSettings

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, payload:, voice:, client_state: nil, command_id: nil, language: nil, loop_: nil, payload_type: nil, service_level: nil, stop: nil, target_legs: nil, voice_settings: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionSpeakParams for more details.

Parameters:



# File 'lib/telnyx/models/calls/action_speak_params.rb', line 146

Instance Attribute Details

#call_control_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Parameters:

  • (String)

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 88

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same command_id for the same call_control_id.

Parameters:

  • (String)

Returns:

  • (String, nil)


95
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 95

optional :command_id, String

#languageSymbol, ...

The language you want spoken. This parameter is ignored when a Polly.* voice is specified.



102
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 102

optional :language, enum: -> { Telnyx::Calls::ActionSpeakParams::Language }

#loop_String, ...

The number of times to play the audio file. Use infinity to loop indefinitely. Defaults to 1.

Returns:

  • (String, Integer, nil)


109
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 109

optional :loop_, union: -> { Telnyx::Calls::Loopcount }, api_name: :loop

#payloadString

The text or SSML to be converted into speech. There is a 3,000 character limit.

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 20

required :payload, String

#payload_typeSymbol, ...

The type of the provided payload. The payload can either be plain text, or Speech Synthesis Markup Language (SSML).



116
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 116

optional :payload_type, enum: -> { Telnyx::Calls::ActionSpeakParams::PayloadType }

#service_levelSymbol, ...

This parameter impacts speech quality, language options and payload types. When using basic, only the en-US language and payload type text are allowed.



123
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 123

optional :service_level, enum: -> { Telnyx::Calls::ActionSpeakParams::ServiceLevel }

#stopString?

When specified, it stops the current audio being played. Specify current to stop the current audio being played, and to play the next file in the queue. Specify all to stop the current audio file being played and to also clear all audio files from the queue.

Parameters:

  • (String)

Returns:

  • (String, nil)


132
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 132

optional :stop, String

#target_legsSymbol, ...

Specifies which legs of the call should receive the spoken audio.



138
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 138

optional :target_legs, enum: -> { Telnyx::Calls::ActionSpeakParams::TargetLegs }

#voiceString

Specifies the voice used in speech synthesis.

  • Define voices using the format <Provider>.<Model>.<VoiceId>. Specifying only the provider will give default values for voice_id and model_id.

    Supported Providers:

  • AWS: Use AWS.Polly.<VoiceId> (e.g., AWS.Polly.Joanna). For neural voices, which provide more realistic, human-like speech, append -Neural to the VoiceId (e.g., AWS.Polly.Joanna-Neural). Check the available voices for compatibility.

  • Azure: Use Azure.<VoiceId> (e.g., Azure.en-CA-ClaraNeural, Azure.en-US-BrianMultilingualNeural, Azure.en-US-Ava:DragonHDLatestNeural). For a complete list of voices, go to Azure Voice Gallery. Use voice_settings to configure custom deployments, regions, or API keys.

  • ElevenLabs: Use ElevenLabs.<ModelId>.<VoiceId> (e.g., ElevenLabs.eleven_multilingual_v2.21m00Tcm4TlvDq8ikWAM). The ModelId part is optional. To use ElevenLabs, you must provide your ElevenLabs API key as an integration identifier secret in "voice_settings": {"api_key_ref": "<secret_identifier>"}. See integration secrets documentation for details. Check available voices.

  • Telnyx: Use Telnyx.<model_id>.<voice_id> (e.g., Telnyx.KokoroTTS.af). Use voice_settings to configure voice_speed and other synthesis parameters. Bayan provides Arabic (multiple dialects) and English voices (e.g., Telnyx.Bayan.Ahmed, Telnyx.Bayan.Amanda). Sukhan provides Urdu voices (e.g., Telnyx.Sukhan.urdu-professor); voice_speed is not supported.

  • Minimax: Use Minimax.<ModelId>.<VoiceId> (e.g., Minimax.speech-02-hd.Wise_Woman). Supported models: speech-02-turbo, speech-02-hd, speech-2.6-turbo, speech-2.8-turbo. Use voice_settings to configure speed, volume, pitch, and language_boost.

  • Rime: Use Rime.<model_id>.<voice_id> (e.g., Rime.Arcana.cove). Supported model_ids: Arcana, Mist, ArcanaV3, Coda. Use voice_settings to configure voice_speed.

  • Resemble: Use Resemble.Turbo.<voice_id> (e.g., Resemble.Turbo.my_voice). Only Turbo model is supported. Use voice_settings to configure precision, sample_rate, and format.

  • Inworld: Use Inworld.<ModelId>.<VoiceId> (e.g., Inworld.Mini.Loretta, Inworld.Max.Oliver, Inworld.TTS2.Loretta). Supported models: Mini, Max, TTS2. Use voice_settings to configure delivery_mode (STABLE, BALANCED, CREATIVE), supported by TTS2 only.

  • Fish Audio: Use FishAudio.<ModelId>.<VoiceId> (e.g., FishAudio.s2.1-pro.<reference_id>). Supported models: s2.1-pro, s2-pro, s1. VoiceId is a Fish Voice-Library reference ID.

  • xAI: Use xAI.<VoiceId> (e.g., xAI.eve). Available voices: eve, ara, rex, sal, leo.

  • Humain: Use Humain.<VoiceId> (e.g., Humain.sara-ar). Available voices: sara-en, abdulaziz-en, sara-ar, abdulaziz-ar, nourah-ar, abdullah-ar. Native Arabic (Saudi dialect) and English voices only — no ModelId segment.

For service_level basic, you may define the gender of the speaker (male or female).

Parameters:

  • value (String)

Returns:

  • (String)


81
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 81

required :voice, String

#voice_settingsTelnyx::Models::Calls::ElevenLabsVoiceSettings, ...

The settings associated with the voice selected



144
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 144

optional :voice_settings, union: -> { Telnyx::Calls::ActionSpeakParams::VoiceSettings }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_speak_params.rb', line 211

Instance Method Details

#to_hash{

Returns:

  • ({)


95
# File 'sig/telnyx/models/calls/action_speak_params.rbs', line 95

def to_hash: -> {