Class: Telnyx::Models::Calls::ActionSpeakParams::VoiceSettings::Inworld
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionSpeakParams::VoiceSettings::Inworld
- Defined in:
- lib/telnyx/models/calls/action_speak_params.rb
Defined Under Namespace
Modules: DeliveryMode
Instance Attribute Summary collapse
-
#delivery_mode ⇒ Symbol, ...
Controls the expressiveness and consistency of the Inworld ‘TTS2` model’s speech synthesis.
-
#type ⇒ Symbol, :inworld
Voice settings provider type.
Instance Method Summary collapse
-
#initialize(delivery_mode: nil, type: :inworld) ⇒ Object
constructor
Some parameter documentations has been truncated, see Inworld for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(delivery_mode: nil, type: :inworld) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionSpeakParams::VoiceSettings::Inworld for more details.
|
|
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 282
|
Instance Attribute Details
#delivery_mode ⇒ Symbol, ...
Controls the expressiveness and consistency of the Inworld ‘TTS2` model’s speech synthesis. ‘STABLE` favors consistent, predictable output, `CREATIVE` allows more expressive variation, and `BALANCED` sits in between. Optional and only supported by `TTS2`; when omitted, the provider default applies.
279 280 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 279 optional :delivery_mode, enum: -> { Telnyx::Calls::ActionSpeakParams::VoiceSettings::Inworld::DeliveryMode } |
#type ⇒ Symbol, :inworld
Voice settings provider type
270 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 270 required :type, const: :inworld |