Module: Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/calls/action_start_ai_assistant_params.rb

Overview

Messages sent by an end user

Defined Under Namespace

Classes: Assistant, Developer, System, Tool, User

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 286

Instance Method Details

#initialize(content:, metadata: nil, role: :system) ⇒ Object

Developer-provided instructions that the model should follow, regardless of messages sent by the user.

Parameters:

  • content (String)

    The contents of the system message.

  • metadata (Hash{Symbol=>Object}) (defaults to: nil)

    Metadata to add to the message

  • role (Symbol, :system) (defaults to: :system)

    The role of the messages author, in this case ‘system`.



# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 187