Class: Telnyx::Models::Calls::ActionStartAIAssistantParams::Participant

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/action_start_ai_assistant_params.rb

Defined Under Namespace

Modules: OnHangup, Role

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, role:, name: nil, on_hangup: nil) ⇒ Object

Parameters:



# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 416

Instance Attribute Details

#idString

The call_control_id of the participant to add to the conversation.

Returns:

  • (String)


396
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 396

required :id, String

#nameString?

Display name for the participant.

Returns:

  • (String, nil)


408
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 408

optional :name, String

#on_hangupSymbol, ...

Determines what happens to the conversation when this participant hangs up.



414
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 414

optional :on_hangup, enum: -> { Telnyx::Calls::ActionStartAIAssistantParams::Participant::OnHangup }

#roleSymbol, Telnyx::Models::Calls::ActionStartAIAssistantParams::Participant::Role

The role of the participant in the conversation.



402
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 402

required :role, enum: -> { Telnyx::Calls::ActionStartAIAssistantParams::Participant::Role }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 433