Class: Telnyx::Models::Calls::ActionStartConversationRelayParams::Language
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionStartConversationRelayParams::Language
- Defined in:
- lib/telnyx/models/calls/action_start_conversation_relay_params.rb
Defined Under Namespace
Modules: TranscriptionEngine, VoiceSettings
Instance Attribute Summary collapse
-
#language ⇒ String
BCP 47 language tag for this language configuration.
-
#speech_model ⇒ String?
Conversation Relay speech model.
-
#transcription_engine ⇒ Symbol, ...
Engine to use for speech recognition.
-
#transcription_engine_config ⇒ Hash{Symbol=>Object}?
Engine-specific transcription settings for Conversation Relay.
-
#transcription_provider ⇒ String?
Conversation Relay transcription provider name.
-
#tts_provider ⇒ String?
Text-to-speech provider for this language.
-
#voice ⇒ String?
Voice identifier for this language.
-
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(language:, speech_model: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_provider: nil, tts_provider: nil, voice: nil, voice_settings: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Language for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(language:, speech_model: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_provider: nil, tts_provider: nil, voice: nil, voice_settings: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStartConversationRelayParams::Language for more details.
Language-specific TTS and transcription settings for Conversation Relay.
|
|
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 716
|
Instance Attribute Details
#language ⇒ String
BCP 47 language tag for this language configuration.
660 |
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 660 required :language, String |
#speech_model ⇒ String?
Conversation Relay speech model. Prefer ‘transcription_engine_config.transcription_model` when configuring speech-to-text.
668 |
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 668 optional :speech_model, String |
#transcription_engine ⇒ Symbol, ...
Engine to use for speech recognition. Legacy values ‘A` - `Google`, `B` - `Telnyx` are supported for backward compatibility. When provided in a Conversation Relay language entry, Telnyx derives `transcription_provider` and `speech_model` for that language.
677 678 |
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 677 optional :transcription_engine, enum: -> { Telnyx::Calls::ActionStartConversationRelayParams::Language::TranscriptionEngine } |
#transcription_engine_config ⇒ Hash{Symbol=>Object}?
Engine-specific transcription settings for Conversation Relay. This accepts the same provider-specific options used by the Call Transcription Start command, such as ‘transcription_model`, without requiring the engine discriminator to be repeated inside this object.
687 |
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 687 optional :transcription_engine_config, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#transcription_provider ⇒ String?
Conversation Relay transcription provider name. Prefer ‘transcription_engine` when configuring speech-to-text.
694 |
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 694 optional :transcription_provider, String |
#tts_provider ⇒ String?
Text-to-speech provider for this language. If omitted and ‘voice` is provided, Telnyx derives the provider from the voice identifier.
701 |
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 701 optional :tts_provider, String |
#voice ⇒ String?
Voice identifier for this language.
707 |
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 707 optional :voice, String |
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected
713 714 |
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 713 optional :voice_settings, union: -> { Telnyx::Calls::ActionStartConversationRelayParams::Language::VoiceSettings } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 759
|