Class: Telnyx::Models::Calls::ActionStartForkingParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionStartForkingParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_start_forking_params.rb
Overview
Defined Under Namespace
Modules: StreamType
Instance Attribute Summary collapse
- #call_control_id ⇒ String
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#rx ⇒ String?
The network target, <udp:ip_address:port>, where the call’s incoming RTP media packets should be forwarded.
-
#stream_type ⇒ Symbol, ...
Optionally specify a media type to stream.
-
#tx ⇒ String?
The network target, <udp:ip_address:port>, where the call’s outgoing RTP media packets should be forwarded.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(call_control_id:, client_state: nil, command_id: nil, rx: nil, stream_type: nil, tx: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionStartForkingParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id:, client_state: nil, command_id: nil, rx: nil, stream_type: nil, tx: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStartForkingParams for more details.
|
|
# File 'lib/telnyx/models/calls/action_start_forking_params.rb', line 52
|
Instance Attribute Details
#call_control_id ⇒ String
14 |
# File 'lib/telnyx/models/calls/action_start_forking_params.rb', line 14 required :call_control_id, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
21 |
# File 'lib/telnyx/models/calls/action_start_forking_params.rb', line 21 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
28 |
# File 'lib/telnyx/models/calls/action_start_forking_params.rb', line 28 optional :command_id, String |
#rx ⇒ String?
The network target, <udp:ip_address:port>, where the call’s incoming RTP media packets should be forwarded.
35 |
# File 'lib/telnyx/models/calls/action_start_forking_params.rb', line 35 optional :rx, String |
#stream_type ⇒ Symbol, ...
Optionally specify a media type to stream. If ‘decrypted` selected, Telnyx will decrypt incoming SIP media before forking to the target. `rx` and `tx` are required fields if `decrypted` selected.
43 |
# File 'lib/telnyx/models/calls/action_start_forking_params.rb', line 43 optional :stream_type, enum: -> { Telnyx::Calls::ActionStartForkingParams::StreamType } |
#tx ⇒ String?
The network target, <udp:ip_address:port>, where the call’s outgoing RTP media packets should be forwarded.
50 |
# File 'lib/telnyx/models/calls/action_start_forking_params.rb', line 50 optional :tx, String |