Class: Telnyx::Models::Calls::ActionStartSiprecParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_start_siprec_params.rb

Overview

Defined Under Namespace

Modules: IncludeMetadataCustomHeaders, Secure, SipTransport, SiprecTrack

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, client_state: nil, connector_name: nil, include_metadata_custom_headers: nil, secure: nil, session_timeout_secs: nil, sip_transport: nil, siprec_track: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStartSiprecParams for more details.

Parameters:



# File 'lib/telnyx/models/calls/action_start_siprec_params.rb', line 65

Instance Attribute Details

#call_control_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_start_siprec_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/calls/action_start_siprec_params.rb', line 21

optional :client_state, String

#connector_nameString?

Name of configured SIPREC connector to be used.

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/calls/action_start_siprec_params.rb', line 27

optional :connector_name, String

#include_metadata_custom_headersBoolean, ...

When set, custom parameters will be added as metadata (recording.session.ExtensionParameters). Otherwise, they’ll be added to sip headers.



35
36
# File 'lib/telnyx/models/calls/action_start_siprec_params.rb', line 35

optional :include_metadata_custom_headers,
enum: -> { Telnyx::Calls::ActionStartSiprecParams::IncludeMetadataCustomHeaders }

#secureBoolean, ...

Controls whether to encrypt media sent to your SRS using SRTP and TLS. When set you need to configure SRS port in your connector to 5061.



43
# File 'lib/telnyx/models/calls/action_start_siprec_params.rb', line 43

optional :secure, enum: -> { Telnyx::Calls::ActionStartSiprecParams::Secure }

#session_timeout_secsInteger?

Sets ‘Session-Expires` header to the INVITE. A reinvite is sent every half the value set. Usefull for session keep alive. Minimum value is 90, set to 0 to disable.

Returns:

  • (Integer, nil)


51
# File 'lib/telnyx/models/calls/action_start_siprec_params.rb', line 51

optional :session_timeout_secs, Integer

#sip_transportSymbol, ...

Specifies SIP transport protocol.



57
# File 'lib/telnyx/models/calls/action_start_siprec_params.rb', line 57

optional :sip_transport, enum: -> { Telnyx::Calls::ActionStartSiprecParams::SipTransport }

#siprec_trackSymbol, ...

Specifies which track should be sent on siprec session.



63
# File 'lib/telnyx/models/calls/action_start_siprec_params.rb', line 63

optional :siprec_track, enum: -> { Telnyx::Calls::ActionStartSiprecParams::SiprecTrack }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_start_siprec_params.rb', line 96