Class: Telnyx::Models::Calls::ActionStartStreamingParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_start_streaming_params.rb

Overview

Defined Under Namespace

Modules: StreamTrack Classes: CustomParameter

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil, value: nil) ⇒ Object

Parameters:

  • name (String) (defaults to: nil)

    The name of the custom parameter.

  • value (String) (defaults to: nil)

    The value of the custom parameter.



# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 147

Instance Attribute Details

#call_control_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 21

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 28

optional :command_id, String

#custom_parametersArray<Telnyx::Models::Calls::ActionStartStreamingParams::CustomParameter>?

Custom parameters to be sent as part of the WebSocket connection.



34
35
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 34

optional :custom_parameters,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Calls::ActionStartStreamingParams::CustomParameter] }

#dialogflow_configTelnyx::Models::DialogflowConfig?



40
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 40

optional :dialogflow_config, -> { Telnyx::DialogflowConfig }

#enable_dialogflowBoolean?

Enables Dialogflow for the current call. The default value is false.

Returns:

  • (Boolean, nil)


46
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 46

optional :enable_dialogflow, Telnyx::Internal::Type::Boolean

#stream_auth_tokenString?

An authentication token to be sent as part of the WebSocket connection. Maximum length is 4000 characters.

Returns:

  • (String, nil)


53
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 53

optional :stream_auth_token, String

#stream_bidirectional_codecSymbol, ...

Indicates codec for bidirectional streaming RTP payloads. Used only with stream_bidirectional_mode=rtp. Case sensitive.



60
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 60

optional :stream_bidirectional_codec, enum: -> { Telnyx::StreamBidirectionalCodec }

#stream_bidirectional_modeSymbol, ...

Configures method of bidirectional streaming (mp3, rtp).

Returns:



66
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 66

optional :stream_bidirectional_mode, enum: -> { Telnyx::StreamBidirectionalMode }

#stream_bidirectional_sampling_rateInteger, ...

Audio sampling rate.



72
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 72

optional :stream_bidirectional_sampling_rate, enum: -> { Telnyx::StreamBidirectionalSamplingRate }

#stream_bidirectional_target_legsSymbol, ...

Specifies which call legs should receive the bidirectional stream audio.



78
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 78

optional :stream_bidirectional_target_legs, enum: -> { Telnyx::StreamBidirectionalTargetLegs }

#stream_codecSymbol, ...

Specifies the codec to be used for the streamed audio. When set to ‘default’ or when transcoding is not possible, the codec from the call will be used.

Returns:



85
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 85

optional :stream_codec, enum: -> { Telnyx::StreamCodec }

#stream_trackSymbol, ...

Specifies which track should be streamed.



91
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 91

optional :stream_track, enum: -> { Telnyx::Calls::ActionStartStreamingParams::StreamTrack }

#stream_urlString?

The destination WebSocket address where the stream is going to be delivered.

Returns:

  • (String, nil)


97
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 97

optional :stream_url, String