Class: Telnyx::Models::Calls::ActionStartStreamingParams::CustomParameter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/action_start_streaming_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, client_state: nil, command_id: nil, custom_parameters: nil, dialogflow_config: nil, enable_dialogflow: nil, stream_auth_token: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_sampling_rate: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStartStreamingParams for more details.

stream_

Parameters:

  • call_control_id (String)
  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. It must be a valid Base

  • command_id (String) (defaults to: nil)

    Use this field to avoid duplicate commands. Telnyx will ignore any command with

  • custom_parameters (Array<Telnyx::Models::Calls::ActionStartStreamingParams::CustomParameter>) (defaults to: nil)

    Custom parameters to be sent as part of the WebSocket connection.

  • dialogflow_config (Telnyx::Models::DialogflowConfig) (defaults to: nil)
  • enable_dialogflow (Boolean) (defaults to: nil)

    Enables Dialogflow for the current call. The default value is false.

  • stream_auth_token (String) (defaults to: nil)

    An authentication token to be sent as part of the WebSocket connection. Maximum

  • stream_bidirectional_codec (Symbol, Telnyx::Models::StreamBidirectionalCodec) (defaults to: nil)

    Indicates codec for bidirectional streaming RTP payloads. Used only with

  • stream_bidirectional_mode (Symbol, Telnyx::Models::StreamBidirectionalMode) (defaults to: nil)

    Configures method of bidirectional streaming (mp3, rtp).

  • stream_bidirectional_sampling_rate (Integer, Telnyx::Models::StreamBidirectionalSamplingRate) (defaults to: nil)

    Audio sampling rate.

  • stream_bidirectional_target_legs (Symbol, Telnyx::Models::StreamBidirectionalTargetLegs) (defaults to: nil)

    Specifies which call legs should receive the bidirectional stream audio.

  • stream_codec (Symbol, Telnyx::Models::StreamCodec) (defaults to: nil)

    Specifies the codec to be used for the streamed audio. When set to ‘default’ or

  • stream_track (Symbol, Telnyx::Models::Calls::ActionStartStreamingParams::StreamTrack) (defaults to: nil)

    Specifies which track should be streamed.

  • stream_url (String) (defaults to: nil)

    The destination WebSocket address where the stream is going to be delivered.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 134

class CustomParameter < Telnyx::Internal::Type::BaseModel
  # @!attribute name
  #   The name of the custom parameter.
  #
  #   @return [String, nil]
  optional :name, String

  # @!attribute value
  #   The value of the custom parameter.
  #
  #   @return [String, nil]
  optional :value, String

  # @!method initialize(name: nil, value: nil)
  #   @param name [String] The name of the custom parameter.
  #
  #   @param value [String] The value of the custom parameter.
end

Instance Attribute Details

#nameString?

The name of the custom parameter.

Returns:

  • (String, nil)


139
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 139

optional :name, String

#valueString?

The value of the custom parameter.

Returns:

  • (String, nil)


145
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 145

optional :value, String