Class: Telnyx::Models::Calls::ActionStopForkingParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionStopForkingParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_stop_forking_params.rb
Overview
Defined Under Namespace
Modules: StreamType
Instance Attribute Summary collapse
- #call_control_id ⇒ String
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#stream_type ⇒ Symbol, ...
Optionally specify a ‘stream_type`.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(call_control_id:, client_state: nil, command_id: nil, stream_type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionStopForkingParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id:, client_state: nil, command_id: nil, stream_type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStopForkingParams for more details.
|
|
# File 'lib/telnyx/models/calls/action_stop_forking_params.rb', line 37
|
Instance Attribute Details
#call_control_id ⇒ String
14 |
# File 'lib/telnyx/models/calls/action_stop_forking_params.rb', line 14 required :call_control_id, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
21 |
# File 'lib/telnyx/models/calls/action_stop_forking_params.rb', line 21 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
28 |
# File 'lib/telnyx/models/calls/action_stop_forking_params.rb', line 28 optional :command_id, String |
#stream_type ⇒ Symbol, ...
Optionally specify a ‘stream_type`. This should match the `stream_type` that was used in `fork_start` command to properly stop the fork.
35 |
# File 'lib/telnyx/models/calls/action_stop_forking_params.rb', line 35 optional :stream_type, enum: -> { Telnyx::Calls::ActionStopForkingParams::StreamType } |