Class: Telnyx::Models::Calls::ActionStopPlaybackParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_stop_playback_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, client_state: nil, command_id: nil, overlay: nil, stop: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStopPlaybackParams for more details.

Parameters:

  • call_control_id (String)
  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. It must be a valid Base

  • command_id (String) (defaults to: nil)

    Use this field to avoid duplicate commands. Telnyx will ignore any command with

  • overlay (Boolean) (defaults to: nil)

    When enabled, it stops the audio being played in the overlay queue.

  • stop (String) (defaults to: nil)

    Use ‘current` to stop the current audio being played. Use `all` to stop the curr

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/calls/action_stop_playback_params.rb', line 43

Instance Attribute Details

#call_control_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_stop_playback_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/calls/action_stop_playback_params.rb', line 21

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/calls/action_stop_playback_params.rb', line 28

optional :command_id, String

#overlayBoolean?

When enabled, it stops the audio being played in the overlay queue.

Returns:

  • (Boolean, nil)


34
# File 'lib/telnyx/models/calls/action_stop_playback_params.rb', line 34

optional :overlay, Telnyx::Internal::Type::Boolean

#stopString?

Use ‘current` to stop the current audio being played. Use `all` to stop the current audio file being played and clear all audio files from the queue.

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/calls/action_stop_playback_params.rb', line 41

optional :stop, String