Module: Telnyx::Models::Calls::ActionTransferParams::AnsweringMachineDetection

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/calls/action_transfer_params.rb

Overview

Enables Answering Machine Detection. When a call is answered, Telnyx runs real-time detection to determine if it was picked up by a human or a machine and sends an ‘call.machine.detection.ended` webhook with the analysis result. If ’greeting_end’ or ‘detect_words’ is used and a ‘machine’ is detected, you will receive another ‘call.machine.greeting.ended’ webhook when the answering machine greeting ends with a beep or silence. If ‘detect_beep` is used, you will only receive ’call.machine.greeting.ended’ if a beep is detected.

Constant Summary collapse

PREMIUM =
:premium
DETECT =
:detect
DETECT_BEEP =
:detect_beep
DETECT_WORDS =
:detect_words
GREETING_END =
:greeting_end
DISABLED =
:disabled

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info