Class: Telnyx::Models::Calls::DeepgramNova2Config
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::DeepgramNova2Config
- Defined in:
- lib/telnyx/models/calls/deepgram_nova2_config.rb,
sig/telnyx/models/calls/deepgram_nova2_config.rbs
Defined Under Namespace
Modules: Language, TranscriptionEngine, TranscriptionModel
Instance Attribute Summary collapse
-
#hints ⇒ Array<String>?
Nova-2 keyword biasing without intensifiers.
-
#interim_results ⇒ Boolean?
Whether to send also interim results.
-
#keywords_boosting ⇒ Hash{Symbol=>Float}?
Keywords and their respective intensifiers (boosting values) to improve transcription accuracy for specific words or phrases.
-
#language ⇒ Symbol, ...
Language to use for speech recognition with nova-2 model.
-
#smart_format ⇒ Boolean?
Enable Deepgram's smart formatting (capitalization, punctuation, and digit normalization).
- #transcription_engine ⇒ Symbol, Telnyx::Models::Calls::DeepgramNova2Config::TranscriptionEngine
- #transcription_model ⇒ Symbol, Telnyx::Models::Calls::DeepgramNova2Config::TranscriptionModel
-
#utterance_end_ms ⇒ Integer?
Number of milliseconds of silence to consider an utterance ended.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(transcription_engine:, transcription_model:, hints: nil, interim_results: nil, keywords_boosting: nil, language: nil, smart_format: nil, utterance_end_ms: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DeepgramNova2Config for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transcription_engine:, transcription_model:, hints: nil, interim_results: nil, keywords_boosting: nil, language: nil, smart_format: nil, utterance_end_ms: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::DeepgramNova2Config for more details.
|
|
# File 'lib/telnyx/models/calls/deepgram_nova2_config.rb', line 63
|
Instance Attribute Details
#hints ⇒ Array<String>?
Nova-2 keyword biasing without intensifiers. Up to 100 terms to bias recognition
toward. For weighted biasing, use keywords_boosting instead. Nova-2-only; use
keyterms on Nova-3.
23 |
# File 'lib/telnyx/models/calls/deepgram_nova2_config.rb', line 23 optional :hints, Telnyx::Internal::Type::ArrayOf[String] |
#interim_results ⇒ Boolean?
Whether to send also interim results. If set to false, only final results will be sent.
30 |
# File 'lib/telnyx/models/calls/deepgram_nova2_config.rb', line 30 optional :interim_results, Telnyx::Internal::Type::Boolean |
#keywords_boosting ⇒ Hash{Symbol=>Float}?
Keywords and their respective intensifiers (boosting values) to improve
transcription accuracy for specific words or phrases. The intensifier should be
a numeric value. Example: {"snuffleupagus": 5, "systrom": 2, "krieger": 1}.
38 |
# File 'lib/telnyx/models/calls/deepgram_nova2_config.rb', line 38 optional :keywords_boosting, Telnyx::Internal::Type::HashOf[Float] |
#language ⇒ Symbol, ...
Language to use for speech recognition with nova-2 model
44 |
# File 'lib/telnyx/models/calls/deepgram_nova2_config.rb', line 44 optional :language, enum: -> { Telnyx::Calls::DeepgramNova2Config::Language } |
#smart_format ⇒ Boolean?
Enable Deepgram's smart formatting (capitalization, punctuation, and digit
normalization). Note: Telnyx defaults this to true, overriding Deepgram's
underlying default of false — omit the field to get a smart-formatted
transcript, or set it to false to receive the raw lowercase transcript without
punctuation.
54 |
# File 'lib/telnyx/models/calls/deepgram_nova2_config.rb', line 54 optional :smart_format, Telnyx::Internal::Type::Boolean |
#transcription_engine ⇒ Symbol, Telnyx::Models::Calls::DeepgramNova2Config::TranscriptionEngine
10 |
# File 'lib/telnyx/models/calls/deepgram_nova2_config.rb', line 10 required :transcription_engine, enum: -> { Telnyx::Calls::DeepgramNova2Config::TranscriptionEngine } |
#transcription_model ⇒ Symbol, Telnyx::Models::Calls::DeepgramNova2Config::TranscriptionModel
15 |
# File 'lib/telnyx/models/calls/deepgram_nova2_config.rb', line 15 required :transcription_model, enum: -> { Telnyx::Calls::DeepgramNova2Config::TranscriptionModel } |
#utterance_end_ms ⇒ Integer?
Number of milliseconds of silence to consider an utterance ended. Ranges from 0 to 5000 ms.
61 |
# File 'lib/telnyx/models/calls/deepgram_nova2_config.rb', line 61 optional :utterance_end_ms, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/deepgram_nova2_config.rb', line 89
|
Instance Method Details
#to_hash ⇒ {
58 |
# File 'sig/telnyx/models/calls/deepgram_nova2_config.rbs', line 58
def to_hash: -> {
|