Class: Telnyx::Models::Calls::DeepgramNova3Config

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/deepgram_nova3_config.rb,
sig/telnyx/models/calls/deepgram_nova3_config.rbs

Defined Under Namespace

Modules: Language, TranscriptionEngine, TranscriptionModel

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(transcription_engine:, transcription_model:, interim_results: nil, keyterms: nil, keywords_boosting: nil, language: nil, smart_format: nil, utterance_end_ms: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::DeepgramNova3Config for more details.

Parameters:

  • transcription_engine (Symbol, Telnyx::Models::Calls::DeepgramNova3Config::TranscriptionEngine)
  • transcription_model (Symbol, Telnyx::Models::Calls::DeepgramNova3Config::TranscriptionModel)
  • interim_results (Boolean) (defaults to: nil)

    Whether to send also interim results. If set to false, only final results will b

  • keyterms (Array<String>) (defaults to: nil)

    Nova-3 keyterm prompting. Up to 100 domain-specific terms or brand names to bias

  • keywords_boosting (Hash{Symbol=>Float}) (defaults to: nil)

    Keywords and their respective intensifiers (boosting values) to improve transcri

  • language (Symbol, Telnyx::Models::Calls::DeepgramNova3Config::Language) (defaults to: nil)

    Language to use for speech recognition with nova-3 model

  • smart_format (Boolean) (defaults to: nil)

    Enable Deepgram's smart formatting (capitalization, punctuation, and digit norma

  • utterance_end_ms (Integer) (defaults to: nil)

    Number of milliseconds of silence to consider an utterance ended. Ranges from 0



# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 62

Instance Attribute Details

#interim_resultsBoolean?

Whether to send also interim results. If set to false, only final results will be sent.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


22
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 22

optional :interim_results, Telnyx::Internal::Type::Boolean

#keytermsArray<String>?

Nova-3 keyterm prompting. Up to 100 domain-specific terms or brand names to bias recognition toward. Nova-3-only; use hints on Nova-2.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


29
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 29

optional :keyterms, Telnyx::Internal::Type::ArrayOf[String]

#keywords_boostingHash{Symbol=>Float}?

Keywords and their respective intensifiers (boosting values) to improve transcription accuracy for specific words or phrases. The intensifier should be a numeric value. Example: {"snuffleupagus": 5, "systrom": 2, "krieger": 1}.

Parameters:

  • (::Hash[Symbol, Float])

Returns:

  • (Hash{Symbol=>Float}, nil)


37
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 37

optional :keywords_boosting, Telnyx::Internal::Type::HashOf[Float]

#languageSymbol, ...

Language to use for speech recognition with nova-3 model



43
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 43

optional :language, enum: -> { Telnyx::Calls::DeepgramNova3Config::Language }

#smart_formatBoolean?

Enable Deepgram's smart formatting (capitalization, punctuation, and digit normalization). Note: Telnyx defaults this to true, overriding Deepgram's underlying default of false — omit the field to get a smart-formatted transcript, or set it to false to receive the raw lowercase transcript without punctuation.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


53
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 53

optional :smart_format, Telnyx::Internal::Type::Boolean

#transcription_engineSymbol, Telnyx::Models::Calls::DeepgramNova3Config::TranscriptionEngine

Parameters:

  • value (Telnyx::Models::Calls::DeepgramNova3Config::transcription_engine)

Returns:



10
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 10

required :transcription_engine, enum: -> { Telnyx::Calls::DeepgramNova3Config::TranscriptionEngine }

#transcription_modelSymbol, Telnyx::Models::Calls::DeepgramNova3Config::TranscriptionModel

Parameters:

  • value (Telnyx::Models::Calls::DeepgramNova3Config::transcription_model)

Returns:



15
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 15

required :transcription_model, enum: -> { Telnyx::Calls::DeepgramNova3Config::TranscriptionModel }

#utterance_end_msInteger?

Number of milliseconds of silence to consider an utterance ended. Ranges from 0 to 5000 ms.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


60
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 60

optional :utterance_end_ms, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 88

Instance Method Details

#to_hash{

Returns:

  • ({)


58
# File 'sig/telnyx/models/calls/deepgram_nova3_config.rbs', line 58

def to_hash: -> {