Class: Telnyx::Models::Calls::DeveloperMessage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::DeveloperMessage
- Defined in:
- lib/telnyx/models/calls/developer_message.rb
Defined Under Namespace
Modules: Role
Instance Attribute Summary collapse
-
#content ⇒ String
The contents of the developer message.
-
#metadata ⇒ Hash{Symbol=>Object}?
Metadata to add to the message.
-
#role ⇒ Symbol, Telnyx::Models::Calls::DeveloperMessage::Role
The role of the messages author, in this case developer.
Instance Method Summary collapse
-
#initialize(content:, role:, metadata: nil) ⇒ Object
constructor
Developer-provided instructions that the model should follow, regardless of messages sent by the user.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content:, role:, metadata: nil) ⇒ Object
Developer-provided instructions that the model should follow, regardless of messages sent by the user.
|
|
# File 'lib/telnyx/models/calls/developer_message.rb', line 25
|
Instance Attribute Details
#content ⇒ String
The contents of the developer message.
11 |
# File 'lib/telnyx/models/calls/developer_message.rb', line 11 required :content, String |
#metadata ⇒ Hash{Symbol=>Object}?
Metadata to add to the message
23 |
# File 'lib/telnyx/models/calls/developer_message.rb', line 23 optional :metadata, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#role ⇒ Symbol, Telnyx::Models::Calls::DeveloperMessage::Role
The role of the messages author, in this case developer.
17 |
# File 'lib/telnyx/models/calls/developer_message.rb', line 17 required :role, enum: -> { Telnyx::Calls::DeveloperMessage::Role } |