Class: Telnyx::Models::Calls::InterruptionSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/interruption_settings.rb,
sig/telnyx/models/calls/interruption_settings.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enable: nil) ⇒ InterruptionSettings

Settings for handling user interruptions during assistant speech

Parameters:

  • enable (Boolean) (defaults to: nil)

    When true, allows users to interrupt the assistant while speaking

  • enable: (Boolean) (defaults to: nil)


# File 'lib/telnyx/models/calls/interruption_settings.rb', line 13

Instance Attribute Details

#enableBoolean?

When true, allows users to interrupt the assistant while speaking

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


11
# File 'lib/telnyx/models/calls/interruption_settings.rb', line 11

optional :enable, Telnyx::Internal::Type::Boolean

Instance Method Details

#to_hash{ enable: bool }

Returns:

  • ({ enable: bool })


13
# File 'sig/telnyx/models/calls/interruption_settings.rbs', line 13

def to_hash: -> { enable: bool }