Class: Telnyx::Models::Calls::PayPromptValue::UnionMember1

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/pay_prompt_value.rb,
sig/telnyx/models/calls/pay_prompt_value.rbs

Defined Under Namespace

Modules: CardType, ErrorType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(text:, attempt: nil, card_type: nil, error_type: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::PayPromptValue::UnionMember1 for more details.

A text-to-speech prompt with optional matching qualifiers.

Parameters:



# File 'lib/telnyx/models/calls/pay_prompt_value.rb', line 41

Instance Attribute Details

#attemptString?

Space-separated 1-based attempt numbers for which this prompt applies.

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/calls/pay_prompt_value.rb', line 25

optional :attempt, String

#card_typeSymbol, ...

Lowercase, case-sensitive detected card type for which this prompt applies. Only the listed brands are currently detected; accepted UnionPay and Maestro test cards do not produce a card-type qualifier.



33
# File 'lib/telnyx/models/calls/pay_prompt_value.rb', line 33

optional :card_type, enum: -> { Telnyx::Calls::PayPromptValue::UnionMember1::CardType }

#error_typeSymbol, ...

Step error for which this prompt applies.



39
# File 'lib/telnyx/models/calls/pay_prompt_value.rb', line 39

optional :error_type, enum: -> { Telnyx::Calls::PayPromptValue::UnionMember1::ErrorType }

#textString

Text spoken for the payment collection step.

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/telnyx/models/calls/pay_prompt_value.rb', line 19

required :text, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/pay_prompt_value.rb', line 70

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/telnyx/models/calls/pay_prompt_value.rbs', line 44

def to_hash: -> {