Class: Telnyx::Models::Calls::StopRecordingRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/stop_recording_request.rb

Direct Known Subclasses

ActionStopRecordingParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(client_state: nil, command_id: nil, recording_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::StopRecordingRequest for more details.

Parameters:

  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. It must be a valid Base

  • command_id (String) (defaults to: nil)

    Use this field to avoid duplicate commands. Telnyx will ignore any command with

  • recording_id (String) (defaults to: nil)

    Uniquely identifies the resource.



# File 'lib/telnyx/models/calls/stop_recording_request.rb', line 27

Instance Attribute Details

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/calls/stop_recording_request.rb', line 12

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


19
# File 'lib/telnyx/models/calls/stop_recording_request.rb', line 19

optional :command_id, String

#recording_idString?

Uniquely identifies the resource.

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/calls/stop_recording_request.rb', line 25

optional :recording_id, String