Module: Telnyx::Models::Calls::TranscriptionConfig::Model

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/calls/transcription_config.rb,
sig/telnyx/models/calls/transcription_config.rbs

Overview

The speech to text model to be used by the voice assistant. Supported models include:

  • deepgram/flux (or flux) for live streaming turn-taking.
  • deepgram/nova-3 and deepgram/nova-2 for live streaming transcription.
  • speechmatics/standard and speechmatics/enhanced for live streaming transcription.
  • assemblyai/universal-streaming for live streaming transcription.
  • xai/grok-stt for live streaming transcription.
  • soniox/stt-rt-v4 for live streaming multilingual transcription with automatic language detection.
  • parakeet/tdt-0.6b-v3 for multilingual transcription with automatic language detection.
  • azure/fast and azure/realtime; Azure models require region, and unsupported regions require api_key_ref.
  • google/latest_long for non-streaming multilingual transcription.
  • distil-whisper/distil-large-v2 for lower-latency English-only non-streaming transcription.
  • openai/whisper-large-v3-turbo for multilingual non-streaming transcription with automatic language detection.

See Also:

  • Telnyx::Models::Calls::TranscriptionConfig#model

Constant Summary collapse

DEEPGRAM_FLUX =

Returns:

  • (:"deepgram/flux")
:"deepgram/flux"
FLUX =

Returns:

  • (:flux)
:flux
DEEPGRAM_NOVA_3 =

Returns:

  • (:"deepgram/nova-3")
:"deepgram/nova-3"
DEEPGRAM_NOVA_2 =

Returns:

  • (:"deepgram/nova-2")
:"deepgram/nova-2"
SPEECHMATICS_STANDARD =

Returns:

  • (:"speechmatics/standard")
:"speechmatics/standard"
SPEECHMATICS_ENHANCED =

Returns:

  • (:"speechmatics/enhanced")
:"speechmatics/enhanced"
ASSEMBLYAI_UNIVERSAL_STREAMING =

Returns:

  • (:"assemblyai/universal-streaming")
:"assemblyai/universal-streaming"
XAI_GROK_STT =

Returns:

  • (:"xai/grok-stt")
:"xai/grok-stt"
SONIOX_STT_RT_V4 =

Returns:

  • (:"soniox/stt-rt-v4")
:"soniox/stt-rt-v4"
PARAKEET_TDT_0_6B_V3 =

Returns:

  • (:"parakeet/tdt-0.6b-v3")
:"parakeet/tdt-0.6b-v3"
AZURE_FAST =

Returns:

  • (:"azure/fast")
:"azure/fast"
AZURE_REALTIME =

Returns:

  • (:"azure/realtime")
:"azure/realtime"
GOOGLE_LATEST_LONG =

Returns:

  • (:"google/latest_long")
:"google/latest_long"
DISTIL_WHISPER_DISTIL_LARGE_V2 =

Returns:

  • (:"distil-whisper/distil-large-v2")
:"distil-whisper/distil-large-v2"
OPENAI_WHISPER_LARGE_V3_TURBO =

Returns:

  • (:"openai/whisper-large-v3-turbo")
:"openai/whisper-large-v3-turbo"

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/transcription_config.rb', line 99

Instance Method Details

#self?.values::Array[Telnyx::Models::Calls::TranscriptionConfig::model]

Returns:

  • (::Array[Telnyx::Models::Calls::TranscriptionConfig::model])


67
# File 'sig/telnyx/models/calls/transcription_config.rbs', line 67

def self?.values: -> ::Array[Telnyx::Models::Calls::TranscriptionConfig::model]