Class: Telnyx::Models::Calls::TranscriptionEngineDeepgramConfig::DeepgramNova3
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::TranscriptionEngineDeepgramConfig::DeepgramNova3
- Defined in:
- lib/telnyx/models/calls/transcription_engine_deepgram_config.rb
Defined Under Namespace
Modules: Language, TranscriptionEngine
Instance Attribute Summary collapse
-
#keywords_boosting ⇒ Hash{Symbol=>Float}?
Keywords and their respective intensifiers (boosting values) to improve transcription accuracy for specific words or phrases.
-
#language ⇒ Symbol, ...
Language to use for speech recognition with nova-3 model.
- #transcription_engine ⇒ Symbol, Telnyx::Models::Calls::TranscriptionEngineDeepgramConfig::DeepgramNova3::TranscriptionEngine
- #transcription_model ⇒ Symbol, :"deepgram/nova-3"
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(transcription_engine:, keywords_boosting: nil, language: nil, transcription_model: :"deepgram/nova-3") ⇒ Object
constructor
Some parameter documentations has been truncated, see DeepgramNova3 for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transcription_engine:, keywords_boosting: nil, language: nil, transcription_model: :"deepgram/nova-3") ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::TranscriptionEngineDeepgramConfig::DeepgramNova3 for more details.
|
|
# File 'lib/telnyx/models/calls/transcription_engine_deepgram_config.rb', line 156
|
Instance Attribute Details
#keywords_boosting ⇒ Hash{Symbol=>Float}?
Keywords and their respective intensifiers (boosting values) to improve transcription accuracy for specific words or phrases. The intensifier should be a numeric value. Example: ‘5, “systrom”: 2, “krieger”: 1`.
148 |
# File 'lib/telnyx/models/calls/transcription_engine_deepgram_config.rb', line 148 optional :keywords_boosting, Telnyx::Internal::Type::HashOf[Float] |
#language ⇒ Symbol, ...
Language to use for speech recognition with nova-3 model
154 |
# File 'lib/telnyx/models/calls/transcription_engine_deepgram_config.rb', line 154 optional :language, enum: -> { Telnyx::Calls::TranscriptionEngineDeepgramConfig::DeepgramNova3::Language } |
#transcription_engine ⇒ Symbol, Telnyx::Models::Calls::TranscriptionEngineDeepgramConfig::DeepgramNova3::TranscriptionEngine
134 135 |
# File 'lib/telnyx/models/calls/transcription_engine_deepgram_config.rb', line 134 required :transcription_engine, enum: -> { Telnyx::Calls::TranscriptionEngineDeepgramConfig::DeepgramNova3::TranscriptionEngine } |
#transcription_model ⇒ Symbol, :"deepgram/nova-3"
140 |
# File 'lib/telnyx/models/calls/transcription_engine_deepgram_config.rb', line 140 required :transcription_model, const: :"deepgram/nova-3" |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/transcription_engine_deepgram_config.rb', line 175
|