Class: Telnyx::Models::Calls::TranscriptionEngineSonioxConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/transcription_engine_soniox_config.rb

Defined Under Namespace

Modules: TranscriptionEngine, TranscriptionModel

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(transcription_engine:, enable_endpoint_detection: nil, interim_results: nil, language: nil, max_endpoint_delay_ms: nil, transcription_model: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::TranscriptionEngineSonioxConfig for more details.

Parameters:

  • transcription_engine (Symbol, Telnyx::Models::Calls::TranscriptionEngineSonioxConfig::TranscriptionEngine)

    Engine identifier for Soniox transcription service

  • enable_endpoint_detection (Boolean) (defaults to: nil)

    When true, Soniox emits end-of-utterance events at the cadence configured by ‘ma

  • interim_results (Boolean) (defaults to: nil)

    Whether to send also interim results. If set to false, only final results will b

  • language (String) (defaults to: nil)

    ISO 639-1 language hint (e.g. ‘en`, `es`), or `auto` to omit the hint and let So

  • max_endpoint_delay_ms (Integer) (defaults to: nil)

    Maximum silence (in milliseconds) before Soniox emits an end-of-utterance event.

  • transcription_model (Symbol, Telnyx::Models::Calls::TranscriptionEngineSonioxConfig::TranscriptionModel) (defaults to: nil)

    The model to use for transcription.



# File 'lib/telnyx/models/calls/transcription_engine_soniox_config.rb', line 49

Instance Attribute Details

#enable_endpoint_detectionBoolean?

When true, Soniox emits end-of-utterance events at the cadence configured by ‘max_endpoint_delay_ms`.

Returns:

  • (Boolean, nil)


19
# File 'lib/telnyx/models/calls/transcription_engine_soniox_config.rb', line 19

optional :enable_endpoint_detection, Telnyx::Internal::Type::Boolean

#interim_resultsBoolean?

Whether to send also interim results. If set to false, only final results will be sent.

Returns:

  • (Boolean, nil)


26
# File 'lib/telnyx/models/calls/transcription_engine_soniox_config.rb', line 26

optional :interim_results, Telnyx::Internal::Type::Boolean

#languageString?

ISO 639-1 language hint (e.g. ‘en`, `es`), or `auto` to omit the hint and let Soniox auto-detect supported languages multilingually.

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/calls/transcription_engine_soniox_config.rb', line 33

optional :language, String

#max_endpoint_delay_msInteger?

Maximum silence (in milliseconds) before Soniox emits an end-of-utterance event. Only honored when ‘enable_endpoint_detection` is true. Range: 500-3000 ms.

Returns:

  • (Integer, nil)


40
# File 'lib/telnyx/models/calls/transcription_engine_soniox_config.rb', line 40

optional :max_endpoint_delay_ms, Integer

#transcription_engineSymbol, Telnyx::Models::Calls::TranscriptionEngineSonioxConfig::TranscriptionEngine

Engine identifier for Soniox transcription service



11
12
# File 'lib/telnyx/models/calls/transcription_engine_soniox_config.rb', line 11

required :transcription_engine,
enum: -> { Telnyx::Calls::TranscriptionEngineSonioxConfig::TranscriptionEngine }

#transcription_modelSymbol, ...

The model to use for transcription.



46
47
# File 'lib/telnyx/models/calls/transcription_engine_soniox_config.rb', line 46

optional :transcription_model,
enum: -> { Telnyx::Calls::TranscriptionEngineSonioxConfig::TranscriptionModel }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/transcription_engine_soniox_config.rb', line 73