Class: Telnyx::Models::Calls::TranscriptionStartRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/transcription_start_request.rb,
sig/telnyx/models/calls/transcription_start_request.rbs

Direct Known Subclasses

ActionStartTranscriptionParams

Defined Under Namespace

Modules: TranscriptionEngine, TranscriptionEngineConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(client_state: nil, command_id: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_tracks: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::TranscriptionStartRequest for more details.

Parameters:



# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 42

Instance Attribute Details

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Parameters:

  • (String)

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 12

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same command_id for the same call_control_id.

Parameters:

  • (String)

Returns:

  • (String, nil)


19
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 19

optional :command_id, String

#transcription_engineSymbol, ...

Engine to use for speech recognition. Legacy values A - Google, B - Telnyx are supported for backward compatibility.



26
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 26

optional :transcription_engine, enum: -> { Telnyx::Calls::TranscriptionStartRequest::TranscriptionEngine }

#transcription_tracksString?

Indicates which leg of the call will be transcribed. Use inbound for the leg that requested the transcription, outbound for the other leg, and both for both legs of the call. Will default to inbound.

Parameters:

  • (String)

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 40

optional :transcription_tracks, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 75

Instance Method Details

#to_hash{

Returns:

  • ({)


46
# File 'sig/telnyx/models/calls/transcription_start_request.rbs', line 46

def to_hash: -> {