Class: Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::DeepgramNova3Config
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::DeepgramNova3Config
- Defined in:
- lib/telnyx/models/calls/transcription_start_request.rb
Defined Under Namespace
Modules: Language, TranscriptionModel
Instance Attribute Summary collapse
-
#keywords_boosting ⇒ Hash{Symbol=>Float}?
Keywords and their respective intensifiers (boosting values) to improve transcription accuracy for specific words or phrases.
-
#language ⇒ Symbol, ...
Language to use for speech recognition with nova-3 model.
- #transcription_engine ⇒ Symbol, :Deepgram
- #transcription_model ⇒ Symbol, Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::DeepgramNova3Config::TranscriptionModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(transcription_model:, keywords_boosting: nil, language: nil, transcription_engine: :Deepgram) ⇒ Object
constructor
Some parameter documentations has been truncated, see DeepgramNova3Config for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transcription_model:, keywords_boosting: nil, language: nil, transcription_engine: :Deepgram) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::DeepgramNova3Config for more details.
|
|
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 237
|
Instance Attribute Details
#keywords_boosting ⇒ Hash{Symbol=>Float}?
Keywords and their respective intensifiers (boosting values) to improve transcription accuracy for specific words or phrases. The intensifier should be a numeric value. Example: ‘5, “systrom”: 2, “krieger”: 1`.
228 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 228 optional :keywords_boosting, Telnyx::Internal::Type::HashOf[Float] |
#language ⇒ Symbol, ...
Language to use for speech recognition with nova-3 model
234 235 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 234 optional :language, enum: -> { Telnyx::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::DeepgramNova3Config::Language } |
#transcription_engine ⇒ Symbol, :Deepgram
214 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 214 required :transcription_engine, const: :Deepgram |
#transcription_model ⇒ Symbol, Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::DeepgramNova3Config::TranscriptionModel
219 220 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 219 required :transcription_model, enum: -> { Telnyx::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::DeepgramNova3Config::TranscriptionModel } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 256
|