Class: Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::Soniox

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/transcription_start_request.rb

Defined Under Namespace

Modules: TranscriptionModel

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enable_endpoint_detection: nil, interim_results: nil, language: nil, max_endpoint_delay_ms: nil, transcription_model: nil, transcription_engine: :Soniox) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::Soniox for more details.

Parameters:

  • enable_endpoint_detection (Boolean) (defaults to: nil)

    When true, Soniox emits end-of-utterance events at the cadence configured by ‘ma

  • interim_results (Boolean) (defaults to: nil)

    Whether to send also interim results. If set to false, only final results will b

  • language (String) (defaults to: nil)

    ISO 639-1 language hint (e.g. ‘en`, `es`), or `auto` to omit the hint and let So

  • max_endpoint_delay_ms (Integer) (defaults to: nil)

    Maximum silence (in milliseconds) before Soniox emits an end-of-utterance event.

  • transcription_model (Symbol, Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::Soniox::TranscriptionModel) (defaults to: nil)

    The model to use for transcription.

  • transcription_engine (Symbol, :Soniox) (defaults to: :Soniox)

    Engine identifier for Soniox transcription service



# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 244

Instance Attribute Details

#enable_endpoint_detectionBoolean?

When true, Soniox emits end-of-utterance events at the cadence configured by ‘max_endpoint_delay_ms`.

Returns:

  • (Boolean, nil)


214
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 214

optional :enable_endpoint_detection, Telnyx::Internal::Type::Boolean

#interim_resultsBoolean?

Whether to send also interim results. If set to false, only final results will be sent.

Returns:

  • (Boolean, nil)


221
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 221

optional :interim_results, Telnyx::Internal::Type::Boolean

#languageString?

ISO 639-1 language hint (e.g. ‘en`, `es`), or `auto` to omit the hint and let Soniox auto-detect supported languages multilingually.

Returns:

  • (String, nil)


228
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 228

optional :language, String

#max_endpoint_delay_msInteger?

Maximum silence (in milliseconds) before Soniox emits an end-of-utterance event. Only honored when ‘enable_endpoint_detection` is true. Range: 500-3000 ms.

Returns:

  • (Integer, nil)


235
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 235

optional :max_endpoint_delay_ms, Integer

#transcription_engineSymbol, :Soniox

Engine identifier for Soniox transcription service

Returns:

  • (Symbol, :Soniox)


207
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 207

required :transcription_engine, const: :Soniox

#transcription_modelSymbol, ...

The model to use for transcription.



241
242
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 241

optional :transcription_model,
enum: -> { Telnyx::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::Soniox::TranscriptionModel }