Class: Telnyx::Models::ChannelZoneUpdateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/channel_zone_update_response.rb

Overview

Defined Under Namespace

Modules: RecordType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, channels:, countries:, name:, record_type:, created_at: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ChannelZoneUpdateResponse for more details.

Parameters:

  • id (String)
  • channels (Integer)
  • countries (Array<String>)

    List of countries (in ISO 3166-2, capitalized) members of the billing channel zo

  • name (String)
  • record_type (Symbol, Telnyx::Models::ChannelZoneUpdateResponse::RecordType)
  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the channel zone was created

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the channel zone was updated



# File 'lib/telnyx/models/channel_zone_update_response.rb', line 46

Instance Attribute Details

#channelsInteger

Returns:

  • (Integer)


15
# File 'lib/telnyx/models/channel_zone_update_response.rb', line 15

required :channels, Integer

#countriesArray<String>

List of countries (in ISO 3166-2, capitalized) members of the billing channel zone

Returns:

  • (Array<String>)


22
# File 'lib/telnyx/models/channel_zone_update_response.rb', line 22

required :countries, Telnyx::Internal::Type::ArrayOf[String]

#created_atString?

ISO 8601 formatted date of when the channel zone was created

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/channel_zone_update_response.rb', line 38

optional :created_at, String

#idString

Returns:

  • (String)


10
# File 'lib/telnyx/models/channel_zone_update_response.rb', line 10

required :id, String

#nameString

Returns:

  • (String)


27
# File 'lib/telnyx/models/channel_zone_update_response.rb', line 27

required :name, String

#record_typeSymbol, Telnyx::Models::ChannelZoneUpdateResponse::RecordType



32
# File 'lib/telnyx/models/channel_zone_update_response.rb', line 32

required :record_type, enum: -> { Telnyx::Models::ChannelZoneUpdateResponse::RecordType }

#updated_atString?

ISO 8601 formatted date of when the channel zone was updated

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/channel_zone_update_response.rb', line 44

optional :updated_at, String