Class: Telnyx::Models::CheckAvailabilityToolParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/check_availability_tool_params.rb,
sig/telnyx/models/check_availability_tool_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_key_ref:, event_type_id:) ⇒ CheckAvailabilityToolParams

Some parameter documentations has been truncated, see Telnyx::Models::CheckAvailabilityToolParams for more details.

Parameters:

  • api_key_ref (String)

    Reference to an integration secret that contains your Cal.com API key. You would

  • event_type_id (Integer)

    Event Type ID for which slots are being fetched. [cal.com](https://cal.com/docs/

  • api_key_ref: (String)
  • event_type_id: (Integer)


# File 'lib/telnyx/models/check_availability_tool_params.rb', line 22

Instance Attribute Details

#api_key_refString

Reference to an integration secret that contains your Cal.com API key. You would pass the identifier for an integration secret /v2/integration_secrets that refers to your Cal.com API key.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/telnyx/models/check_availability_tool_params.rb', line 13

required :api_key_ref, String

#event_type_idInteger

Event Type ID for which slots are being fetched. cal.com

Parameters:

  • value (Integer)

Returns:

  • (Integer)


20
# File 'lib/telnyx/models/check_availability_tool_params.rb', line 20

required :event_type_id, Integer

Instance Method Details

#to_hash{ api_key_ref: String, event_type_id: Integer }

Returns:

  • ({ api_key_ref: String, event_type_id: Integer })


13
# File 'sig/telnyx/models/check_availability_tool_params.rbs', line 13

def to_hash: -> { api_key_ref: String, event_type_id: Integer }