Class: Telnyx::Models::CommentListParams::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CommentListParams::Filter
- Defined in:
- lib/telnyx/models/comment_list_params.rb,
sig/telnyx/models/comment_list_params.rbs
Defined Under Namespace
Modules: CommentRecordType
Instance Attribute Summary collapse
-
#comment_record_id ⇒ String?
ID of the record the comments relate to.
-
#comment_record_type ⇒ Symbol, ...
Record type that the comment relates to.
Instance Method Summary collapse
-
#initialize(comment_record_id: nil, comment_record_type: nil) ⇒ Object
constructor
Consolidated filter parameter (deepObject style).
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(comment_record_id: nil, comment_record_type: nil) ⇒ Object
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/telnyx/models/comment_list_params.rb', line 25 class Filter < Telnyx::Internal::Type::BaseModel # @!attribute comment_record_id # ID of the record the comments relate to # # @return [String, nil] optional :comment_record_id, String # @!attribute comment_record_type # Record type that the comment relates to # # @return [Symbol, Telnyx::Models::CommentListParams::Filter::CommentRecordType, nil] optional :comment_record_type, enum: -> { Telnyx::CommentListParams::Filter::CommentRecordType } # @!method initialize(comment_record_id: nil, comment_record_type: nil) # Consolidated filter parameter (deepObject style). Originally: # filter[comment_record_type], filter[comment_record_id] # # @param comment_record_id [String] ID of the record the comments relate to # # @param comment_record_type [Symbol, Telnyx::Models::CommentListParams::Filter::CommentRecordType] Record type that the comment relates to # Record type that the comment relates to # # @see Telnyx::Models::CommentListParams::Filter#comment_record_type module CommentRecordType extend Telnyx::Internal::Type::Enum SUB_NUMBER_ORDER = :sub_number_order REQUIREMENT_GROUP = :requirement_group # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#comment_record_id ⇒ String?
ID of the record the comments relate to
30 |
# File 'lib/telnyx/models/comment_list_params.rb', line 30 optional :comment_record_id, String |
#comment_record_type ⇒ Symbol, ...
Record type that the comment relates to
36 |
# File 'lib/telnyx/models/comment_list_params.rb', line 36 optional :comment_record_type, enum: -> { Telnyx::CommentListParams::Filter::CommentRecordType } |
Instance Method Details
#to_hash ⇒ {
49 |
# File 'sig/telnyx/models/comment_list_params.rbs', line 49
def to_hash: -> {
|