Class: Telnyx::Models::Conference

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/conference.rb

Overview

Defined Under Namespace

Modules: EndReason, RecordType, Status Classes: EndedBy

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id: nil, call_session_id: nil) ⇒ Object

IDs related to who ended the conference. It is expected for them to all be there or all be null

Parameters:

  • call_control_id (String) (defaults to: nil)

    Call Control ID which ended the conference

  • call_session_id (String) (defaults to: nil)

    Call Session ID which ended the conference



# File 'lib/telnyx/models/conference.rb', line 73

Instance Attribute Details

#connection_idString?

Identifies the connection associated with the conference

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/conference.rb', line 40

optional :connection_id, String

#created_atString

ISO 8601 formatted date of when the conference was created

Returns:

  • (String)


17
# File 'lib/telnyx/models/conference.rb', line 17

required :created_at, String

#end_reasonSymbol, ...

Reason why the conference ended

Returns:



46
# File 'lib/telnyx/models/conference.rb', line 46

optional :end_reason, enum: -> { Telnyx::Conference::EndReason }

#ended_byTelnyx::Models::Conference::EndedBy?

IDs related to who ended the conference. It is expected for them to all be there or all be null



53
# File 'lib/telnyx/models/conference.rb', line 53

optional :ended_by, -> { Telnyx::Conference::EndedBy }

#expires_atString

ISO 8601 formatted date of when the conference will expire

Returns:

  • (String)


23
# File 'lib/telnyx/models/conference.rb', line 23

required :expires_at, String

#idString

Uniquely identifies the conference

Returns:

  • (String)


11
# File 'lib/telnyx/models/conference.rb', line 11

required :id, String

#nameString

Name of the conference

Returns:

  • (String)


29
# File 'lib/telnyx/models/conference.rb', line 29

required :name, String

#record_typeSymbol, Telnyx::Models::Conference::RecordType



34
# File 'lib/telnyx/models/conference.rb', line 34

required :record_type, enum: -> { Telnyx::Conference::RecordType }

#regionString?

Region where the conference is hosted

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/conference.rb', line 59

optional :region, String

#statusSymbol, ...

Status of the conference

Returns:



65
# File 'lib/telnyx/models/conference.rb', line 65

optional :status, enum: -> { Telnyx::Conference::Status }

#updated_atString?

ISO 8601 formatted date of when the conference was last updated

Returns:

  • (String, nil)


71
# File 'lib/telnyx/models/conference.rb', line 71

optional :updated_at, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/conference.rb', line 105