Class: Telnyx::Models::ConferenceCreatedWebhookEvent::Data::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/conference_created_webhook_event.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#call_control_idString?

Call ID used to issue commands via Call Control API.

Returns:

  • (String, nil)


66
# File 'lib/telnyx/models/conference_created_webhook_event.rb', line 66

optional :call_control_id, String

#call_leg_idString?

ID that is unique to the call and can be used to correlate webhook events.

Returns:

  • (String, nil)


72
# File 'lib/telnyx/models/conference_created_webhook_event.rb', line 72

optional :call_leg_id, String

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


80
# File 'lib/telnyx/models/conference_created_webhook_event.rb', line 80

optional :call_session_id, String

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


86
# File 'lib/telnyx/models/conference_created_webhook_event.rb', line 86

optional :client_state, String

#conference_idString?

Conference ID that the participant joined.

Returns:

  • (String, nil)


92
# File 'lib/telnyx/models/conference_created_webhook_event.rb', line 92

optional :conference_id, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


98
# File 'lib/telnyx/models/conference_created_webhook_event.rb', line 98

optional :connection_id, String

#occurred_atTime?

ISO 8601 datetime of when the event occurred.

Returns:

  • (Time, nil)


104
# File 'lib/telnyx/models/conference_created_webhook_event.rb', line 104

optional :occurred_at, Time