Class: Telnyx::Models::ConferenceListParticipantsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/conference_list_participants_params.rb

Overview

Defined Under Namespace

Modules: Region Classes: Filter

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(muted: nil, on_hold: nil, whispering: nil) ⇒ Object

Some parameter documentations has been truncated, see Filter for more details.

Consolidated filter parameter (deepObject style). Originally: filter, filter, filter

Parameters:

  • muted (Boolean) (defaults to: nil)

    If present, participants will be filtered to those who are/are not muted

  • on_hold (Boolean) (defaults to: nil)

    If present, participants will be filtered to those who are/are not put on hold

  • whispering (Boolean) (defaults to: nil)

    If present, participants will be filtered to those who are whispering or are not



# File 'lib/telnyx/models/conference_list_participants_params.rb', line 73

Instance Attribute Details

#conference_idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/conference_list_participants_params.rb', line 13

required :conference_id, String

#filterTelnyx::Models::ConferenceListParticipantsParams::Filter?

Consolidated filter parameter (deepObject style). Originally: filter, filter, filter



20
# File 'lib/telnyx/models/conference_list_participants_params.rb', line 20

optional :filter, -> { Telnyx::ConferenceListParticipantsParams::Filter }

#page_numberInteger?

Returns:

  • (Integer, nil)


25
# File 'lib/telnyx/models/conference_list_participants_params.rb', line 25

optional :page_number, Integer

#page_sizeInteger?

Returns:

  • (Integer, nil)


30
# File 'lib/telnyx/models/conference_list_participants_params.rb', line 30

optional :page_size, Integer

#regionSymbol, ...

Region where the conference data is located



36
# File 'lib/telnyx/models/conference_list_participants_params.rb', line 36

optional :region, enum: -> { Telnyx::ConferenceListParticipantsParams::Region }