Class: Telnyx::Models::ConferenceListParticipantsParams::Filter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/conference_list_participants_params.rb,
sig/telnyx/models/conference_list_participants_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(conference_id:, filter: nil, page_number: nil, page_size: nil, region: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ConferenceListParticipantsParams for more details.

Parameters:



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/telnyx/models/conference_list_participants_params.rb', line 54

class Filter < Telnyx::Internal::Type::BaseModel
  # @!attribute muted
  #   If present, participants will be filtered to those who are/are not muted
  #
  #   @return [Boolean, nil]
  optional :muted, Telnyx::Internal::Type::Boolean

  # @!attribute on_hold
  #   If present, participants will be filtered to those who are/are not put on hold
  #
  #   @return [Boolean, nil]
  optional :on_hold, Telnyx::Internal::Type::Boolean

  # @!attribute whispering
  #   If present, participants will be filtered to those who are whispering or are not
  #
  #   @return [Boolean, nil]
  optional :whispering, Telnyx::Internal::Type::Boolean

  # @!method initialize(muted: nil, on_hold: nil, whispering: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::ConferenceListParticipantsParams::Filter} for more details.
  #
  #   Consolidated filter parameter (deepObject style). Originally: filter[muted],
  #   filter[on_hold], filter[whispering]
  #
  #   @param muted [Boolean] If present, participants will be filtered to those who are/are not muted
  #
  #   @param on_hold [Boolean] If present, participants will be filtered to those who are/are not put on hold
  #
  #   @param whispering [Boolean] If present, participants will be filtered to those who are whispering or are not
end

Instance Attribute Details

#mutedBoolean?

If present, participants will be filtered to those who are/are not muted

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


59
# File 'lib/telnyx/models/conference_list_participants_params.rb', line 59

optional :muted, Telnyx::Internal::Type::Boolean

#on_holdBoolean?

If present, participants will be filtered to those who are/are not put on hold

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


65
# File 'lib/telnyx/models/conference_list_participants_params.rb', line 65

optional :on_hold, Telnyx::Internal::Type::Boolean

#whisperingBoolean?

If present, participants will be filtered to those who are whispering or are not

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


71
# File 'lib/telnyx/models/conference_list_participants_params.rb', line 71

optional :whispering, Telnyx::Internal::Type::Boolean

Instance Method Details

#to_hash{ muted: bool, on_hold: bool, whispering: bool }

Returns:

  • ({ muted: bool, on_hold: bool, whispering: bool })


78
# File 'sig/telnyx/models/conference_list_participants_params.rbs', line 78

def to_hash: -> { muted: bool, on_hold: bool, whispering: bool }