Class: Telnyx::Models::ConferenceListParticipantsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/conference_list_participants_response.rb

Overview

Defined Under Namespace

Modules: RecordType, Status Classes: Conference

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, name: nil) ⇒ Object

Info about the conference that the participant is in

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the conference

  • name (String) (defaults to: nil)

    Name of the conference



# File 'lib/telnyx/models/conference_list_participants_response.rb', line 86

Instance Attribute Details

#call_control_idString

Call Control ID associated with the partiipant of the conference

Returns:

  • (String)


17
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 17

required :call_control_id, String

#call_leg_idString

Uniquely identifies the call leg associated with the participant

Returns:

  • (String)


23
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 23

required :call_leg_id, String

#conferenceTelnyx::Models::ConferenceListParticipantsResponse::Conference

Info about the conference that the participant is in



29
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 29

required :conference, -> { Telnyx::Models::ConferenceListParticipantsResponse::Conference }

#created_atString

ISO 8601 formatted date of when the participant was created

Returns:

  • (String)


35
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 35

required :created_at, String

#end_conference_on_exitBoolean

Whether the conference will end and all remaining participants be hung up after the participant leaves the conference.

Returns:

  • (Boolean)


42
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 42

required :end_conference_on_exit, Telnyx::Internal::Type::Boolean

#idString

Uniquely identifies the participant

Returns:

  • (String)


11
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 11

required :id, String

#mutedBoolean

Whether the participant is muted.

Returns:

  • (Boolean)


48
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 48

required :muted, Telnyx::Internal::Type::Boolean

#on_holdBoolean

Whether the participant is put on_hold.

Returns:

  • (Boolean)


54
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 54

required :on_hold, Telnyx::Internal::Type::Boolean

#record_typeSymbol, Telnyx::Models::ConferenceListParticipantsResponse::RecordType



59
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 59

required :record_type, enum: -> { Telnyx::Models::ConferenceListParticipantsResponse::RecordType }

#soft_end_conference_on_exitBoolean

Whether the conference will end after the participant leaves the conference.

Returns:

  • (Boolean)


65
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 65

required :soft_end_conference_on_exit, Telnyx::Internal::Type::Boolean

#statusSymbol, Telnyx::Models::ConferenceListParticipantsResponse::Status

The status of the participant with respect to the lifecycle within the conference



72
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 72

required :status, enum: -> { Telnyx::Models::ConferenceListParticipantsResponse::Status }

#updated_atString

ISO 8601 formatted date of when the participant was last updated

Returns:

  • (String)


78
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 78

required :updated_at, String

#whisper_call_control_idsArray<String>

Array of unique call_control_ids the participant can whisper to..

Returns:

  • (Array<String>)


84
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 84

required :whisper_call_control_ids, Telnyx::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/conference_list_participants_response.rb', line 144