Class: Telnyx::Models::ConferenceParticipantLeft
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ConferenceParticipantLeft
- Defined in:
- lib/telnyx/models/conference_participant_left.rb
Defined Under Namespace
Modules: EventType, RecordType Classes: Payload
Instance Attribute Summary collapse
-
#event_type ⇒ Symbol, ...
The type of event being delivered.
-
#id ⇒ String?
Identifies the type of resource.
-
#occurred_at ⇒ Time?
ISO 8601 datetime of when the event occurred.
- #payload ⇒ Telnyx::Models::ConferenceParticipantLeft::Payload?
-
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, conference_id: nil, connection_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, conference_id: nil, connection_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Payload for more details.
|
|
# File 'lib/telnyx/models/conference_participant_left.rb', line 35
|
Instance Attribute Details
#event_type ⇒ Symbol, ...
The type of event being delivered.
16 |
# File 'lib/telnyx/models/conference_participant_left.rb', line 16 optional :event_type, enum: -> { Telnyx::ConferenceParticipantLeft::EventType } |
#id ⇒ String?
Identifies the type of resource.
10 |
# File 'lib/telnyx/models/conference_participant_left.rb', line 10 optional :id, String |
#occurred_at ⇒ Time?
ISO 8601 datetime of when the event occurred.
22 |
# File 'lib/telnyx/models/conference_participant_left.rb', line 22 optional :occurred_at, Time |
#payload ⇒ Telnyx::Models::ConferenceParticipantLeft::Payload?
27 |
# File 'lib/telnyx/models/conference_participant_left.rb', line 27 optional :payload, -> { Telnyx::ConferenceParticipantLeft::Payload } |
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
33 |
# File 'lib/telnyx/models/conference_participant_left.rb', line 33 optional :record_type, enum: -> { Telnyx::ConferenceParticipantLeft::RecordType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/conference_participant_left.rb', line 54
|