Class: Telnyx::Models::ConferenceParticipantPlaybackEndedWebhookEvent::Data::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#call_control_idString?

Participant’s call ID used to issue commands via Call Control API.

Returns:

  • (String, nil)


67
# File 'lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb', line 67

optional :call_control_id, String

#call_leg_idString?

ID that is unique to the call and can be used to correlate webhook events.

Returns:

  • (String, nil)


73
# File 'lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb', line 73

optional :call_leg_id, String

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


81
# File 'lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb', line 81

optional :call_session_id, String

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


87
# File 'lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb', line 87

optional :client_state, String

#conference_idString?

ID of the conference the text was spoken in.

Returns:

  • (String, nil)


93
# File 'lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb', line 93

optional :conference_id, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


99
# File 'lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb', line 99

optional :connection_id, String

#creator_call_session_idString?

ID that is unique to the call session that started the conference.

Returns:

  • (String, nil)


105
# File 'lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb', line 105

optional :creator_call_session_id, String

#media_nameString?

The name of the audio media file being played back, if media_name has been used to start.

Returns:

  • (String, nil)


112
# File 'lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb', line 112

optional :media_name, String

#media_urlString?

The audio URL being played back, if audio_url has been used to start.

Returns:

  • (String, nil)


118
# File 'lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb', line 118

optional :media_url, String

#occurred_atTime?

ISO 8601 datetime of when the event occurred.

Returns:

  • (Time, nil)


124
# File 'lib/telnyx/models/conference_participant_playback_ended_webhook_event.rb', line 124

optional :occurred_at, Time