Class: Telnyx::Models::ConferenceParticipantPlaybackStarted::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ConferenceParticipantPlaybackStarted::Payload
- Defined in:
- lib/telnyx/models/conference_participant_playback_started.rb
Overview
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Participant’s call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#conference_id ⇒ String?
ID of the conference the text was spoken in.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#creator_call_session_id ⇒ String?
ID that is unique to the call session that started the conference.
-
#media_name ⇒ String?
The name of the audio media file being played back, if media_name has been used to start.
-
#media_url ⇒ String?
The audio URL being played back, if audio_url has been used to start.
-
#occurred_at ⇒ Time?
ISO 8601 datetime of when the event occurred.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#call_control_id ⇒ String?
Participant’s call ID used to issue commands via Call Control API.
56 |
# File 'lib/telnyx/models/conference_participant_playback_started.rb', line 56 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
62 |
# File 'lib/telnyx/models/conference_participant_playback_started.rb', line 62 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
70 |
# File 'lib/telnyx/models/conference_participant_playback_started.rb', line 70 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command.
76 |
# File 'lib/telnyx/models/conference_participant_playback_started.rb', line 76 optional :client_state, String |
#conference_id ⇒ String?
ID of the conference the text was spoken in.
82 |
# File 'lib/telnyx/models/conference_participant_playback_started.rb', line 82 optional :conference_id, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
88 |
# File 'lib/telnyx/models/conference_participant_playback_started.rb', line 88 optional :connection_id, String |
#creator_call_session_id ⇒ String?
ID that is unique to the call session that started the conference.
94 |
# File 'lib/telnyx/models/conference_participant_playback_started.rb', line 94 optional :creator_call_session_id, String |
#media_name ⇒ String?
The name of the audio media file being played back, if media_name has been used to start.
101 |
# File 'lib/telnyx/models/conference_participant_playback_started.rb', line 101 optional :media_name, String |
#media_url ⇒ String?
The audio URL being played back, if audio_url has been used to start.
107 |
# File 'lib/telnyx/models/conference_participant_playback_started.rb', line 107 optional :media_url, String |
#occurred_at ⇒ Time?
ISO 8601 datetime of when the event occurred.
113 |
# File 'lib/telnyx/models/conference_participant_playback_started.rb', line 113 optional :occurred_at, Time |