Class: Telnyx::Models::ConferenceRecordingSaved::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/conference_recording_saved.rb

Overview

See Also:

Defined Under Namespace

Modules: Channels, Format Classes: PublicRecordingURLs, RecordingURLs

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mp3: nil, wav: nil) ⇒ Object

Recording URLs in requested format. The URL is valid for as long as the file exists. For security purposes, this feature is activated on a per request basis. Please contact customer support with your Account ID to request activation.

Parameters:

  • mp3 (String, nil) (defaults to: nil)

    Recording URL in requested ‘mp3` format.

  • wav (String, nil) (defaults to: nil)

    Recording URL in requested ‘wav` format.



# File 'lib/telnyx/models/conference_recording_saved.rb', line 135

Instance Attribute Details

#call_control_idString?

Participant’s call ID used to issue commands via Call Control API.

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/conference_recording_saved.rb', line 56

optional :call_control_id, String

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/conference_recording_saved.rb', line 64

optional :call_session_id, String

#channelsSymbol, ...

Whether recording was recorded in ‘single` or `dual` channel.



70
# File 'lib/telnyx/models/conference_recording_saved.rb', line 70

optional :channels, enum: -> { Telnyx::ConferenceRecordingSaved::Payload::Channels }

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


76
# File 'lib/telnyx/models/conference_recording_saved.rb', line 76

optional :client_state, String

#conference_idString?

ID of the conference that is being recorded.

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/conference_recording_saved.rb', line 82

optional :conference_id, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/conference_recording_saved.rb', line 88

optional :connection_id, String

#file_formatSymbol, ...

The audio file format used when storing the call recording. Can be either ‘mp3` or `wav`.



95
96
97
98
99
# File 'lib/telnyx/models/conference_recording_saved.rb', line 95

optional :file_format,
enum: -> {
  Telnyx::ConferenceRecordingSaved::Payload::Format
},
api_name: :format

#public_recording_urlsTelnyx::Models::ConferenceRecordingSaved::Payload::PublicRecordingURLs?

Recording URLs in requested format. The URL is valid for as long as the file exists. For security purposes, this feature is activated on a per request basis. Please contact customer support with your Account ID to request activation.



107
# File 'lib/telnyx/models/conference_recording_saved.rb', line 107

optional :public_recording_urls, -> { Telnyx::ConferenceRecordingSaved::Payload::PublicRecordingURLs }

#recording_ended_atTime?

ISO 8601 datetime of when recording ended.

Returns:

  • (Time, nil)


113
# File 'lib/telnyx/models/conference_recording_saved.rb', line 113

optional :recording_ended_at, Time

#recording_idString?

ID of the conference recording.

Returns:

  • (String, nil)


119
# File 'lib/telnyx/models/conference_recording_saved.rb', line 119

optional :recording_id, String

#recording_started_atTime?

ISO 8601 datetime of when recording started.

Returns:

  • (Time, nil)


125
# File 'lib/telnyx/models/conference_recording_saved.rb', line 125

optional :recording_started_at, Time

#recording_urlsTelnyx::Models::ConferenceRecordingSaved::Payload::RecordingURLs?

Recording URLs in requested format. These URLs are valid for 10 minutes. After 10 minutes, you may retrieve recordings via API using Reports -> Call Recordings documentation, or via Mission Control under Reporting -> Recordings.



133
# File 'lib/telnyx/models/conference_recording_saved.rb', line 133

optional :recording_urls, -> { Telnyx::ConferenceRecordingSaved::Payload::RecordingURLs }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/conference_recording_saved.rb', line 172