Class: Telnyx::Models::ConferenceRecordingSavedWebhookEvent::Data::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ConferenceRecordingSavedWebhookEvent::Data::Payload
- Defined in:
- lib/telnyx/models/conference_recording_saved_webhook_event.rb
Overview
Defined Under Namespace
Modules: Channels, Format Classes: PublicRecordingURLs, RecordingURLs
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Participant’s call ID used to issue commands via Call Control API.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#channels ⇒ Symbol, ...
Whether recording was recorded in ‘single` or `dual` channel.
-
#client_state ⇒ String?
State received from a command.
-
#conference_id ⇒ String?
ID of the conference that is being recorded.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#file_format ⇒ Symbol, ...
The audio file format used when storing the call recording.
-
#public_recording_urls ⇒ Telnyx::Models::ConferenceRecordingSavedWebhookEvent::Data::Payload::PublicRecordingURLs?
Recording URLs in requested format.
-
#recording_ended_at ⇒ Time?
ISO 8601 datetime of when recording ended.
-
#recording_id ⇒ String?
ID of the conference recording.
-
#recording_started_at ⇒ Time?
ISO 8601 datetime of when recording started.
-
#recording_urls ⇒ Telnyx::Models::ConferenceRecordingSavedWebhookEvent::Data::Payload::RecordingURLs?
Recording URLs in requested format.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(mp3: nil, wav: nil) ⇒ Object
constructor
Recording URLs in requested format.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mp3: nil, wav: nil) ⇒ Object
Recording URLs in requested format. The URL is valid for as long as the file exists. For security purposes, this feature is activated on a per request basis. Please contact customer support with your Account ID to request activation.
|
|
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 145
|
Instance Attribute Details
#call_control_id ⇒ String?
Participant’s call ID used to issue commands via Call Control API.
66 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 66 optional :call_control_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
74 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 74 optional :call_session_id, String |
#channels ⇒ Symbol, ...
Whether recording was recorded in ‘single` or `dual` channel.
80 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 80 optional :channels, enum: -> { Telnyx::ConferenceRecordingSavedWebhookEvent::Data::Payload::Channels } |
#client_state ⇒ String?
State received from a command.
86 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 86 optional :client_state, String |
#conference_id ⇒ String?
ID of the conference that is being recorded.
92 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 92 optional :conference_id, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
98 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 98 optional :connection_id, String |
#file_format ⇒ Symbol, ...
The audio file format used when storing the call recording. Can be either ‘mp3` or `wav`.
105 106 107 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 105 optional :file_format, enum: -> { Telnyx::ConferenceRecordingSavedWebhookEvent::Data::Payload::Format }, api_name: :format |
#public_recording_urls ⇒ Telnyx::Models::ConferenceRecordingSavedWebhookEvent::Data::Payload::PublicRecordingURLs?
Recording URLs in requested format. The URL is valid for as long as the file exists. For security purposes, this feature is activated on a per request basis. Please contact customer support with your Account ID to request activation.
115 116 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 115 optional :public_recording_urls, -> { Telnyx::ConferenceRecordingSavedWebhookEvent::Data::Payload::PublicRecordingURLs } |
#recording_ended_at ⇒ Time?
ISO 8601 datetime of when recording ended.
122 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 122 optional :recording_ended_at, Time |
#recording_id ⇒ String?
ID of the conference recording.
128 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 128 optional :recording_id, String |
#recording_started_at ⇒ Time?
ISO 8601 datetime of when recording started.
134 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 134 optional :recording_started_at, Time |
#recording_urls ⇒ Telnyx::Models::ConferenceRecordingSavedWebhookEvent::Data::Payload::RecordingURLs?
Recording URLs in requested format. These URLs are valid for 10 minutes. After 10 minutes, you may retrieve recordings via API using Reports -> Call Recordings documentation, or via Mission Control under Reporting -> Recordings.
142 143 |
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 142 optional :recording_urls, -> { Telnyx::ConferenceRecordingSavedWebhookEvent::Data::Payload::RecordingURLs } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/conference_recording_saved_webhook_event.rb', line 183
|