Class: Telnyx::Models::ConferenceSpeakEndedWebhookEvent::Data::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/conference_speak_ended_webhook_event.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#conference_idString?

ID of the conference the text was spoken in.

Returns:

  • (String, nil)


66
# File 'lib/telnyx/models/conference_speak_ended_webhook_event.rb', line 66

optional :conference_id, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


72
# File 'lib/telnyx/models/conference_speak_ended_webhook_event.rb', line 72

optional :connection_id, String

#creator_call_session_idString?

ID that is unique to the call session that started the conference.

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/conference_speak_ended_webhook_event.rb', line 78

optional :creator_call_session_id, String

#occurred_atTime?

ISO 8601 datetime of when the event occurred.

Returns:

  • (Time, nil)


84
# File 'lib/telnyx/models/conference_speak_ended_webhook_event.rb', line 84

optional :occurred_at, Time