Class: Telnyx::Models::ConferenceSpeakStarted::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ConferenceSpeakStarted::Payload
- Defined in:
- lib/telnyx/models/conference_speak_started.rb
Overview
Instance Attribute Summary collapse
-
#conference_id ⇒ String?
ID of the conference the text was spoken in.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#creator_call_session_id ⇒ String?
ID that is unique to the call session that started the conference.
-
#occurred_at ⇒ Time?
ISO 8601 datetime of when the event occurred.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#conference_id ⇒ String?
ID of the conference the text was spoken in.
56 |
# File 'lib/telnyx/models/conference_speak_started.rb', line 56 optional :conference_id, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
62 |
# File 'lib/telnyx/models/conference_speak_started.rb', line 62 optional :connection_id, String |
#creator_call_session_id ⇒ String?
ID that is unique to the call session that started the conference.
68 |
# File 'lib/telnyx/models/conference_speak_started.rb', line 68 optional :creator_call_session_id, String |
#occurred_at ⇒ Time?
ISO 8601 datetime of when the event occurred.
74 |
# File 'lib/telnyx/models/conference_speak_started.rb', line 74 optional :occurred_at, Time |