Class: Telnyx::Models::ConferenceUpdateParticipantParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/conference_update_participant_params.rb

Overview

Defined Under Namespace

Modules: BeepEnabled

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, participant_id:, beep_enabled: nil, end_conference_on_exit: nil, soft_end_conference_on_exit: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ConferenceUpdateParticipantParams for more details.

Parameters:

  • id (String)
  • participant_id (String)
  • beep_enabled (Symbol, Telnyx::Models::ConferenceUpdateParticipantParams::BeepEnabled) (defaults to: nil)

    Whether entry/exit beeps are enabled for this participant.

  • end_conference_on_exit (Boolean) (defaults to: nil)

    Whether the conference should end when this participant exits.

  • soft_end_conference_on_exit (Boolean) (defaults to: nil)

    Whether the conference should soft-end when this participant exits. A soft end w

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/conference_update_participant_params.rb', line 40

Instance Attribute Details

#beep_enabledSymbol, ...

Whether entry/exit beeps are enabled for this participant.



24
# File 'lib/telnyx/models/conference_update_participant_params.rb', line 24

optional :beep_enabled, enum: -> { Telnyx::ConferenceUpdateParticipantParams::BeepEnabled }

#end_conference_on_exitBoolean?

Whether the conference should end when this participant exits.

Returns:

  • (Boolean, nil)


30
# File 'lib/telnyx/models/conference_update_participant_params.rb', line 30

optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean

#idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/conference_update_participant_params.rb', line 13

required :id, String

#participant_idString

Returns:

  • (String)


18
# File 'lib/telnyx/models/conference_update_participant_params.rb', line 18

required :participant_id, String

#soft_end_conference_on_exitBoolean?

Whether the conference should soft-end when this participant exits. A soft end will stop new participants from joining but allow existing participants to remain.

Returns:

  • (Boolean, nil)


38
# File 'lib/telnyx/models/conference_update_participant_params.rb', line 38

optional :soft_end_conference_on_exit, Telnyx::Internal::Type::Boolean