Class: Telnyx::Models::Conferences::ActionLeaveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/conferences/action_leave_params.rb

Overview

Defined Under Namespace

Modules: BeepEnabled, Region

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, call_control_id:, beep_enabled: nil, command_id: nil, region: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionLeaveParams for more details.

Parameters:



# File 'lib/telnyx/models/conferences/action_leave_params.rb', line 44

Instance Attribute Details

#beep_enabledSymbol, ...

Whether a beep sound should be played when the participant leaves the conference. Can be used to override the conference-level setting.



27
# File 'lib/telnyx/models/conferences/action_leave_params.rb', line 27

optional :beep_enabled, enum: -> { Telnyx::Conferences::ActionLeaveParams::BeepEnabled }

#call_control_idString

Unique identifier and token for controlling the call

Returns:

  • (String)


20
# File 'lib/telnyx/models/conferences/action_leave_params.rb', line 20

required :call_control_id, String

#command_idString?

Use this field to avoid execution of duplicate commands. Telnyx will ignore subsequent commands with the same ‘command_id` as one that has already been executed.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/conferences/action_leave_params.rb', line 35

optional :command_id, String

#idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/conferences/action_leave_params.rb', line 14

required :id, String

#regionSymbol, ...

Region where the conference data is located. Defaults to the region defined in user’s data locality settings (Europe or US).



42
# File 'lib/telnyx/models/conferences/action_leave_params.rb', line 42

optional :region, enum: -> { Telnyx::Conferences::ActionLeaveParams::Region }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/conferences/action_leave_params.rb', line 70