Class: Telnyx::Models::Conferences::ActionPlayParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/conferences/action_play_params.rb

Overview

Defined Under Namespace

Modules: Region

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, audio_url: nil, call_control_ids: nil, loop_: nil, media_name: nil, region: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionPlayParams for more details.

Parameters:

  • id (String)
  • audio_url (String) (defaults to: nil)

    The URL of a file to be played back in the conference. media_name and audio_url

  • call_control_ids (Array<String>) (defaults to: nil)

    List of call control ids identifying participants the audio file should be playe

  • loop_ (String, Integer) (defaults to: nil)

    The number of times the audio file should be played. If supplied, the value must

  • media_name (String) (defaults to: nil)

    The media_name of a file to be played back in the conference. The media_name mus

  • region (Symbol, Telnyx::Models::Conferences::ActionPlayParams::Region) (defaults to: nil)

    Region where the conference data is located. Defaults to the region defined in u

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/conferences/action_play_params.rb', line 53

Instance Attribute Details

#audio_urlString?

The URL of a file to be played back in the conference. media_name and audio_url cannot be used together in one request.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 21

optional :audio_url, String

#call_control_idsArray<String>?

List of call control ids identifying participants the audio file should be played to. If not given, the audio file will be played to the entire conference.

Returns:

  • (Array<String>, nil)


28
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 28

optional :call_control_ids, Telnyx::Internal::Type::ArrayOf[String]

#idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 14

required :id, String

#loop_String, ...

The number of times the audio file should be played. If supplied, the value must be an integer between 1 and 100, or the special string ‘infinity` for an endless loop.

Returns:

  • (String, Integer, nil)


36
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 36

optional :loop_, union: -> { Telnyx::Calls::Loopcount }, api_name: :loop

#media_nameString?

The media_name of a file to be played back in the conference. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 44

optional :media_name, String

#regionSymbol, ...

Region where the conference data is located. Defaults to the region defined in user’s data locality settings (Europe or US).



51
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 51

optional :region, enum: -> { Telnyx::Conferences::ActionPlayParams::Region }