Class: Telnyx::Models::Conferences::ActionRecordStartParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/conferences/action_record_start_params.rb,
sig/telnyx/models/conferences/action_record_start_params.rbs

Overview

See Also:

  • Telnyx::Resources::Conferences::Actions#record_start

Defined Under Namespace

Modules: Channels, Format, Trim

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, format_:, channels: nil, command_id: nil, custom_file_name: nil, play_beep: nil, region: nil, trim: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionRecordStartParams for more details.

Parameters:



# File 'lib/telnyx/models/conferences/action_record_start_params.rb', line 68

Instance Attribute Details

#channelsSymbol, ...

When dual, final audio file will be stereo recorded with the conference creator on the first channel, and the rest on the second channel.



32
# File 'lib/telnyx/models/conferences/action_record_start_params.rb', line 32

optional :channels, enum: -> { Telnyx::Conferences::ActionRecordStartParams::Channels }

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same command_id for the same conference_id.

Parameters:

  • (String)

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/conferences/action_record_start_params.rb', line 39

optional :command_id, String

#custom_file_nameString?

The custom recording file name to be used instead of the default call_leg_id. Telnyx will still add a Unix timestamp suffix.

Parameters:

  • (String)

Returns:

  • (String, nil)


46
# File 'lib/telnyx/models/conferences/action_record_start_params.rb', line 46

optional :custom_file_name, String

#format_Symbol, Telnyx::Models::Conferences::ActionRecordStartParams::Format

The audio file format used when storing the conference recording. Can be either mp3 or wav.

Parameters:

  • value (Telnyx::Models::Conferences::ActionRecordStartParams::format_)

Returns:



21
22
23
24
25
# File 'lib/telnyx/models/conferences/action_record_start_params.rb', line 21

required :format_,
enum: -> {
  Telnyx::Conferences::ActionRecordStartParams::Format
},
api_name: :format

#idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/telnyx/models/conferences/action_record_start_params.rb', line 14

required :id, String

#play_beepBoolean?

If enabled, a beep sound will be played at the start of a recording.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


52
# File 'lib/telnyx/models/conferences/action_record_start_params.rb', line 52

optional :play_beep, Telnyx::Internal::Type::Boolean

#regionSymbol, ...

Region where the conference data is located. Defaults to the region defined in user's data locality settings (Europe or US).



59
# File 'lib/telnyx/models/conferences/action_record_start_params.rb', line 59

optional :region, enum: -> { Telnyx::Conferences::ConferenceRegion }

#trimSymbol, ...

When set to trim-silence, silence will be removed from the beginning and end of the recording.



66
# File 'lib/telnyx/models/conferences/action_record_start_params.rb', line 66

optional :trim, enum: -> { Telnyx::Conferences::ActionRecordStartParams::Trim }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/conferences/action_record_start_params.rb', line 98

Instance Method Details

#to_hash{

Returns:

  • ({)


67
# File 'sig/telnyx/models/conferences/action_record_start_params.rbs', line 67

def to_hash: -> {