Module: Telnyx::Models::Conferences::ActionRecordStartParams::Channels

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/conferences/action_record_start_params.rb,
sig/telnyx/models/conferences/action_record_start_params.rbs

Overview

When dual, final audio file will be stereo recorded with the conference creator on the first channel, and the rest on the second channel.

Constant Summary collapse

SINGLE =

Returns:

  • (:single)
:single
DUAL =

Returns:

  • (:dual)
:dual

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Telnyx::Models::Conferences::ActionRecordStartParams::channels]

Returns:

  • (::Array[Telnyx::Models::Conferences::ActionRecordStartParams::channels])


98
# File 'sig/telnyx/models/conferences/action_record_start_params.rbs', line 98

def self?.values: -> ::Array[Telnyx::Models::Conferences::ActionRecordStartParams::channels]