Class: Telnyx::Models::Conferences::ActionSendDtmfParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/conferences/action_send_dtmf_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, digits:, call_control_ids: nil, client_state: nil, duration_millis: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionSendDtmfParams for more details.

pau

Parameters:

  • id (String)
  • digits (String)

    DTMF digits to send. Valid characters: 0-9, A-D, *, #, w (0.5s pause), W (1s

  • call_control_ids (Array<String>) (defaults to: nil)

    Array of participant call control IDs to send DTMF to. When empty, DTMF will be

  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. Must be a valid Base-64

  • duration_millis (Integer) (defaults to: nil)

    Duration of each DTMF digit in milliseconds.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/conferences/action_send_dtmf_params.rb', line 43

Instance Attribute Details

#call_control_idsArray<String>?

Array of participant call control IDs to send DTMF to. When empty, DTMF will be sent to all participants.

Returns:

  • (Array<String>, nil)


28
# File 'lib/telnyx/models/conferences/action_send_dtmf_params.rb', line 28

optional :call_control_ids, Telnyx::Internal::Type::ArrayOf[String]

#client_stateString?

Use this field to add state to every subsequent webhook. Must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/conferences/action_send_dtmf_params.rb', line 35

optional :client_state, String

#digitsString

DTMF digits to send. Valid characters: 0-9, A-D, *, #, w (0.5s pause), W (1s pause).

Returns:

  • (String)


21
# File 'lib/telnyx/models/conferences/action_send_dtmf_params.rb', line 21

required :digits, String

#duration_millisInteger?

Duration of each DTMF digit in milliseconds.

Returns:

  • (Integer, nil)


41
# File 'lib/telnyx/models/conferences/action_send_dtmf_params.rb', line 41

optional :duration_millis, Integer

#idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/conferences/action_send_dtmf_params.rb', line 14

required :id, String