Class: Telnyx::Models::Conferences::ActionUnholdParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/conferences/action_unhold_params.rb

Overview

Defined Under Namespace

Modules: Region

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, call_control_ids:, region: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionUnholdParams for more details.

Parameters:

  • id (String)
  • call_control_ids (Array<String>)

    List of unique identifiers and tokens for controlling the call. Enter each call

  • region (Symbol, Telnyx::Models::Conferences::ActionUnholdParams::Region) (defaults to: nil)

    Region where the conference data is located. Defaults to the region defined in u

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/conferences/action_unhold_params.rb', line 30

Instance Attribute Details

#call_control_idsArray<String>

List of unique identifiers and tokens for controlling the call. Enter each call control ID to be unheld.

Returns:

  • (Array<String>)


21
# File 'lib/telnyx/models/conferences/action_unhold_params.rb', line 21

required :call_control_ids, Telnyx::Internal::Type::ArrayOf[String]

#idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/conferences/action_unhold_params.rb', line 14

required :id, String

#regionSymbol, ...

Region where the conference data is located. Defaults to the region defined in user’s data locality settings (Europe or US).



28
# File 'lib/telnyx/models/conferences/action_unhold_params.rb', line 28

optional :region, enum: -> { Telnyx::Conferences::ActionUnholdParams::Region }