Class: Telnyx::Models::Conferences::UpdateConference

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/conferences/update_conference.rb

Direct Known Subclasses

ActionUpdateParams

Defined Under Namespace

Modules: Region, SupervisorRole

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, supervisor_role:, command_id: nil, region: nil, whisper_call_control_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Conferences::UpdateConference for more details.

Parameters:

  • call_control_id (String)

    Unique identifier and token for controlling the call

  • supervisor_role (Symbol, Telnyx::Models::Conferences::UpdateConference::SupervisorRole)

    Sets the participant as a supervisor for the conference. A conference can have m

  • command_id (String) (defaults to: nil)

    Use this field to avoid execution of duplicate commands. Telnyx will ignore subs

  • region (Symbol, Telnyx::Models::Conferences::UpdateConference::Region) (defaults to: nil)

    Region where the conference data is located. Defaults to the region defined in u

  • whisper_call_control_ids (Array<String>) (defaults to: nil)

    Array of unique call_control_ids the supervisor can whisper to. If none provided



# File 'lib/telnyx/models/conferences/update_conference.rb', line 46

Instance Attribute Details

#call_control_idString

Unique identifier and token for controlling the call

Returns:

  • (String)


11
# File 'lib/telnyx/models/conferences/update_conference.rb', line 11

required :call_control_id, String

#command_idString?

Use this field to avoid execution of duplicate commands. Telnyx will ignore subsequent commands with the same ‘command_id` as one that has already been executed.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/conferences/update_conference.rb', line 29

optional :command_id, String

#regionSymbol, ...

Region where the conference data is located. Defaults to the region defined in user’s data locality settings (Europe or US).



36
# File 'lib/telnyx/models/conferences/update_conference.rb', line 36

optional :region, enum: -> { Telnyx::Conferences::UpdateConference::Region }

#supervisor_roleSymbol, Telnyx::Models::Conferences::UpdateConference::SupervisorRole

Sets the participant as a supervisor for the conference. A conference can have multiple supervisors. “barge” means the supervisor enters the conference as a normal participant. This is the same as “none”. “monitor” means the supervisor is muted but can hear all participants. “whisper” means that only the specified “whisper_call_control_ids” can hear the supervisor. Defaults to “none”.



21
# File 'lib/telnyx/models/conferences/update_conference.rb', line 21

required :supervisor_role, enum: -> { Telnyx::Conferences::UpdateConference::SupervisorRole }

#whisper_call_control_idsArray<String>?

Array of unique call_control_ids the supervisor can whisper to. If none provided, the supervisor will join the conference as a monitoring participant only.

Returns:

  • (Array<String>, nil)


44
# File 'lib/telnyx/models/conferences/update_conference.rb', line 44

optional :whisper_call_control_ids, Telnyx::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/conferences/update_conference.rb', line 75