Class: Telnyx::Models::ConnectionJitterBuffer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/connection_jitter_buffer.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enable_jitter_buffer: nil, jitterbuffer_msec_max: nil, jitterbuffer_msec_min: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ConnectionJitterBuffer for more details.

Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.

Parameters:

  • enable_jitter_buffer (Boolean) (defaults to: nil)

    Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off

  • jitterbuffer_msec_max (Integer) (defaults to: nil)

    The maximum jitter buffer size in milliseconds. Must be between 40 and 400. Has

  • jitterbuffer_msec_min (Integer) (defaults to: nil)

    The minimum jitter buffer size in milliseconds. Must be between 40 and 400. Has



# File 'lib/telnyx/models/connection_jitter_buffer.rb', line 27

Instance Attribute Details

#enable_jitter_bufferBoolean?

Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled.

Returns:

  • (Boolean, nil)


11
# File 'lib/telnyx/models/connection_jitter_buffer.rb', line 11

optional :enable_jitter_buffer, Telnyx::Internal::Type::Boolean

#jitterbuffer_msec_maxInteger?

The maximum jitter buffer size in milliseconds. Must be between 40 and 400. Has no effect if enable_jitter_buffer is not true.

Returns:

  • (Integer, nil)


18
# File 'lib/telnyx/models/connection_jitter_buffer.rb', line 18

optional :jitterbuffer_msec_max, Integer

#jitterbuffer_msec_minInteger?

The minimum jitter buffer size in milliseconds. Must be between 40 and 400. Has no effect if enable_jitter_buffer is not true.

Returns:

  • (Integer, nil)


25
# File 'lib/telnyx/models/connection_jitter_buffer.rb', line 25

optional :jitterbuffer_msec_min, Integer