Class: Telnyx::Models::ConnectionListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/connection_list_response.rb

Overview

Defined Under Namespace

Modules: WebhookAPIVersion

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, active: nil, anchorsite_override: nil, connection_name: nil, created_at: nil, outbound_voice_profile_id: nil, record_type: nil, tags: nil, updated_at: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ConnectionListResponse for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the specific resource.

  • active (Boolean) (defaults to: nil)

    Defaults to true

  • anchorsite_override (Symbol, Telnyx::Models::AnchorsiteOverride) (defaults to: nil)

    ‘Latency` directs Telnyx to route media through the site with the lowest round-t

  • connection_name (String) (defaults to: nil)
  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • outbound_voice_profile_id (String) (defaults to: nil)

    Identifies the associated outbound voice profile.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • tags (Array<String>) (defaults to: nil)

    Tags associated with the connection.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.

  • webhook_api_version (Symbol, Telnyx::Models::ConnectionListResponse::WebhookAPIVersion) (defaults to: nil)

    Determines which webhook format will be used, Telnyx API v1 or v2.

  • webhook_event_failover_url (String, nil) (defaults to: nil)

    The failover URL where webhooks related to this connection will be sent if sendi

  • webhook_event_url (String, nil) (defaults to: nil)

    The URL where webhooks related to this connection will be sent.



# File 'lib/telnyx/models/connection_list_response.rb', line 81

Instance Attribute Details

#activeBoolean?

Defaults to true

Returns:

  • (Boolean, nil)


17
# File 'lib/telnyx/models/connection_list_response.rb', line 17

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



25
# File 'lib/telnyx/models/connection_list_response.rb', line 25

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#connection_nameString?

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/connection_list_response.rb', line 30

optional :connection_name, String

#created_atString?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/connection_list_response.rb', line 36

optional :created_at, String

#idString?

Identifies the specific resource.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/connection_list_response.rb', line 11

optional :id, String

#outbound_voice_profile_idString?

Identifies the associated outbound voice profile.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/connection_list_response.rb', line 42

optional :outbound_voice_profile_id, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/connection_list_response.rb', line 48

optional :record_type, String

#tagsArray<String>?

Tags associated with the connection.

Returns:

  • (Array<String>, nil)


54
# File 'lib/telnyx/models/connection_list_response.rb', line 54

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#updated_atString?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (String, nil)


60
# File 'lib/telnyx/models/connection_list_response.rb', line 60

optional :updated_at, String

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1 or v2.



66
# File 'lib/telnyx/models/connection_list_response.rb', line 66

optional :webhook_api_version, enum: -> { Telnyx::Models::ConnectionListResponse::WebhookAPIVersion }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.

Returns:

  • (String, nil)


73
# File 'lib/telnyx/models/connection_list_response.rb', line 73

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent.

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/connection_list_response.rb', line 79

optional :webhook_event_url, String, nil?: true