Class: Telnyx::Models::ConversationRelayLanguage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/conversation_relay_language.rb,
sig/telnyx/models/conversation_relay_language.rbs

Defined Under Namespace

Modules: TranscriptionEngine, VoiceSettings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(language:, speech_model: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_provider: nil, tts_provider: nil, voice: nil, voice_settings: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ConversationRelayLanguage for more details.

Language-specific TTS and transcription settings for Conversation Relay.

Parameters:



# File 'lib/telnyx/models/conversation_relay_language.rb', line 64

Instance Attribute Details

#languageString

BCP 47 language tag for this language configuration.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/telnyx/models/conversation_relay_language.rb', line 10

required :language, String

#speech_modelString?

Conversation Relay speech model. Prefer transcription_engine_config.transcription_model when configuring speech-to-text.

Parameters:

  • (String)

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/conversation_relay_language.rb', line 18

optional :speech_model, String

#transcription_engineSymbol, ...

Engine to use for speech recognition. Legacy values A - Google, B - Telnyx are supported for backward compatibility. When provided in a Conversation Relay language entry, Telnyx derives transcription_provider and speech_model for that language.



27
# File 'lib/telnyx/models/conversation_relay_language.rb', line 27

optional :transcription_engine, enum: -> { Telnyx::ConversationRelayLanguage::TranscriptionEngine }

#transcription_engine_configHash{Symbol=>Object}?

Engine-specific transcription settings for Conversation Relay. This accepts the same provider-specific options used by the Call Transcription Start command, such as transcription_model, without requiring the engine discriminator to be repeated inside this object.

Returns:

  • (Hash{Symbol=>Object}, nil)


36
# File 'lib/telnyx/models/conversation_relay_language.rb', line 36

optional :transcription_engine_config, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#transcription_providerString?

Conversation Relay transcription provider name. Prefer transcription_engine when configuring speech-to-text.

Parameters:

  • (String)

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/conversation_relay_language.rb', line 43

optional :transcription_provider, String

#tts_providerString?

Text-to-speech provider for this language. If omitted and voice is provided, Telnyx derives the provider from the voice identifier.

Parameters:

  • (String)

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/conversation_relay_language.rb', line 50

optional :tts_provider, String

#voiceString?

Voice identifier for this language.

Parameters:

  • (String)

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/conversation_relay_language.rb', line 56

optional :voice, String

#voice_settingsTelnyx::Models::Calls::ElevenLabsVoiceSettings, ...

The settings associated with the voice selected



62
# File 'lib/telnyx/models/conversation_relay_language.rb', line 62

optional :voice_settings, union: -> { Telnyx::ConversationRelayLanguage::VoiceSettings }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/conversation_relay_language.rb', line 106

Instance Method Details

#to_hash{

Returns:

  • ({)


63
# File 'sig/telnyx/models/conversation_relay_language.rbs', line 63

def to_hash: -> {