Class: Telnyx::Models::CountryCoverageAPI
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CountryCoverageAPI
- Defined in:
- lib/telnyx/models/country_coverage.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#code ⇒ String?
Country ISO code.
-
#features ⇒ Array<String>?
Set of features supported.
- #international_sms ⇒ Boolean?
-
#inventory_coverage ⇒ Boolean?
Indicates whether country can be queried with inventory coverage endpoint.
- #local ⇒ Telnyx::Models::CountryCoverageAPI::Local?
- #mobile ⇒ Hash{Symbol=>Object}?
- #national ⇒ Hash{Symbol=>Object}?
- #numbers ⇒ Boolean?
- #p2p ⇒ Boolean?
-
#phone_number_type ⇒ Array<String>?
Phone number type.
-
#quickship ⇒ Boolean?
Supports quickship.
-
#region ⇒ String?
Geographic region (e.g., AMER, EMEA, APAC).
-
#reservable ⇒ Boolean?
Supports reservable.
- #shared_cost ⇒ Hash{Symbol=>Object}?
- #toll_free ⇒ Telnyx::Models::CountryCoverageAPI::TollFree?
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(features: nil, full_pstn_replacement: nil, international_sms: nil, p2p: nil, quickship: nil, reservable: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/country_coverage.rb', line 88
|
Instance Attribute Details
#code ⇒ String?
Country ISO code
10 |
# File 'lib/telnyx/models/country_coverage.rb', line 10 optional :code, String |
#features ⇒ Array<String>?
Set of features supported
16 |
# File 'lib/telnyx/models/country_coverage.rb', line 16 optional :features, Telnyx::Internal::Type::ArrayOf[String] |
#international_sms ⇒ Boolean?
21 |
# File 'lib/telnyx/models/country_coverage.rb', line 21 optional :international_sms, Telnyx::Internal::Type::Boolean |
#inventory_coverage ⇒ Boolean?
Indicates whether country can be queried with inventory coverage endpoint
27 |
# File 'lib/telnyx/models/country_coverage.rb', line 27 optional :inventory_coverage, Telnyx::Internal::Type::Boolean |
#local ⇒ Telnyx::Models::CountryCoverageAPI::Local?
32 |
# File 'lib/telnyx/models/country_coverage.rb', line 32 optional :local, -> { Telnyx::CountryCoverageAPI::Local } |
#mobile ⇒ Hash{Symbol=>Object}?
37 |
# File 'lib/telnyx/models/country_coverage.rb', line 37 optional :mobile, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#national ⇒ Hash{Symbol=>Object}?
42 |
# File 'lib/telnyx/models/country_coverage.rb', line 42 optional :national, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#numbers ⇒ Boolean?
47 |
# File 'lib/telnyx/models/country_coverage.rb', line 47 optional :numbers, Telnyx::Internal::Type::Boolean |
#p2p ⇒ Boolean?
52 |
# File 'lib/telnyx/models/country_coverage.rb', line 52 optional :p2p, Telnyx::Internal::Type::Boolean |
#phone_number_type ⇒ Array<String>?
Phone number type
58 |
# File 'lib/telnyx/models/country_coverage.rb', line 58 optional :phone_number_type, Telnyx::Internal::Type::ArrayOf[String] |
#quickship ⇒ Boolean?
Supports quickship
64 |
# File 'lib/telnyx/models/country_coverage.rb', line 64 optional :quickship, Telnyx::Internal::Type::Boolean |
#region ⇒ String?
Geographic region (e.g., AMER, EMEA, APAC)
70 |
# File 'lib/telnyx/models/country_coverage.rb', line 70 optional :region, String, nil?: true |
#reservable ⇒ Boolean?
Supports reservable
76 |
# File 'lib/telnyx/models/country_coverage.rb', line 76 optional :reservable, Telnyx::Internal::Type::Boolean |
#shared_cost ⇒ Hash{Symbol=>Object}?
81 |
# File 'lib/telnyx/models/country_coverage.rb', line 81 optional :shared_cost, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#toll_free ⇒ Telnyx::Models::CountryCoverageAPI::TollFree?
86 |
# File 'lib/telnyx/models/country_coverage.rb', line 86 optional :toll_free, -> { Telnyx::CountryCoverageAPI::TollFree } |