Class: Telnyx::Models::CreateVerificationRequestSMS
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CreateVerificationRequestSMS
- Defined in:
- lib/telnyx/models/create_verification_request_sms.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#custom_code ⇒ String?
Send a self-generated numeric code to the end-user.
-
#phone_number ⇒ String
+E164 formatted phone number.
-
#timeout_secs ⇒ Integer?
The number of seconds the verification code is valid for.
-
#verify_profile_id ⇒ String
The identifier of the associated Verify profile.
Instance Method Summary collapse
-
#initialize(phone_number:, verify_profile_id:, custom_code: nil, timeout_secs: nil) ⇒ Object
constructor
The request body when creating a verification.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(phone_number:, verify_profile_id:, custom_code: nil, timeout_secs: nil) ⇒ Object
The request body when creating a verification.
|
|
# File 'lib/telnyx/models/create_verification_request_sms.rb', line 30
|
Instance Attribute Details
#custom_code ⇒ String?
Send a self-generated numeric code to the end-user
22 |
# File 'lib/telnyx/models/create_verification_request_sms.rb', line 22 optional :custom_code, String, nil?: true |
#phone_number ⇒ String
+E164 formatted phone number.
10 |
# File 'lib/telnyx/models/create_verification_request_sms.rb', line 10 required :phone_number, String |
#timeout_secs ⇒ Integer?
The number of seconds the verification code is valid for.
28 |
# File 'lib/telnyx/models/create_verification_request_sms.rb', line 28 optional :timeout_secs, Integer |
#verify_profile_id ⇒ String
The identifier of the associated Verify profile.
16 |
# File 'lib/telnyx/models/create_verification_request_sms.rb', line 16 required :verify_profile_id, String |