Module: Telnyx::Models::CredentialConnection::SipUriCallingPreference
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/credential_connection.rb
Overview
This feature enables inbound SIP URI calls to your Credential Auth Connection. If enabled for all (unrestricted) then anyone who calls the SIP URI <your-username>@telnyx.com will be connected to your Connection. You can also choose to allow only calls that are originated on any Connections under your account (internal).
Constant Summary collapse
- DISABLED =
:disabled- UNRESTRICTED =
:unrestricted- INTERNAL =
:internal
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info