Module: Telnyx::Models::CredentialConnectionCreateParams::WebhookAPIVersion
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/credential_connection_create_params.rb
Overview
Determines which webhook format will be used, Telnyx API v1, v2 or texml. Note - texml can only be set when the outbound object parameter call_parking_enabled is included and set to true.
Constant Summary collapse
- V1 =
:"1"- V2 =
:"2"- TEXML =
:texml
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/credential_connection_create_params.rb', line 285
|