Class: Telnyx::Models::CredentialConnections::ActionCheckRegistrationStatusResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/credential_connections/action_check_registration_status_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ip_address: nil, last_registration: nil, port: nil, record_type: nil, sip_username: nil, status: nil, transport: nil, user_agent: nil) ⇒ Object

Parameters:

  • ip_address (String) (defaults to: nil)

    The ip used during the SIP connection

  • last_registration (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was last updated.

  • port (Integer) (defaults to: nil)

    The port of the SIP connection

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • sip_username (String) (defaults to: nil)

    The user name of the SIP connection

  • status (Symbol, Telnyx::Models::CredentialConnections::ActionCheckRegistrationStatusResponse::Data::Status) (defaults to: nil)

    The current registration status of your SIP connection

  • transport (String) (defaults to: nil)

    The protocol of the SIP connection

  • user_agent (String) (defaults to: nil)

    The user agent of the SIP connection



# File 'lib/telnyx/models/credential_connections/action_check_registration_status_response.rb', line 67

Instance Attribute Details

#ip_addressString?

The ip used during the SIP connection

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/credential_connections/action_check_registration_status_response.rb', line 22

optional :ip_address, String

#last_registrationString?

ISO 8601 formatted date indicating when the resource was last updated.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/credential_connections/action_check_registration_status_response.rb', line 28

optional :last_registration, String

#portInteger?

The port of the SIP connection

Returns:

  • (Integer, nil)


34
# File 'lib/telnyx/models/credential_connections/action_check_registration_status_response.rb', line 34

optional :port, Integer

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/credential_connections/action_check_registration_status_response.rb', line 40

optional :record_type, String

#sip_usernameString?

The user name of the SIP connection

Returns:

  • (String, nil)


46
# File 'lib/telnyx/models/credential_connections/action_check_registration_status_response.rb', line 46

optional :sip_username, String

#statusSymbol, ...

The current registration status of your SIP connection



52
53
# File 'lib/telnyx/models/credential_connections/action_check_registration_status_response.rb', line 52

optional :status,
enum: -> { Telnyx::Models::CredentialConnections::ActionCheckRegistrationStatusResponse::Data::Status }

#transportString?

The protocol of the SIP connection

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/credential_connections/action_check_registration_status_response.rb', line 59

optional :transport, String

#user_agentString?

The user agent of the SIP connection

Returns:

  • (String, nil)


65
# File 'lib/telnyx/models/credential_connections/action_check_registration_status_response.rb', line 65

optional :user_agent, String