Class: Telnyx::Models::CredentialInbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/credential_inbound.rb

Defined Under Namespace

Modules: AniNumberFormat, DefaultRoutingMethod, DnisNumberFormat, SimultaneousRinging

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, simultaneous_ringing: nil, sip_compact_headers_enabled: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CredentialInbound for more details.

Parameters:

  • ani_number_format (Symbol, Telnyx::Models::CredentialInbound::AniNumberFormat) (defaults to: nil)

    This setting allows you to set the format with which the caller’s number (ANI) i

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the total number of inbound calls to phone numbers ass

  • codecs (Array<String>) (defaults to: nil)

    Defines the list of codecs that Telnyx will send for inbound calls to a specific

  • default_routing_method (Symbol, Telnyx::Models::CredentialInbound::DefaultRoutingMethod) (defaults to: nil)

    Default routing method to be used when a number is associated with the connectio

  • dnis_number_format (Symbol, Telnyx::Models::CredentialInbound::DnisNumberFormat) (defaults to: nil)
  • generate_ringback_tone (Boolean) (defaults to: nil)

    Generate ringback tone through 183 session progress message with early media.

  • isup_headers_enabled (Boolean) (defaults to: nil)

    When set, inbound phone calls will receive ISUP parameters via SIP headers. (Onl

  • prack_enabled (Boolean) (defaults to: nil)

    Enable PRACK messages as defined in RFC3262.

  • shaken_stir_enabled (Boolean) (defaults to: nil)

    When enabled the SIP Connection will receive the Identity header with Shaken/Sti

  • simultaneous_ringing (Symbol, Telnyx::Models::CredentialInbound::SimultaneousRinging) (defaults to: nil)

    When enabled, allows multiple devices to ring simultaneously on incoming calls.

  • sip_compact_headers_enabled (Boolean) (defaults to: nil)

    Defaults to true.

  • timeout_1xx_secs (Integer) (defaults to: nil)

    Time(sec) before aborting if connection is not made.

  • timeout_2xx_secs (Integer) (defaults to: nil)

    Time(sec) before aborting if call is unanswered (min: 1, max: 600).



# File 'lib/telnyx/models/credential_inbound.rb', line 93

Instance Attribute Details

#ani_number_formatSymbol, ...

This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.



11
# File 'lib/telnyx/models/credential_inbound.rb', line 11

optional :ani_number_format, enum: -> { Telnyx::CredentialInbound::AniNumberFormat }

#channel_limitInteger?

When set, this will limit the total number of inbound calls to phone numbers associated with this connection.

Returns:

  • (Integer, nil)


18
# File 'lib/telnyx/models/credential_inbound.rb', line 18

optional :channel_limit, Integer

#codecsArray<String>?

Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order. This only works when the Connection the number is assigned to uses Media Handling mode: default. OPUS and H.264 codecs are available only when using TCP or TLS transport for SIP.

Returns:

  • (Array<String>, nil)


27
# File 'lib/telnyx/models/credential_inbound.rb', line 27

optional :codecs, Telnyx::Internal::Type::ArrayOf[String]

#default_routing_methodSymbol, ...

Default routing method to be used when a number is associated with the connection. Must be one of the routing method types or left blank, other values are not allowed.



35
# File 'lib/telnyx/models/credential_inbound.rb', line 35

optional :default_routing_method, enum: -> { Telnyx::CredentialInbound::DefaultRoutingMethod }

#dnis_number_formatSymbol, ...



40
# File 'lib/telnyx/models/credential_inbound.rb', line 40

optional :dnis_number_format, enum: -> { Telnyx::CredentialInbound::DnisNumberFormat }

#generate_ringback_toneBoolean?

Generate ringback tone through 183 session progress message with early media.

Returns:

  • (Boolean, nil)


46
# File 'lib/telnyx/models/credential_inbound.rb', line 46

optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean

#isup_headers_enabledBoolean?

When set, inbound phone calls will receive ISUP parameters via SIP headers. (Only when available and only when using TCP or TLS transport.)

Returns:

  • (Boolean, nil)


53
# File 'lib/telnyx/models/credential_inbound.rb', line 53

optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean

#prack_enabledBoolean?

Enable PRACK messages as defined in RFC3262.

Returns:

  • (Boolean, nil)


59
# File 'lib/telnyx/models/credential_inbound.rb', line 59

optional :prack_enabled, Telnyx::Internal::Type::Boolean

#shaken_stir_enabledBoolean?

When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.

Returns:

  • (Boolean, nil)


67
# File 'lib/telnyx/models/credential_inbound.rb', line 67

optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean

#simultaneous_ringingSymbol, ...

When enabled, allows multiple devices to ring simultaneously on incoming calls.



73
# File 'lib/telnyx/models/credential_inbound.rb', line 73

optional :simultaneous_ringing, enum: -> { Telnyx::CredentialInbound::SimultaneousRinging }

#sip_compact_headers_enabledBoolean?

Defaults to true.

Returns:

  • (Boolean, nil)


79
# File 'lib/telnyx/models/credential_inbound.rb', line 79

optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean

#timeout_1xx_secsInteger?

Time(sec) before aborting if connection is not made.

Returns:

  • (Integer, nil)


85
# File 'lib/telnyx/models/credential_inbound.rb', line 85

optional :timeout_1xx_secs, Integer

#timeout_2xx_secsInteger?

Time(sec) before aborting if call is unanswered (min: 1, max: 600).

Returns:

  • (Integer, nil)


91
# File 'lib/telnyx/models/credential_inbound.rb', line 91

optional :timeout_2xx_secs, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/credential_inbound.rb', line 135