Class: Telnyx::Models::CustomStorageConfiguration::Configuration::S3Generic

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/custom_storage_configuration.rb,
sig/telnyx/models/custom_storage_configuration.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(aws_access_key_id:, aws_secret_access_key:, bucket:, endpoint:, region:, backend: :"s3-generic") ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CustomStorageConfiguration::Configuration::S3Generic for more details.

Parameters:

  • aws_access_key_id (String)

    AWS credentials access key id.

  • aws_secret_access_key (String)

    AWS secret access key.

  • bucket (String)

    Name of the bucket to be used to store recording files.

  • endpoint (String)

    URL of an S3-compatible storage endpoint, used to direct uploads and presigned d

  • region (String)

    Region where the bucket is located.

  • backend (Symbol, :"s3-generic") (defaults to: :"s3-generic")

    Storage backend type



# File 'lib/telnyx/models/custom_storage_configuration.rb', line 88

Instance Attribute Details

#aws_access_key_idString

AWS credentials access key id.

Parameters:

  • value (String)

Returns:

  • (String)


52
# File 'lib/telnyx/models/custom_storage_configuration.rb', line 52

required :aws_access_key_id, String

#aws_secret_access_keyString

AWS secret access key.

Parameters:

  • value (String)

Returns:

  • (String)


58
# File 'lib/telnyx/models/custom_storage_configuration.rb', line 58

required :aws_secret_access_key, String

#backendSymbol, :"s3-generic"

Storage backend type

Parameters:

  • value (:"s3-generic")

Returns:

  • (Symbol, :"s3-generic")


64
# File 'lib/telnyx/models/custom_storage_configuration.rb', line 64

required :backend, const: :"s3-generic"

#bucketString

Name of the bucket to be used to store recording files.

Parameters:

  • value (String)

Returns:

  • (String)


70
# File 'lib/telnyx/models/custom_storage_configuration.rb', line 70

required :bucket, String

#endpointString

URL of an S3-compatible storage endpoint, used to direct uploads and presigned download URLs to a non-AWS store (for example MinIO, Cloudflare R2, Wasabi, Backblaze B2, or Supabase). A bare host (https://s3.example.com) or a path-prefixed URL (https://xyz.supabase.co/storage/v1/s3) is accepted, and must use the http or https scheme.

Parameters:

  • value (String)

Returns:

  • (String)


80
# File 'lib/telnyx/models/custom_storage_configuration.rb', line 80

required :endpoint, String

#regionString

Region where the bucket is located.

Parameters:

  • value (String)

Returns:

  • (String)


86
# File 'lib/telnyx/models/custom_storage_configuration.rb', line 86

required :region, String

Instance Method Details

#to_hash{

Returns:

  • ({)


78
# File 'sig/telnyx/models/custom_storage_configuration.rbs', line 78

def to_hash: -> {