Class: Telnyx::Models::CustomerServiceRecord

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/customer_service_record.rb

Overview

Defined Under Namespace

Modules: Status Classes: Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number: nil, authorized_person_name: nil, billing_phone_number: nil, name: nil) ⇒ Object

The admin of the customer service record.

Parameters:

  • account_number (String) (defaults to: nil)

    The account number of the customer service record.

  • authorized_person_name (String) (defaults to: nil)

    The authorized person name of the customer service record.

  • billing_phone_number (String) (defaults to: nil)

    The billing phone number of the customer service record.

  • name (String) (defaults to: nil)

    The name of the customer service record.



# File 'lib/telnyx/models/customer_service_record.rb', line 65

Instance Attribute Details

#error_messageString?

The error message in case status is ‘failed`. This field would be null in case of `pending` or `completed` status.

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/customer_service_record.rb', line 12

optional :error_message, String, nil?: true

#phone_numberString?

The phone number of the customer service record.

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/customer_service_record.rb', line 18

optional :phone_number, String

#resultTelnyx::Models::CustomerServiceRecord::Result?

The result of the CSR request. This field would be null in case of ‘pending` or `failed` status.



25
# File 'lib/telnyx/models/customer_service_record.rb', line 25

optional :result, -> { Telnyx::CustomerServiceRecord::Result }, nil?: true

#statusSymbol, ...

The status of the customer service record



31
# File 'lib/telnyx/models/customer_service_record.rb', line 31

optional :status, enum: -> { Telnyx::CustomerServiceRecord::Status }

#webhook_urlString?

Callback URL to receive webhook notifications.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/customer_service_record.rb', line 37

optional :webhook_url, String