Class: Telnyx::Models::CustomerServiceRecord::Result

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/customer_service_record.rb

Overview

See Also:

Defined Under Namespace

Classes: Address, Admin

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(administrative_area: nil, full_address: nil, locality: nil, postal_code: nil, street_address: nil) ⇒ Object

The address of the customer service record

Parameters:

  • administrative_area (String) (defaults to: nil)

    The state of the address

  • full_address (String) (defaults to: nil)

    The full address

  • locality (String) (defaults to: nil)

    The city of the address

  • postal_code (String) (defaults to: nil)

    The zip code of the address

  • street_address (String) (defaults to: nil)

    The street address



# File 'lib/telnyx/models/customer_service_record.rb', line 113

Instance Attribute Details

#addressTelnyx::Models::CustomerServiceRecord::Result::Address?

The address of the customer service record



93
# File 'lib/telnyx/models/customer_service_record.rb', line 93

optional :address, -> { Telnyx::CustomerServiceRecord::Result::Address }

#adminTelnyx::Models::CustomerServiceRecord::Result::Admin?

The admin of the customer service record.



99
# File 'lib/telnyx/models/customer_service_record.rb', line 99

optional :admin, -> { Telnyx::CustomerServiceRecord::Result::Admin }

#associated_phone_numbersArray<String>?

The associated phone numbers of the customer service record.

Returns:

  • (Array<String>, nil)


105
# File 'lib/telnyx/models/customer_service_record.rb', line 105

optional :associated_phone_numbers, Telnyx::Internal::Type::ArrayOf[String]

#carrier_nameString?

The name of the carrier that the customer service record is for.

Returns:

  • (String, nil)


111
# File 'lib/telnyx/models/customer_service_record.rb', line 111

optional :carrier_name, String