Class: Telnyx::Models::CustomerServiceRecordVerifyPhoneNumberCoverageResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CustomerServiceRecordVerifyPhoneNumberCoverageResponse::Data
- Defined in:
- lib/telnyx/models/customer_service_record_verify_phone_number_coverage_response.rb
Defined Under Namespace
Modules: AdditionalDataRequired
Instance Attribute Summary collapse
-
#additional_data_required ⇒ Array<Symbol, Telnyx::Models::CustomerServiceRecordVerifyPhoneNumberCoverageResponse::Data::AdditionalDataRequired>?
Additional data required to perform CSR for the phone number.
-
#has_csr_coverage ⇒ Boolean?
Indicates whether the phone number is covered or not.
-
#phone_number ⇒ String?
The phone number that is being verified.
-
#reason ⇒ String?
The reason why the phone number is not covered.
-
#record_type ⇒ String?
Identifies the type of the resource.
Instance Method Summary collapse
- #initialize(data: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data: nil) ⇒ Object
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/telnyx/models/customer_service_record_verify_phone_number_coverage_response.rb', line 16 class Data < Telnyx::Internal::Type::BaseModel # @!attribute additional_data_required # Additional data required to perform CSR for the phone number. Only returned if # `has_csr_coverage` is true. # # @return [Array<Symbol, Telnyx::Models::CustomerServiceRecordVerifyPhoneNumberCoverageResponse::Data::AdditionalDataRequired>, nil] optional :additional_data_required, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::CustomerServiceRecordVerifyPhoneNumberCoverageResponse::Data::AdditionalDataRequired] } # @!attribute has_csr_coverage # Indicates whether the phone number is covered or not. # # @return [Boolean, nil] optional :has_csr_coverage, Telnyx::Internal::Type::Boolean # @!attribute phone_number # The phone number that is being verified. # # @return [String, nil] optional :phone_number, String # @!attribute reason # The reason why the phone number is not covered. Only returned if # `has_csr_coverage` is false. # # @return [String, nil] optional :reason, String # @!attribute record_type # Identifies the type of the resource. # # @return [String, nil] optional :record_type, String # @!method initialize(additional_data_required: nil, has_csr_coverage: nil, phone_number: nil, reason: nil, record_type: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::CustomerServiceRecordVerifyPhoneNumberCoverageResponse::Data} # for more details. # # @param additional_data_required [Array<Symbol, Telnyx::Models::CustomerServiceRecordVerifyPhoneNumberCoverageResponse::Data::AdditionalDataRequired>] Additional data required to perform CSR for the phone number. Only returned if ` # # @param has_csr_coverage [Boolean] Indicates whether the phone number is covered or not. # # @param phone_number [String] The phone number that is being verified. # # @param reason [String] The reason why the phone number is not covered. Only returned if `has_csr_covera # # @param record_type [String] Identifies the type of the resource. module AdditionalDataRequired extend Telnyx::Internal::Type::Enum NAME = :name AUTHORIZED_PERSON_NAME = :authorized_person_name ACCOUNT_NUMBER = :account_number CUSTOMER_CODE = :customer_code PIN = :pin ADDRESS_LINE_1 = :address_line_1 CITY = :city STATE = :state ZIP_CODE = :zip_code BILLING_PHONE_NUMBER = :billing_phone_number # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#additional_data_required ⇒ Array<Symbol, Telnyx::Models::CustomerServiceRecordVerifyPhoneNumberCoverageResponse::Data::AdditionalDataRequired>?
Additional data required to perform CSR for the phone number. Only returned if ‘has_csr_coverage` is true.
22 23 |
# File 'lib/telnyx/models/customer_service_record_verify_phone_number_coverage_response.rb', line 22 optional :additional_data_required, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::CustomerServiceRecordVerifyPhoneNumberCoverageResponse::Data::AdditionalDataRequired] } |
#has_csr_coverage ⇒ Boolean?
Indicates whether the phone number is covered or not.
29 |
# File 'lib/telnyx/models/customer_service_record_verify_phone_number_coverage_response.rb', line 29 optional :has_csr_coverage, Telnyx::Internal::Type::Boolean |
#phone_number ⇒ String?
The phone number that is being verified.
35 |
# File 'lib/telnyx/models/customer_service_record_verify_phone_number_coverage_response.rb', line 35 optional :phone_number, String |
#reason ⇒ String?
The reason why the phone number is not covered. Only returned if ‘has_csr_coverage` is false.
42 |
# File 'lib/telnyx/models/customer_service_record_verify_phone_number_coverage_response.rb', line 42 optional :reason, String |
#record_type ⇒ String?
Identifies the type of the resource.
48 |
# File 'lib/telnyx/models/customer_service_record_verify_phone_number_coverage_response.rb', line 48 optional :record_type, String |