Module: Telnyx::Models::DetailRecordListResponse

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/detail_record_list_response.rb

Overview

An object following one of the schemas published in developers.telnyx.com/docs/api/v2/detail-records

Defined Under Namespace

Classes: AmdDetailRecord, ConferenceDetailRecord, ConferenceParticipantDetailRecord, MediaStorageDetailRecord, MessageDetailRecord, SimCardUsageDetailRecord, VerifyDetailRecord

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(record_type:, id: nil, closed_at: nil, created_at: nil, currency: nil, data_cost: nil, data_rate: nil, data_unit: nil, downlink_data: nil, imsi: nil, ip_address: nil, mcc: nil, mnc: nil, phone_number: nil, sim_card_id: nil, sim_card_tags: nil, sim_group_id: nil, sim_group_name: nil, uplink_data: nil) ⇒ Object

Some parameter documentations has been truncated, see SimCardUsageDetailRecord for more details.

Parameters:

  • record_type (String)
  • id (String) (defaults to: nil)

    Unique identifier for this SIM Card Usage

  • closed_at (Time) (defaults to: nil)

    Event close time

  • created_at (Time) (defaults to: nil)

    Event creation time

  • currency (String) (defaults to: nil)

    Telnyx account currency used to describe monetary values, including billing cost

  • data_cost (Float) (defaults to: nil)

    Data cost

  • data_rate (String) (defaults to: nil)

    Currency amount per billing unit used to calculate the Telnyx billing cost

  • data_unit (String) (defaults to: nil)

    Unit of wireless link consumption

  • downlink_data (Float) (defaults to: nil)

    Number of megabytes downloaded

  • imsi (String) (defaults to: nil)

    International Mobile Subscriber Identity

  • ip_address (String) (defaults to: nil)

    Ip address that generated the event

  • mcc (String) (defaults to: nil)

    Mobile country code

  • mnc (String) (defaults to: nil)

    Mobile network code

  • phone_number (String) (defaults to: nil)

    Telephone number associated to SIM card

  • sim_card_id (String) (defaults to: nil)

    Unique identifier for SIM card

  • sim_card_tags (String) (defaults to: nil)

    User-provided tags

  • sim_group_id (String) (defaults to: nil)

    Unique identifier for SIM group

  • sim_group_name (String) (defaults to: nil)

    Sim group name for sim card

  • uplink_data (Float) (defaults to: nil)

    Number of megabytes uploaded



# File 'lib/telnyx/models/detail_record_list_response.rb', line 432