Class: Telnyx::Models::DetailRecordListResponse::ConferenceDetailRecord
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DetailRecordListResponse::ConferenceDetailRecord
- Defined in:
- lib/telnyx/models/detail_record_list_response.rb
Instance Attribute Summary collapse
-
#call_leg_id ⇒ String?
Telnyx UUID that identifies the conference call leg.
-
#call_sec ⇒ Integer?
Duration of the conference call in seconds.
-
#call_session_id ⇒ String?
Telnyx UUID that identifies with conference call session.
-
#connection_id ⇒ String?
Connection id.
-
#ended_at ⇒ Time?
Conference end time.
-
#expires_at ⇒ Time?
Conference expiry time.
-
#id ⇒ String?
Conference id.
-
#is_telnyx_billable ⇒ Boolean?
Indicates whether Telnyx billing charges might be applicable.
-
#name ⇒ String?
Conference name.
-
#participant_call_sec ⇒ Integer?
Sum of the conference call duration for all participants in seconds.
-
#participant_count ⇒ Integer?
Number of participants that joined the conference call.
- #record_type ⇒ String
-
#region ⇒ String?
Region where the conference is hosted.
-
#started_at ⇒ Time?
Conference start time.
-
#user_id ⇒ String?
User id.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#call_leg_id ⇒ String?
Telnyx UUID that identifies the conference call leg
358 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 358 optional :call_leg_id, String |
#call_sec ⇒ Integer?
Duration of the conference call in seconds
364 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 364 optional :call_sec, Integer |
#call_session_id ⇒ String?
Telnyx UUID that identifies with conference call session
370 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 370 optional :call_session_id, String |
#connection_id ⇒ String?
Connection id
376 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 376 optional :connection_id, String |
#ended_at ⇒ Time?
Conference end time
382 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 382 optional :ended_at, Time |
#expires_at ⇒ Time?
Conference expiry time
388 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 388 optional :expires_at, Time |
#id ⇒ String?
Conference id
352 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 352 optional :id, String |
#is_telnyx_billable ⇒ Boolean?
Indicates whether Telnyx billing charges might be applicable
394 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 394 optional :is_telnyx_billable, Telnyx::Internal::Type::Boolean |
#name ⇒ String?
Conference name
400 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 400 optional :name, String |
#participant_call_sec ⇒ Integer?
Sum of the conference call duration for all participants in seconds
406 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 406 optional :participant_call_sec, Integer |
#participant_count ⇒ Integer?
Number of participants that joined the conference call
412 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 412 optional :participant_count, Integer |
#record_type ⇒ String
346 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 346 required :record_type, String |
#region ⇒ String?
Region where the conference is hosted
418 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 418 optional :region, String |
#started_at ⇒ Time?
Conference start time
424 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 424 optional :started_at, Time |
#user_id ⇒ String?
User id
430 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 430 optional :user_id, String |