Class: Telnyx::Models::DetailRecordListResponse::ConferenceParticipantDetailRecord
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DetailRecordListResponse::ConferenceParticipantDetailRecord
- Defined in:
- lib/telnyx/models/detail_record_list_response.rb
Instance Attribute Summary collapse
-
#billed_sec ⇒ Integer?
Duration of the conference call for billing purposes.
-
#call_leg_id ⇒ String?
Telnyx UUID that identifies the conference call leg.
-
#call_sec ⇒ Integer?
Duration of the conference call in seconds.
-
#call_session_id ⇒ String?
Telnyx UUID that identifies with conference call session.
-
#conference_id ⇒ String?
Conference id.
-
#cost ⇒ String?
Currency amount for Telnyx billing cost.
-
#currency ⇒ String?
Telnyx account currency used to describe monetary values, including billing cost.
-
#destination_number ⇒ String?
Number called by the participant to join the conference.
-
#id ⇒ String?
Participant id.
-
#is_telnyx_billable ⇒ Boolean?
Indicates whether Telnyx billing charges might be applicable.
-
#joined_at ⇒ Time?
Participant join time.
-
#left_at ⇒ Time?
Participant leave time.
-
#originating_number ⇒ String?
Participant origin number used in the conference call.
-
#rate ⇒ String?
Currency amount per billing unit used to calculate the Telnyx billing cost.
-
#rate_measured_in ⇒ String?
Billing unit used to calculate the Telnyx billing cost.
- #record_type ⇒ String
-
#user_id ⇒ String?
User id.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#billed_sec ⇒ Integer?
Duration of the conference call for billing purposes
480 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 480 optional :billed_sec, Integer |
#call_leg_id ⇒ String?
Telnyx UUID that identifies the conference call leg
486 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 486 optional :call_leg_id, String |
#call_sec ⇒ Integer?
Duration of the conference call in seconds
492 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 492 optional :call_sec, Integer |
#call_session_id ⇒ String?
Telnyx UUID that identifies with conference call session
498 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 498 optional :call_session_id, String |
#conference_id ⇒ String?
Conference id
504 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 504 optional :conference_id, String |
#cost ⇒ String?
Currency amount for Telnyx billing cost
510 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 510 optional :cost, String |
#currency ⇒ String?
Telnyx account currency used to describe monetary values, including billing cost
516 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 516 optional :currency, String |
#destination_number ⇒ String?
Number called by the participant to join the conference
522 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 522 optional :destination_number, String |
#id ⇒ String?
Participant id
474 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 474 optional :id, String |
#is_telnyx_billable ⇒ Boolean?
Indicates whether Telnyx billing charges might be applicable
528 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 528 optional :is_telnyx_billable, Telnyx::Internal::Type::Boolean |
#joined_at ⇒ Time?
Participant join time
534 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 534 optional :joined_at, Time |
#left_at ⇒ Time?
Participant leave time
540 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 540 optional :left_at, Time |
#originating_number ⇒ String?
Participant origin number used in the conference call
546 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 546 optional :originating_number, String |
#rate ⇒ String?
Currency amount per billing unit used to calculate the Telnyx billing cost
552 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 552 optional :rate, String |
#rate_measured_in ⇒ String?
Billing unit used to calculate the Telnyx billing cost
558 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 558 optional :rate_measured_in, String |
#record_type ⇒ String
468 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 468 required :record_type, String |
#user_id ⇒ String?
User id
564 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 564 optional :user_id, String |