Class: Telnyx::Models::DetailRecordListResponse::MessageDetailRecord

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/detail_record_list_response.rb

Defined Under Namespace

Modules: Direction, MessageType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(record_type:, carrier: nil, carrier_fee: nil, cld: nil, cli: nil, completed_at: nil, cost: nil, country_code: nil, created_at: nil, currency: nil, delivery_status: nil, delivery_status_failover_url: nil, delivery_status_webhook_url: nil, direction: nil, errors: nil, fteu: nil, mcc: nil, message_type: nil, mnc: nil, on_net: nil, parts: nil, profile_id: nil, profile_name: nil, rate: nil, sent_at: nil, source_country_code: nil, status: nil, tags: nil, updated_at: nil, user_id: nil, uuid: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::DetailRecordListResponse::MessageDetailRecord for more details.

Parameters:

  • record_type (String)

    Identifies the record schema

  • carrier (String) (defaults to: nil)

    Country-specific carrier used to send or receive the message

  • carrier_fee (String) (defaults to: nil)

    Fee charged by certain carriers in order to deliver certain message types. Telny

  • cld (String) (defaults to: nil)

    The recipient of the message (to parameter in the Messaging API)

  • cli (String) (defaults to: nil)

    The sender of the message (from parameter in the Messaging API). For Alphanumeri

  • completed_at (Time) (defaults to: nil)

    Message completion time

  • cost (String) (defaults to: nil)

    Amount, in the user currency, for the Telnyx billing cost

  • country_code (String) (defaults to: nil)

    Two-letter representation of the country of the cld property using the ISO 3166-

  • created_at (Time) (defaults to: nil)

    Message creation time

  • currency (String) (defaults to: nil)

    Telnyx account currency used to describe monetary values, including billing cost

  • delivery_status (String) (defaults to: nil)

    Final webhook delivery status

  • delivery_status_failover_url (String) (defaults to: nil)

    Failover customer-provided URL which Telnyx posts delivery status webhooks to

  • delivery_status_webhook_url (String) (defaults to: nil)

    Primary customer-provided URL which Telnyx posts delivery status webhooks to

  • direction (Symbol, Telnyx::Models::DetailRecordListResponse::MessageDetailRecord::Direction) (defaults to: nil)

    Logical direction of the message from the Telnyx customer’s perspective. It’s in

  • errors (Array<String>) (defaults to: nil)

    Telnyx API error codes returned by the Telnyx gateway

  • fteu (Boolean) (defaults to: nil)

    Indicates whether this is a Free-To-End-User (FTEU) short code message

  • mcc (String) (defaults to: nil)

    Mobile country code. Only available for certain products, such as Global Outboun

  • message_type (Symbol, Telnyx::Models::DetailRecordListResponse::MessageDetailRecord::MessageType) (defaults to: nil)

    Describes the Messaging service used to send the message. Available services are

  • mnc (String) (defaults to: nil)

    Mobile network code. Only available for certain products, such as Global Outboun

  • on_net (Boolean) (defaults to: nil)

    Indicates whether both sender and recipient numbers are Telnyx-managed

  • parts (Integer) (defaults to: nil)

    Number of message parts. The message is broken down in multiple parts when its l

  • profile_id (String) (defaults to: nil)

    Unique identifier of the Messaging Profile used to send or receive the message

  • profile_name (String) (defaults to: nil)

    Name of the Messaging Profile used to send or receive the message

  • rate (String) (defaults to: nil)

    Currency amount per billing unit used to calculate the Telnyx billing cost

  • sent_at (Time) (defaults to: nil)

    Time when the message was sent

  • source_country_code (String) (defaults to: nil)

    Two-letter representation of the country of the cli property using the ISO 3166-

  • status (Symbol, Telnyx::Models::DetailRecordListResponse::MessageDetailRecord::Status) (defaults to: nil)

    Final status of the message after the delivery attempt

  • tags (String) (defaults to: nil)

    Comma-separated tags assigned to the Telnyx number associated with the message

  • updated_at (Time) (defaults to: nil)

    Message updated time

  • user_id (String) (defaults to: nil)

    Identifier of the Telnyx account who owns the message

  • uuid (String) (defaults to: nil)

    Unique identifier of the message



# File 'lib/telnyx/models/detail_record_list_response.rb', line 226

Instance Attribute Details

#carrierString?

Country-specific carrier used to send or receive the message

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/detail_record_list_response.rb', line 39

optional :carrier, String

#carrier_feeString?

Fee charged by certain carriers in order to deliver certain message types. Telnyx passes this fee on to the customer according to our pricing table

Returns:

  • (String, nil)


46
# File 'lib/telnyx/models/detail_record_list_response.rb', line 46

optional :carrier_fee, String

#cldString?

The recipient of the message (to parameter in the Messaging API)

Returns:

  • (String, nil)


52
# File 'lib/telnyx/models/detail_record_list_response.rb', line 52

optional :cld, String

#cliString?

The sender of the message (from parameter in the Messaging API). For Alphanumeric ID messages, this is the sender ID value

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/detail_record_list_response.rb', line 59

optional :cli, String

#completed_atTime?

Message completion time

Returns:

  • (Time, nil)


65
# File 'lib/telnyx/models/detail_record_list_response.rb', line 65

optional :completed_at, Time

#costString?

Amount, in the user currency, for the Telnyx billing cost

Returns:

  • (String, nil)


71
# File 'lib/telnyx/models/detail_record_list_response.rb', line 71

optional :cost, String

#country_codeString?

Two-letter representation of the country of the cld property using the ISO 3166-1 alpha-2 format

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/detail_record_list_response.rb', line 78

optional :country_code, String

#created_atTime?

Message creation time

Returns:

  • (Time, nil)


84
# File 'lib/telnyx/models/detail_record_list_response.rb', line 84

optional :created_at, Time

#currencyString?

Telnyx account currency used to describe monetary values, including billing cost

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/detail_record_list_response.rb', line 90

optional :currency, String

#delivery_statusString?

Final webhook delivery status

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/detail_record_list_response.rb', line 96

optional :delivery_status, String

#delivery_status_failover_urlString?

Failover customer-provided URL which Telnyx posts delivery status webhooks to

Returns:

  • (String, nil)


102
# File 'lib/telnyx/models/detail_record_list_response.rb', line 102

optional :delivery_status_failover_url, String

#delivery_status_webhook_urlString?

Primary customer-provided URL which Telnyx posts delivery status webhooks to

Returns:

  • (String, nil)


108
# File 'lib/telnyx/models/detail_record_list_response.rb', line 108

optional :delivery_status_webhook_url, String

#directionSymbol, ...

Logical direction of the message from the Telnyx customer’s perspective. It’s inbound when the Telnyx customer receives the message, or outbound otherwise



115
# File 'lib/telnyx/models/detail_record_list_response.rb', line 115

optional :direction, enum: -> { Telnyx::Models::DetailRecordListResponse::MessageDetailRecord::Direction }

#errorsArray<String>?

Telnyx API error codes returned by the Telnyx gateway

Returns:

  • (Array<String>, nil)


121
# File 'lib/telnyx/models/detail_record_list_response.rb', line 121

optional :errors, Telnyx::Internal::Type::ArrayOf[String]

#fteuBoolean?

Indicates whether this is a Free-To-End-User (FTEU) short code message

Returns:

  • (Boolean, nil)


127
# File 'lib/telnyx/models/detail_record_list_response.rb', line 127

optional :fteu, Telnyx::Internal::Type::Boolean

#mccString?

Mobile country code. Only available for certain products, such as Global Outbound-Only from Alphanumeric Sender ID

Returns:

  • (String, nil)


134
# File 'lib/telnyx/models/detail_record_list_response.rb', line 134

optional :mcc, String

#message_typeSymbol, ...

Describes the Messaging service used to send the message. Available services are: Short Message Service (SMS), Multimedia Messaging Service (MMS), and Rich Communication Services (RCS)



142
143
# File 'lib/telnyx/models/detail_record_list_response.rb', line 142

optional :message_type,
enum: -> { Telnyx::Models::DetailRecordListResponse::MessageDetailRecord::MessageType }

#mncString?

Mobile network code. Only available for certain products, such as Global Outbound-Only from Alphanumeric Sender ID

Returns:

  • (String, nil)


150
# File 'lib/telnyx/models/detail_record_list_response.rb', line 150

optional :mnc, String

#on_netBoolean?

Indicates whether both sender and recipient numbers are Telnyx-managed

Returns:

  • (Boolean, nil)


156
# File 'lib/telnyx/models/detail_record_list_response.rb', line 156

optional :on_net, Telnyx::Internal::Type::Boolean

#partsInteger?

Number of message parts. The message is broken down in multiple parts when its length surpasses the limit of 160 characters

Returns:

  • (Integer, nil)


163
# File 'lib/telnyx/models/detail_record_list_response.rb', line 163

optional :parts, Integer

#profile_idString?

Unique identifier of the Messaging Profile used to send or receive the message

Returns:

  • (String, nil)


169
# File 'lib/telnyx/models/detail_record_list_response.rb', line 169

optional :profile_id, String

#profile_nameString?

Name of the Messaging Profile used to send or receive the message

Returns:

  • (String, nil)


175
# File 'lib/telnyx/models/detail_record_list_response.rb', line 175

optional :profile_name, String

#rateString?

Currency amount per billing unit used to calculate the Telnyx billing cost

Returns:

  • (String, nil)


181
# File 'lib/telnyx/models/detail_record_list_response.rb', line 181

optional :rate, String

#record_typeString

Identifies the record schema

Returns:

  • (String)


33
# File 'lib/telnyx/models/detail_record_list_response.rb', line 33

required :record_type, String

#sent_atTime?

Time when the message was sent

Returns:

  • (Time, nil)


187
# File 'lib/telnyx/models/detail_record_list_response.rb', line 187

optional :sent_at, Time

#source_country_codeString?

Two-letter representation of the country of the cli property using the ISO 3166-1 alpha-2 format

Returns:

  • (String, nil)


194
# File 'lib/telnyx/models/detail_record_list_response.rb', line 194

optional :source_country_code, String

#statusSymbol, ...

Final status of the message after the delivery attempt



200
# File 'lib/telnyx/models/detail_record_list_response.rb', line 200

optional :status, enum: -> { Telnyx::Models::DetailRecordListResponse::MessageDetailRecord::Status }

#tagsString?

Comma-separated tags assigned to the Telnyx number associated with the message

Returns:

  • (String, nil)


206
# File 'lib/telnyx/models/detail_record_list_response.rb', line 206

optional :tags, String

#updated_atTime?

Message updated time

Returns:

  • (Time, nil)


212
# File 'lib/telnyx/models/detail_record_list_response.rb', line 212

optional :updated_at, Time

#user_idString?

Identifier of the Telnyx account who owns the message

Returns:

  • (String, nil)


218
# File 'lib/telnyx/models/detail_record_list_response.rb', line 218

optional :user_id, String

#uuidString?

Unique identifier of the message

Returns:

  • (String, nil)


224
# File 'lib/telnyx/models/detail_record_list_response.rb', line 224

optional :uuid, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/detail_record_list_response.rb', line 303