Module: Telnyx::Models::DetailRecordListResponse::MessageDetailRecord::Direction
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/detail_record_list_response.rb
Overview
Logical direction of the message from the Telnyx customer’s perspective. It’s inbound when the Telnyx customer receives the message, or outbound otherwise
Constant Summary collapse
- INBOUND =
:inbound- OUTBOUND =
:outbound
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info