Class: Telnyx::Models::DetailRecordListResponse::VerifyDetailRecord
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DetailRecordListResponse::VerifyDetailRecord
- Defined in:
- lib/telnyx/models/detail_record_list_response.rb
Defined Under Namespace
Modules: VerifyChannelType
Instance Attribute Summary collapse
- #created_at ⇒ Time?
-
#currency ⇒ String?
Telnyx account currency used to describe monetary values, including billing costs.
- #delivery_status ⇒ String?
-
#destination_phone_number ⇒ String?
E.164 formatted phone number.
-
#id ⇒ String?
Unique ID of the verification.
-
#rate ⇒ String?
Currency amount per billing unit used to calculate the Telnyx billing costs.
-
#rate_measured_in ⇒ String?
Billing unit used to calculate the Telnyx billing costs.
- #record_type ⇒ String
- #updated_at ⇒ Time?
- #verification_status ⇒ String?
- #verify_channel_id ⇒ String?
-
#verify_channel_type ⇒ Symbol, ...
Depending on the type of verification, the ‘verify_channel_id` points to one of the following channel ids;.
- #verify_profile_id ⇒ String?
-
#verify_usage_fee ⇒ String?
Currency amount for Verify Usage Fee.
Instance Method Summary collapse
-
#initialize(record_type:, id: nil, created_at: nil, currency: nil, delivery_status: nil, destination_phone_number: nil, rate: nil, rate_measured_in: nil, updated_at: nil, verification_status: nil, verify_channel_id: nil, verify_channel_type: nil, verify_profile_id: nil, verify_usage_fee: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see VerifyDetailRecord for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(record_type:, id: nil, created_at: nil, currency: nil, delivery_status: nil, destination_phone_number: nil, rate: nil, rate_measured_in: nil, updated_at: nil, verification_status: nil, verify_channel_id: nil, verify_channel_type: nil, verify_profile_id: nil, verify_usage_fee: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::DetailRecordListResponse::VerifyDetailRecord for more details.
|
|
# File 'lib/telnyx/models/detail_record_list_response.rb', line 841
|
Instance Attribute Details
#created_at ⇒ Time?
766 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 766 optional :created_at, Time |
#currency ⇒ String?
Telnyx account currency used to describe monetary values, including billing costs
773 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 773 optional :currency, String |
#delivery_status ⇒ String?
778 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 778 optional :delivery_status, String |
#destination_phone_number ⇒ String?
E.164 formatted phone number
784 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 784 optional :destination_phone_number, String |
#id ⇒ String?
Unique ID of the verification
761 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 761 optional :id, String |
#rate ⇒ String?
Currency amount per billing unit used to calculate the Telnyx billing costs
790 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 790 optional :rate, String |
#rate_measured_in ⇒ String?
Billing unit used to calculate the Telnyx billing costs
796 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 796 optional :rate_measured_in, String |
#record_type ⇒ String
755 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 755 required :record_type, String |
#updated_at ⇒ Time?
801 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 801 optional :updated_at, Time |
#verification_status ⇒ String?
806 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 806 optional :verification_status, String |
#verify_channel_id ⇒ String?
811 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 811 optional :verify_channel_id, String |
#verify_channel_type ⇒ Symbol, ...
Depending on the type of verification, the ‘verify_channel_id` points to one of the following channel ids;
| verify_channel_type | verify_channel_id | | ——————- | —————– | | sms, psd2 | messaging_id | | call, flashcall | call_control_id |
827 828 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 827 optional :verify_channel_type, enum: -> { Telnyx::Models::DetailRecordListResponse::VerifyDetailRecord::VerifyChannelType } |
#verify_profile_id ⇒ String?
833 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 833 optional :verify_profile_id, String |
#verify_usage_fee ⇒ String?
Currency amount for Verify Usage Fee
839 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 839 optional :verify_usage_fee, String |