Class: Telnyx::Models::DialogflowConnectionCreateResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DialogflowConnectionCreateResponse::Data
- Defined in:
- lib/telnyx/models/dialogflow_connection_create_response.rb
Overview
Instance Attribute Summary collapse
-
#connection_id ⇒ String?
Uniquely identifies a Telnyx application (Call Control).
-
#conversation_profile_id ⇒ String?
The id of a configured conversation profile on your Dialogflow account.
-
#environment ⇒ String?
Which Dialogflow environment will be used.
- #record_type ⇒ String?
-
#service_account ⇒ String?
The JSON map to connect your Dialoglow account.
Instance Method Summary collapse
-
#initialize(connection_id: nil, conversation_profile_id: nil, environment: nil, record_type: nil, service_account: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_id: nil, conversation_profile_id: nil, environment: nil, record_type: nil, service_account: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::DialogflowConnectionCreateResponse::Data for more details.
|
|
# File 'lib/telnyx/models/dialogflow_connection_create_response.rb', line 47
|
Instance Attribute Details
#connection_id ⇒ String?
Uniquely identifies a Telnyx application (Call Control).
21 |
# File 'lib/telnyx/models/dialogflow_connection_create_response.rb', line 21 optional :connection_id, String |
#conversation_profile_id ⇒ String?
The id of a configured conversation profile on your Dialogflow account. (If you use Dialogflow CX, this param is required)
28 |
# File 'lib/telnyx/models/dialogflow_connection_create_response.rb', line 28 optional :conversation_profile_id, String |
#environment ⇒ String?
Which Dialogflow environment will be used.
34 |
# File 'lib/telnyx/models/dialogflow_connection_create_response.rb', line 34 optional :environment, String |
#record_type ⇒ String?
39 |
# File 'lib/telnyx/models/dialogflow_connection_create_response.rb', line 39 optional :record_type, String |
#service_account ⇒ String?
The JSON map to connect your Dialoglow account.
45 |
# File 'lib/telnyx/models/dialogflow_connection_create_response.rb', line 45 optional :service_account, String |