Class: Telnyx::Models::DialogflowConnectionRetrieveResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/dialogflow_connection_retrieve_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(connection_id: nil, conversation_profile_id: nil, environment: nil, record_type: nil, service_account: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::DialogflowConnectionRetrieveResponse::Data for more details.

Parameters:

  • connection_id (String) (defaults to: nil)

    Uniquely identifies a Telnyx application (Call Control).

  • conversation_profile_id (String) (defaults to: nil)

    The id of a configured conversation profile on your Dialogflow account. (If you

  • environment (String) (defaults to: nil)

    Which Dialogflow environment will be used.

  • record_type (String) (defaults to: nil)
  • service_account (String) (defaults to: nil)

    The JSON map to connect your Dialoglow account.



# File 'lib/telnyx/models/dialogflow_connection_retrieve_response.rb', line 47

Instance Attribute Details

#connection_idString?

Uniquely identifies a Telnyx application (Call Control).

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/dialogflow_connection_retrieve_response.rb', line 21

optional :connection_id, String

#conversation_profile_idString?

The id of a configured conversation profile on your Dialogflow account. (If you use Dialogflow CX, this param is required)

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/dialogflow_connection_retrieve_response.rb', line 28

optional :conversation_profile_id, String

#environmentString?

Which Dialogflow environment will be used.

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/dialogflow_connection_retrieve_response.rb', line 34

optional :environment, String

#record_typeString?

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/dialogflow_connection_retrieve_response.rb', line 39

optional :record_type, String

#service_accountString?

The JSON map to connect your Dialoglow account.

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/dialogflow_connection_retrieve_response.rb', line 45

optional :service_account, String