Class: Telnyx::Models::DialogflowConnectionUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/dialogflow_connection_update_params.rb

Overview

Defined Under Namespace

Modules: DialogflowAPI

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(connection_id:, service_account:, conversation_profile_id: nil, dialogflow_api: nil, environment: nil, location: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::DialogflowConnectionUpdateParams for more details.

Parameters:

  • connection_id (String)
  • service_account (Hash{Symbol=>Object})

    The JSON map to connect your Dialoglow account.

  • conversation_profile_id (String) (defaults to: nil)

    The id of a configured conversation profile on your Dialogflow account. (If you

  • dialogflow_api (Symbol, Telnyx::Models::DialogflowConnectionUpdateParams::DialogflowAPI) (defaults to: nil)

    Determine which Dialogflow will be used.

  • environment (String) (defaults to: nil)

    Which Dialogflow environment will be used.

  • location (String) (defaults to: nil)

    The region of your agent is. (If you use Dialogflow CX, this param is required)

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 46

Instance Attribute Details

#connection_idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 13

required :connection_id, String

#conversation_profile_idString?

The id of a configured conversation profile on your Dialogflow account. (If you use Dialogflow CX, this param is required)

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 26

optional :conversation_profile_id, String

#dialogflow_apiSymbol, ...

Determine which Dialogflow will be used.



32
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 32

optional :dialogflow_api, enum: -> { Telnyx::DialogflowConnectionUpdateParams::DialogflowAPI }

#environmentString?

Which Dialogflow environment will be used.

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 38

optional :environment, String

#locationString?

The region of your agent is. (If you use Dialogflow CX, this param is required)

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 44

optional :location, String

#service_accountHash{Symbol=>Object}

The JSON map to connect your Dialoglow account.

Returns:

  • (Hash{Symbol=>Object})


19
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 19

required :service_account, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]