Class: Telnyx::Models::Dir::CommentCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/dir/comment_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dir_id:, content:, parent_comment_id: nil, request_options: {}) ⇒ Object

Parameters:

  • dir_id (String)
  • content (String)

    Comment body. 1–5000 characters.

  • parent_comment_id (String) (defaults to: nil)

    Optional parent comment id to thread this reply under.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/dir/comment_create_params.rb', line 28

Instance Attribute Details

#contentString

Comment body. 1–5000 characters.

Returns:

  • (String)


20
# File 'lib/telnyx/models/dir/comment_create_params.rb', line 20

required :content, String

#dir_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/dir/comment_create_params.rb', line 14

required :dir_id, String

#parent_comment_idString?

Optional parent comment id to thread this reply under.

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/dir/comment_create_params.rb', line 26

optional :parent_comment_id, String