Class: Telnyx::Models::Dir::CommentListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Dir::CommentListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/dir/comment_list_params.rb
Overview
Defined Under Namespace
Modules: CommentType
Instance Attribute Summary collapse
-
#comment_type ⇒ Symbol, ...
Restrict to comments of this category.
- #dir_id ⇒ String
-
#page_number ⇒ Integer?
1-based page number.
-
#page_size ⇒ Integer?
Items per page.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(dir_id:, comment_type: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CommentListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(dir_id:, comment_type: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Dir::CommentListParams for more details.
|
|
# File 'lib/telnyx/models/dir/comment_list_params.rb', line 35
|
Instance Attribute Details
#comment_type ⇒ Symbol, ...
Restrict to comments of this category. Customer-visible categories only: internal-only comments are filtered out regardless of this filter.
21 |
# File 'lib/telnyx/models/dir/comment_list_params.rb', line 21 optional :comment_type, enum: -> { Telnyx::Dir::CommentListParams::CommentType } |
#dir_id ⇒ String
14 |
# File 'lib/telnyx/models/dir/comment_list_params.rb', line 14 required :dir_id, String |
#page_number ⇒ Integer?
1-based page number. Out-of-range values return an empty page with correct meta.
27 |
# File 'lib/telnyx/models/dir/comment_list_params.rb', line 27 optional :page_number, Integer |
#page_size ⇒ Integer?
Items per page. Maximum 250; values above are clamped to 250.
33 |
# File 'lib/telnyx/models/dir/comment_list_params.rb', line 33 optional :page_size, Integer |