Class: Telnyx::Models::Dir::PhoneNumberBatchListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/dir/phone_number_batch_list_params.rb

Overview

Defined Under Namespace

Modules: FilterStatus

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dir_id:, filter_status: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Dir::PhoneNumberBatchListParams for more details.

Parameters:

  • dir_id (String)
  • filter_status (Symbol, Telnyx::Models::Dir::PhoneNumberBatchListParams::FilterStatus) (defaults to: nil)

    Restrict to batches whose aggregate status equals this value.

  • page_number (Integer) (defaults to: nil)

    1-based page number. Out-of-range values return an empty page with correct meta.

  • page_size (Integer) (defaults to: nil)

    Items per page. Maximum 250; values above are clamped to 250.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/dir/phone_number_batch_list_params.rb', line 34

Instance Attribute Details

#dir_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/dir/phone_number_batch_list_params.rb', line 14

required :dir_id, String

#filter_statusSymbol, ...

Restrict to batches whose aggregate status equals this value.



20
# File 'lib/telnyx/models/dir/phone_number_batch_list_params.rb', line 20

optional :filter_status, enum: -> { Telnyx::Dir::PhoneNumberBatchListParams::FilterStatus }

#page_numberInteger?

1-based page number. Out-of-range values return an empty page with correct meta.

Returns:

  • (Integer, nil)


26
# File 'lib/telnyx/models/dir/phone_number_batch_list_params.rb', line 26

optional :page_number, Integer

#page_sizeInteger?

Items per page. Maximum 250; values above are clamped to 250.

Returns:

  • (Integer, nil)


32
# File 'lib/telnyx/models/dir/phone_number_batch_list_params.rb', line 32

optional :page_size, Integer