Class: Telnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/dir/phone_number_batch_list_response.rb

Defined Under Namespace

Modules: Status Classes: RejectionReason

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(code: nil, detail: nil, message: nil, title: nil) ⇒ Object

Some parameter documentations has been truncated, see RejectionReason for more details.

Populated when ‘status` is `unsuccessful` or `permanently_rejected`.

Parameters:

  • code (String) (defaults to: nil)
  • detail (String) (defaults to: nil)
  • message (String, nil) (defaults to: nil)

    Customer-visible free-text comment from the Telnyx vetting team. Only the first

  • title (String) (defaults to: nil)


# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 229

Instance Attribute Details

#batch_idString?

Id of the batch this number was vetted as part of.

Returns:

  • (String, nil)


157
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 157

optional :batch_id, String, nil?: true

#dir_idString?

Returns:

  • (String, nil)


162
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 162

optional :dir_id, String

#enterprise_idString?

Returns:

  • (String, nil)


167
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 167

optional :enterprise_id, String

#loa_document_idString?

Id of the Letter of Authorization document attached to this number’s batch.

Returns:

  • (String, nil)


173
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 173

optional :loa_document_id, String, nil?: true

#phone_numberString?

E.164 with leading ‘+`.

Returns:

  • (String, nil)


179
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 179

optional :phone_number, String

#rejection_reasonTelnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber::RejectionReason?

Populated when ‘status` is `unsuccessful` or `permanently_rejected`.



185
186
187
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 185

optional :rejection_reason,
-> { Telnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber::RejectionReason },
nil?: true

#statusSymbol, ...

Phone-number lifecycle status.

  • ‘submitted` / `in_review` - Telnyx is reviewing the batch this number belongs to.

  • ‘verified` - approved; the DIR’s display identity will be shown on outbound calls from this number.

  • ‘unsuccessful` - Telnyx rejected this submission; the customer may re-add to retry.

  • ‘suspended` - temporarily disabled (e.g. by an active infringement claim on the DIR).

  • ‘expired` - verification expired; re-add to renew.

  • ‘permanently_rejected` - terminal; cannot be re-added on this or any other DIR you own.



205
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 205

optional :status, enum: -> { Telnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber::Status }