Module: Telnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/dir/phone_number_batch_list_response.rb

Overview

Phone-number lifecycle status.

  • ‘submitted` / `in_review` - Telnyx is reviewing the batch this number belongs to.

  • ‘verified` - approved; the DIR’s display identity will be shown on outbound calls from this number.

  • ‘unsuccessful` - Telnyx rejected this submission; the customer may re-add to retry.

  • ‘suspended` - temporarily disabled (e.g. by an active infringement claim on the DIR).

  • ‘expired` - verification expired; re-add to renew.

  • ‘permanently_rejected` - terminal; cannot be re-added on this or any other DIR you own.

See Also:

Constant Summary collapse

SUBMITTED =
:submitted
IN_REVIEW =
:in_review
VERIFIED =
:verified
UNSUCCESSFUL =
:unsuccessful
SUSPENDED =
:suspended
EXPIRED =
:expired
PERMANENTLY_REJECTED =
:permanently_rejected

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info