Class: Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data::Document

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/dir/phone_number_batch_retrieve_response.rb

Defined Under Namespace

Modules: DocumentType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(document_id:, document_type:, description: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data::Document for more details.

Parameters:



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/telnyx/models/dir/phone_number_batch_retrieve_response.rb', line 110

class Document < Telnyx::Internal::Type::BaseModel
  # @!attribute document_id
  #   Id returned by the Telnyx Documents API after you upload the file (upload via
  #   `POST /v2/documents`; see https://developers.telnyx.com/api/documents).
  #
  #   @return [String]
  required :document_id, String

  # @!attribute document_type
  #   Type of supporting document. Pick the closest match to what the file actually
  #   contains; `other` triggers manual vetting and may slow approval. The matching
  #   short_name reference list is at `GET /v2/dir/document_types`.
  #
  #   @return [Symbol, Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data::Document::DocumentType]
  required :document_type,
           enum: -> { Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data::Document::DocumentType }

  # @!attribute description
  #
  #   @return [String, nil]
  optional :description, String

  # @!method initialize(document_id:, document_type:, description: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data::Document} for more
  #   details.
  #
  #   @param document_id [String] Id returned by the Telnyx Documents API after you upload the file (upload via `P
  #
  #   @param document_type [Symbol, Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data::Document::DocumentType] Type of supporting document. Pick the closest match to what the file actually co
  #
  #   @param description [String]

  # Type of supporting document. Pick the closest match to what the file actually
  # contains; `other` triggers manual vetting and may slow approval. The matching
  # short_name reference list is at `GET /v2/dir/document_types`.
  #
  # @see Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data::Document#document_type
  module DocumentType
    extend Telnyx::Internal::Type::Enum

    LETTER_OF_AUTHORIZATION = :letter_of_authorization
    BUSINESS_REGISTRATION = :business_registration
    ARTICLES_OF_INCORPORATION = :articles_of_incorporation
    TAX_DOCUMENT = :tax_document
    EIN_LETTER = :ein_letter
    TRADEMARK_REGISTRATION = :trademark_registration
    WEBSITE_OWNERSHIP = :website_ownership
    BUSINESS_LICENSE = :business_license
    PROFESSIONAL_LICENSE = :professional_license
    GOVERNMENT_ID = :government_id
    UTILITY_BILL = :utility_bill
    BANK_STATEMENT = :bank_statement
    OTHER = :other

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#descriptionString?

Returns:

  • (String, nil)


130
# File 'lib/telnyx/models/dir/phone_number_batch_retrieve_response.rb', line 130

optional :description, String

#document_idString

Id returned by the Telnyx Documents API after you upload the file (upload via ‘POST /v2/documents`; see developers.telnyx.com/api/documents).

Returns:

  • (String)


116
# File 'lib/telnyx/models/dir/phone_number_batch_retrieve_response.rb', line 116

required :document_id, String

#document_typeSymbol, Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data::Document::DocumentType

Type of supporting document. Pick the closest match to what the file actually contains; ‘other` triggers manual vetting and may slow approval. The matching short_name reference list is at `GET /v2/dir/document_types`.



124
125
# File 'lib/telnyx/models/dir/phone_number_batch_retrieve_response.rb', line 124

required :document_type,
enum: -> { Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data::Document::DocumentType }