Class: Telnyx::Models::Dir::PhoneNumberListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Dir::PhoneNumberListResponse
- Defined in:
- lib/telnyx/models/dir/phone_number_list_response.rb
Overview
Defined Under Namespace
Modules: Status Classes: RejectionReason
Instance Attribute Summary collapse
-
#batch_id ⇒ String?
Id of the batch this number was vetted as part of.
- #dir_id ⇒ String?
- #enterprise_id ⇒ String?
-
#loa_document_id ⇒ String?
Id of the Letter of Authorization document attached to this number’s batch.
-
#phone_number ⇒ String?
E.164 with leading ‘+`.
-
#rejection_reason ⇒ Telnyx::Models::Dir::PhoneNumberListResponse::RejectionReason?
Populated when ‘status` is `unsuccessful` or `permanently_rejected`.
-
#status ⇒ Symbol, ...
Phone-number lifecycle status.
Instance Method Summary collapse
-
#initialize(code: nil, detail: nil, message: nil, title: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RejectionReason for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code: nil, detail: nil, message: nil, title: nil) ⇒ Object
Some parameter documentations has been truncated, see RejectionReason for more details.
Populated when ‘status` is `unsuccessful` or `permanently_rejected`.
|
|
# File 'lib/telnyx/models/dir/phone_number_list_response.rb', line 84
|
Instance Attribute Details
#batch_id ⇒ String?
Id of the batch this number was vetted as part of.
12 |
# File 'lib/telnyx/models/dir/phone_number_list_response.rb', line 12 optional :batch_id, String, nil?: true |
#dir_id ⇒ String?
17 |
# File 'lib/telnyx/models/dir/phone_number_list_response.rb', line 17 optional :dir_id, String |
#enterprise_id ⇒ String?
22 |
# File 'lib/telnyx/models/dir/phone_number_list_response.rb', line 22 optional :enterprise_id, String |
#loa_document_id ⇒ String?
Id of the Letter of Authorization document attached to this number’s batch.
28 |
# File 'lib/telnyx/models/dir/phone_number_list_response.rb', line 28 optional :loa_document_id, String, nil?: true |
#phone_number ⇒ String?
E.164 with leading ‘+`.
34 |
# File 'lib/telnyx/models/dir/phone_number_list_response.rb', line 34 optional :phone_number, String |
#rejection_reason ⇒ Telnyx::Models::Dir::PhoneNumberListResponse::RejectionReason?
Populated when ‘status` is `unsuccessful` or `permanently_rejected`.
40 41 42 |
# File 'lib/telnyx/models/dir/phone_number_list_response.rb', line 40 optional :rejection_reason, -> { Telnyx::Models::Dir::PhoneNumberListResponse::RejectionReason }, nil?: true |
#status ⇒ Symbol, ...
Phone-number lifecycle status.
-
‘submitted` / `in_review` - Telnyx is reviewing the batch this number belongs to.
-
‘verified` - approved; the DIR’s display identity will be shown on outbound calls from this number.
-
‘unsuccessful` - Telnyx rejected this submission; the customer may re-add to retry.
-
‘suspended` - temporarily disabled (e.g. by an active infringement claim on the DIR).
-
‘expired` - verification expired; re-add to renew.
-
‘permanently_rejected` - terminal; cannot be re-added on this or any other DIR you own.
60 |
# File 'lib/telnyx/models/dir/phone_number_list_response.rb', line 60 optional :status, enum: -> { Telnyx::Models::Dir::PhoneNumberListResponse::Status } |