Class: Telnyx::Models::Dir::ReferenceInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/dir/reference_input.rb,
sig/telnyx/models/dir/reference_input.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email:, full_name:, phone_e164:, timezone:, job_title: nil, organization: nil, relationship_to_registrant: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Dir::ReferenceInput for more details.

One reference supplied at submit. The reference type is implied by the field that carries it (business_references vs financial_reference).

Parameters:

  • email (String)

    Reference contact email address. Required: the reference is emailed scheduling a

  • full_name (String)

    Full name of the reference contact.

  • phone_e164 (String)

    Reference phone number in E.164 format, e.g. +14155550123.

  • timezone (String)

    IANA timezone id for the reference (e.g. America/New_York). Required: calls are

  • job_title (String, nil) (defaults to: nil)

    Job title of the reference contact.

  • organization (String, nil) (defaults to: nil)

    Organization the reference contact belongs to.

  • relationship_to_registrant (String, nil) (defaults to: nil)

    How the reference contact is related to the registering business.



# File 'lib/telnyx/models/dir/reference_input.rb', line 51

Instance Attribute Details

#emailString

Reference contact email address. Required: the reference is emailed scheduling and dial-in notices.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/telnyx/models/dir/reference_input.rb', line 12

required :email, String

#full_nameString

Full name of the reference contact.

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/telnyx/models/dir/reference_input.rb', line 18

required :full_name, String

#job_titleString?

Job title of the reference contact.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/dir/reference_input.rb', line 37

optional :job_title, String, nil?: true

#organizationString?

Organization the reference contact belongs to.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/dir/reference_input.rb', line 43

optional :organization, String, nil?: true

#phone_e164String

Reference phone number in E.164 format, e.g. +14155550123.

Parameters:

  • value (String)

Returns:

  • (String)


24
# File 'lib/telnyx/models/dir/reference_input.rb', line 24

required :phone_e164, String

#relationship_to_registrantString?

How the reference contact is related to the registering business.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/dir/reference_input.rb', line 49

optional :relationship_to_registrant, String, nil?: true

#timezoneString

IANA timezone id for the reference (e.g. America/New_York). Required: calls are only placed within the reference's local 8am-9pm window.

Parameters:

  • value (String)

Returns:

  • (String)


31
# File 'lib/telnyx/models/dir/reference_input.rb', line 31

required :timezone, String

Instance Method Details

#to_hash{

Returns:

  • ({)


40
# File 'sig/telnyx/models/dir/reference_input.rbs', line 40

def to_hash: -> {