Class: Telnyx::Models::Dir::ReferenceUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Dir::ReferenceUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/dir/reference_update_params.rb,
sig/telnyx/models/dir/reference_update_params.rbs
Overview
Defined Under Namespace
Modules: RefType
Instance Attribute Summary collapse
- #dir_id ⇒ String
-
#email ⇒ String?
Reference contact email address.
-
#full_name ⇒ String?
Full name of the reference contact.
-
#job_title ⇒ String?
Job title of the reference contact.
-
#organization ⇒ String?
Organization the reference contact belongs to.
-
#phone_e164 ⇒ String?
Reference phone number in E.164 format.
- #ref_type ⇒ Symbol, Telnyx::Models::Dir::ReferenceUpdateParams::RefType
-
#relationship_to_registrant ⇒ String?
How the reference contact is related to the registering business.
- #slot ⇒ Integer
-
#timezone ⇒ String?
IANA timezone id for the reference.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
51 |
# File 'sig/telnyx/models/dir/reference_update_params.rbs', line 51
def initialize: (
|
Instance Attribute Details
#dir_id ⇒ String
14 |
# File 'lib/telnyx/models/dir/reference_update_params.rb', line 14 required :dir_id, String |
#email ⇒ String?
Reference contact email address.
30 |
# File 'lib/telnyx/models/dir/reference_update_params.rb', line 30 optional :email, String |
#full_name ⇒ String?
Full name of the reference contact.
36 |
# File 'lib/telnyx/models/dir/reference_update_params.rb', line 36 optional :full_name, String |
#job_title ⇒ String?
Job title of the reference contact.
42 |
# File 'lib/telnyx/models/dir/reference_update_params.rb', line 42 optional :job_title, String, nil?: true |
#organization ⇒ String?
Organization the reference contact belongs to.
48 |
# File 'lib/telnyx/models/dir/reference_update_params.rb', line 48 optional :organization, String, nil?: true |
#phone_e164 ⇒ String?
Reference phone number in E.164 format.
54 |
# File 'lib/telnyx/models/dir/reference_update_params.rb', line 54 optional :phone_e164, String |
#ref_type ⇒ Symbol, Telnyx::Models::Dir::ReferenceUpdateParams::RefType
19 |
# File 'lib/telnyx/models/dir/reference_update_params.rb', line 19 required :ref_type, enum: -> { Telnyx::Dir::ReferenceUpdateParams::RefType } |
#relationship_to_registrant ⇒ String?
How the reference contact is related to the registering business.
60 |
# File 'lib/telnyx/models/dir/reference_update_params.rb', line 60 optional :relationship_to_registrant, String, nil?: true |
#slot ⇒ Integer
24 |
# File 'lib/telnyx/models/dir/reference_update_params.rb', line 24 required :slot, Integer |
#timezone ⇒ String?
IANA timezone id for the reference.
66 |
# File 'lib/telnyx/models/dir/reference_update_params.rb', line 66 optional :timezone, String |
Instance Method Details
#to_hash ⇒ {
65 |
# File 'sig/telnyx/models/dir/reference_update_params.rbs', line 65
def to_hash: -> {
|