Class: Telnyx::Models::DirCreateLoaParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/dir_create_loa_params.rb

Overview

Defined Under Namespace

Classes: Agent, Signature

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(administrative_area:, city:, contact_email:, contact_name:, contact_phone:, contact_title:, country:, legal_name:, postal_code:, street_address:, dba: nil, extended_address: nil) ⇒ Object

Third-party reseller / partner managing the enterprise’s phone numbers. Omit when the enterprise works directly with Telnyx.

Parameters:

  • administrative_area (String)
  • city (String)
  • contact_email (String)
  • contact_name (String)
  • contact_phone (String)
  • contact_title (String)
  • country (String)
  • legal_name (String)
  • postal_code (String)
  • street_address (String)
  • dba (String, nil) (defaults to: nil)
  • extended_address (String, nil) (defaults to: nil)


# File 'lib/telnyx/models/dir_create_loa_params.rb', line 112

Instance Attribute Details

#agentTelnyx::Models::DirCreateLoaParams::Agent?

Third-party reseller / partner managing the enterprise’s phone numbers. Omit when the enterprise works directly with Telnyx.



27
# File 'lib/telnyx/models/dir_create_loa_params.rb', line 27

optional :agent, -> { Telnyx::DirCreateLoaParams::Agent }

#dir_idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/dir_create_loa_params.rb', line 13

required :dir_id, String

#phone_numbersArray<String>

Telephone numbers to authorize on the DIR, in ‘+E164` format (`+` followed by 10-15 digits). Max 15 per request.

Returns:

  • (Array<String>)


20
# File 'lib/telnyx/models/dir_create_loa_params.rb', line 20

required :phone_numbers, Telnyx::Internal::Type::ArrayOf[String]

#signatureTelnyx::Models::DirCreateLoaParams::Signature?

Optional. When provided the rendered PDF embeds the signature image, printed name, and signed-at date. When absent the PDF is returned unsigned so the customer can sign externally and upload it via the Documents API.



35
# File 'lib/telnyx/models/dir_create_loa_params.rb', line 35

optional :signature, -> { Telnyx::DirCreateLoaParams::Signature }