Class: Telnyx::Models::DirLoaParams::Signature

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/dir_loa_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(image_base64:, signer_name: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::DirLoaParams::Signature for more details.

Optional. When provided the rendered PDF embeds the signature image, printed name, and signed-at date. When absent the PDF is returned unsigned so the customer can sign externally and upload it via the Documents API.

Parameters:

  • image_base64 (String)

    PNG image, base64-encoded.

  • signer_name (String, nil) (defaults to: nil)

    Optional. When absent the rendered PDF falls back to the enterprise contact’s le



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/telnyx/models/dir_loa_params.rb', line 51

class Signature < Telnyx::Internal::Type::BaseModel
  # @!attribute image_base64
  #   PNG image, base64-encoded.
  #
  #   @return [String]
  required :image_base64, String

  # @!attribute signer_name
  #   Optional. When absent the rendered PDF falls back to the enterprise contact's
  #   legal name.
  #
  #   @return [String, nil]
  optional :signer_name, String, nil?: true

  # @!method initialize(image_base64:, signer_name: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::DirLoaParams::Signature} for more details.
  #
  #   Optional. When provided the rendered PDF embeds the signature image, printed
  #   name, and signed-at date. When absent the PDF is returned unsigned so the
  #   customer can sign externally and upload it via the Documents API.
  #
  #   @param image_base64 [String] PNG image, base64-encoded.
  #
  #   @param signer_name [String, nil] Optional. When absent the rendered PDF falls back to the enterprise contact's le
end

Instance Attribute Details

#image_base64String

PNG image, base64-encoded.

Returns:

  • (String)


56
# File 'lib/telnyx/models/dir_loa_params.rb', line 56

required :image_base64, String

#signer_nameString?

Optional. When absent the rendered PDF falls back to the enterprise contact’s legal name.

Returns:

  • (String, nil)


63
# File 'lib/telnyx/models/dir_loa_params.rb', line 63

optional :signer_name, String, nil?: true