Class: Telnyx::Models::DirRetrieveResponse::Data::Document
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DirRetrieveResponse::Data::Document
- Defined in:
- lib/telnyx/models/dir_retrieve_response.rb
Defined Under Namespace
Modules: DocumentType
Instance Attribute Summary collapse
- #description ⇒ String?
-
#document_id ⇒ String
Id returned by the Telnyx Documents API after you upload the file (upload via ‘POST /v2/documents`; see developers.telnyx.com/api/documents).
-
#document_type ⇒ Symbol, Telnyx::Models::DirRetrieveResponse::Data::Document::DocumentType
Type of supporting document.
Instance Method Summary collapse
-
#initialize(document_id:, document_type:, description: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Document for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(document_id:, document_type:, description: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::DirRetrieveResponse::Data::Document for more details.
|
|
# File 'lib/telnyx/models/dir_retrieve_response.rb', line 223
|
Instance Attribute Details
#description ⇒ String?
221 |
# File 'lib/telnyx/models/dir_retrieve_response.rb', line 221 optional :description, String |
#document_id ⇒ String
Id returned by the Telnyx Documents API after you upload the file (upload via ‘POST /v2/documents`; see developers.telnyx.com/api/documents).
208 |
# File 'lib/telnyx/models/dir_retrieve_response.rb', line 208 required :document_id, String |
#document_type ⇒ Symbol, Telnyx::Models::DirRetrieveResponse::Data::Document::DocumentType
Type of supporting document. Pick the closest match to what the file actually contains; ‘other` triggers manual vetting and may slow approval. The matching short_name reference list is at `GET /v2/dir/document_types`.
216 |
# File 'lib/telnyx/models/dir_retrieve_response.rb', line 216 required :document_type, enum: -> { Telnyx::Models::DirRetrieveResponse::Data::Document::DocumentType } |