Class: Telnyx::Models::DocReqsRequirement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/doc_reqs_requirement.rb,
sig/telnyx/models/doc_reqs_requirement.rbs

Overview

See Also:

  • Telnyx::Resources::Requirements#list

Defined Under Namespace

Modules: Action, PhoneNumberType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, action: nil, country_code: nil, created_at: nil, effective_end_at: nil, effective_start_at: nil, locality: nil, phone_number_type: nil, record_type: nil, requirement_types: nil, updated_at: nil, version: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::DocReqsRequirement for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the associated document

  • action (Symbol, Telnyx::Models::DocReqsRequirement::Action) (defaults to: nil)

    Indicates whether this requirement applies to branded_calling, ordering, porting

  • country_code (String) (defaults to: nil)

    The 2-character (ISO 3166-1 alpha-2) country code where this requirement applies

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • effective_end_at (Time, nil) (defaults to: nil)

    When this version was superseded. NULL means this is the active or pending versi

  • effective_start_at (Time, nil) (defaults to: nil)

    When this version became (or will become) active.

  • locality (String) (defaults to: nil)

    The locality where this requirement applies

  • phone_number_type (Symbol, Telnyx::Models::DocReqsRequirement::PhoneNumberType) (defaults to: nil)

    Indicates the phone_number_type this requirement applies to. Leave blank if this

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • requirement_types (Array<Telnyx::Models::DocReqsRequirementType>) (defaults to: nil)

    Lists the requirement types necessary to fulfill this requirement

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was last updated.

  • version (Integer) (defaults to: nil)

    Version number. Increments with each new version. Defaults to 1.



# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 84

Instance Attribute Details

#actionSymbol, ...

Indicates whether this requirement applies to branded_calling, ordering, porting, or both ordering and porting



12
# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 12

optional :action, enum: -> { Telnyx::DocReqsRequirement::Action }

#country_codeString?

The 2-character (ISO 3166-1 alpha-2) country code where this requirement applies

Parameters:

  • (String)

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 18

optional :country_code, String

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


44
45
46
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 44

def created_at
  @created_at
end

#effective_end_atTime?

Returns the value of attribute effective_end_at.

Returns:

  • (Time, nil)


48
49
50
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 48

def effective_end_at
  @effective_end_at
end

#effective_start_atTime?

Returns the value of attribute effective_start_at.

Returns:

  • (Time, nil)


50
51
52
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 50

def effective_start_at
  @effective_start_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


40
41
42
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 40

def id
  @id
end

#localityString?

The locality where this requirement applies

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 24

optional :locality, String

#phone_number_typeSymbol, ...

Indicates the phone_number_type this requirement applies to. Leave blank if this requirement applies to all number_types.



31
# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 31

optional :phone_number_type, enum: -> { Telnyx::DocReqsRequirement::PhoneNumberType }

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


52
53
54
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 52

def record_type
  @record_type
end

#requirement_types::Array[Telnyx::DocReqsRequirementType]? (readonly)

Returns the value of attribute requirement_types.

Returns:



56
57
58
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 56

def requirement_types
  @requirement_types
end

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


62
63
64
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 62

def updated_at
  @updated_at
end

#versionInteger? (readonly)

Returns the value of attribute version.

Returns:

  • (Integer, nil)


66
67
68
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 66

def version
  @version
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 124

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


46
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 46

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


42
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 42

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


54
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 54

def record_type=: (String) -> String

#requirement_types=Object (readonly)



58
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 58

def requirement_types=: (

#to_hash{

Returns:

  • ({)


85
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 85

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


64
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 64

def updated_at=: (String) -> String

#version=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


68
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 68

def version=: (Integer) -> Integer