Class: Telnyx::Models::DocReqsRequirementType::AcceptanceCriteria
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DocReqsRequirementType::AcceptanceCriteria
- Defined in:
- lib/telnyx/models/doc_reqs_requirement_type.rb
Overview
Instance Attribute Summary collapse
-
#acceptable_characters ⇒ String?
Specifies the allowed characters as a string.
-
#acceptable_values ⇒ Array<String>?
Specifies the list of strictly possible values for the requirement.
-
#locality_limit ⇒ String?
Specifies geography-based acceptance criteria.
-
#max_length ⇒ Integer?
Maximum length allowed for the value.
-
#min_length ⇒ Integer?
Minimum length allowed for the value.
-
#time_limit ⇒ String?
Specifies time-based acceptance criteria.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#acceptable_characters ⇒ String?
Specifies the allowed characters as a string
87 |
# File 'lib/telnyx/models/doc_reqs_requirement_type.rb', line 87 optional :acceptable_characters, String |
#acceptable_values ⇒ Array<String>?
Specifies the list of strictly possible values for the requirement. Ignored when empty
94 |
# File 'lib/telnyx/models/doc_reqs_requirement_type.rb', line 94 optional :acceptable_values, Telnyx::Internal::Type::ArrayOf[String] |
#locality_limit ⇒ String?
Specifies geography-based acceptance criteria
100 |
# File 'lib/telnyx/models/doc_reqs_requirement_type.rb', line 100 optional :locality_limit, String |
#max_length ⇒ Integer?
Maximum length allowed for the value
106 |
# File 'lib/telnyx/models/doc_reqs_requirement_type.rb', line 106 optional :max_length, Integer |
#min_length ⇒ Integer?
Minimum length allowed for the value
112 |
# File 'lib/telnyx/models/doc_reqs_requirement_type.rb', line 112 optional :min_length, Integer |
#time_limit ⇒ String?
Specifies time-based acceptance criteria
118 |
# File 'lib/telnyx/models/doc_reqs_requirement_type.rb', line 118 optional :time_limit, String |