Class: Telnyx::Models::Document

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/document.rb,
sig/telnyx/models/document.rbs

Defined Under Namespace

Modules: DocumentType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(document_id:, document_type:, description: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Document for more details.

Parameters:

  • document_id (String)

    Id returned by the Telnyx Documents API after you upload the file (upload via `P

  • document_type (Symbol, Telnyx::Models::Document::DocumentType)

    Type of supporting document. Pick the closest match to what the file actually co

  • description (String) (defaults to: nil)


# File 'lib/telnyx/models/document.rb', line 26

Instance Attribute Details

#descriptionString?

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/document.rb', line 24

optional :description, String

#document_idString

Id returned by the Telnyx Documents API after you upload the file (upload via POST /v2/documents; see https://developers.telnyx.com/api/documents).

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/telnyx/models/document.rb', line 11

required :document_id, String

#document_typeSymbol, Telnyx::Models::Document::DocumentType

Type of supporting document. Pick the closest match to what the file actually contains; other triggers manual vetting and may slow approval. The matching short_name reference list is at GET /v2/dir/document_types.

Parameters:

  • value (Telnyx::Models::Document::document_type)

Returns:



19
# File 'lib/telnyx/models/document.rb', line 19

required :document_type, enum: -> { Telnyx::Document::DocumentType }

Instance Method Details

#to_hash{

Returns:

  • ({)


25
# File 'sig/telnyx/models/document.rbs', line 25

def to_hash: -> {