Class: Telnyx::Models::DocumentUploadParams::Document

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/document_upload_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(customer_reference: nil, file: nil, filename: nil, url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::DocumentUploadParams::Document for more details.

Parameters:

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • file (String) (defaults to: nil)

    Alternatively, instead of the URL you can provide the Base64 encoded contents of

  • filename (String) (defaults to: nil)

    The filename of the document.

  • url (String) (defaults to: nil)

    If the file is already hosted publicly, you can provide a URL and have the docum



19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/telnyx/models/document_upload_params.rb', line 19

class Document < Telnyx::Internal::Type::BaseModel
  # @!attribute customer_reference
  #   A customer reference string for customer look ups.
  #
  #   @return [String, nil]
  optional :customer_reference, String

  # @!attribute file
  #   Alternatively, instead of the URL you can provide the Base64 encoded contents of
  #   the file you are uploading.
  #
  #   @return [String, nil]
  optional :file, String

  # @!attribute filename
  #   The filename of the document.
  #
  #   @return [String, nil]
  optional :filename, String

  # @!attribute url
  #   If the file is already hosted publicly, you can provide a URL and have the
  #   documents service fetch it for you.
  #
  #   @return [String, nil]
  optional :url, String

  # @!method initialize(customer_reference: nil, file: nil, filename: nil, url: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::DocumentUploadParams::Document} for more details.
  #
  #   @param customer_reference [String] A customer reference string for customer look ups.
  #
  #   @param file [String] Alternatively, instead of the URL you can provide the Base64 encoded contents of
  #
  #   @param filename [String] The filename of the document.
  #
  #   @param url [String] If the file is already hosted publicly, you can provide a URL and have the docum
end

Instance Attribute Details

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/document_upload_params.rb', line 24

optional :customer_reference, String

#fileString?

Alternatively, instead of the URL you can provide the Base64 encoded contents of the file you are uploading.

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/document_upload_params.rb', line 31

optional :file, String

#filenameString?

The filename of the document.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/document_upload_params.rb', line 37

optional :filename, String

#urlString?

If the file is already hosted publicly, you can provide a URL and have the documents service fetch it for you.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/document_upload_params.rb', line 44

optional :url, String