Class: Telnyx::Models::DynamicEmergencyAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/dynamic_emergency_address.rb,
sig/telnyx/models/dynamic_emergency_address.rbs

Overview

See Also:

  • Telnyx::Resources::DynamicEmergencyAddresses#list

Direct Known Subclasses

DynamicEmergencyAddressCreateParams

Defined Under Namespace

Modules: CountryCode, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(administrative_area:, country_code:, house_number:, locality:, postal_code:, street_name:, id: nil, created_at: nil, extended_address: nil, house_suffix: nil, record_type: nil, sip_geolocation_id: nil, status: nil, street_post_directional: nil, street_pre_directional: nil, street_suffix: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::DynamicEmergencyAddress for more details.

Parameters:

  • administrative_area (String)
  • country_code (Symbol, Telnyx::Models::DynamicEmergencyAddress::CountryCode)
  • house_number (String)
  • locality (String)
  • postal_code (String)
  • street_name (String)
  • id (String) (defaults to: nil)
  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the resource was created

  • extended_address (String) (defaults to: nil)
  • house_suffix (String) (defaults to: nil)
  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • sip_geolocation_id (String) (defaults to: nil)

    Unique location reference string to be used in SIP INVITE from / p-asserted head

  • status (Symbol, Telnyx::Models::DynamicEmergencyAddress::Status) (defaults to: nil)

    Status of dynamic emergency address

  • street_post_directional (String) (defaults to: nil)
  • street_pre_directional (String) (defaults to: nil)
  • street_suffix (String) (defaults to: nil)
  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the resource was last updated



# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 100

Instance Attribute Details

#administrative_areaString

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 10

required :administrative_area, String

#country_codeSymbol, Telnyx::Models::DynamicEmergencyAddress::CountryCode

Parameters:

  • value (Telnyx::Models::DynamicEmergencyAddress::country_code)

Returns:



15
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 15

required :country_code, enum: -> { Telnyx::DynamicEmergencyAddress::CountryCode }

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


61
62
63
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 61

def created_at
  @created_at
end

#extended_addressString?

Parameters:

  • (String)

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 40

optional :extended_address, String

#house_numberString

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 20

required :house_number, String

#house_suffixString?

Parameters:

  • (String)

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 45

optional :house_suffix, String

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


57
58
59
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 57

def id
  @id
end

#localityString

Parameters:

  • value (String)

Returns:

  • (String)


25
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 25

required :locality, String

#postal_codeString

Parameters:

  • value (String)

Returns:

  • (String)


30
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 30

required :postal_code, String

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


65
66
67
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 65

def record_type
  @record_type
end

#sip_geolocation_idString? (readonly)

Returns the value of attribute sip_geolocation_id.

Returns:

  • (String, nil)


69
70
71
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 69

def sip_geolocation_id
  @sip_geolocation_id
end

#statusTelnyx::Models::DynamicEmergencyAddress::status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::DynamicEmergencyAddress::status, nil)


73
74
75
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 73

def status
  @status
end

#street_nameString

Parameters:

  • value (String)

Returns:

  • (String)


35
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 35

required :street_name, String

#street_post_directionalString?

Parameters:

  • (String)

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 50

optional :street_post_directional, String

#street_pre_directionalString?

Parameters:

  • (String)

Returns:

  • (String, nil)


55
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 55

optional :street_pre_directional, String

#street_suffixString?

Parameters:

  • (String)

Returns:

  • (String, nil)


60
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 60

optional :street_suffix, String

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


79
80
81
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 79

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 146

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


63
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 63

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


59
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 59

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


67
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 67

def record_type=: (String) -> String

#sip_geolocation_id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


71
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 71

def sip_geolocation_id=: (String) -> String

#status=Object (readonly)



75
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 75

def status=: (

#to_hash{

Returns:

  • ({)


103
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 103

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


81
# File 'sig/telnyx/models/dynamic_emergency_address.rbs', line 81

def updated_at=: (String) -> String