Class: Telnyx::Models::DynamicEmergencyEndpoint

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/dynamic_emergency_endpoint.rb,
sig/telnyx/models/dynamic_emergency_endpoint.rbs

Overview

See Also:

  • Telnyx::Resources::DynamicEmergencyEndpoints#list

Direct Known Subclasses

DynamicEmergencyEndpointCreateParams

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(callback_number:, caller_name:, dynamic_emergency_address_id:, id: nil, created_at: nil, record_type: nil, sip_from_id: nil, status: nil, updated_at: nil) ⇒ Object

Parameters:

  • callback_number (String)
  • caller_name (String)
  • dynamic_emergency_address_id (String)

    An id of a currently active dynamic emergency location.

  • id (String) (defaults to: nil)
  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the resource was created

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • sip_from_id (String) (defaults to: nil)
  • status (Symbol, Telnyx::Models::DynamicEmergencyEndpoint::Status) (defaults to: nil)

    Status of dynamic emergency address

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the resource was last updated



# File 'lib/telnyx/models/dynamic_emergency_endpoint.rb', line 59

Instance Attribute Details

#callback_numberString

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/telnyx/models/dynamic_emergency_endpoint.rb', line 10

required :callback_number, String

#caller_nameString

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/telnyx/models/dynamic_emergency_endpoint.rb', line 15

required :caller_name, String

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


27
28
29
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 27

def created_at
  @created_at
end

#dynamic_emergency_address_idString

An id of a currently active dynamic emergency location.

Parameters:

  • value (String)

Returns:

  • (String)


21
# File 'lib/telnyx/models/dynamic_emergency_endpoint.rb', line 21

required :dynamic_emergency_address_id, String

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


23
24
25
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 23

def id
  @id
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


31
32
33
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 31

def record_type
  @record_type
end

#sip_from_idString? (readonly)

Returns the value of attribute sip_from_id.

Returns:

  • (String, nil)


35
36
37
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 35

def sip_from_id
  @sip_from_id
end

#statusTelnyx::Models::DynamicEmergencyEndpoint::status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::DynamicEmergencyEndpoint::status, nil)


39
40
41
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 39

def status
  @status
end

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


45
46
47
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 45

def updated_at
  @updated_at
end

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


29
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 29

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


25
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 25

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


33
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 33

def record_type=: (String) -> String

#sip_from_id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


37
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 37

def sip_from_id=: (String) -> String

#status=Object (readonly)



41
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 41

def status=: (

#to_hash{

Returns:

  • ({)


61
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 61

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


47
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 47

def updated_at=: (String) -> String