Class: Telnyx::Models::EmailDomainListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/email_domain_list_params.rb,
sig/telnyx/models/email_domain_list_params.rbs

Overview

See Also:

  • Telnyx::Resources::EmailDomains#list

Defined Under Namespace

Modules: Sort

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filter_domain: nil, filter_profile_id: nil, filter_status: nil, filter_type: nil, filter_usable_for_inbound: nil, filter_usable_for_sending: nil, page_after: nil, page_before: nil, page_number: nil, page_size: nil, sort: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::EmailDomainListParams for more details.

Parameters:

  • filter_domain (String) (defaults to: nil)

    Partial match on domain name (case-insensitive)

  • filter_profile_id (String) (defaults to: nil)

    Filter by profile UUID

  • filter_status (Symbol, Telnyx::Models::EmailDomainStatus) (defaults to: nil)

    Filter domains by verification status: pending, verifying, verified, failed, deg

  • filter_type (Symbol, Telnyx::Models::EmailDomainType) (defaults to: nil)

    Filter domains by type: custom, shared, or shared_inbound.

  • filter_usable_for_inbound (Boolean) (defaults to: nil)

    Filter domains by whether they can currently receive inbound email.

  • filter_usable_for_sending (Boolean) (defaults to: nil)

    Filter domains by whether they can currently be used to send email.

  • page_after (String) (defaults to: nil)

    Cursor for records after the provided value (cursor pagination)

  • page_before (String) (defaults to: nil)

    Cursor for records before the provided value (cursor pagination)

  • page_number (Integer) (defaults to: nil)

    Page number to return (offset pagination)

  • page_size (Integer) (defaults to: nil)

    Number of records per page

  • sort (Symbol, Telnyx::Models::EmailDomainListParams::Sort) (defaults to: nil)

    Field to sort by. Prefix with - for descending order.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/email_domain_list_params.rb', line 77

Instance Attribute Details

#filter_domainString?

Partial match on domain name (case-insensitive)

Parameters:

  • (String)

Returns:

  • (String, nil)


14
# File 'lib/telnyx/models/email_domain_list_params.rb', line 14

optional :filter_domain, String

#filter_profile_idString?

Filter by profile UUID

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/email_domain_list_params.rb', line 20

optional :filter_profile_id, String

#filter_statusSymbol, ...

Filter domains by verification status: pending, verifying, verified, failed, degraded, or suspended.

Returns:



27
# File 'lib/telnyx/models/email_domain_list_params.rb', line 27

optional :filter_status, enum: -> { Telnyx::EmailDomainStatus }

#filter_typeSymbol, ...

Filter domains by type: custom, shared, or shared_inbound.

Returns:



33
# File 'lib/telnyx/models/email_domain_list_params.rb', line 33

optional :filter_type, enum: -> { Telnyx::EmailDomainType }

#filter_usable_for_inboundBoolean?

Filter domains by whether they can currently receive inbound email.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


39
# File 'lib/telnyx/models/email_domain_list_params.rb', line 39

optional :filter_usable_for_inbound, Telnyx::Internal::Type::Boolean

#filter_usable_for_sendingBoolean?

Filter domains by whether they can currently be used to send email.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


45
# File 'lib/telnyx/models/email_domain_list_params.rb', line 45

optional :filter_usable_for_sending, Telnyx::Internal::Type::Boolean

#page_afterString?

Cursor for records after the provided value (cursor pagination)

Parameters:

  • (String)

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/email_domain_list_params.rb', line 51

optional :page_after, String

#page_beforeString?

Cursor for records before the provided value (cursor pagination)

Parameters:

  • (String)

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/email_domain_list_params.rb', line 57

optional :page_before, String

#page_numberInteger?

Page number to return (offset pagination)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


63
# File 'lib/telnyx/models/email_domain_list_params.rb', line 63

optional :page_number, Integer

#page_sizeInteger?

Number of records per page

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


69
# File 'lib/telnyx/models/email_domain_list_params.rb', line 69

optional :page_size, Integer

#sortSymbol, ...

Field to sort by. Prefix with - for descending order.



75
# File 'lib/telnyx/models/email_domain_list_params.rb', line 75

optional :sort, enum: -> { Telnyx::EmailDomainListParams::Sort }

Instance Method Details

#to_hash{

Returns:

  • ({)


88
# File 'sig/telnyx/models/email_domain_list_params.rbs', line 88

def to_hash: -> {