Class: Telnyx::Models::EmailDomainRetrieveHealthResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::EmailDomainRetrieveHealthResponse::Data
- Defined in:
- lib/telnyx/models/email_domain_retrieve_health_response.rb,
sig/telnyx/models/email_domain_retrieve_health_response.rbs
Overview
Defined Under Namespace
Modules: RecordType, Status
Instance Attribute Summary collapse
-
#checked_at ⇒ Time
Timestamp of the last health check.
-
#id ⇒ String
Unique identifier for the email domain.
-
#record_type ⇒ Symbol, Telnyx::Models::EmailDomainRetrieveHealthResponse::Data::RecordType
Record type discriminator.
-
#status ⇒ Symbol, Telnyx::Models::EmailDomainRetrieveHealthResponse::Data::Status
Current domain status.
-
#usable_for_inbound ⇒ Boolean
Whether the domain is usable for receiving inbound email.
-
#usable_for_sending ⇒ Boolean
Whether the domain is usable for sending email.
- #verification ⇒ Telnyx::Models::EmailDomainVerification
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:, checked_at:, record_type:, status:, usable_for_inbound:, usable_for_sending:, verification:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, checked_at:, record_type:, status:, usable_for_inbound:, usable_for_sending:, verification:) ⇒ Object
|
|
# File 'lib/telnyx/models/email_domain_retrieve_health_response.rb', line 58
|
Instance Attribute Details
#checked_at ⇒ Time
Timestamp of the last health check
27 |
# File 'lib/telnyx/models/email_domain_retrieve_health_response.rb', line 27 required :checked_at, Time |
#id ⇒ String
Unique identifier for the email domain
21 |
# File 'lib/telnyx/models/email_domain_retrieve_health_response.rb', line 21 required :id, String |
#record_type ⇒ Symbol, Telnyx::Models::EmailDomainRetrieveHealthResponse::Data::RecordType
Record type discriminator
33 |
# File 'lib/telnyx/models/email_domain_retrieve_health_response.rb', line 33 required :record_type, enum: -> { Telnyx::Models::EmailDomainRetrieveHealthResponse::Data::RecordType } |
#status ⇒ Symbol, Telnyx::Models::EmailDomainRetrieveHealthResponse::Data::Status
Current domain status
39 |
# File 'lib/telnyx/models/email_domain_retrieve_health_response.rb', line 39 required :status, enum: -> { Telnyx::Models::EmailDomainRetrieveHealthResponse::Data::Status } |
#usable_for_inbound ⇒ Boolean
Whether the domain is usable for receiving inbound email
45 |
# File 'lib/telnyx/models/email_domain_retrieve_health_response.rb', line 45 required :usable_for_inbound, Telnyx::Internal::Type::Boolean |
#usable_for_sending ⇒ Boolean
Whether the domain is usable for sending email
51 |
# File 'lib/telnyx/models/email_domain_retrieve_health_response.rb', line 51 required :usable_for_sending, Telnyx::Internal::Type::Boolean |
#verification ⇒ Telnyx::Models::EmailDomainVerification
56 |
# File 'lib/telnyx/models/email_domain_retrieve_health_response.rb', line 56 required :verification, -> { Telnyx::EmailDomainVerification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/email_domain_retrieve_health_response.rb', line 81
|
Instance Method Details
#to_hash ⇒ {
53 |
# File 'sig/telnyx/models/email_domain_retrieve_health_response.rbs', line 53
def to_hash: -> {
|