Class: Telnyx::Models::EmailEventRetrieveStatsResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::EmailEventRetrieveStatsResponse::Data
- Defined in:
- lib/telnyx/models/email_event_retrieve_stats_response.rb,
sig/telnyx/models/email_event_retrieve_stats_response.rbs
Overview
Defined Under Namespace
Modules: RecordType Classes: Counts, Rates
Instance Attribute Summary collapse
-
#counts ⇒ Telnyx::Models::EmailEventRetrieveStatsResponse::Data::Counts
Recipient-level outcome counts for the queried time range.
-
#rates ⇒ Telnyx::Models::EmailEventRetrieveStatsResponse::Data::Rates
Recipient-level event rates as percentages, rounded to 2 decimal places.
- #record_type ⇒ Symbol, Telnyx::Models::EmailEventRetrieveStatsResponse::Data::RecordType
- #time_range ⇒ Telnyx::Models::TimeRange
Instance Method Summary collapse
-
#initialize(bounce_rate:, click_rate:, complaint_rate:, deferred_rate:, delivery_rate:, open_rate:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Rates for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bounce_rate:, click_rate:, complaint_rate:, deferred_rate:, delivery_rate:, open_rate:) ⇒ Object
Some parameter documentations has been truncated, see Rates for more details.
Recipient-level event rates as percentages, rounded to 2 decimal places.
|
|
# File 'lib/telnyx/models/email_event_retrieve_stats_response.rb', line 44
|
Instance Attribute Details
#counts ⇒ Telnyx::Models::EmailEventRetrieveStatsResponse::Data::Counts
Recipient-level outcome counts for the queried time range. Each to, cc, and bcc recipient counts separately; repeated events of the same type for the same message and recipient count once. Partial MTA injection results count successful recipients as sent and unsuccessful recipients as failed. Only the ten listed event types are counted; other valid event types (scheduled, cancelled, sandbox, sending, rejected) are not included in stats.
26 |
# File 'lib/telnyx/models/email_event_retrieve_stats_response.rb', line 26 required :counts, -> { Telnyx::Models::EmailEventRetrieveStatsResponse::Data::Counts } |
#rates ⇒ Telnyx::Models::EmailEventRetrieveStatsResponse::Data::Rates
Recipient-level event rates as percentages, rounded to 2 decimal places.
32 |
# File 'lib/telnyx/models/email_event_retrieve_stats_response.rb', line 32 required :rates, -> { Telnyx::Models::EmailEventRetrieveStatsResponse::Data::Rates } |
#record_type ⇒ Symbol, Telnyx::Models::EmailEventRetrieveStatsResponse::Data::RecordType
37 |
# File 'lib/telnyx/models/email_event_retrieve_stats_response.rb', line 37 required :record_type, enum: -> { Telnyx::Models::EmailEventRetrieveStatsResponse::Data::RecordType } |
#time_range ⇒ Telnyx::Models::TimeRange
42 |
# File 'lib/telnyx/models/email_event_retrieve_stats_response.rb', line 42 required :time_range, -> { Telnyx::TimeRange } |
Instance Method Details
#to_hash ⇒ {
41 |
# File 'sig/telnyx/models/email_event_retrieve_stats_response.rbs', line 41
def to_hash: -> {
|