Class: Telnyx::Models::EmailInboxCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::EmailInboxCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/email_inbox_create_params.rb,
sig/telnyx/models/email_inbox_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#domain_id ⇒ String?
Account-owned, inbound-enabled domain UUID.
-
#username ⇒ String?
Inbox local part.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(domain_id: nil, username: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EmailInboxCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(domain_id: nil, username: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::EmailInboxCreateParams for more details.
|
|
# File 'lib/telnyx/models/email_inbox_create_params.rb', line 25
|
Instance Attribute Details
#domain_id ⇒ String?
Account-owned, inbound-enabled domain UUID. The account's shared inbound subdomain is allocated when omitted.
15 |
# File 'lib/telnyx/models/email_inbox_create_params.rb', line 15 optional :domain_id, String |
#username ⇒ String?
Inbox local part. Trimmed and lowercased before validation; the normalized value must be 1-64 characters, start and end with a letter or digit, and contain only letters, digits, dots, hyphens, and underscores. Generated when omitted.
23 |
# File 'lib/telnyx/models/email_inbox_create_params.rb', line 23 optional :username, String |
Instance Method Details
#to_hash ⇒ {
25 |
# File 'sig/telnyx/models/email_inbox_create_params.rbs', line 25
def to_hash: -> {
|