Class: Telnyx::Models::EmailInboxes::Messages::ActionForwardParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::EmailInboxes::Messages::ActionForwardParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/email_inboxes/messages/action_forward_params.rb,
sig/telnyx/models/email_inboxes/messages/action_forward_params.rbs
Overview
Defined Under Namespace
Modules: To
Instance Attribute Summary collapse
-
#bcc ⇒ String, ...
One recipient or a recipient array.
-
#cc ⇒ String, ...
One recipient or a recipient array.
-
#html ⇒ String?
Optional HTML note prepended to the generated forwarded-message block.
- #inbox_id ⇒ String
- #message_id ⇒ String
-
#text ⇒ String?
Optional plain-text note prepended to the generated forwarded-message block.
-
#to ⇒ String, ...
One recipient or a non-empty recipient array.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(inbox_id:, message_id:, to:, bcc: nil, cc: nil, html: nil, text: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionForwardParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(inbox_id:, message_id:, to:, bcc: nil, cc: nil, html: nil, text: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::EmailInboxes::Messages::ActionForwardParams for more details.
|
|
# File 'lib/telnyx/models/email_inboxes/messages/action_forward_params.rb', line 57
|
Instance Attribute Details
#bcc ⇒ String, ...
One recipient or a recipient array. Each recipient may be an email string or an
object with email and optional name.
34 |
# File 'lib/telnyx/models/email_inboxes/messages/action_forward_params.rb', line 34 optional :bcc, union: -> { Telnyx::EmailInboxes::Messages::InboxActionRecipientInput } |
#cc ⇒ String, ...
One recipient or a recipient array. Each recipient may be an email string or an
object with email and optional name.
41 |
# File 'lib/telnyx/models/email_inboxes/messages/action_forward_params.rb', line 41 optional :cc, union: -> { Telnyx::EmailInboxes::Messages::InboxActionRecipientInput } |
#html ⇒ String?
Optional HTML note prepended to the generated forwarded-message block. Blank values are treated as omitted.
48 |
# File 'lib/telnyx/models/email_inboxes/messages/action_forward_params.rb', line 48 optional :html, String |
#inbox_id ⇒ String
15 |
# File 'lib/telnyx/models/email_inboxes/messages/action_forward_params.rb', line 15 required :inbox_id, String |
#message_id ⇒ String
20 |
# File 'lib/telnyx/models/email_inboxes/messages/action_forward_params.rb', line 20 required :message_id, String |
#text ⇒ String?
Optional plain-text note prepended to the generated forwarded-message block. Blank values are treated as omitted.
55 |
# File 'lib/telnyx/models/email_inboxes/messages/action_forward_params.rb', line 55 optional :text, String |
#to ⇒ String, ...
One recipient or a non-empty recipient array. Each recipient may be an email
string or an object with email and optional name.
27 |
# File 'lib/telnyx/models/email_inboxes/messages/action_forward_params.rb', line 27 required :to, union: -> { Telnyx::EmailInboxes::Messages::ActionForwardParams::To } |
Instance Method Details
#to_hash ⇒ {
58 |
# File 'sig/telnyx/models/email_inboxes/messages/action_forward_params.rbs', line 58
def to_hash: -> {
|