Class: Telnyx::Models::EmailMessageBatchParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::EmailMessageBatchParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/email_message_batch_params.rb,
sig/telnyx/models/email_message_batch_params.rbs
Overview
Defined Under Namespace
Classes: Message
Instance Attribute Summary collapse
- #idempotency_key ⇒ String?
- #messages ⇒ Array<Telnyx::Models::EmailMessageBatchParams::Message>
-
#sandbox_mode ⇒ Boolean?
Applies sandbox mode to all messages in the batch.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
25 |
# File 'sig/telnyx/models/email_message_batch_params.rbs', line 25
def initialize: (
|
Instance Attribute Details
#idempotency_key ⇒ String?
25 |
# File 'lib/telnyx/models/email_message_batch_params.rb', line 25 optional :idempotency_key, String |
#messages ⇒ Array<Telnyx::Models::EmailMessageBatchParams::Message>
13 |
# File 'lib/telnyx/models/email_message_batch_params.rb', line 13 required :messages, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::EmailMessageBatchParams::Message] } |
#sandbox_mode ⇒ Boolean?
Applies sandbox mode to all messages in the batch. Overrides any per-message sandbox_mode in the messages array.
20 |
# File 'lib/telnyx/models/email_message_batch_params.rb', line 20 optional :sandbox_mode, Telnyx::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/telnyx/models/email_message_batch_params.rbs', line 32
def to_hash: -> {
|