Class: Telnyx::Models::Enterprises::Reputation::LoaRenderParams::Signature

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/enterprises/reputation/loa_render_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(image_base64:, signer_name: nil) ⇒ Object

Optional signature embedded in the rendered PDF. When omitted the PDF is returned unsigned for the customer to sign and upload.

Parameters:

  • image_base64 (String)

    Base64-encoded signature image.

  • signer_name (String, nil) (defaults to: nil)


43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/telnyx/models/enterprises/reputation/loa_render_params.rb', line 43

class Signature < Telnyx::Internal::Type::BaseModel
  # @!attribute image_base64
  #   Base64-encoded signature image.
  #
  #   @return [String]
  required :image_base64, String

  # @!attribute signer_name
  #
  #   @return [String, nil]
  optional :signer_name, String, nil?: true

  # @!method initialize(image_base64:, signer_name: nil)
  #   Optional signature embedded in the rendered PDF. When omitted the PDF is
  #   returned unsigned for the customer to sign and upload.
  #
  #   @param image_base64 [String] Base64-encoded signature image.
  #
  #   @param signer_name [String, nil]
end

Instance Attribute Details

#image_base64String

Base64-encoded signature image.

Returns:

  • (String)


48
# File 'lib/telnyx/models/enterprises/reputation/loa_render_params.rb', line 48

required :image_base64, String

#signer_nameString?

Returns:

  • (String, nil)


53
# File 'lib/telnyx/models/enterprises/reputation/loa_render_params.rb', line 53

optional :signer_name, String, nil?: true