Class: Telnyx::Models::Enterprises::Reputation::NumberAssociateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/enterprises/reputation/number_associate_response.rb

Overview

Defined Under Namespace

Classes: Data, Meta

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, enterprise_id: nil, phone_number: nil, reputation_data: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)
  • created_at (Time) (defaults to: nil)
  • enterprise_id (String) (defaults to: nil)
  • phone_number (String) (defaults to: nil)

    E.164 with leading ‘+`.

  • reputation_data (Telnyx::Models::ReputationData, nil) (defaults to: nil)

    ‘null` until the first refresh has been collected for this number.

  • updated_at (Time) (defaults to: nil)


# File 'lib/telnyx/models/enterprises/reputation/number_associate_response.rb', line 68

Instance Attribute Details

#dataArray<Telnyx::Models::Enterprises::Reputation::NumberAssociateResponse::Data>



12
13
# File 'lib/telnyx/models/enterprises/reputation/number_associate_response.rb', line 12

required :data,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::Enterprises::Reputation::NumberAssociateResponse::Data] }

#metaTelnyx::Models::Enterprises::Reputation::NumberAssociateResponse::Meta

JSON:API pagination metadata returned with every paginated list response. Page numbering is 1-based. ‘page_size` reports the number of items actually returned in `data` for this page; the requested size is taken from the `page` query parameter.



22
# File 'lib/telnyx/models/enterprises/reputation/number_associate_response.rb', line 22

required :meta, -> { Telnyx::Models::Enterprises::Reputation::NumberAssociateResponse::Meta }