Class: Telnyx::Models::Enterprises::Reputation::NumberAssociateResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Enterprises::Reputation::NumberAssociateResponse::Data
- Defined in:
- lib/telnyx/models/enterprises/reputation/number_associate_response.rb
Instance Attribute Summary collapse
- #enterprise_id ⇒ String?
-
#phone_number ⇒ String?
E.164 with leading ‘+`.
-
#reputation_data ⇒ Telnyx::Models::ReputationData?
‘null` until the first refresh has been collected for this number.
Instance Method Summary collapse
-
#initialize(data:, meta:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Telnyx::Models::Enterprises::Reputation::NumberAssociateResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data:, meta:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Enterprises::Reputation::NumberAssociateResponse for more details.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/telnyx/models/enterprises/reputation/number_associate_response.rb', line 33 class Data < Telnyx::Internal::Type::BaseModel # @!attribute enterprise_id # # @return [String, nil] optional :enterprise_id, String # @!attribute phone_number # E.164 with leading `+`. # # @return [String, nil] optional :phone_number, String # @!attribute reputation_data # `null` until the first refresh has been collected for this number. # # @return [Telnyx::Models::ReputationData, nil] optional :reputation_data, -> { Telnyx::ReputationData }, nil?: true response_only do # @!attribute id # # @return [String, nil] optional :id, String # @!attribute created_at # # @return [Time, nil] optional :created_at, Time # @!attribute updated_at # # @return [Time, nil] optional :updated_at, Time end # @!method initialize(id: nil, created_at: nil, enterprise_id: nil, phone_number: nil, reputation_data: nil, updated_at: nil) # @param id [String] # # @param created_at [Time] # # @param enterprise_id [String] # # @param phone_number [String] E.164 with leading `+`. # # @param reputation_data [Telnyx::Models::ReputationData, nil] `null` until the first refresh has been collected for this number. # # @param updated_at [Time] end |
Instance Attribute Details
#enterprise_id ⇒ String?
37 |
# File 'lib/telnyx/models/enterprises/reputation/number_associate_response.rb', line 37 optional :enterprise_id, String |
#phone_number ⇒ String?
E.164 with leading ‘+`.
43 |
# File 'lib/telnyx/models/enterprises/reputation/number_associate_response.rb', line 43 optional :phone_number, String |
#reputation_data ⇒ Telnyx::Models::ReputationData?
‘null` until the first refresh has been collected for this number.
49 |
# File 'lib/telnyx/models/enterprises/reputation/number_associate_response.rb', line 49 optional :reputation_data, -> { Telnyx::ReputationData }, nil?: true |