Class: Telnyx::Models::Enterprises::Reputation::ReputationPhoneNumber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Enterprises::Reputation::ReputationPhoneNumber
- Defined in:
- lib/telnyx/models/enterprises/reputation/reputation_phone_number.rb,
sig/telnyx/models/enterprises/reputation/reputation_phone_number.rbs
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
readonly
Returns the value of attribute created_at.
- #enterprise_id ⇒ String?
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#phone_number ⇒ String?
E.164 with leading
+. -
#reputation_data ⇒ Telnyx::Models::ReputationData?
nulluntil the first refresh has been collected for this number. -
#updated_at ⇒ Time?
readonly
Returns the value of attribute updated_at.
Instance Method Summary collapse
- #created_at ⇒ Time readonly
- #id ⇒ String readonly
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
- #updated_at ⇒ Time readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
40 |
# File 'sig/telnyx/models/enterprises/reputation/reputation_phone_number.rbs', line 40
def initialize: (
|
Instance Attribute Details
#created_at ⇒ Time? (readonly)
Returns the value of attribute created_at.
32 33 34 |
# File 'sig/telnyx/models/enterprises/reputation/reputation_phone_number.rbs', line 32 def created_at @created_at end |
#enterprise_id ⇒ String?
12 |
# File 'lib/telnyx/models/enterprises/reputation/reputation_phone_number.rb', line 12 optional :enterprise_id, String |
#id ⇒ String? (readonly)
Returns the value of attribute id.
28 29 30 |
# File 'sig/telnyx/models/enterprises/reputation/reputation_phone_number.rbs', line 28 def id @id end |
#phone_number ⇒ String?
E.164 with leading +.
18 |
# File 'lib/telnyx/models/enterprises/reputation/reputation_phone_number.rb', line 18 optional :phone_number, String |
#reputation_data ⇒ Telnyx::Models::ReputationData?
null until the first refresh has been collected for this number.
24 |
# File 'lib/telnyx/models/enterprises/reputation/reputation_phone_number.rb', line 24 optional :reputation_data, -> { Telnyx::ReputationData }, nil?: true |
#updated_at ⇒ Time? (readonly)
Returns the value of attribute updated_at.
36 37 38 |
# File 'sig/telnyx/models/enterprises/reputation/reputation_phone_number.rbs', line 36 def updated_at @updated_at end |
Instance Method Details
#created_at= ⇒ Time (readonly)
34 |
# File 'sig/telnyx/models/enterprises/reputation/reputation_phone_number.rbs', line 34
def created_at=: (Time) -> Time
|
#id= ⇒ String (readonly)
30 |
# File 'sig/telnyx/models/enterprises/reputation/reputation_phone_number.rbs', line 30
def id=: (String) -> String
|
#to_hash ⇒ {
49 |
# File 'sig/telnyx/models/enterprises/reputation/reputation_phone_number.rbs', line 49
def to_hash: -> {
|
#updated_at= ⇒ Time (readonly)
38 |
# File 'sig/telnyx/models/enterprises/reputation/reputation_phone_number.rbs', line 38
def updated_at=: (Time) -> Time
|