Class: Telnyx::Models::ExternalConnection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/external_connection.rb

Overview

Defined Under Namespace

Modules: ExternalSipConnection, WebhookAPIVersion Classes: Inbound, Outbound

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel_limit: nil, outbound_voice_profile_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Outbound for more details.

Parameters:

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the number of concurrent outbound calls to phone numbe

  • outbound_voice_profile_id (String) (defaults to: nil)

    Identifies the associated outbound voice profile.



# File 'lib/telnyx/models/external_connection.rb', line 91

Instance Attribute Details

#activeBoolean?

Specifies whether the connection can be used.

Returns:

  • (Boolean, nil)


17
# File 'lib/telnyx/models/external_connection.rb', line 17

optional :active, Telnyx::Internal::Type::Boolean

#created_atString?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/external_connection.rb', line 23

optional :created_at, String

#credential_activeBoolean?

If the credential associated with this service is active.

Returns:

  • (Boolean, nil)


29
# File 'lib/telnyx/models/external_connection.rb', line 29

optional :credential_active, Telnyx::Internal::Type::Boolean

#external_sip_connectionSymbol, ...

The service that will be consuming this connection.



35
# File 'lib/telnyx/models/external_connection.rb', line 35

optional :external_sip_connection, enum: -> { Telnyx::ExternalConnection::ExternalSipConnection }

#idString?

Uniquely identifies the resource.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/external_connection.rb', line 11

optional :id, String

#inboundTelnyx::Models::ExternalConnection::Inbound?



40
# File 'lib/telnyx/models/external_connection.rb', line 40

optional :inbound, -> { Telnyx::ExternalConnection::Inbound }

#outboundTelnyx::Models::ExternalConnection::Outbound?



45
# File 'lib/telnyx/models/external_connection.rb', line 45

optional :outbound, -> { Telnyx::ExternalConnection::Outbound }

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/external_connection.rb', line 51

optional :record_type, String

#tagsArray<String>?

Tags associated with the connection.

Returns:

  • (Array<String>, nil)


57
# File 'lib/telnyx/models/external_connection.rb', line 57

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#updated_atString?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (String, nil)


63
# File 'lib/telnyx/models/external_connection.rb', line 63

optional :updated_at, String

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1 or v2.



69
# File 'lib/telnyx/models/external_connection.rb', line 69

optional :webhook_api_version, enum: -> { Telnyx::ExternalConnection::WebhookAPIVersion }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


76
# File 'lib/telnyx/models/external_connection.rb', line 76

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


83
# File 'lib/telnyx/models/external_connection.rb', line 83

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


89
# File 'lib/telnyx/models/external_connection.rb', line 89

optional :webhook_timeout_secs, Integer, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/external_connection.rb', line 132