Class: Telnyx::Models::ExternalConnection::Inbound
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalConnection::Inbound
- Defined in:
- lib/telnyx/models/external_connection.rb,
sig/telnyx/models/external_connection.rbs
Overview
Instance Attribute Summary collapse
-
#channel_limit ⇒ Integer?
When set, this will limit the number of concurrent inbound calls to phone numbers associated with this connection.
Instance Method Summary collapse
-
#initialize ⇒ Inbound
constructor
A new instance of Inbound.
- #to_hash ⇒ { channel_limit: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Inbound
Returns a new instance of Inbound.
134 |
# File 'sig/telnyx/models/external_connection.rbs', line 134
def initialize: (?channel_limit: Integer) -> void
|
Instance Attribute Details
#channel_limit ⇒ Integer?
When set, this will limit the number of concurrent inbound calls to phone numbers associated with this connection.
143 |
# File 'lib/telnyx/models/external_connection.rb', line 143 optional :channel_limit, Integer |
Instance Method Details
#to_hash ⇒ { channel_limit: Integer }
136 |
# File 'sig/telnyx/models/external_connection.rbs', line 136
def to_hash: -> { channel_limit: Integer }
|