Class: Telnyx::Models::ExternalConnection::Outbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/external_connection.rb,
sig/telnyx/models/external_connection.rbs

Overview

See Also:

  • Telnyx::Models::ExternalConnection#outbound

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



151
# File 'sig/telnyx/models/external_connection.rbs', line 151

def initialize: (

Instance Attribute Details

#channel_limitInteger?

When set, this will limit the number of concurrent outbound calls to phone numbers associated with this connection.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


159
# File 'lib/telnyx/models/external_connection.rb', line 159

optional :channel_limit, Integer

#outbound_voice_profile_idString?

Identifies the associated outbound voice profile.

Parameters:

  • (String)

Returns:

  • (String, nil)


165
# File 'lib/telnyx/models/external_connection.rb', line 165

optional :outbound_voice_profile_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


156
# File 'sig/telnyx/models/external_connection.rbs', line 156

def to_hash: -> {