Class: Telnyx::Models::ExternalConnectionCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/external_connection_create_params.rb

Overview

Defined Under Namespace

Modules: ExternalSipConnection Classes: Inbound, Outbound

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel_limit: nil, outbound_voice_profile_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Outbound for more details.

Parameters:

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the number of concurrent outbound calls to phone numbe

  • outbound_voice_profile_id (String) (defaults to: nil)

    Identifies the associated outbound voice profile.



# File 'lib/telnyx/models/external_connection_create_params.rb', line 59

Instance Attribute Details

#activeBoolean?

Specifies whether the connection can be used.

Returns:

  • (Boolean, nil)


26
# File 'lib/telnyx/models/external_connection_create_params.rb', line 26

optional :active, Telnyx::Internal::Type::Boolean

#external_sip_connectionSymbol, Telnyx::Models::ExternalConnectionCreateParams::ExternalSipConnection

The service that will be consuming this connection.



14
15
# File 'lib/telnyx/models/external_connection_create_params.rb', line 14

required :external_sip_connection,
enum: -> { Telnyx::ExternalConnectionCreateParams::ExternalSipConnection }

#inboundTelnyx::Models::ExternalConnectionCreateParams::Inbound?



31
# File 'lib/telnyx/models/external_connection_create_params.rb', line 31

optional :inbound, -> { Telnyx::ExternalConnectionCreateParams::Inbound }

#outboundTelnyx::Models::ExternalConnectionCreateParams::Outbound



20
# File 'lib/telnyx/models/external_connection_create_params.rb', line 20

required :outbound, -> { Telnyx::ExternalConnectionCreateParams::Outbound }

#tagsArray<String>?

Tags associated with the connection.

Returns:

  • (Array<String>, nil)


37
# File 'lib/telnyx/models/external_connection_create_params.rb', line 37

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/external_connection_create_params.rb', line 44

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/external_connection_create_params.rb', line 51

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


57
# File 'lib/telnyx/models/external_connection_create_params.rb', line 57

optional :webhook_timeout_secs, Integer, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/external_connection_create_params.rb', line 87