Class: Telnyx::Models::ExternalConnectionCreateParams::Inbound
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalConnectionCreateParams::Inbound
- Defined in:
- lib/telnyx/models/external_connection_create_params.rb
Instance Attribute Summary collapse
-
#channel_limit ⇒ Integer?
When set, this will limit the number of concurrent inbound calls to phone numbers associated with this connection.
-
#outbound_voice_profile_id ⇒ String
The ID of the outbound voice profile to use for inbound calls.
Instance Method Summary collapse
-
#initialize(outbound_voice_profile_id:, channel_limit: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Inbound for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(outbound_voice_profile_id:, channel_limit: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ExternalConnectionCreateParams::Inbound for more details.
|
|
# File 'lib/telnyx/models/external_connection_create_params.rb', line 128
|
Instance Attribute Details
#channel_limit ⇒ Integer?
When set, this will limit the number of concurrent inbound calls to phone numbers associated with this connection.
126 |
# File 'lib/telnyx/models/external_connection_create_params.rb', line 126 optional :channel_limit, Integer |
#outbound_voice_profile_id ⇒ String
The ID of the outbound voice profile to use for inbound calls.
119 |
# File 'lib/telnyx/models/external_connection_create_params.rb', line 119 required :outbound_voice_profile_id, String |