Class: Telnyx::Models::ExternalConnectionCreateParams::Outbound
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalConnectionCreateParams::Outbound
- Defined in:
- lib/telnyx/models/external_connection_create_params.rb,
sig/telnyx/models/external_connection_create_params.rbs
Instance Attribute Summary collapse
-
#channel_limit ⇒ Integer?
When set, this will limit the number of concurrent outbound calls to phone numbers associated with this connection.
-
#outbound_voice_profile_id ⇒ String?
Identifies the associated outbound voice profile.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
92 |
# File 'sig/telnyx/models/external_connection_create_params.rbs', line 92
def initialize: (
|
Instance Attribute Details
#channel_limit ⇒ Integer?
When set, this will limit the number of concurrent outbound calls to phone numbers associated with this connection.
97 |
# File 'lib/telnyx/models/external_connection_create_params.rb', line 97 optional :channel_limit, Integer |
#outbound_voice_profile_id ⇒ String?
Identifies the associated outbound voice profile.
103 |
# File 'lib/telnyx/models/external_connection_create_params.rb', line 103 optional :outbound_voice_profile_id, String |
Instance Method Details
#to_hash ⇒ {
97 |
# File 'sig/telnyx/models/external_connection_create_params.rbs', line 97
def to_hash: -> {
|