Class: Telnyx::Models::ExternalConnectionUpdateParams::Outbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/external_connection_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, outbound:, active: nil, inbound: nil, tags: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ExternalConnectionUpdateParams for more details.

Parameters:

  • id (String)
  • outbound (Telnyx::Models::ExternalConnectionUpdateParams::Outbound)
  • active (Boolean) (defaults to: nil)

    Specifies whether the connection can be used.

  • inbound (Telnyx::Models::ExternalConnectionUpdateParams::Inbound) (defaults to: nil)
  • tags (Array<String>) (defaults to: nil)

    Tags associated with the connection.

  • webhook_event_failover_url (String, nil) (defaults to: nil)

    The failover URL where webhooks related to this connection will be sent if sendi

  • webhook_event_url (String) (defaults to: nil)

    The URL where webhooks related to this connection will be sent. Must include a s

  • webhook_timeout_secs (Integer, nil) (defaults to: nil)

    Specifies how many seconds to wait before timing out a webhook.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/telnyx/models/external_connection_update_params.rb', line 79

class Outbound < Telnyx::Internal::Type::BaseModel
  # @!attribute outbound_voice_profile_id
  #   Identifies the associated outbound voice profile.
  #
  #   @return [String]
  required :outbound_voice_profile_id, String

  # @!attribute channel_limit
  #   When set, this will limit the number of concurrent outbound calls to phone
  #   numbers associated with this connection.
  #
  #   @return [Integer, nil]
  optional :channel_limit, Integer

  # @!method initialize(outbound_voice_profile_id:, channel_limit: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::ExternalConnectionUpdateParams::Outbound} for more details.
  #
  #   @param outbound_voice_profile_id [String] Identifies the associated outbound voice profile.
  #
  #   @param channel_limit [Integer] When set, this will limit the number of concurrent outbound calls to phone numbe
end

Instance Attribute Details

#channel_limitInteger?

When set, this will limit the number of concurrent outbound calls to phone numbers associated with this connection.

Returns:

  • (Integer, nil)


91
# File 'lib/telnyx/models/external_connection_update_params.rb', line 91

optional :channel_limit, Integer

#outbound_voice_profile_idString

Identifies the associated outbound voice profile.

Returns:

  • (String)


84
# File 'lib/telnyx/models/external_connection_update_params.rb', line 84

required :outbound_voice_profile_id, String