Class: Telnyx::Models::ExternalConnections::CivicAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/external_connections/civic_address.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, city_or_town: nil, city_or_town_alias: nil, company_name: nil, country: nil, country_or_district: nil, default_location_id: nil, description: nil, house_number: nil, house_number_suffix: nil, locations: nil, postal_or_zip_code: nil, record_type: nil, state_or_province: nil, street_name: nil, street_suffix: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the resource.

  • city_or_town (String) (defaults to: nil)
  • city_or_town_alias (String) (defaults to: nil)
  • company_name (String) (defaults to: nil)
  • country (String) (defaults to: nil)
  • country_or_district (String) (defaults to: nil)
  • default_location_id (String) (defaults to: nil)

    Identifies what is the default location in the list of locations.

  • description (String) (defaults to: nil)
  • house_number (String) (defaults to: nil)
  • house_number_suffix (String) (defaults to: nil)
  • locations (Array<Telnyx::Models::ExternalConnections::Location>) (defaults to: nil)
  • postal_or_zip_code (String) (defaults to: nil)
  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • state_or_province (String) (defaults to: nil)
  • street_name (String) (defaults to: nil)
  • street_suffix (String) (defaults to: nil)


# File 'lib/telnyx/models/external_connections/civic_address.rb', line 90

Instance Attribute Details

#city_or_townString?

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 16

optional :city_or_town, String

#city_or_town_aliasString?

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 21

optional :city_or_town_alias, String

#company_nameString?

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 26

optional :company_name, String

#countryString?

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 31

optional :country, String

#country_or_districtString?

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 36

optional :country_or_district, String

#default_location_idString?

Identifies what is the default location in the list of locations.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 42

optional :default_location_id, String

#descriptionString?

Returns:

  • (String, nil)


47
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 47

optional :description, String

#house_numberString?

Returns:

  • (String, nil)


52
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 52

optional :house_number, String

#house_number_suffixString?

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 57

optional :house_number_suffix, String

#idString?

Uniquely identifies the resource.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 11

optional :id, String

#locationsArray<Telnyx::Models::ExternalConnections::Location>?



62
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 62

optional :locations, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::ExternalConnections::Location] }

#postal_or_zip_codeString?

Returns:

  • (String, nil)


67
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 67

optional :postal_or_zip_code, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


73
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 73

optional :record_type, String

#state_or_provinceString?

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 78

optional :state_or_province, String

#street_nameString?

Returns:

  • (String, nil)


83
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 83

optional :street_name, String

#street_suffixString?

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/external_connections/civic_address.rb', line 88

optional :street_suffix, String