Class: Telnyx::Models::ExternalConnections::CivicAddressRetrieveResponse::Data::Location

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/external_connections/civic_address_retrieve_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, additional_info: nil, description: nil, is_default: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the resource.

  • additional_info (String) (defaults to: nil)
  • description (String) (defaults to: nil)
  • is_default (Boolean) (defaults to: nil)

    Represents whether the location is the default or not.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/telnyx/models/external_connections/civic_address_retrieve_response.rb', line 135

class Location < Telnyx::Internal::Type::BaseModel
  # @!attribute id
  #   Uniquely identifies the resource.
  #
  #   @return [String, nil]
  optional :id, String

  # @!attribute additional_info
  #
  #   @return [String, nil]
  optional :additional_info, String

  # @!attribute description
  #
  #   @return [String, nil]
  optional :description, String

  # @!attribute is_default
  #   Represents whether the location is the default or not.
  #
  #   @return [Boolean, nil]
  optional :is_default, Telnyx::Internal::Type::Boolean

  # @!method initialize(id: nil, additional_info: nil, description: nil, is_default: nil)
  #   @param id [String] Uniquely identifies the resource.
  #
  #   @param additional_info [String]
  #
  #   @param description [String]
  #
  #   @param is_default [Boolean] Represents whether the location is the default or not.
end

Instance Attribute Details

#additional_infoString?

Returns:

  • (String, nil)


145
# File 'lib/telnyx/models/external_connections/civic_address_retrieve_response.rb', line 145

optional :additional_info, String

#descriptionString?

Returns:

  • (String, nil)


150
# File 'lib/telnyx/models/external_connections/civic_address_retrieve_response.rb', line 150

optional :description, String

#idString?

Uniquely identifies the resource.

Returns:

  • (String, nil)


140
# File 'lib/telnyx/models/external_connections/civic_address_retrieve_response.rb', line 140

optional :id, String

#is_defaultBoolean?

Represents whether the location is the default or not.

Returns:

  • (Boolean, nil)


156
# File 'lib/telnyx/models/external_connections/civic_address_retrieve_response.rb', line 156

optional :is_default, Telnyx::Internal::Type::Boolean