Class: Telnyx::Models::ExternalConnections::LogMessageListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/external_connections/log_message_list_response.rb

Overview

Defined Under Namespace

Classes: Meta, Source

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_connection_id: nil, telephone_number: nil, ticket_id: nil) ⇒ Object

Parameters:

  • external_connection_id (String) (defaults to: nil)

    The external connection the log message is associated with, if any.

  • telephone_number (String) (defaults to: nil)

    The telephone number the log message is associated with, if any.

  • ticket_id (String) (defaults to: nil)

    The ticket ID for an operation that generated the log message, if any.



# File 'lib/telnyx/models/external_connections/log_message_list_response.rb', line 33

Instance Attribute Details

#codeString

Returns:

  • (String)


11
# File 'lib/telnyx/models/external_connections/log_message_list_response.rb', line 11

required :code, String

#detailString?

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/external_connections/log_message_list_response.rb', line 21

optional :detail, String

#metaTelnyx::Models::ExternalConnections::LogMessageListResponse::Meta?



26
# File 'lib/telnyx/models/external_connections/log_message_list_response.rb', line 26

optional :meta, -> { Telnyx::Models::ExternalConnections::LogMessageListResponse::Meta }

#sourceTelnyx::Models::ExternalConnections::LogMessageListResponse::Source?



31
# File 'lib/telnyx/models/external_connections/log_message_list_response.rb', line 31

optional :source, -> { Telnyx::Models::ExternalConnections::LogMessageListResponse::Source }

#titleString

Returns:

  • (String)


16
# File 'lib/telnyx/models/external_connections/log_message_list_response.rb', line 16

required :title, String