Class: Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/external_connections/log_message_retrieve_response.rb

Defined Under Namespace

Classes: Meta, Source

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_connection_id: nil, telephone_number: nil, ticket_id: nil) ⇒ Object

Parameters:

  • external_connection_id (String) (defaults to: nil)

    The external connection the log message is associated with, if any.

  • telephone_number (String) (defaults to: nil)

    The telephone number the log message is associated with, if any.

  • ticket_id (String) (defaults to: nil)

    The ticket ID for an operation that generated the log message, if any.



17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/telnyx/models/external_connections/log_message_retrieve_response.rb', line 17

class LogMessage < Telnyx::Internal::Type::BaseModel
  # @!attribute code
  #
  #   @return [String]
  required :code, String

  # @!attribute title
  #
  #   @return [String]
  required :title, String

  # @!attribute detail
  #
  #   @return [String, nil]
  optional :detail, String

  # @!attribute meta
  #
  #   @return [Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Meta, nil]
  optional :meta, -> { Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Meta }

  # @!attribute source
  #
  #   @return [Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Source, nil]
  optional :source,
           -> { Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Source }

  # @!method initialize(code:, title:, detail: nil, meta: nil, source: nil)
  #   @param code [String]
  #   @param title [String]
  #   @param detail [String]
  #   @param meta [Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Meta]
  #   @param source [Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Source]

  # @see Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage#meta
  class Meta < Telnyx::Internal::Type::BaseModel
    # @!attribute external_connection_id
    #   The external connection the log message is associated with, if any.
    #
    #   @return [String, nil]
    optional :external_connection_id, String

    # @!attribute telephone_number
    #   The telephone number the log message is associated with, if any.
    #
    #   @return [String, nil]
    optional :telephone_number, String

    # @!attribute ticket_id
    #   The ticket ID for an operation that generated the log message, if any.
    #
    #   @return [String, nil]
    optional :ticket_id, String

    # @!method initialize(external_connection_id: nil, telephone_number: nil, ticket_id: nil)
    #   @param external_connection_id [String] The external connection the log message is associated with, if any.
    #
    #   @param telephone_number [String] The telephone number the log message is associated with, if any.
    #
    #   @param ticket_id [String] The ticket ID for an operation that generated the log message, if any.
  end

  # @see Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage#source
  class Source < Telnyx::Internal::Type::BaseModel
    # @!attribute pointer
    #   JSON pointer (RFC6901) to the offending entity.
    #
    #   @return [String, nil]
    optional :pointer, String

    # @!method initialize(pointer: nil)
    #   @param pointer [String] JSON pointer (RFC6901) to the offending entity.
  end
end

Instance Attribute Details

#codeString

Returns:

  • (String)


21
# File 'lib/telnyx/models/external_connections/log_message_retrieve_response.rb', line 21

required :code, String

#detailString?

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/external_connections/log_message_retrieve_response.rb', line 31

optional :detail, String

#metaTelnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Meta?



36
# File 'lib/telnyx/models/external_connections/log_message_retrieve_response.rb', line 36

optional :meta, -> { Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Meta }

#sourceTelnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Source?



41
42
# File 'lib/telnyx/models/external_connections/log_message_retrieve_response.rb', line 41

optional :source,
-> { Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Source }

#titleString

Returns:

  • (String)


26
# File 'lib/telnyx/models/external_connections/log_message_retrieve_response.rb', line 26

required :title, String