Class: Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Meta
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalConnections::LogMessageRetrieveResponse::LogMessage::Meta
- Defined in:
- lib/telnyx/models/external_connections/log_message_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#external_connection_id ⇒ String?
The external connection the log message is associated with, if any.
-
#telephone_number ⇒ String?
The telephone number the log message is associated with, if any.
-
#ticket_id ⇒ String?
The ticket ID for an operation that generated the log message, if any.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#external_connection_id ⇒ String?
The external connection the log message is associated with, if any.
57 |
# File 'lib/telnyx/models/external_connections/log_message_retrieve_response.rb', line 57 optional :external_connection_id, String |
#telephone_number ⇒ String?
The telephone number the log message is associated with, if any.
63 |
# File 'lib/telnyx/models/external_connections/log_message_retrieve_response.rb', line 63 optional :telephone_number, String |
#ticket_id ⇒ String?
The ticket ID for an operation that generated the log message, if any.
69 |
# File 'lib/telnyx/models/external_connections/log_message_retrieve_response.rb', line 69 optional :ticket_id, String |