Class: Telnyx::Models::ExternalConnections::TnUploadEntry

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/external_connections/tn_upload_entry.rb

Defined Under Namespace

Modules: ErrorCode, InternalStatus, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(civic_address_id: nil, error_code: nil, error_message: nil, internal_status: nil, location_id: nil, number_id: nil, phone_number: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ExternalConnections::TnUploadEntry for more details.

Parameters:

  • civic_address_id (String) (defaults to: nil)

    Identifies the civic address assigned to the phone number entry.

  • error_code (Symbol, Telnyx::Models::ExternalConnections::TnUploadEntry::ErrorCode) (defaults to: nil)

    A code returned by Microsoft Teams if there is an error with the phone number en

  • error_message (String) (defaults to: nil)

    A message returned by Microsoft Teams if there is an error with the upload proce

  • internal_status (Symbol, Telnyx::Models::ExternalConnections::TnUploadEntry::InternalStatus) (defaults to: nil)

    Represents the status of the phone number entry upload on Telnyx.

  • location_id (String) (defaults to: nil)

    Identifies the location assigned to the phone number entry.

  • number_id (String) (defaults to: nil)

    Uniquely identifies the resource.

  • phone_number (String) (defaults to: nil)

    Phone number in E164 format.

  • status (Symbol, Telnyx::Models::ExternalConnections::TnUploadEntry::Status) (defaults to: nil)

    Represents the status of the phone number entry upload on Microsoft Teams.



# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 57

Instance Attribute Details

#civic_address_idString?

Identifies the civic address assigned to the phone number entry.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 11

optional :civic_address_id, String

#error_codeSymbol, ...

A code returned by Microsoft Teams if there is an error with the phone number entry upload.



18
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 18

optional :error_code, enum: -> { Telnyx::ExternalConnections::TnUploadEntry::ErrorCode }

#error_messageString?

A message returned by Microsoft Teams if there is an error with the upload process.

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 25

optional :error_message, String

#internal_statusSymbol, ...

Represents the status of the phone number entry upload on Telnyx.



31
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 31

optional :internal_status, enum: -> { Telnyx::ExternalConnections::TnUploadEntry::InternalStatus }

#location_idString?

Identifies the location assigned to the phone number entry.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 37

optional :location_id, String

#number_idString?

Uniquely identifies the resource.

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 43

optional :number_id, String

#phone_numberString?

Phone number in E164 format.

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 49

optional :phone_number, String

#statusSymbol, ...

Represents the status of the phone number entry upload on Microsoft Teams.



55
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 55

optional :status, enum: -> { Telnyx::ExternalConnections::TnUploadEntry::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 91