Class: Telnyx::Models::ExternalConnections::UploadCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/external_connections/upload_create_params.rb

Overview

Defined Under Namespace

Modules: AdditionalUsage, Usage

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, number_ids:, additional_usages: nil, civic_address_id: nil, location_id: nil, usage: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ExternalConnections::UploadCreateParams for more details.

Parameters:



# File 'lib/telnyx/models/external_connections/upload_create_params.rb', line 46

Instance Attribute Details

#additional_usagesArray<Symbol, Telnyx::Models::ExternalConnections::UploadCreateParams::AdditionalUsage>?



24
25
# File 'lib/telnyx/models/external_connections/upload_create_params.rb', line 24

optional :additional_usages,
-> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::ExternalConnections::UploadCreateParams::AdditionalUsage] }

#civic_address_idString?

Identifies the civic address to assign all phone numbers to.

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/external_connections/upload_create_params.rb', line 31

optional :civic_address_id, String

#idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/external_connections/upload_create_params.rb', line 14

required :id, String

#location_idString?

Identifies the location to assign all phone numbers to.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/external_connections/upload_create_params.rb', line 37

optional :location_id, String

#number_idsArray<String>

Returns:

  • (Array<String>)


19
# File 'lib/telnyx/models/external_connections/upload_create_params.rb', line 19

required :number_ids, Telnyx::Internal::Type::ArrayOf[String]

#usageSymbol, ...

The use case of the upload request. NOTE: ‘calling_user_assignment` is not supported for toll free numbers.



44
# File 'lib/telnyx/models/external_connections/upload_create_params.rb', line 44

optional :usage, enum: -> { Telnyx::ExternalConnections::UploadCreateParams::Usage }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/external_connections/upload_create_params.rb', line 72