Class: Telnyx::Models::ExternalRequirements::SubNumberOrderRetrieveResponse::Data::RequirementAction

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/telnyx/models/external_requirements/sub_number_order_retrieve_response.rb,
sig/telnyx/models/external_requirements/sub_number_order_retrieve_response.rbs

Overview

See Also:

  • Telnyx::Models::ExternalRequirements::SubNumberOrderRetrieveResponse::Data#requirement_action

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type: nil, value: nil) ⇒ RequirementAction

Some parameter documentations has been truncated, see Telnyx::Models::ExternalRequirements::SubNumberOrderRetrieveResponse::Data::RequirementAction for more details.

Parameters:

  • type (String) (defaults to: nil)

    The type of action the end user must complete.

  • value (String, nil) (defaults to: nil)

    The action value. For ID verification this is the verification link URL, or null

  • type: (String) (defaults to: nil)
  • value: (String, nil) (defaults to: nil)


# File 'lib/telnyx/models/external_requirements/sub_number_order_retrieve_response.rb', line 91


Instance Attribute Details

#typeString?

The type of action the end user must complete.

Parameters:

  • (String)

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/external_requirements/sub_number_order_retrieve_response.rb', line 82

optional :type, String

#valueString?

The action value. For ID verification this is the verification link URL, or null until it has been generated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


89
# File 'lib/telnyx/models/external_requirements/sub_number_order_retrieve_response.rb', line 89

optional :value, String, nil?: true

Instance Method Details

#to_hash{ type: String, value: String? }

Returns:

  • ({ type: String, value: String? })


104
# File 'sig/telnyx/models/external_requirements/sub_number_order_retrieve_response.rbs', line 104

def to_hash: -> { type: String, value: String? }