Class: Telnyx::Models::ExternalRequirements::SubNumberOrderUpdateResponse::Data::RequirementAction

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/telnyx/models/external_requirements/sub_number_order_update_response.rb,
sig/telnyx/models/external_requirements/sub_number_order_update_response.rbs

Overview

See Also:

  • Telnyx::Models::ExternalRequirements::SubNumberOrderUpdateResponse::Data#requirement_action

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type: nil, value: nil) ⇒ RequirementAction

Some parameter documentations has been truncated, see Telnyx::Models::ExternalRequirements::SubNumberOrderUpdateResponse::Data::RequirementAction for more details.

Parameters:

  • type (String) (defaults to: nil)
  • value (String, nil) (defaults to: nil)

    For Australia mobile ID verification, the unique Onfido verification link to sha

  • type: (String) (defaults to: nil)
  • value: (String, nil) (defaults to: nil)


# File 'lib/telnyx/models/external_requirements/sub_number_order_update_response.rb', line 53

Instance Attribute Details

#typeString?

Parameters:

  • (String)

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/external_requirements/sub_number_order_update_response.rb', line 44

optional :type, String

#valueString?

For Australia mobile ID verification, the unique Onfido verification link to share with the end user.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/external_requirements/sub_number_order_update_response.rb', line 51

optional :value, String, nil?: true

Instance Method Details

#to_hash{ type: String, value: String? }

Returns:

  • ({ type: String, value: String? })


69
# File 'sig/telnyx/models/external_requirements/sub_number_order_update_response.rbs', line 69

def to_hash: -> { type: String, value: String? }