Class: Telnyx::Models::Fax

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/fax.rb

Overview

Defined Under Namespace

Modules: Direction, Quality, RecordType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, client_state: nil, connection_id: nil, created_at: nil, direction: nil, from: nil, from_display_name: nil, media_name: nil, media_url: nil, preview_url: nil, quality: nil, record_type: nil, status: nil, store_media: nil, stored_media_url: nil, to: nil, updated_at: nil, webhook_failover_url: nil, webhook_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Fax for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the type of resource.

  • client_state (String) (defaults to: nil)

    State received from a command.

  • connection_id (String) (defaults to: nil)

    The ID of the connection used to send the fax.

  • created_at (Time) (defaults to: nil)

    ISO 8601 timestamp when resource was created

  • direction (Symbol, Telnyx::Models::Fax::Direction) (defaults to: nil)

    The direction of the fax.

  • from (String) (defaults to: nil)

    The phone number, in E.164 format, the fax will be sent from.

  • from_display_name (String) (defaults to: nil)

    The string used as the caller id name (SIP From Display Name) presented to the d

  • media_name (String) (defaults to: nil)

    The media_name used for the fax’s media. Must point to a file previously uploade

  • media_url (String) (defaults to: nil)

    The URL (or list of URLs) to the PDF used for the fax’s media. media_url and med

  • preview_url (String) (defaults to: nil)

    If ‘store_preview` was set to `true`, this is a link to temporary location. Link

  • quality (Symbol, Telnyx::Models::Fax::Quality) (defaults to: nil)

    The quality of the fax. The ‘ultra` settings provides the highest quality availa

  • record_type (Symbol, Telnyx::Models::Fax::RecordType) (defaults to: nil)

    Identifies the type of the resource.

  • status (Symbol, Telnyx::Models::Fax::Status) (defaults to: nil)

    Status of the fax

  • store_media (Boolean) (defaults to: nil)

    Should fax media be stored on temporary URL. It does not support media_name.

  • stored_media_url (String) (defaults to: nil)

    If store_media was set to true, this is a link to temporary location. Link expir

  • to (String) (defaults to: nil)

    The phone number, in E.164 format, the fax will be sent to or SIP URI

  • updated_at (Time) (defaults to: nil)

    ISO 8601 timestamp when resource was updated

  • webhook_failover_url (String) (defaults to: nil)

    Optional failover URL that will receive fax webhooks if webhook_url doesn’t retu

  • webhook_url (String) (defaults to: nil)

    URL that will receive fax webhooks



# File 'lib/telnyx/models/fax.rb', line 130

Instance Attribute Details

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/fax.rb', line 17

optional :client_state, String

#connection_idString?

The ID of the connection used to send the fax.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/fax.rb', line 23

optional :connection_id, String

#created_atTime?

ISO 8601 timestamp when resource was created

Returns:

  • (Time, nil)


29
# File 'lib/telnyx/models/fax.rb', line 29

optional :created_at, Time

#directionSymbol, ...

The direction of the fax.

Returns:



35
# File 'lib/telnyx/models/fax.rb', line 35

optional :direction, enum: -> { Telnyx::Fax::Direction }

#fromString?

The phone number, in E.164 format, the fax will be sent from.

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/fax.rb', line 41

optional :from, String

#from_display_nameString?

The string used as the caller id name (SIP From Display Name) presented to the destination (‘to` number).

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/fax.rb', line 48

optional :from_display_name, String

#idString?

Identifies the type of resource.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/fax.rb', line 11

optional :id, String

#media_nameString?

The media_name used for the fax’s media. Must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. media_name and media_url/contents can’t be submitted together.

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/fax.rb', line 56

optional :media_name, String

#media_urlString?

The URL (or list of URLs) to the PDF used for the fax’s media. media_url and media_name/contents can’t be submitted together.

Returns:

  • (String, nil)


63
# File 'lib/telnyx/models/fax.rb', line 63

optional :media_url, String

#preview_urlString?

If ‘store_preview` was set to `true`, this is a link to temporary location. Link expires after 10 minutes.

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/fax.rb', line 70

optional :preview_url, String

#qualitySymbol, ...

The quality of the fax. The ‘ultra` settings provides the highest quality available, but also present longer fax processing times. `ultra_light` is best suited for images, wihle `ultra_dark` is best suited for text.

Returns:



78
# File 'lib/telnyx/models/fax.rb', line 78

optional :quality, enum: -> { Telnyx::Fax::Quality }

#record_typeSymbol, ...

Identifies the type of the resource.

Returns:



84
# File 'lib/telnyx/models/fax.rb', line 84

optional :record_type, enum: -> { Telnyx::Fax::RecordType }

#statusSymbol, ...

Status of the fax

Returns:



90
# File 'lib/telnyx/models/fax.rb', line 90

optional :status, enum: -> { Telnyx::Fax::Status }

#store_mediaBoolean?

Should fax media be stored on temporary URL. It does not support media_name.

Returns:

  • (Boolean, nil)


96
# File 'lib/telnyx/models/fax.rb', line 96

optional :store_media, Telnyx::Internal::Type::Boolean

#stored_media_urlString?

If store_media was set to true, this is a link to temporary location. Link expires after 10 minutes.

Returns:

  • (String, nil)


103
# File 'lib/telnyx/models/fax.rb', line 103

optional :stored_media_url, String

#toString?

The phone number, in E.164 format, the fax will be sent to or SIP URI

Returns:

  • (String, nil)


109
# File 'lib/telnyx/models/fax.rb', line 109

optional :to, String

#updated_atTime?

ISO 8601 timestamp when resource was updated

Returns:

  • (Time, nil)


115
# File 'lib/telnyx/models/fax.rb', line 115

optional :updated_at, Time

#webhook_failover_urlString?

Optional failover URL that will receive fax webhooks if webhook_url doesn’t return a 2XX response

Returns:

  • (String, nil)


122
# File 'lib/telnyx/models/fax.rb', line 122

optional :webhook_failover_url, String

#webhook_urlString?

URL that will receive fax webhooks

Returns:

  • (String, nil)


128
# File 'lib/telnyx/models/fax.rb', line 128

optional :webhook_url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/fax.rb', line 181