Class: Telnyx::Models::FaxApplication

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/fax_application.rb

Overview

Defined Under Namespace

Classes: Inbound, Outbound

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, active: nil, anchorsite_override: nil, application_name: nil, created_at: nil, inbound: nil, outbound: nil, record_type: nil, tags: nil, updated_at: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::FaxApplication for more details.

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the resource.

  • active (Boolean) (defaults to: nil)

    Specifies whether the connection can be used.

  • anchorsite_override (Symbol, Telnyx::Models::AnchorsiteOverride) (defaults to: nil)

    ‘Latency` directs Telnyx to route media through the site with the lowest round-t

  • application_name (String) (defaults to: nil)

    A user-assigned name to help manage the application.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • inbound (Telnyx::Models::FaxApplication::Inbound) (defaults to: nil)
  • outbound (Telnyx::Models::FaxApplication::Outbound) (defaults to: nil)
  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • tags (Array<String>) (defaults to: nil)

    Tags associated with the Fax Application.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.

  • webhook_event_failover_url (String, nil) (defaults to: nil)

    The failover URL where webhooks related to this connection will be sent if sendi

  • webhook_event_url (String) (defaults to: nil)

    The URL where webhooks related to this connection will be sent. Must include a s

  • webhook_timeout_secs (Integer, nil) (defaults to: nil)

    Specifies how many seconds to wait before timing out a webhook.



# File 'lib/telnyx/models/fax_application.rb', line 87

Instance Attribute Details

#activeBoolean?

Specifies whether the connection can be used.

Returns:

  • (Boolean, nil)


17
# File 'lib/telnyx/models/fax_application.rb', line 17

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



25
# File 'lib/telnyx/models/fax_application.rb', line 25

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#application_nameString?

A user-assigned name to help manage the application.

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/fax_application.rb', line 31

optional :application_name, String

#created_atString?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/fax_application.rb', line 37

optional :created_at, String

#idString?

Uniquely identifies the resource.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/fax_application.rb', line 11

optional :id, String

#inboundTelnyx::Models::FaxApplication::Inbound?



42
# File 'lib/telnyx/models/fax_application.rb', line 42

optional :inbound, -> { Telnyx::FaxApplication::Inbound }

#outboundTelnyx::Models::FaxApplication::Outbound?



47
# File 'lib/telnyx/models/fax_application.rb', line 47

optional :outbound, -> { Telnyx::FaxApplication::Outbound }

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


53
# File 'lib/telnyx/models/fax_application.rb', line 53

optional :record_type, String

#tagsArray<String>?

Tags associated with the Fax Application.

Returns:

  • (Array<String>, nil)


59
# File 'lib/telnyx/models/fax_application.rb', line 59

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#updated_atString?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (String, nil)


65
# File 'lib/telnyx/models/fax_application.rb', line 65

optional :updated_at, String

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


72
# File 'lib/telnyx/models/fax_application.rb', line 72

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/fax_application.rb', line 79

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


85
# File 'lib/telnyx/models/fax_application.rb', line 85

optional :webhook_timeout_secs, Integer, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/fax_application.rb', line 167