Class: Telnyx::Models::FaxApplication::Inbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/fax_application.rb

Overview

See Also:

Defined Under Namespace

Modules: SipSubdomainReceiveSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel_limit: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::FaxApplication::Inbound for more details.

Parameters:

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the number of concurrent inbound calls to phone number

  • sip_subdomain (String) (defaults to: nil)

    Specifies a subdomain that can be used to receive Inbound calls to a Connection,

  • sip_subdomain_receive_settings (Symbol, Telnyx::Models::FaxApplication::Inbound::SipSubdomainReceiveSettings) (defaults to: nil)

    This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in



# File 'lib/telnyx/models/fax_application.rb', line 146

Instance Attribute Details

#channel_limitInteger?

When set, this will limit the number of concurrent inbound calls to phone numbers associated with this connection.

Returns:

  • (Integer, nil)


124
# File 'lib/telnyx/models/fax_application.rb', line 124

optional :channel_limit, Integer

#sip_subdomainString?

Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint. Example: the subdomain “example.sip.telnyx.com” can be called from any SIP endpoint by using the SIP URI “sip:@example.sip.telnyx.com” where the user part can be any alphanumeric value. Please note TLS encrypted calls are not allowed for subdomain calls.

Returns:

  • (String, nil)


135
# File 'lib/telnyx/models/fax_application.rb', line 135

optional :sip_subdomain, String

#sip_subdomain_receive_settingsSymbol, ...

This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).



143
144
# File 'lib/telnyx/models/fax_application.rb', line 143

optional :sip_subdomain_receive_settings,
enum: -> { Telnyx::FaxApplication::Inbound::SipSubdomainReceiveSettings }