Class: Telnyx::Models::FaxApplication::Outbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/fax_application.rb,
sig/telnyx/models/fax_application.rbs

Overview

See Also:

  • Telnyx::Models::FaxApplication#outbound

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel_limit: nil, outbound_voice_profile_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::FaxApplication::Outbound for more details.



# File 'lib/telnyx/models/fax_application.rb', line 187


Instance Attribute Details

#channel_limitInteger?

When set, this will limit the number of concurrent outbound calls to phone numbers associated with this connection.



179
# File 'lib/telnyx/models/fax_application.rb', line 179

optional :channel_limit, Integer

#outbound_voice_profile_idString?

Identifies the associated outbound voice profile.



185
# File 'lib/telnyx/models/fax_application.rb', line 185

optional :outbound_voice_profile_id, String

Instance Method Details

#to_hash{



171
# File 'sig/telnyx/models/fax_application.rbs', line 171

def to_hash: -> {