Class: Telnyx::Models::FaxApplicationCreateParams::Inbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/fax_application_create_params.rb

Defined Under Namespace

Modules: SipSubdomainReceiveSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel_limit: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::FaxApplicationCreateParams::Inbound for more details.

Parameters:

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the number of concurrent inbound calls to phone number

  • sip_subdomain (String) (defaults to: nil)

    Specifies a subdomain that can be used to receive Inbound calls to a Connection,

  • sip_subdomain_receive_settings (Symbol, Telnyx::Models::FaxApplicationCreateParams::Inbound::SipSubdomainReceiveSettings) (defaults to: nil)

    This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/telnyx/models/fax_application_create_params.rb', line 90

class Inbound < Telnyx::Internal::Type::BaseModel
  # @!attribute channel_limit
  #   When set, this will limit the number of concurrent inbound calls to phone
  #   numbers associated with this connection.
  #
  #   @return [Integer, nil]
  optional :channel_limit, Integer

  # @!attribute sip_subdomain
  #   Specifies a subdomain that can be used to receive Inbound calls to a Connection,
  #   in the same way a phone number is used, from a SIP endpoint. Example: the
  #   subdomain "example.sip.telnyx.com" can be called from any SIP endpoint by using
  #   the SIP URI "sip:@example.sip.telnyx.com" where the user part can be any
  #   alphanumeric value. Please note TLS encrypted calls are not allowed for
  #   subdomain calls.
  #
  #   @return [String, nil]
  optional :sip_subdomain, String

  # @!attribute sip_subdomain_receive_settings
  #   This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in
  #   the public Internet) or "Only my connections" (any connection assigned to the
  #   same Telnyx user).
  #
  #   @return [Symbol, Telnyx::Models::FaxApplicationCreateParams::Inbound::SipSubdomainReceiveSettings, nil]
  optional :sip_subdomain_receive_settings,
           enum: -> { Telnyx::FaxApplicationCreateParams::Inbound::SipSubdomainReceiveSettings }

  # @!method initialize(channel_limit: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::FaxApplicationCreateParams::Inbound} for more details.
  #
  #   @param channel_limit [Integer] When set, this will limit the number of concurrent inbound calls to phone number
  #
  #   @param sip_subdomain [String] Specifies a subdomain that can be used to receive Inbound calls to a Connection,
  #
  #   @param sip_subdomain_receive_settings [Symbol, Telnyx::Models::FaxApplicationCreateParams::Inbound::SipSubdomainReceiveSettings] This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in

  # This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in
  # the public Internet) or "Only my connections" (any connection assigned to the
  # same Telnyx user).
  #
  # @see Telnyx::Models::FaxApplicationCreateParams::Inbound#sip_subdomain_receive_settings
  module SipSubdomainReceiveSettings
    extend Telnyx::Internal::Type::Enum

    ONLY_MY_CONNECTIONS = :only_my_connections
    FROM_ANYONE = :from_anyone

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#channel_limitInteger?

When set, this will limit the number of concurrent inbound calls to phone numbers associated with this connection.

Returns:

  • (Integer, nil)


96
# File 'lib/telnyx/models/fax_application_create_params.rb', line 96

optional :channel_limit, Integer

#sip_subdomainString?

Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint. Example: the subdomain “example.sip.telnyx.com” can be called from any SIP endpoint by using the SIP URI “sip:@example.sip.telnyx.com” where the user part can be any alphanumeric value. Please note TLS encrypted calls are not allowed for subdomain calls.

Returns:

  • (String, nil)


107
# File 'lib/telnyx/models/fax_application_create_params.rb', line 107

optional :sip_subdomain, String

#sip_subdomain_receive_settingsSymbol, ...

This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).



115
116
# File 'lib/telnyx/models/fax_application_create_params.rb', line 115

optional :sip_subdomain_receive_settings,
enum: -> { Telnyx::FaxApplicationCreateParams::Inbound::SipSubdomainReceiveSettings }