Class: Telnyx::Models::FaxApplicationCreateParams::Outbound
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FaxApplicationCreateParams::Outbound
- Defined in:
- lib/telnyx/models/fax_application_create_params.rb
Instance Attribute Summary collapse
-
#channel_limit ⇒ Integer?
When set, this will limit the number of concurrent outbound calls to phone numbers associated with this connection.
-
#outbound_voice_profile_id ⇒ String?
Identifies the associated outbound voice profile.
Instance Method Summary collapse
-
#initialize(channel_limit: nil, outbound_voice_profile_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Outbound for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channel_limit: nil, outbound_voice_profile_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::FaxApplicationCreateParams::Outbound for more details.
|
|
# File 'lib/telnyx/models/fax_application_create_params.rb', line 158
|
Instance Attribute Details
#channel_limit ⇒ Integer?
When set, this will limit the number of concurrent outbound calls to phone numbers associated with this connection.
150 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 150 optional :channel_limit, Integer |
#outbound_voice_profile_id ⇒ String?
Identifies the associated outbound voice profile.
156 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 156 optional :outbound_voice_profile_id, String |