Class: Telnyx::Models::FaxApplicationUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/fax_application_update_params.rb

Overview

Defined Under Namespace

Classes: Inbound, Outbound

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#activeBoolean?

Specifies whether the connection can be used.

Returns:

  • (Boolean, nil)


32
# File 'lib/telnyx/models/fax_application_update_params.rb', line 32

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



40
# File 'lib/telnyx/models/fax_application_update_params.rb', line 40

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#application_nameString

A user-assigned name to help manage the application.

Returns:

  • (String)


19
# File 'lib/telnyx/models/fax_application_update_params.rb', line 19

required :application_name, String

#fax_email_recipientString?

Specifies an email address where faxes sent to this application will be forwarded to (as pdf or tiff attachments)

Returns:

  • (String, nil)


47
# File 'lib/telnyx/models/fax_application_update_params.rb', line 47

optional :fax_email_recipient, String, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/fax_application_update_params.rb', line 13

required :id, String

#inboundTelnyx::Models::FaxApplicationUpdateParams::Inbound?



52
# File 'lib/telnyx/models/fax_application_update_params.rb', line 52

optional :inbound, -> { Telnyx::FaxApplicationUpdateParams::Inbound }

#outboundTelnyx::Models::FaxApplicationUpdateParams::Outbound?



57
# File 'lib/telnyx/models/fax_application_update_params.rb', line 57

optional :outbound, -> { Telnyx::FaxApplicationUpdateParams::Outbound }

#tagsArray<String>?

Tags associated with the Fax Application.

Returns:

  • (Array<String>, nil)


63
# File 'lib/telnyx/models/fax_application_update_params.rb', line 63

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/fax_application_update_params.rb', line 70

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String)


26
# File 'lib/telnyx/models/fax_application_update_params.rb', line 26

required :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


76
# File 'lib/telnyx/models/fax_application_update_params.rb', line 76

optional :webhook_timeout_secs, Integer, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/fax_application_update_params.rb', line 155