Class: Telnyx::Models::FaxCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/fax_create_params.rb

Overview

Defined Under Namespace

Modules: PreviewFormat, Quality

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(connection_id:, from:, to:, black_threshold: nil, client_state: nil, from_display_name: nil, media_name: nil, media_url: nil, monochrome: nil, preview_format: nil, quality: nil, store_media: nil, store_preview: nil, t38_enabled: nil, webhook_url: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::FaxCreateParams for more details.

Parameters:

  • connection_id (String)

    The connection ID to send the fax with.

  • from (String)

    The phone number, in E.164 format, the fax will be sent from.

  • to (String)

    The phone number, in E.164 format, the fax will be sent to or SIP URI

  • black_threshold (Integer) (defaults to: nil)

    The black threshold percentage for monochrome faxes. Only applicable if ‘monochr

  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. It must be a valid Base

  • from_display_name (String) (defaults to: nil)

    The ‘from_display_name` string to be used as the caller id name (SIP From Displa

  • media_name (String) (defaults to: nil)

    The media_name used for the fax’s media. Must point to a file previously uploade

  • media_url (String) (defaults to: nil)

    The URL (or list of URLs) to the PDF used for the fax’s media. media_url and med

  • monochrome (Boolean) (defaults to: nil)

    The flag to enable monochrome, true black and white fax results.

  • preview_format (Symbol, Telnyx::Models::FaxCreateParams::PreviewFormat) (defaults to: nil)

    The format for the preview file in case the ‘store_preview` is `true`.

  • quality (Symbol, Telnyx::Models::FaxCreateParams::Quality) (defaults to: nil)

    The quality of the fax. The ‘ultra` settings provides the highest quality availa

  • store_media (Boolean) (defaults to: nil)

    Should fax media be stored on temporary URL. It does not support media_name, the

  • store_preview (Boolean) (defaults to: nil)

    Should fax preview be stored on temporary URL.

  • t38_enabled (Boolean) (defaults to: nil)

    The flag to disable the T.38 protocol.

  • webhook_url (String) (defaults to: nil)

    Use this field to override the URL to which Telnyx will send subsequent webhooks

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/fax_create_params.rb', line 113

Instance Attribute Details

#black_thresholdInteger?

The black threshold percentage for monochrome faxes. Only applicable if ‘monochrome` is set to `true`.

Returns:

  • (Integer, nil)


33
# File 'lib/telnyx/models/fax_create_params.rb', line 33

optional :black_threshold, Integer

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/fax_create_params.rb', line 40

optional :client_state, String

#connection_idString

The connection ID to send the fax with.

Returns:

  • (String)


14
# File 'lib/telnyx/models/fax_create_params.rb', line 14

required :connection_id, String

#fromString

The phone number, in E.164 format, the fax will be sent from.

Returns:

  • (String)


20
# File 'lib/telnyx/models/fax_create_params.rb', line 20

required :from, String

#from_display_nameString?

The ‘from_display_name` string to be used as the caller id name (SIP From Display Name) presented to the destination (`to` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and -_~!.+ special characters. If ommited, the display name will be the same as the number in the `from` field.

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/fax_create_params.rb', line 50

optional :from_display_name, String

#media_nameString?

The media_name used for the fax’s media. Must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. media_name and media_url/contents can’t be submitted together.

Returns:

  • (String, nil)


58
# File 'lib/telnyx/models/fax_create_params.rb', line 58

optional :media_name, String

#media_urlString?

The URL (or list of URLs) to the PDF used for the fax’s media. media_url and media_name/contents can’t be submitted together.

Returns:

  • (String, nil)


65
# File 'lib/telnyx/models/fax_create_params.rb', line 65

optional :media_url, String

#monochromeBoolean?

The flag to enable monochrome, true black and white fax results.

Returns:

  • (Boolean, nil)


71
# File 'lib/telnyx/models/fax_create_params.rb', line 71

optional :monochrome, Telnyx::Internal::Type::Boolean

#preview_formatSymbol, ...

The format for the preview file in case the ‘store_preview` is `true`.



77
# File 'lib/telnyx/models/fax_create_params.rb', line 77

optional :preview_format, enum: -> { Telnyx::FaxCreateParams::PreviewFormat }

#qualitySymbol, ...

The quality of the fax. The ‘ultra` settings provides the highest quality available, but also present longer fax processing times. `ultra_light` is best suited for images, wihle `ultra_dark` is best suited for text.



85
# File 'lib/telnyx/models/fax_create_params.rb', line 85

optional :quality, enum: -> { Telnyx::FaxCreateParams::Quality }

#store_mediaBoolean?

Should fax media be stored on temporary URL. It does not support media_name, they can’t be submitted together.

Returns:

  • (Boolean, nil)


92
# File 'lib/telnyx/models/fax_create_params.rb', line 92

optional :store_media, Telnyx::Internal::Type::Boolean

#store_previewBoolean?

Should fax preview be stored on temporary URL.

Returns:

  • (Boolean, nil)


98
# File 'lib/telnyx/models/fax_create_params.rb', line 98

optional :store_preview, Telnyx::Internal::Type::Boolean

#t38_enabledBoolean?

The flag to disable the T.38 protocol.

Returns:

  • (Boolean, nil)


104
# File 'lib/telnyx/models/fax_create_params.rb', line 104

optional :t38_enabled, Telnyx::Internal::Type::Boolean

#toString

The phone number, in E.164 format, the fax will be sent to or SIP URI

Returns:

  • (String)


26
# File 'lib/telnyx/models/fax_create_params.rb', line 26

required :to, String

#webhook_urlString?

Use this field to override the URL to which Telnyx will send subsequent webhooks for this fax.

Returns:

  • (String, nil)


111
# File 'lib/telnyx/models/fax_create_params.rb', line 111

optional :webhook_url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/fax_create_params.rb', line 156