Class: Telnyx::Models::FaxDelivered::Data::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/fax_delivered.rb

Overview

See Also:

Defined Under Namespace

Modules: Direction, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_duration_secs: nil, client_state: nil, connection_id: nil, direction: nil, fax_id: nil, from: nil, media_name: nil, original_media_url: nil, page_count: nil, status: nil, to: nil, user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::FaxDelivered::Data::Payload for more details.

Parameters:

  • call_duration_secs (Integer) (defaults to: nil)

    The duration of the call in seconds.

  • client_state (String) (defaults to: nil)

    State received from a command.

  • connection_id (String) (defaults to: nil)

    The ID of the connection used to send the fax.

  • direction (Symbol, Telnyx::Models::FaxDelivered::Data::Payload::Direction) (defaults to: nil)

    The direction of the fax.

  • fax_id (String) (defaults to: nil)

    Identifies the fax.

  • from (String) (defaults to: nil)

    The phone number, in E.164 format, the fax will be sent from.

  • media_name (String) (defaults to: nil)

    The media_name used for the fax’s media. Must point to a file previously uploade

  • original_media_url (String) (defaults to: nil)

    The original URL to the PDF used for the fax’s media. If media_name was supplied

  • page_count (Integer) (defaults to: nil)

    Number of transferred pages

  • status (Symbol, Telnyx::Models::FaxDelivered::Data::Payload::Status) (defaults to: nil)

    The status of the fax.

  • to (String) (defaults to: nil)

    The phone number, in E.164 format, the fax will be sent to or SIP URI

  • user_id (String) (defaults to: nil)

    Identifier of the user to whom the fax belongs



# File 'lib/telnyx/models/fax_delivered.rb', line 153

Instance Attribute Details

#call_duration_secsInteger?

The duration of the call in seconds.

Returns:

  • (Integer, nil)


82
# File 'lib/telnyx/models/fax_delivered.rb', line 82

optional :call_duration_secs, Integer

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/fax_delivered.rb', line 88

optional :client_state, String

#connection_idString?

The ID of the connection used to send the fax.

Returns:

  • (String, nil)


94
# File 'lib/telnyx/models/fax_delivered.rb', line 94

optional :connection_id, String

#directionSymbol, ...

The direction of the fax.



100
# File 'lib/telnyx/models/fax_delivered.rb', line 100

optional :direction, enum: -> { Telnyx::FaxDelivered::Data::Payload::Direction }

#fax_idString?

Identifies the fax.

Returns:

  • (String, nil)


106
# File 'lib/telnyx/models/fax_delivered.rb', line 106

optional :fax_id, String

#fromString?

The phone number, in E.164 format, the fax will be sent from.

Returns:

  • (String, nil)


112
# File 'lib/telnyx/models/fax_delivered.rb', line 112

optional :from, String

#media_nameString?

The media_name used for the fax’s media. Must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. media_name and media_url/contents can’t be submitted together.

Returns:

  • (String, nil)


120
# File 'lib/telnyx/models/fax_delivered.rb', line 120

optional :media_name, String

#original_media_urlString?

The original URL to the PDF used for the fax’s media. If media_name was supplied, this is omitted

Returns:

  • (String, nil)


127
# File 'lib/telnyx/models/fax_delivered.rb', line 127

optional :original_media_url, String

#page_countInteger?

Number of transferred pages

Returns:

  • (Integer, nil)


133
# File 'lib/telnyx/models/fax_delivered.rb', line 133

optional :page_count, Integer

#statusSymbol, ...

The status of the fax.



139
# File 'lib/telnyx/models/fax_delivered.rb', line 139

optional :status, enum: -> { Telnyx::FaxDelivered::Data::Payload::Status }

#toString?

The phone number, in E.164 format, the fax will be sent to or SIP URI

Returns:

  • (String, nil)


145
# File 'lib/telnyx/models/fax_delivered.rb', line 145

optional :to, String

#user_idString?

Identifier of the user to whom the fax belongs

Returns:

  • (String, nil)


151
# File 'lib/telnyx/models/fax_delivered.rb', line 151

optional :user_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/fax_delivered.rb', line 190