Class: Telnyx::Models::FaxFailed::Data::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FaxFailed::Data::Payload
- Defined in:
- lib/telnyx/models/fax_failed.rb,
sig/telnyx/models/fax_failed.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
The ID of the connection used to send the fax.
-
#direction ⇒ Symbol, ...
The direction of the fax.
-
#failure_reason ⇒ String?
Customer-facing cause of the fax failure.
-
#fax_id ⇒ String?
Identifies the fax.
-
#from ⇒ String?
The phone number, in E.164 format, the fax will be sent from.
-
#internal_failure_reason ⇒ String?
Internal, more granular cause of the fax failure.
-
#media_name ⇒ String?
The media_name used for the fax's media.
-
#original_media_url ⇒ String?
The original URL to the PDF used for the fax's media.
-
#status ⇒ Symbol, ...
The status of the fax.
-
#to ⇒ String?
The phone number, in E.164 format, the fax will be sent to or SIP URI.
-
#user_id ⇒ String?
Identifier of the user to whom the fax belongs.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(client_state: nil, connection_id: nil, direction: nil, failure_reason: nil, fax_id: nil, from: nil, internal_failure_reason: nil, media_name: nil, original_media_url: nil, status: nil, to: nil, user_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(client_state: nil, connection_id: nil, direction: nil, failure_reason: nil, fax_id: nil, from: nil, internal_failure_reason: nil, media_name: nil, original_media_url: nil, status: nil, to: nil, user_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::FaxFailed::Data::Payload for more details.
|
|
# File 'lib/telnyx/models/fax_failed.rb', line 156
|
Instance Attribute Details
#client_state ⇒ String?
State received from a command.
82 |
# File 'lib/telnyx/models/fax_failed.rb', line 82 optional :client_state, String |
#connection_id ⇒ String?
The ID of the connection used to send the fax.
88 |
# File 'lib/telnyx/models/fax_failed.rb', line 88 optional :connection_id, String |
#direction ⇒ Symbol, ...
The direction of the fax.
94 |
# File 'lib/telnyx/models/fax_failed.rb', line 94 optional :direction, enum: -> { Telnyx::FaxFailed::Data::Payload::Direction } |
#failure_reason ⇒ String?
Customer-facing cause of the fax failure. Mapped from the more granular
internal_failure_reason.
101 |
# File 'lib/telnyx/models/fax_failed.rb', line 101 optional :failure_reason, String |
#fax_id ⇒ String?
Identifies the fax.
107 |
# File 'lib/telnyx/models/fax_failed.rb', line 107 optional :fax_id, String |
#from ⇒ String?
The phone number, in E.164 format, the fax will be sent from.
113 |
# File 'lib/telnyx/models/fax_failed.rb', line 113 optional :from, String |
#internal_failure_reason ⇒ String?
Internal, more granular cause of the fax failure. Useful for deeper debugging
beyond the customer-facing failure_reason.
120 |
# File 'lib/telnyx/models/fax_failed.rb', line 120 optional :internal_failure_reason, String |
#media_name ⇒ String?
The media_name used for the fax's media. Must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. Supported formats: PDF, TIFF, JPEG, PNG, DOC, DOCX, RTF, and TXT. media_name and media_url/contents can't be submitted together.
129 |
# File 'lib/telnyx/models/fax_failed.rb', line 129 optional :media_name, String |
#original_media_url ⇒ String?
The original URL to the PDF used for the fax's media. If media_name was supplied, this is omitted
136 |
# File 'lib/telnyx/models/fax_failed.rb', line 136 optional :original_media_url, String |
#status ⇒ Symbol, ...
The status of the fax.
142 |
# File 'lib/telnyx/models/fax_failed.rb', line 142 optional :status, enum: -> { Telnyx::FaxFailed::Data::Payload::Status } |
#to ⇒ String?
The phone number, in E.164 format, the fax will be sent to or SIP URI
148 |
# File 'lib/telnyx/models/fax_failed.rb', line 148 optional :to, String |
#user_id ⇒ String?
Identifier of the user to whom the fax belongs
154 |
# File 'lib/telnyx/models/fax_failed.rb', line 154 optional :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/fax_failed.rb', line 193
|
Instance Method Details
#to_hash ⇒ {
171 |
# File 'sig/telnyx/models/fax_failed.rbs', line 171
def to_hash: -> {
|