Class: Telnyx::Models::FaxQueued::Data::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/fax_queued.rb

Overview

See Also:

Defined Under Namespace

Modules: Direction, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(client_state: nil, connection_id: nil, direction: nil, fax_id: nil, from: nil, media_name: nil, original_media_url: nil, status: nil, to: nil, user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::FaxQueued::Data::Payload for more details.

Parameters:

  • client_state (String) (defaults to: nil)

    State received from a command.

  • connection_id (String) (defaults to: nil)

    The ID of the connection used to send the fax.

  • direction (Symbol, Telnyx::Models::FaxQueued::Data::Payload::Direction) (defaults to: nil)

    The direction of the fax.

  • fax_id (String) (defaults to: nil)

    Identifies the fax.

  • from (String) (defaults to: nil)

    The phone number, in E.164 format, the fax will be sent from.

  • media_name (String) (defaults to: nil)

    The media_name used for the fax’s media. Must point to a file previously uploade

  • original_media_url (String) (defaults to: nil)

    The original URL to the PDF used for the fax’s media. If media_name was supplied

  • status (Symbol, Telnyx::Models::FaxQueued::Data::Payload::Status) (defaults to: nil)

    The status of the fax.

  • to (String) (defaults to: nil)

    The phone number, in E.164 format, the fax will be sent to or SIP URI

  • user_id (String) (defaults to: nil)

    Identifier of the user to whom the fax belongs



# File 'lib/telnyx/models/fax_queued.rb', line 141

Instance Attribute Details

#client_stateString?

State received from a command.

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/fax_queued.rb', line 82

optional :client_state, String

#connection_idString?

The ID of the connection used to send the fax.

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/fax_queued.rb', line 88

optional :connection_id, String

#directionSymbol, ...

The direction of the fax.



94
# File 'lib/telnyx/models/fax_queued.rb', line 94

optional :direction, enum: -> { Telnyx::FaxQueued::Data::Payload::Direction }

#fax_idString?

Identifies the fax.

Returns:

  • (String, nil)


100
# File 'lib/telnyx/models/fax_queued.rb', line 100

optional :fax_id, String

#fromString?

The phone number, in E.164 format, the fax will be sent from.

Returns:

  • (String, nil)


106
# File 'lib/telnyx/models/fax_queued.rb', line 106

optional :from, String

#media_nameString?

The media_name used for the fax’s media. Must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. media_name and media_url/contents can’t be submitted together.

Returns:

  • (String, nil)


114
# File 'lib/telnyx/models/fax_queued.rb', line 114

optional :media_name, String

#original_media_urlString?

The original URL to the PDF used for the fax’s media. If media_name was supplied, this is omitted

Returns:

  • (String, nil)


121
# File 'lib/telnyx/models/fax_queued.rb', line 121

optional :original_media_url, String

#statusSymbol, ...

The status of the fax.



127
# File 'lib/telnyx/models/fax_queued.rb', line 127

optional :status, enum: -> { Telnyx::FaxQueued::Data::Payload::Status }

#toString?

The phone number, in E.164 format, the fax will be sent to or SIP URI

Returns:

  • (String, nil)


133
# File 'lib/telnyx/models/fax_queued.rb', line 133

optional :to, String

#user_idString?

Identifier of the user to whom the fax belongs

Returns:

  • (String, nil)


139
# File 'lib/telnyx/models/fax_queued.rb', line 139

optional :user_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/fax_queued.rb', line 174