Class: Telnyx::Models::FqdnConnectionCreateParams::JitterBuffer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/fqdn_connection_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(connection_name:, active: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_in_webhooks: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, inbound: nil, ios_push_credential_id: nil, jitter_buffer: nil, microsoft_teams_sbc: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, rtcp_settings: nil, tags: nil, transport_protocol: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::FqdnConnectionCreateParams for more details.

Parameters:

  • connection_name (String)

    A user-assigned name to help manage the connection.

  • active (Boolean) (defaults to: nil)

    Defaults to true

  • anchorsite_override (Symbol, Telnyx::Models::AnchorsiteOverride) (defaults to: nil)

    ‘Latency` directs Telnyx to route media through the site with the lowest round-t

  • android_push_credential_id (String, nil) (defaults to: nil)

    The uuid of the push credential for Android

  • call_cost_in_webhooks (Boolean) (defaults to: nil)

    Specifies if call cost webhooks should be sent for this connection.

  • default_on_hold_comfort_noise_enabled (Boolean) (defaults to: nil)

    When enabled, Telnyx will generate comfort noise when you place the call on hold

  • dtmf_type (Symbol, Telnyx::Models::DtmfType) (defaults to: nil)

    Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF

  • encode_contact_header_enabled (Boolean) (defaults to: nil)

    Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scen

  • encrypted_media (Symbol, Telnyx::Models::EncryptedMedia, nil) (defaults to: nil)

    Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TL

  • inbound (Telnyx::Models::InboundFqdn) (defaults to: nil)
  • ios_push_credential_id (String, nil) (defaults to: nil)

    The uuid of the push credential for Ios

  • jitter_buffer (Telnyx::Models::FqdnConnectionCreateParams::JitterBuffer) (defaults to: nil)

    Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams o

  • microsoft_teams_sbc (Boolean) (defaults to: nil)

    When enabled, the connection will be created for Microsoft Teams Direct Routing.

  • noise_suppression (Symbol, Telnyx::Models::FqdnConnectionCreateParams::NoiseSuppression) (defaults to: nil)

    Controls when noise suppression is applied to calls. When set to ‘inbound’, nois

  • noise_suppression_details (Telnyx::Models::ConnectionNoiseSuppressionDetails) (defaults to: nil)

    Configuration options for noise suppression. These settings are stored regardles

  • onnet_t38_passthrough_enabled (Boolean) (defaults to: nil)

    Enable on-net T38 if you prefer the sender and receiver negotiating T38 directly

  • outbound (Telnyx::Models::OutboundFqdn) (defaults to: nil)
  • rtcp_settings (Telnyx::Models::ConnectionRtcpSettings) (defaults to: nil)
  • tags (Array<String>) (defaults to: nil)

    Tags associated with the connection.

  • transport_protocol (Symbol, Telnyx::Models::TransportProtocol) (defaults to: nil)

    One of UDP, TLS, or TCP. Applies only to connections with IP authentication or F

  • webhook_api_version (Symbol, Telnyx::Models::WebhookAPIVersion) (defaults to: nil)

    Determines which webhook format will be used, Telnyx API v1 or v2.

  • webhook_event_failover_url (String, nil) (defaults to: nil)

    The failover URL where webhooks related to this connection will be sent if sendi

  • webhook_event_url (String) (defaults to: nil)

    The URL where webhooks related to this connection will be sent. Must include a s

  • webhook_timeout_secs (Integer, nil) (defaults to: nil)

    Specifies how many seconds to wait before timing out a webhook.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/telnyx/models/fqdn_connection_create_params.rb', line 228

class JitterBuffer < Telnyx::Internal::Type::BaseModel
  # @!attribute enable_jitter_buffer
  #   Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off
  #   unless enabled.
  #
  #   @return [Boolean, nil]
  optional :enable_jitter_buffer, Telnyx::Internal::Type::Boolean

  # @!attribute jitterbuffer_msec_max
  #   The maximum jitter buffer size in milliseconds. Must be between 40 and 400. Has
  #   no effect if enable_jitter_buffer is not true.
  #
  #   @return [Integer, nil]
  optional :jitterbuffer_msec_max, Integer

  # @!attribute jitterbuffer_msec_min
  #   The minimum jitter buffer size in milliseconds. Must be between 40 and 400. Has
  #   no effect if enable_jitter_buffer is not true.
  #
  #   @return [Integer, nil]
  optional :jitterbuffer_msec_min, Integer

  # @!method initialize(enable_jitter_buffer: nil, jitterbuffer_msec_max: nil, jitterbuffer_msec_min: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::FqdnConnectionCreateParams::JitterBuffer} for more details.
  #
  #   Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams
  #   of SIP Trunking calls. The feature is off unless enabled. You may define min and
  #   max values in msec for customized buffering behaviors. Larger values add latency
  #   but tolerate more jitter, while smaller values reduce latency but are more
  #   sensitive to jitter and reordering.
  #
  #   @param enable_jitter_buffer [Boolean] Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off
  #
  #   @param jitterbuffer_msec_max [Integer] The maximum jitter buffer size in milliseconds. Must be between 40 and 400. Has
  #
  #   @param jitterbuffer_msec_min [Integer] The minimum jitter buffer size in milliseconds. Must be between 40 and 400. Has
end

Instance Attribute Details

#enable_jitter_bufferBoolean?

Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled.

Returns:

  • (Boolean, nil)


234
# File 'lib/telnyx/models/fqdn_connection_create_params.rb', line 234

optional :enable_jitter_buffer, Telnyx::Internal::Type::Boolean

#jitterbuffer_msec_maxInteger?

The maximum jitter buffer size in milliseconds. Must be between 40 and 400. Has no effect if enable_jitter_buffer is not true.

Returns:

  • (Integer, nil)


241
# File 'lib/telnyx/models/fqdn_connection_create_params.rb', line 241

optional :jitterbuffer_msec_max, Integer

#jitterbuffer_msec_minInteger?

The minimum jitter buffer size in milliseconds. Must be between 40 and 400. Has no effect if enable_jitter_buffer is not true.

Returns:

  • (Integer, nil)


248
# File 'lib/telnyx/models/fqdn_connection_create_params.rb', line 248

optional :jitterbuffer_msec_min, Integer