Class: Telnyx::Models::FqdnConnectionUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FqdnConnectionUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/fqdn_connection_update_params.rb,
sig/telnyx/models/fqdn_connection_update_params.rbs
Overview
Constant Summary collapse
- Telnyx =
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Defaults to true.
-
#anchorsite_override ⇒ Symbol, ...
Latencydirects Telnyx to route media through the site with the lowest round-trip time to the user's connection. -
#android_push_credential_id ⇒ String?
The uuid of the push credential for Android.
-
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this connection.
-
#connection_name ⇒ String?
A user-assigned name to help manage the connection.
-
#conversation_persistence ⇒ Boolean?
Whether conversation persistence is enabled for this connection.
-
#default_on_hold_comfort_noise_enabled ⇒ Boolean?
When enabled, Telnyx will generate comfort noise when you place the call on hold.
-
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection.
-
#encode_contact_header_enabled ⇒ Boolean?
Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.
-
#encrypted_media ⇒ Symbol, ...
Enable use of SRTP for encryption.
- #id ⇒ String
- #inbound ⇒ Telnyx::Models::InboundFqdn?
-
#ios_push_credential_id ⇒ String?
The uuid of the push credential for Ios.
-
#jitter_buffer ⇒ Telnyx::Models::ConnectionJitterBuffer?
Configuration options for Jitter Buffer.
-
#noise_suppression ⇒ Symbol, ...
Controls when noise suppression is applied to calls.
-
#noise_suppression_details ⇒ Telnyx::Models::ConnectionNoiseSuppressionDetails?
Configuration options for noise suppression.
-
#onnet_t38_passthrough_enabled ⇒ Boolean?
Enable on-net T38 if you prefer that the sender and receiver negotiate T38 directly when both are on the Telnyx network.
- #outbound ⇒ Telnyx::Models::OutboundFqdn?
- #rtcp_settings ⇒ Telnyx::Models::ConnectionRtcpSettings?
-
#tags ⇒ Array<String>?
Tags associated with the connection.
-
#transport_protocol ⇒ Symbol, ...
One of UDP, TLS, or TCP.
-
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, active: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_in_webhooks: nil, connection_name: nil, conversation_persistence: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, inbound: nil, ios_push_credential_id: nil, jitter_buffer: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, rtcp_settings: nil, tags: nil, transport_protocol: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FqdnConnectionUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, active: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_in_webhooks: nil, connection_name: nil, conversation_persistence: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, inbound: nil, ios_push_credential_id: nil, jitter_buffer: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, rtcp_settings: nil, tags: nil, transport_protocol: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::FqdnConnectionUpdateParams for more details.
|
|
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 180
|
Instance Attribute Details
#active ⇒ Boolean?
Defaults to true
19 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 19 optional :active, Telnyx::Internal::Type::Boolean |
#anchorsite_override ⇒ Symbol, ...
Latency directs Telnyx to route media through the site with the lowest
round-trip time to the user's connection. Telnyx calculates this time using ICMP
ping messages. This can be disabled by specifying a site to handle all media.
27 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 27 optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride } |
#android_push_credential_id ⇒ String?
The uuid of the push credential for Android
33 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 33 optional :android_push_credential_id, String, nil?: true |
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this connection.
39 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 39 optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean |
#connection_name ⇒ String?
A user-assigned name to help manage the connection.
45 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 45 optional :connection_name, String |
#conversation_persistence ⇒ Boolean?
Whether conversation persistence is enabled for this connection. When enabled, calls handled by the connection are transcribed, stored, and indexed. Defaults to false.
53 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 53 optional :conversation_persistence, Telnyx::Internal::Type::Boolean |
#default_on_hold_comfort_noise_enabled ⇒ Boolean?
When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.
61 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 61 optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean |
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.
68 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 68 optional :dtmf_type, enum: -> { Telnyx::DtmfType } |
#encode_contact_header_enabled ⇒ Boolean?
Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.
75 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 75 optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean |
#encrypted_media ⇒ Symbol, ...
Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.
82 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 82 optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true |
#id ⇒ String
13 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 13 required :id, String |
#inbound ⇒ Telnyx::Models::InboundFqdn?
87 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 87 optional :inbound, -> { Telnyx::InboundFqdn } |
#ios_push_credential_id ⇒ String?
The uuid of the push credential for Ios
93 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 93 optional :ios_push_credential_id, String, nil?: true |
#jitter_buffer ⇒ Telnyx::Models::ConnectionJitterBuffer?
Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.
103 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 103 optional :jitter_buffer, -> { Telnyx::ConnectionJitterBuffer } |
#noise_suppression ⇒ Symbol, ...
Controls when noise suppression is applied to calls. When set to 'inbound', noise suppression is applied to incoming audio. When set to 'outbound', it's applied to outgoing audio. When set to 'both', it's applied in both directions. When set to 'disabled', noise suppression is turned off.
112 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 112 optional :noise_suppression, enum: -> { Telnyx::ConnectionNoiseSuppression } |
#noise_suppression_details ⇒ Telnyx::Models::ConnectionNoiseSuppressionDetails?
Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not 'disabled'. If you disable noise suppression and later re-enable it, the previously configured settings will be used.
121 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 121 optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails } |
#onnet_t38_passthrough_enabled ⇒ Boolean?
Enable on-net T38 if you prefer that the sender and receiver negotiate T38 directly when both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call according to each leg's settings.
129 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 129 optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean |
#outbound ⇒ Telnyx::Models::OutboundFqdn?
134 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 134 optional :outbound, -> { Telnyx::OutboundFqdn } |
#rtcp_settings ⇒ Telnyx::Models::ConnectionRtcpSettings?
139 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 139 optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings } |
#tags ⇒ Array<String>?
Tags associated with the connection.
145 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 145 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#transport_protocol ⇒ Symbol, ...
One of UDP, TLS, or TCP. Applies only to connections with IP authentication or FQDN authentication.
152 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 152 optional :transport_protocol, enum: -> { Telnyx::TransportProtocol } |
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
158 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 158 optional :webhook_api_version, enum: -> { Telnyx::WebhookAPIVersion } |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as 'https'.
165 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 165 optional :webhook_event_failover_url, String, nil?: true |
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent. Must include a scheme, such as 'https'.
172 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 172 optional :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
178 |
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 178 optional :webhook_timeout_secs, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ {
168 |
# File 'sig/telnyx/models/fqdn_connection_update_params.rbs', line 168
def to_hash: -> {
|