Class: Telnyx::Models::FqdnUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/fqdn_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, connection_id: nil, dns_record_type: nil, fqdn: nil, port: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::FqdnUpdateParams for more details.

Parameters:

  • id (String)
  • connection_id (String) (defaults to: nil)

    ID of the FQDN connection to which this IP should be attached.

  • dns_record_type (String) (defaults to: nil)

    The DNS record type for the FQDN. For cases where a port is not set, the DNS rec

  • fqdn (String) (defaults to: nil)

    FQDN represented by this resource.

  • port (Integer, nil) (defaults to: nil)

    Port to use when connecting to this FQDN.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/fqdn_update_params.rb', line 42

Instance Attribute Details

#connection_idString?

ID of the FQDN connection to which this IP should be attached.

Returns:

  • (String, nil)


19
# File 'lib/telnyx/models/fqdn_update_params.rb', line 19

optional :connection_id, String

#dns_record_typeString?

The DNS record type for the FQDN. For cases where a port is not set, the DNS record type must be ‘srv’. For cases where a port is set, the DNS record type must be ‘a’. If the DNS record type is ‘a’ and a port is not specified, 5060 will be used.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/fqdn_update_params.rb', line 28

optional :dns_record_type, String

#fqdnString?

FQDN represented by this resource.

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/fqdn_update_params.rb', line 34

optional :fqdn, String

#idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/fqdn_update_params.rb', line 13

required :id, String

#portInteger?

Port to use when connecting to this FQDN.

Returns:

  • (Integer, nil)


40
# File 'lib/telnyx/models/fqdn_update_params.rb', line 40

optional :port, Integer, nil?: true