Class: Telnyx::Models::GcsConfigurationData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::GcsConfigurationData
- Defined in:
- lib/telnyx/models/gcs_configuration_data.rb
Defined Under Namespace
Modules: Backend
Instance Attribute Summary collapse
-
#backend ⇒ Symbol, Telnyx::Models::GcsConfigurationData::Backend
Storage backend type.
-
#bucket ⇒ String?
Name of the bucket to be used to store recording files.
-
#credentials ⇒ String?
Opaque credential token used to authenticate and authorize with storage provider.
Instance Method Summary collapse
-
#initialize(backend:, bucket: nil, credentials: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see GcsConfigurationData for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(backend:, bucket: nil, credentials: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::GcsConfigurationData for more details.
|
|
# File 'lib/telnyx/models/gcs_configuration_data.rb', line 25
|
Instance Attribute Details
#backend ⇒ Symbol, Telnyx::Models::GcsConfigurationData::Backend
Storage backend type
10 |
# File 'lib/telnyx/models/gcs_configuration_data.rb', line 10 required :backend, enum: -> { Telnyx::GcsConfigurationData::Backend } |
#bucket ⇒ String?
Name of the bucket to be used to store recording files.
16 |
# File 'lib/telnyx/models/gcs_configuration_data.rb', line 16 optional :bucket, String |
#credentials ⇒ String?
Opaque credential token used to authenticate and authorize with storage provider.
23 |
# File 'lib/telnyx/models/gcs_configuration_data.rb', line 23 optional :credentials, String |