Class: Telnyx::Models::IPConnectionCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/ip_connection_create_params.rb

Overview

Defined Under Namespace

Modules: NoiseSuppression, TransportProtocol, WebhookAPIVersion Classes: Inbound

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#activeBoolean?

Defaults to true

Returns:

  • (Boolean, nil)


14
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 14

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



22
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 22

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#android_push_credential_idString?

The uuid of the push credential for Android

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 28

optional :android_push_credential_id, String, nil?: true

#call_cost_in_webhooksBoolean?

Specifies if call cost webhooks should be sent for this connection.

Returns:

  • (Boolean, nil)


34
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 34

optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean

#connection_nameString?

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 39

optional :connection_name, String

#default_on_hold_comfort_noise_enabledBoolean?

When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.

Returns:

  • (Boolean, nil)


47
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 47

optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean

#dtmf_typeSymbol, ...

Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.

Returns:



54
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 54

optional :dtmf_type, enum: -> { Telnyx::DtmfType }

#encode_contact_header_enabledBoolean?

Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.

Returns:

  • (Boolean, nil)


61
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 61

optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean

#encrypted_mediaSymbol, ...

Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.

Returns:



68
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 68

optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true

#inboundTelnyx::Models::IPConnectionCreateParams::Inbound?



73
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 73

optional :inbound, -> { Telnyx::IPConnectionCreateParams::Inbound }

#ios_push_credential_idString?

The uuid of the push credential for Ios

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 79

optional :ios_push_credential_id, String, nil?: true

#jitter_bufferTelnyx::Models::ConnectionJitterBuffer?

Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.



89
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 89

optional :jitter_buffer, -> { Telnyx::ConnectionJitterBuffer }

#noise_suppressionSymbol, ...

Controls when noise suppression is applied to calls. When set to ‘inbound’, noise suppression is applied to incoming audio. When set to ‘outbound’, it’s applied to outgoing audio. When set to ‘both’, it’s applied in both directions. When set to ‘disabled’, noise suppression is turned off.



98
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 98

optional :noise_suppression, enum: -> { Telnyx::IPConnectionCreateParams::NoiseSuppression }

#noise_suppression_detailsTelnyx::Models::ConnectionNoiseSuppressionDetails?

Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not ‘disabled’. If you disable noise suppression and later re-enable it, the previously configured settings will be used.



107
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 107

optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails }

#onnet_t38_passthrough_enabledBoolean?

Enable on-net T38 if you prefer the sender and receiver negotiating T38 directly if both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call depending on each leg’s settings.

Returns:

  • (Boolean, nil)


115
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 115

optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean

#outboundTelnyx::Models::OutboundIP?

Returns:



120
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 120

optional :outbound, -> { Telnyx::OutboundIP }

#rtcp_settingsTelnyx::Models::ConnectionRtcpSettings?



125
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 125

optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings }

#tagsArray<String>?

Tags associated with the connection.

Returns:

  • (Array<String>, nil)


131
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 131

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#transport_protocolSymbol, ...

One of UDP, TLS, or TCP. Applies only to connections with IP authentication or FQDN authentication.



138
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 138

optional :transport_protocol, enum: -> { Telnyx::IPConnectionCreateParams::TransportProtocol }

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1 or v2.



144
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 144

optional :webhook_api_version, enum: -> { Telnyx::IPConnectionCreateParams::WebhookAPIVersion }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


151
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 151

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


158
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 158

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


164
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 164

optional :webhook_timeout_secs, Integer, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ip_connection_create_params.rb', line 432