Class: Telnyx::Models::IPConnectionCreateParams::Inbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ip_connection_create_params.rb

Defined Under Namespace

Modules: AniNumberFormat, DefaultRoutingMethod, DnisNumberFormat, SipRegion, SipSubdomainReceiveSettings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, sip_compact_headers_enabled: nil, sip_region: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::IPConnectionCreateParams::Inbound for more details.

Parameters:

  • ani_number_format (Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::AniNumberFormat) (defaults to: nil)

    This setting allows you to set the format with which the caller’s number (ANI) i

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the total number of inbound calls to phone numbers ass

  • codecs (Array<String>) (defaults to: nil)

    Defines the list of codecs that Telnyx will send for inbound calls to a specific

  • default_routing_method (Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::DefaultRoutingMethod) (defaults to: nil)

    Default routing method to be used when a number is associated with the connectio

  • dnis_number_format (Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::DnisNumberFormat) (defaults to: nil)
  • generate_ringback_tone (Boolean) (defaults to: nil)

    Generate ringback tone through 183 session progress message with early media.

  • isup_headers_enabled (Boolean) (defaults to: nil)

    When set, inbound phone calls will receive ISUP parameters via SIP headers. (Onl

  • prack_enabled (Boolean) (defaults to: nil)

    Enable PRACK messages as defined in RFC3262.

  • shaken_stir_enabled (Boolean) (defaults to: nil)

    When enabled the SIP Connection will receive the Identity header with Shaken/Sti

  • sip_compact_headers_enabled (Boolean) (defaults to: nil)

    Defaults to true.

  • sip_region (Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::SipRegion) (defaults to: nil)

    Selects which ‘sip_region` to receive inbound calls from. If null, the default r

  • sip_subdomain (String) (defaults to: nil)

    Specifies a subdomain that can be used to receive Inbound calls to a Connection,

  • sip_subdomain_receive_settings (Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::SipSubdomainReceiveSettings) (defaults to: nil)

    This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in

  • timeout_1xx_secs (Integer) (defaults to: nil)

    Time(sec) before aborting if connection is not made.

  • timeout_2xx_secs (Integer) (defaults to: nil)

    Time(sec) before aborting if call is unanswered (min: 1, max: 600).



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 218

class Inbound < Telnyx::Internal::Type::BaseModel
  # @!attribute ani_number_format
  #   This setting allows you to set the format with which the caller's number (ANI)
  #   is sent for inbound phone calls.
  #
  #   @return [Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::AniNumberFormat, nil]
  optional :ani_number_format, enum: -> { Telnyx::IPConnectionCreateParams::Inbound::AniNumberFormat }

  # @!attribute channel_limit
  #   When set, this will limit the total number of inbound calls to phone numbers
  #   associated with this connection.
  #
  #   @return [Integer, nil]
  optional :channel_limit, Integer

  # @!attribute codecs
  #   Defines the list of codecs that Telnyx will send for inbound calls to a specific
  #   number on your portal account, in priority order. This only works when the
  #   Connection the number is assigned to uses Media Handling mode: default. OPUS and
  #   H.264 codecs are available only when using TCP or TLS transport for SIP.
  #
  #   @return [Array<String>, nil]
  optional :codecs, Telnyx::Internal::Type::ArrayOf[String]

  # @!attribute default_routing_method
  #   Default routing method to be used when a number is associated with the
  #   connection. Must be one of the routing method types or left blank, other values
  #   are not allowed.
  #
  #   @return [Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::DefaultRoutingMethod, nil]
  optional :default_routing_method,
           enum: -> { Telnyx::IPConnectionCreateParams::Inbound::DefaultRoutingMethod }

  # @!attribute dnis_number_format
  #
  #   @return [Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::DnisNumberFormat, nil]
  optional :dnis_number_format, enum: -> { Telnyx::IPConnectionCreateParams::Inbound::DnisNumberFormat }

  # @!attribute generate_ringback_tone
  #   Generate ringback tone through 183 session progress message with early media.
  #
  #   @return [Boolean, nil]
  optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean

  # @!attribute isup_headers_enabled
  #   When set, inbound phone calls will receive ISUP parameters via SIP headers.
  #   (Only when available and only when using TCP or TLS transport.)
  #
  #   @return [Boolean, nil]
  optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean

  # @!attribute prack_enabled
  #   Enable PRACK messages as defined in RFC3262.
  #
  #   @return [Boolean, nil]
  optional :prack_enabled, Telnyx::Internal::Type::Boolean

  # @!attribute shaken_stir_enabled
  #   When enabled the SIP Connection will receive the Identity header with
  #   Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP
  #   transport.
  #
  #   @return [Boolean, nil]
  optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean

  # @!attribute sip_compact_headers_enabled
  #   Defaults to true.
  #
  #   @return [Boolean, nil]
  optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean

  # @!attribute sip_region
  #   Selects which `sip_region` to receive inbound calls from. If null, the default
  #   region (US) will be used.
  #
  #   @return [Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::SipRegion, nil]
  optional :sip_region, enum: -> { Telnyx::IPConnectionCreateParams::Inbound::SipRegion }

  # @!attribute sip_subdomain
  #   Specifies a subdomain that can be used to receive Inbound calls to a Connection,
  #   in the same way a phone number is used, from a SIP endpoint. Example: the
  #   subdomain "example.sip.telnyx.com" can be called from any SIP endpoint by using
  #   the SIP URI "sip:@example.sip.telnyx.com" where the user part can be any
  #   alphanumeric value. Please note TLS encrypted calls are not allowed for
  #   subdomain calls.
  #
  #   @return [String, nil]
  optional :sip_subdomain, String

  # @!attribute sip_subdomain_receive_settings
  #   This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in
  #   the public Internet) or "Only my connections" (any connection assigned to the
  #   same Telnyx user).
  #
  #   @return [Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::SipSubdomainReceiveSettings, nil]
  optional :sip_subdomain_receive_settings,
           enum: -> { Telnyx::IPConnectionCreateParams::Inbound::SipSubdomainReceiveSettings }

  # @!attribute timeout_1xx_secs
  #   Time(sec) before aborting if connection is not made.
  #
  #   @return [Integer, nil]
  optional :timeout_1xx_secs, Integer

  # @!attribute timeout_2xx_secs
  #   Time(sec) before aborting if call is unanswered (min: 1, max: 600).
  #
  #   @return [Integer, nil]
  optional :timeout_2xx_secs, Integer

  # @!method initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, sip_compact_headers_enabled: nil, sip_region: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::IPConnectionCreateParams::Inbound} for more details.
  #
  #   @param ani_number_format [Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::AniNumberFormat] This setting allows you to set the format with which the caller's number (ANI) i
  #
  #   @param channel_limit [Integer] When set, this will limit the total number of inbound calls to phone numbers ass
  #
  #   @param codecs [Array<String>] Defines the list of codecs that Telnyx will send for inbound calls to a specific
  #
  #   @param default_routing_method [Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::DefaultRoutingMethod] Default routing method to be used when a number is associated with the connectio
  #
  #   @param dnis_number_format [Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::DnisNumberFormat]
  #
  #   @param generate_ringback_tone [Boolean] Generate ringback tone through 183 session progress message with early media.
  #
  #   @param isup_headers_enabled [Boolean] When set, inbound phone calls will receive ISUP parameters via SIP headers. (Onl
  #
  #   @param prack_enabled [Boolean] Enable PRACK messages as defined in RFC3262.
  #
  #   @param shaken_stir_enabled [Boolean] When enabled the SIP Connection will receive the Identity header with Shaken/Sti
  #
  #   @param sip_compact_headers_enabled [Boolean] Defaults to true.
  #
  #   @param sip_region [Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::SipRegion] Selects which `sip_region` to receive inbound calls from. If null, the default r
  #
  #   @param sip_subdomain [String] Specifies a subdomain that can be used to receive Inbound calls to a Connection,
  #
  #   @param sip_subdomain_receive_settings [Symbol, Telnyx::Models::IPConnectionCreateParams::Inbound::SipSubdomainReceiveSettings] This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in
  #
  #   @param timeout_1xx_secs [Integer] Time(sec) before aborting if connection is not made.
  #
  #   @param timeout_2xx_secs [Integer] Time(sec) before aborting if call is unanswered (min: 1, max: 600).

  # This setting allows you to set the format with which the caller's number (ANI)
  # is sent for inbound phone calls.
  #
  # @see Telnyx::Models::IPConnectionCreateParams::Inbound#ani_number_format
  module AniNumberFormat
    extend Telnyx::Internal::Type::Enum

    PLUS_E_164 = :"+E.164"
    E_164 = :"E.164"
    PLUS_E_164_NATIONAL = :"+E.164-national"
    E_164_NATIONAL = :"E.164-national"

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # Default routing method to be used when a number is associated with the
  # connection. Must be one of the routing method types or left blank, other values
  # are not allowed.
  #
  # @see Telnyx::Models::IPConnectionCreateParams::Inbound#default_routing_method
  module DefaultRoutingMethod
    extend Telnyx::Internal::Type::Enum

    SEQUENTIAL = :sequential
    ROUND_ROBIN = :"round-robin"

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # @see Telnyx::Models::IPConnectionCreateParams::Inbound#dnis_number_format
  module DnisNumberFormat
    extend Telnyx::Internal::Type::Enum

    PLUS_E164 = :"+e164"
    E164 = :e164
    NATIONAL = :national
    SIP_USERNAME = :sip_username

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # Selects which `sip_region` to receive inbound calls from. If null, the default
  # region (US) will be used.
  #
  # @see Telnyx::Models::IPConnectionCreateParams::Inbound#sip_region
  module SipRegion
    extend Telnyx::Internal::Type::Enum

    US = :US
    EUROPE = :Europe
    AUSTRALIA = :Australia

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in
  # the public Internet) or "Only my connections" (any connection assigned to the
  # same Telnyx user).
  #
  # @see Telnyx::Models::IPConnectionCreateParams::Inbound#sip_subdomain_receive_settings
  module SipSubdomainReceiveSettings
    extend Telnyx::Internal::Type::Enum

    ONLY_MY_CONNECTIONS = :only_my_connections
    FROM_ANYONE = :from_anyone

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#ani_number_formatSymbol, ...

This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.



224
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 224

optional :ani_number_format, enum: -> { Telnyx::IPConnectionCreateParams::Inbound::AniNumberFormat }

#channel_limitInteger?

When set, this will limit the total number of inbound calls to phone numbers associated with this connection.

Returns:

  • (Integer, nil)


231
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 231

optional :channel_limit, Integer

#codecsArray<String>?

Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order. This only works when the Connection the number is assigned to uses Media Handling mode: default. OPUS and H.264 codecs are available only when using TCP or TLS transport for SIP.

Returns:

  • (Array<String>, nil)


240
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 240

optional :codecs, Telnyx::Internal::Type::ArrayOf[String]

#default_routing_methodSymbol, ...

Default routing method to be used when a number is associated with the connection. Must be one of the routing method types or left blank, other values are not allowed.



248
249
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 248

optional :default_routing_method,
enum: -> { Telnyx::IPConnectionCreateParams::Inbound::DefaultRoutingMethod }

#dnis_number_formatSymbol, ...



254
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 254

optional :dnis_number_format, enum: -> { Telnyx::IPConnectionCreateParams::Inbound::DnisNumberFormat }

#generate_ringback_toneBoolean?

Generate ringback tone through 183 session progress message with early media.

Returns:

  • (Boolean, nil)


260
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 260

optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean

#isup_headers_enabledBoolean?

When set, inbound phone calls will receive ISUP parameters via SIP headers. (Only when available and only when using TCP or TLS transport.)

Returns:

  • (Boolean, nil)


267
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 267

optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean

#prack_enabledBoolean?

Enable PRACK messages as defined in RFC3262.

Returns:

  • (Boolean, nil)


273
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 273

optional :prack_enabled, Telnyx::Internal::Type::Boolean

#shaken_stir_enabledBoolean?

When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.

Returns:

  • (Boolean, nil)


281
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 281

optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean

#sip_compact_headers_enabledBoolean?

Defaults to true.

Returns:

  • (Boolean, nil)


287
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 287

optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean

#sip_regionSymbol, ...

Selects which ‘sip_region` to receive inbound calls from. If null, the default region (US) will be used.



294
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 294

optional :sip_region, enum: -> { Telnyx::IPConnectionCreateParams::Inbound::SipRegion }

#sip_subdomainString?

Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint. Example: the subdomain “example.sip.telnyx.com” can be called from any SIP endpoint by using the SIP URI “sip:@example.sip.telnyx.com” where the user part can be any alphanumeric value. Please note TLS encrypted calls are not allowed for subdomain calls.

Returns:

  • (String, nil)


305
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 305

optional :sip_subdomain, String

#sip_subdomain_receive_settingsSymbol, ...

This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).



313
314
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 313

optional :sip_subdomain_receive_settings,
enum: -> { Telnyx::IPConnectionCreateParams::Inbound::SipSubdomainReceiveSettings }

#timeout_1xx_secsInteger?

Time(sec) before aborting if connection is not made.

Returns:

  • (Integer, nil)


320
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 320

optional :timeout_1xx_secs, Integer

#timeout_2xx_secsInteger?

Time(sec) before aborting if call is unanswered (min: 1, max: 600).

Returns:

  • (Integer, nil)


326
# File 'lib/telnyx/models/ip_connection_create_params.rb', line 326

optional :timeout_2xx_secs, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ip_connection_create_params.rb', line 374