Class: Telnyx::Models::IPConnectionListParams::Filter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ip_connection_list_params.rb,
sig/telnyx/models/ip_connection_list_params.rbs

Defined Under Namespace

Classes: ConnectionName

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(connection_name: nil, fqdn: nil, outbound_voice_profile_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::IPConnectionListParams::Filter for more details.

Consolidated filter parameter (deepObject style). Originally: filter, filter, filter, filter

Parameters:

  • connection_name (Telnyx::Models::IPConnectionListParams::Filter::ConnectionName) (defaults to: nil)

    Filter by connection_name using nested operations

  • fqdn (String) (defaults to: nil)

    If present, connections with an fqdn that equals the given value will be retur

  • outbound_voice_profile_id (String) (defaults to: nil)

    Identifies the associated outbound voice profile.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/telnyx/models/ip_connection_list_params.rb', line 62

class Filter < Telnyx::Internal::Type::BaseModel
  # @!attribute connection_name
  #   Filter by connection_name using nested operations
  #
  #   @return [Telnyx::Models::IPConnectionListParams::Filter::ConnectionName, nil]
  optional :connection_name, -> { Telnyx::IPConnectionListParams::Filter::ConnectionName }

  # @!attribute fqdn
  #   If present, connections with an `fqdn` that equals the given value will be
  #   returned. Matching is case-sensitive, and the full string must match.
  #
  #   @return [String, nil]
  optional :fqdn, String

  # @!attribute outbound_voice_profile_id
  #   Identifies the associated outbound voice profile.
  #
  #   @return [String, nil]
  optional :outbound_voice_profile_id, String

  # @!method initialize(connection_name: nil, fqdn: nil, outbound_voice_profile_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::IPConnectionListParams::Filter} for more details.
  #
  #   Consolidated filter parameter (deepObject style). Originally:
  #   filter[connection_name], filter[fqdn], filter[outbound_voice_profile_id],
  #   filter[outbound.outbound_voice_profile_id]
  #
  #   @param connection_name [Telnyx::Models::IPConnectionListParams::Filter::ConnectionName] Filter by connection_name using nested operations
  #
  #   @param fqdn [String] If present, connections with an `fqdn` that equals the given value will be retur
  #
  #   @param outbound_voice_profile_id [String] Identifies the associated outbound voice profile.

  # @see Telnyx::Models::IPConnectionListParams::Filter#connection_name
  class ConnectionName < Telnyx::Internal::Type::BaseModel
    # @!attribute contains
    #   If present, connections with <code>connection_name</code> containing the given
    #   value will be returned. Matching is not case-sensitive. Requires at least three
    #   characters.
    #
    #   @return [String, nil]
    optional :contains, String

    # @!method initialize(contains: nil)
    #   Some parameter documentations has been truncated, see
    #   {Telnyx::Models::IPConnectionListParams::Filter::ConnectionName} for more
    #   details.
    #
    #   Filter by connection_name using nested operations
    #
    #   @param contains [String] If present, connections with <code>connection_name</code> containing the given v
  end
end

Instance Attribute Details

#connection_nameTelnyx::Models::IPConnectionListParams::Filter::ConnectionName?

Filter by connection_name using nested operations



67
# File 'lib/telnyx/models/ip_connection_list_params.rb', line 67

optional :connection_name, -> { Telnyx::IPConnectionListParams::Filter::ConnectionName }

#fqdnString?

If present, connections with an fqdn that equals the given value will be returned. Matching is case-sensitive, and the full string must match.

Parameters:

  • (String)

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/ip_connection_list_params.rb', line 74

optional :fqdn, String

#outbound_voice_profile_idString?

Identifies the associated outbound voice profile.

Parameters:

  • (String)

Returns:

  • (String, nil)


80
# File 'lib/telnyx/models/ip_connection_list_params.rb', line 80

optional :outbound_voice_profile_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


80
# File 'sig/telnyx/models/ip_connection_list_params.rbs', line 80

def to_hash: -> {