Class: Telnyx::Models::InboundChannelListResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::InboundChannelListResponse::Data
- Defined in:
- lib/telnyx/models/inbound_channel_list_response.rb
Overview
Instance Attribute Summary collapse
-
#channels ⇒ Integer?
The current number of concurrent channels set for the account.
-
#record_type ⇒ String?
Identifies the type of the response.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channels: nil, record_type: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/inbound_channel_list_response.rb', line 29
|
Instance Attribute Details
#channels ⇒ Integer?
The current number of concurrent channels set for the account
21 |
# File 'lib/telnyx/models/inbound_channel_list_response.rb', line 21 optional :channels, Integer |
#record_type ⇒ String?
Identifies the type of the response
27 |
# File 'lib/telnyx/models/inbound_channel_list_response.rb', line 27 optional :record_type, String |