Module: Telnyx::Models::InboundFqdn::DefaultRoutingMethod

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/inbound_fqdn.rb

Overview

Default routing method to be used when a number is associated with the connection. Must be one of the routing method types or null, other values are not allowed.

Constant Summary collapse

SEQUENTIAL =
:sequential
ROUND_ROBIN =
:"round-robin"

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info