Class: Telnyx::Models::InboundIP

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/inbound_ip.rb

Defined Under Namespace

Modules: AniNumberFormat, DefaultRoutingMethod, DnisNumberFormat, SipRegion, SipSubdomainReceiveSettings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_primary_ip_id: nil, default_routing_method: nil, default_secondary_ip_id: nil, default_tertiary_ip_id: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, sip_compact_headers_enabled: nil, sip_region: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::InboundIP for more details.

Parameters:

  • ani_number_format (Symbol, Telnyx::Models::InboundIP::AniNumberFormat) (defaults to: nil)

    This setting allows you to set the format with which the caller’s number (ANI) i

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the total number of inbound calls to phone numbers ass

  • codecs (Array<String>) (defaults to: nil)

    Defines the list of codecs that Telnyx will send for inbound calls to a specific

  • default_primary_ip_id (String) (defaults to: nil)

    The default primary IP to use for the number. Only settable if the connection is

  • default_routing_method (Symbol, Telnyx::Models::InboundIP::DefaultRoutingMethod) (defaults to: nil)

    Default routing method to be used when a number is associated with the connectio

  • default_secondary_ip_id (String) (defaults to: nil)

    The default secondary IP to use for the number. Only settable if the connection

  • default_tertiary_ip_id (String) (defaults to: nil)

    The default tertiary IP to use for the number. Only settable if the connection i

  • dnis_number_format (Symbol, Telnyx::Models::InboundIP::DnisNumberFormat) (defaults to: nil)
  • generate_ringback_tone (Boolean) (defaults to: nil)

    Generate ringback tone through 183 session progress message with early media.

  • isup_headers_enabled (Boolean) (defaults to: nil)

    When set, inbound phone calls will receive ISUP parameters via SIP headers. (Onl

  • prack_enabled (Boolean) (defaults to: nil)

    Enable PRACK messages as defined in RFC3262.

  • shaken_stir_enabled (Boolean) (defaults to: nil)

    When enabled the SIP Connection will receive the Identity header with Shaken/Sti

  • sip_compact_headers_enabled (Boolean) (defaults to: nil)

    Defaults to true.

  • sip_region (Symbol, Telnyx::Models::InboundIP::SipRegion) (defaults to: nil)

    Selects which ‘sip_region` to receive inbound calls from. If null, the default r

  • sip_subdomain (String) (defaults to: nil)

    Specifies a subdomain that can be used to receive Inbound calls to a Connection,

  • sip_subdomain_receive_settings (Symbol, Telnyx::Models::InboundIP::SipSubdomainReceiveSettings) (defaults to: nil)

    This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in

  • timeout_1xx_secs (Integer) (defaults to: nil)

    Time(sec) before aborting if connection is not made.

  • timeout_2xx_secs (Integer) (defaults to: nil)

    Time(sec) before aborting if call is unanswered (min: 1, max: 600).



# File 'lib/telnyx/models/inbound_ip.rb', line 137

Instance Attribute Details

#ani_number_formatSymbol, ...

This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.



11
# File 'lib/telnyx/models/inbound_ip.rb', line 11

optional :ani_number_format, enum: -> { Telnyx::InboundIP::AniNumberFormat }

#channel_limitInteger?

When set, this will limit the total number of inbound calls to phone numbers associated with this connection.

Returns:

  • (Integer, nil)


18
# File 'lib/telnyx/models/inbound_ip.rb', line 18

optional :channel_limit, Integer

#codecsArray<String>?

Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order. This only works when the Connection the number is assigned to uses Media Handling mode: default. OPUS and H.264 codecs are available only when using TCP or TLS transport for SIP.

Returns:

  • (Array<String>, nil)


27
# File 'lib/telnyx/models/inbound_ip.rb', line 27

optional :codecs, Telnyx::Internal::Type::ArrayOf[String]

#default_primary_ip_idString?

The default primary IP to use for the number. Only settable if the connection is of IP authentication type. Value must be the ID of an authorized IP set on the connection.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/inbound_ip.rb', line 35

optional :default_primary_ip_id, String

#default_routing_methodSymbol, ...

Default routing method to be used when a number is associated with the connection. Must be one of the routing method types or left blank, other values are not allowed.



43
# File 'lib/telnyx/models/inbound_ip.rb', line 43

optional :default_routing_method, enum: -> { Telnyx::InboundIP::DefaultRoutingMethod }

#default_secondary_ip_idString?

The default secondary IP to use for the number. Only settable if the connection is of IP authentication type. Value must be the ID of an authorized IP set on the connection.

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/inbound_ip.rb', line 51

optional :default_secondary_ip_id, String

#default_tertiary_ip_idString?

The default tertiary IP to use for the number. Only settable if the connection is of IP authentication type. Value must be the ID of an authorized IP set on the connection.

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/inbound_ip.rb', line 59

optional :default_tertiary_ip_id, String

#dnis_number_formatSymbol, ...



64
# File 'lib/telnyx/models/inbound_ip.rb', line 64

optional :dnis_number_format, enum: -> { Telnyx::InboundIP::DnisNumberFormat }

#generate_ringback_toneBoolean?

Generate ringback tone through 183 session progress message with early media.

Returns:

  • (Boolean, nil)


70
# File 'lib/telnyx/models/inbound_ip.rb', line 70

optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean

#isup_headers_enabledBoolean?

When set, inbound phone calls will receive ISUP parameters via SIP headers. (Only when available and only when using TCP or TLS transport.)

Returns:

  • (Boolean, nil)


77
# File 'lib/telnyx/models/inbound_ip.rb', line 77

optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean

#prack_enabledBoolean?

Enable PRACK messages as defined in RFC3262.

Returns:

  • (Boolean, nil)


83
# File 'lib/telnyx/models/inbound_ip.rb', line 83

optional :prack_enabled, Telnyx::Internal::Type::Boolean

#shaken_stir_enabledBoolean?

When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.

Returns:

  • (Boolean, nil)


91
# File 'lib/telnyx/models/inbound_ip.rb', line 91

optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean

#sip_compact_headers_enabledBoolean?

Defaults to true.

Returns:

  • (Boolean, nil)


97
# File 'lib/telnyx/models/inbound_ip.rb', line 97

optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean

#sip_regionSymbol, ...

Selects which ‘sip_region` to receive inbound calls from. If null, the default region (US) will be used.

Returns:



104
# File 'lib/telnyx/models/inbound_ip.rb', line 104

optional :sip_region, enum: -> { Telnyx::InboundIP::SipRegion }

#sip_subdomainString?

Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint. Example: the subdomain “example.sip.telnyx.com” can be called from any SIP endpoint by using the SIP URI “sip:@example.sip.telnyx.com” where the user part can be any alphanumeric value. Please note TLS encrypted calls are not allowed for subdomain calls.

Returns:

  • (String, nil)


115
# File 'lib/telnyx/models/inbound_ip.rb', line 115

optional :sip_subdomain, String

#sip_subdomain_receive_settingsSymbol, ...

This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).



123
# File 'lib/telnyx/models/inbound_ip.rb', line 123

optional :sip_subdomain_receive_settings, enum: -> { Telnyx::InboundIP::SipSubdomainReceiveSettings }

#timeout_1xx_secsInteger?

Time(sec) before aborting if connection is not made.

Returns:

  • (Integer, nil)


129
# File 'lib/telnyx/models/inbound_ip.rb', line 129

optional :timeout_1xx_secs, Integer

#timeout_2xx_secsInteger?

Time(sec) before aborting if call is unanswered (min: 1, max: 600).

Returns:

  • (Integer, nil)


135
# File 'lib/telnyx/models/inbound_ip.rb', line 135

optional :timeout_2xx_secs, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/inbound_ip.rb', line 189