Class: Telnyx::Models::InboundMessagePayload::Media
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::InboundMessagePayload::Media
- Defined in:
- lib/telnyx/models/inbound_message_payload.rb
Instance Attribute Summary collapse
-
#content_type ⇒ String?
The MIME type of the requested media.
-
#hash_sha256 ⇒ String?
The SHA256 hash of the requested media.
-
#size ⇒ Integer?
The size of the requested media.
-
#url ⇒ String?
The url of the media requested to be sent.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#content_type ⇒ String?
The MIME type of the requested media.
457 |
# File 'lib/telnyx/models/inbound_message_payload.rb', line 457 optional :content_type, String |
#hash_sha256 ⇒ String?
The SHA256 hash of the requested media.
463 |
# File 'lib/telnyx/models/inbound_message_payload.rb', line 463 optional :hash_sha256, String |
#size ⇒ Integer?
The size of the requested media.
469 |
# File 'lib/telnyx/models/inbound_message_payload.rb', line 469 optional :size, Integer |
#url ⇒ String?
The url of the media requested to be sent.
475 |
# File 'lib/telnyx/models/inbound_message_payload.rb', line 475 optional :url, String |