Class: Telnyx::Models::InboundMessageWebhookEvent::Data::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/inbound_message_webhook_event.rb,
sig/telnyx/models/inbound_message_webhook_event.rbs

Overview

See Also:

  • Telnyx::Models::InboundMessageWebhookEvent::Data#payload

Defined Under Namespace

Modules: Direction, RecordType, Type Classes: Cc, Cost, CostBreakdown, From, Media, To

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content_type: nil, hash_sha256: nil, size: nil, url: nil) ⇒ Object

Parameters:

  • content_type (String) (defaults to: nil)

    The MIME type of the requested media.

  • hash_sha256 (String) (defaults to: nil)

    The SHA256 hash of the requested media.

  • size (Integer) (defaults to: nil)

    The size of the requested media.

  • url (String) (defaults to: nil)

    The url of the media requested to be sent.



# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 384

Instance Attribute Details

#ccArray<Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::Cc>?



79
80
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 79

optional :cc,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::InboundMessageWebhookEvent::Data::Payload::Cc] }

#completed_atTime?

Not used for inbound messages.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


86
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 86

optional :completed_at, Time, nil?: true

#costTelnyx::Models::InboundMessageWebhookEvent::Data::Payload::Cost?

Parameters:

  • value (Telnyx::InboundMessageWebhookEvent::Data::Payload::Cost, nil)

Returns:



91
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 91

optional :cost, -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::Cost }, nil?: true

#cost_breakdownTelnyx::Models::InboundMessageWebhookEvent::Data::Payload::CostBreakdown?

Detailed breakdown of the message cost components.

Parameters:

  • value (Telnyx::InboundMessageWebhookEvent::Data::Payload::CostBreakdown, nil)

Returns:



97
98
99
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 97

optional :cost_breakdown,
-> { Telnyx::InboundMessageWebhookEvent::Data::Payload::CostBreakdown },
nil?: true

#directionSymbol, ...

The direction of the message. Inbound messages are sent to you whereas outbound messages are sent from you.



106
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 106

optional :direction, enum: -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::Direction }

#encodingString?

Encoding scheme used for the message body.

Parameters:

  • (String)

Returns:

  • (String, nil)


112
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 112

optional :encoding, String

#errorsArray<Telnyx::Models::MessagingError0b38e7044b>?

These errors may point at addressees when referring to unsuccessful/unconfirmed delivery statuses.



119
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 119

optional :errors, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::MessagingError0b38e7044b] }

#fromTelnyx::Models::InboundMessageWebhookEvent::Data::Payload::From?



124
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 124

optional :from, -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::From }

#idString?

Identifies the type of resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 74

optional :id, String

#mediaArray<Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::Media>?



129
130
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 129

optional :media,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::InboundMessageWebhookEvent::Data::Payload::Media] }

#messaging_profile_idString?

Unique identifier for a messaging profile.

Parameters:

  • (String)

Returns:

  • (String, nil)


136
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 136

optional :messaging_profile_id, String

#num_charsInteger?

The number of characters in the message text

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


142
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 142

optional :num_chars, Integer

#organization_idString?

Unique identifier for a messaging profile.

Parameters:

  • (String)

Returns:

  • (String, nil)


148
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 148

optional :organization_id, String

#partsInteger?

Number of parts into which the message's body must be split.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


154
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 154

optional :parts, Integer

#received_atTime?

ISO 8601 formatted date indicating when the message request was received.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


160
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 160

optional :received_at, Time

#record_typeSymbol, ...

Identifies the type of the resource.



166
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 166

optional :record_type, enum: -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::RecordType }

#sent_atTime?

Not used for inbound messages.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


172
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 172

optional :sent_at, Time, nil?: true

#subjectString?

Message subject.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


178
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 178

optional :subject, String, nil?: true

#tagsArray<String>?

Tags associated with the resource.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


184
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 184

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#tcr_campaign_billableBoolean?

Indicates whether the TCR campaign is billable.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


190
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 190

optional :tcr_campaign_billable, Telnyx::Internal::Type::Boolean

#tcr_campaign_idString?

The Campaign Registry (TCR) campaign ID associated with the message.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


196
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 196

optional :tcr_campaign_id, String, nil?: true

#tcr_campaign_registeredString?

The registration status of the TCR campaign.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


202
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 202

optional :tcr_campaign_registered, String, nil?: true

#textString?

Message body (i.e., content) as a non-empty string.

Required for SMS

Parameters:

  • (String)

Returns:

  • (String, nil)


210
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 210

optional :text, String

#toArray<Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::To>?



215
216
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 215

optional :to,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::InboundMessageWebhookEvent::Data::Payload::To] }

#typeSymbol, ...

The type of message. This value can be either 'sms' or 'mms'.



222
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 222

optional :type, enum: -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::Type }

#valid_untilTime?

Not used for inbound messages.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


228
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 228

optional :valid_until, Time, nil?: true

#webhook_failover_urlString?

The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


235
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 235

optional :webhook_failover_url, String, nil?: true

#webhook_urlString?

The URL where webhooks related to this message will be sent.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


241
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 241

optional :webhook_url, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 365

Instance Method Details

#to_hash{

Returns:

  • ({)


251
# File 'sig/telnyx/models/inbound_message_webhook_event.rbs', line 251

def to_hash: -> {