Class: Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::PhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/inexplicit_number_order_create_params.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#containsString?

Filter for phone numbers that contain the digits specified

Returns:

  • (String, nil)


178
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 178

optional :contains, String

#ends_withString?

Filter by the ending digits of the phone number

Returns:

  • (String, nil)


184
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 184

optional :ends_with, String

#starts_withString?

Filter by the starting digits of the phone number

Returns:

  • (String, nil)


190
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 190

optional :starts_with, String