Module: Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::Strategy

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/inexplicit_number_order_create_params.rb

Overview

Ordering strategy. Define what action should be taken if we don’t have enough phone numbers to fulfill your request. Allowable values are: always = proceed with ordering phone numbers, regardless of current inventory levels; never = do not place any orders unless there are enough phone numbers to satisfy the request. If not specified, the always strategy will be enforced.

See Also:

Constant Summary collapse

ALWAYS =
:always
NEVER =
:never

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 215