Class: Telnyx::Models::InexplicitNumberOrderResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/inexplicit_number_order_response.rb

Overview

Defined Under Namespace

Classes: OrderingGroup

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#billing_group_idString?

Billing group id to apply to phone numbers that are purchased

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 17

optional :billing_group_id, String

#connection_idString?

Connection id to apply to phone numbers that are purchased

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 23

optional :connection_id, String

#created_atTime?

ISO 8601 formatted date indicating when the resource was created

Returns:

  • (Time, nil)


29
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 29

optional :created_at, Time

#customer_referenceString?

Reference label for the customer

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 35

optional :customer_reference, String

#idString?

Unique identifier for the inexplicit number order

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 11

optional :id, String

#messaging_profile_idString?

Messaging profile id to apply to phone numbers that are purchased

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 41

optional :messaging_profile_id, String

#ordering_groupsArray<Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup>?



46
47
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 46

optional :ordering_groups,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::InexplicitNumberOrderResponse::OrderingGroup] }

#updated_atTime?

ISO 8601 formatted date indicating when the resource was updated

Returns:

  • (Time, nil)


53
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 53

optional :updated_at, Time