Class: Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/inexplicit_number_order_response.rb

Defined Under Namespace

Modules: Status, Strategy Classes: Order

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(number_order_id:, sub_number_order_ids:) ⇒ Object

Parameters:

  • number_order_id (String)

    ID of the main number order

  • sub_number_order_ids (Array<String>)

    Array of sub number order IDs



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 72

class OrderingGroup < Telnyx::Internal::Type::BaseModel
  # @!attribute administrative_area
  #   Filter for phone numbers in a given state / province
  #
  #   @return [String, nil]
  optional :administrative_area, String

  # @!attribute count_allocated
  #   Quantity of phone numbers allocated
  #
  #   @return [Integer, nil]
  optional :count_allocated, Integer

  # @!attribute count_requested
  #   Quantity of phone numbers requested
  #
  #   @return [Integer, nil]
  optional :count_requested, Integer

  # @!attribute country_iso
  #   Country where you would like to purchase phone numbers
  #
  #   @return [String, nil]
  optional :country_iso, String

  # @!attribute created_at
  #   ISO 8601 formatted date indicating when the ordering group was created
  #
  #   @return [Time, nil]
  optional :created_at, Time

  # @!attribute error_reason
  #   Error reason if applicable
  #
  #   @return [String, nil]
  optional :error_reason, String

  # @!attribute exclude_held_numbers
  #   Filter to exclude phone numbers that are currently on hold/reserved for your
  #   account.
  #
  #   @return [Boolean, nil]
  optional :exclude_held_numbers, Telnyx::Internal::Type::Boolean

  # @!attribute national_destination_code
  #   Filter by area code
  #
  #   @return [String, nil]
  optional :national_destination_code, String

  # @!attribute orders
  #   Array of orders created to fulfill the inexplicit order
  #
  #   @return [Array<Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Order>, nil]
  optional :orders,
           -> { Telnyx::Internal::Type::ArrayOf[Telnyx::InexplicitNumberOrderResponse::OrderingGroup::Order] }

  # @!attribute phone_number_type
  #   Number type
  #
  #   @return [String, nil]
  optional :phone_number_type, String

  # @!attribute phone_number_contains
  #   Filter for phone numbers that contain the digits specified
  #
  #   @return [String, nil]
  optional :phone_number_contains, String, api_name: :"phone_number[contains]"

  # @!attribute phone_number_ends_with
  #   Filter by the ending digits of the phone number
  #
  #   @return [String, nil]
  optional :phone_number_ends_with, String, api_name: :"phone_number[ends_with]"

  # @!attribute phone_number_starts_with
  #   Filter by the starting digits of the phone number
  #
  #   @return [String, nil]
  optional :phone_number_starts_with, String, api_name: :"phone_number[starts_with]"

  # @!attribute quickship
  #   Filter to exclude phone numbers that need additional time after to purchase to
  #   activate. Only applicable for +1 toll_free numbers.
  #
  #   @return [Boolean, nil]
  optional :quickship, Telnyx::Internal::Type::Boolean

  # @!attribute status
  #   Status of the ordering group
  #
  #   @return [Symbol, Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Status, nil]
  optional :status, enum: -> { Telnyx::InexplicitNumberOrderResponse::OrderingGroup::Status }

  # @!attribute strategy
  #   Ordering strategy used
  #
  #   @return [Symbol, Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Strategy, nil]
  optional :strategy, enum: -> { Telnyx::InexplicitNumberOrderResponse::OrderingGroup::Strategy }

  # @!attribute updated_at
  #   ISO 8601 formatted date indicating when the ordering group was updated
  #
  #   @return [Time, nil]
  optional :updated_at, Time

  # @!method initialize(administrative_area: nil, count_allocated: nil, count_requested: nil, country_iso: nil, created_at: nil, error_reason: nil, exclude_held_numbers: nil, national_destination_code: nil, orders: nil, phone_number_type: nil, phone_number_contains: nil, phone_number_ends_with: nil, phone_number_starts_with: nil, quickship: nil, status: nil, strategy: nil, updated_at: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup} for more details.
  #
  #   @param administrative_area [String] Filter for phone numbers in a given state / province
  #
  #   @param count_allocated [Integer] Quantity of phone numbers allocated
  #
  #   @param count_requested [Integer] Quantity of phone numbers requested
  #
  #   @param country_iso [String] Country where you would like to purchase phone numbers
  #
  #   @param created_at [Time] ISO 8601 formatted date indicating when the ordering group was created
  #
  #   @param error_reason [String] Error reason if applicable
  #
  #   @param exclude_held_numbers [Boolean] Filter to exclude phone numbers that are currently on hold/reserved for your acc
  #
  #   @param national_destination_code [String] Filter by area code
  #
  #   @param orders [Array<Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Order>] Array of orders created to fulfill the inexplicit order
  #
  #   @param phone_number_type [String] Number type
  #
  #   @param phone_number_contains [String] Filter for phone numbers that contain the digits specified
  #
  #   @param phone_number_ends_with [String] Filter by the ending digits of the phone number
  #
  #   @param phone_number_starts_with [String] Filter by the starting digits of the phone number
  #
  #   @param quickship [Boolean] Filter to exclude phone numbers that need additional time after to purchase to a
  #
  #   @param status [Symbol, Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Status] Status of the ordering group
  #
  #   @param strategy [Symbol, Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Strategy] Ordering strategy used
  #
  #   @param updated_at [Time] ISO 8601 formatted date indicating when the ordering group was updated

  class Order < Telnyx::Internal::Type::BaseModel
    # @!attribute number_order_id
    #   ID of the main number order
    #
    #   @return [String]
    required :number_order_id, String

    # @!attribute sub_number_order_ids
    #   Array of sub number order IDs
    #
    #   @return [Array<String>]
    required :sub_number_order_ids, Telnyx::Internal::Type::ArrayOf[String]

    # @!method initialize(number_order_id:, sub_number_order_ids:)
    #   @param number_order_id [String] ID of the main number order
    #
    #   @param sub_number_order_ids [Array<String>] Array of sub number order IDs
  end

  # Status of the ordering group
  #
  # @see Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup#status
  module Status
    extend Telnyx::Internal::Type::Enum

    PENDING = :pending
    PROCESSING = :processing
    FAILED = :failed
    SUCCESS = :success
    PARTIAL_SUCCESS = :partial_success

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # Ordering strategy used
  #
  # @see Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup#strategy
  module Strategy
    extend Telnyx::Internal::Type::Enum

    ALWAYS = :always
    NEVER = :never

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#administrative_areaString?

Filter for phone numbers in a given state / province

Returns:

  • (String, nil)


77
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 77

optional :administrative_area, String

#count_allocatedInteger?

Quantity of phone numbers allocated

Returns:

  • (Integer, nil)


83
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 83

optional :count_allocated, Integer

#count_requestedInteger?

Quantity of phone numbers requested

Returns:

  • (Integer, nil)


89
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 89

optional :count_requested, Integer

#country_isoString?

Country where you would like to purchase phone numbers

Returns:

  • (String, nil)


95
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 95

optional :country_iso, String

#created_atTime?

ISO 8601 formatted date indicating when the ordering group was created

Returns:

  • (Time, nil)


101
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 101

optional :created_at, Time

#error_reasonString?

Error reason if applicable

Returns:

  • (String, nil)


107
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 107

optional :error_reason, String

#exclude_held_numbersBoolean?

Filter to exclude phone numbers that are currently on hold/reserved for your account.

Returns:

  • (Boolean, nil)


114
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 114

optional :exclude_held_numbers, Telnyx::Internal::Type::Boolean

#national_destination_codeString?

Filter by area code

Returns:

  • (String, nil)


120
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 120

optional :national_destination_code, String

#ordersArray<Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Order>?

Array of orders created to fulfill the inexplicit order



126
127
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 126

optional :orders,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::InexplicitNumberOrderResponse::OrderingGroup::Order] }

#phone_number_containsString?

Filter for phone numbers that contain the digits specified

Returns:

  • (String, nil)


139
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 139

optional :phone_number_contains, String, api_name: :"phone_number[contains]"

#phone_number_ends_withString?

Filter by the ending digits of the phone number

Returns:

  • (String, nil)


145
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 145

optional :phone_number_ends_with, String, api_name: :"phone_number[ends_with]"

#phone_number_starts_withString?

Filter by the starting digits of the phone number

Returns:

  • (String, nil)


151
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 151

optional :phone_number_starts_with, String, api_name: :"phone_number[starts_with]"

#phone_number_typeString?

Number type

Returns:

  • (String, nil)


133
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 133

optional :phone_number_type, String

#quickshipBoolean?

Filter to exclude phone numbers that need additional time after to purchase to activate. Only applicable for +1 toll_free numbers.

Returns:

  • (Boolean, nil)


158
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 158

optional :quickship, Telnyx::Internal::Type::Boolean

#statusSymbol, ...

Status of the ordering group



164
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 164

optional :status, enum: -> { Telnyx::InexplicitNumberOrderResponse::OrderingGroup::Status }

#strategySymbol, ...

Ordering strategy used



170
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 170

optional :strategy, enum: -> { Telnyx::InexplicitNumberOrderResponse::OrderingGroup::Strategy }

#updated_atTime?

ISO 8601 formatted date indicating when the ordering group was updated

Returns:

  • (Time, nil)


176
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 176

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 247