Class: Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Order

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/inexplicit_number_order_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(administrative_area: nil, count_allocated: nil, count_requested: nil, country_iso: nil, created_at: nil, error_reason: nil, exclude_held_numbers: nil, national_destination_code: nil, orders: nil, phone_number_type: nil, phone_number_contains: nil, phone_number_ends_with: nil, phone_number_starts_with: nil, quickship: nil, status: nil, strategy: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup for more details.

Parameters:

  • administrative_area (String) (defaults to: nil)

    Filter for phone numbers in a given state / province

  • count_allocated (Integer) (defaults to: nil)

    Quantity of phone numbers allocated

  • count_requested (Integer) (defaults to: nil)

    Quantity of phone numbers requested

  • country_iso (String) (defaults to: nil)

    Country where you would like to purchase phone numbers

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the ordering group was created

  • error_reason (String) (defaults to: nil)

    Error reason if applicable

  • exclude_held_numbers (Boolean) (defaults to: nil)

    Filter to exclude phone numbers that are currently on hold/reserved for your acc

  • national_destination_code (String) (defaults to: nil)

    Filter by area code

  • orders (Array<Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Order>) (defaults to: nil)

    Array of orders created to fulfill the inexplicit order

  • phone_number_type (String) (defaults to: nil)

    Number type

  • phone_number_contains (String) (defaults to: nil)

    Filter for phone numbers that contain the digits specified

  • phone_number_ends_with (String) (defaults to: nil)

    Filter by the ending digits of the phone number

  • phone_number_starts_with (String) (defaults to: nil)

    Filter by the starting digits of the phone number

  • quickship (Boolean) (defaults to: nil)

    Filter to exclude phone numbers that need additional time after to purchase to a

  • status (Symbol, Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Status) (defaults to: nil)

    Status of the ordering group

  • strategy (Symbol, Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup::Strategy) (defaults to: nil)

    Ordering strategy used

  • updated_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the ordering group was updated



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 216

class Order < Telnyx::Internal::Type::BaseModel
  # @!attribute number_order_id
  #   ID of the main number order
  #
  #   @return [String]
  required :number_order_id, String

  # @!attribute sub_number_order_ids
  #   Array of sub number order IDs
  #
  #   @return [Array<String>]
  required :sub_number_order_ids, Telnyx::Internal::Type::ArrayOf[String]

  # @!method initialize(number_order_id:, sub_number_order_ids:)
  #   @param number_order_id [String] ID of the main number order
  #
  #   @param sub_number_order_ids [Array<String>] Array of sub number order IDs
end

Instance Attribute Details

#number_order_idString

ID of the main number order

Returns:

  • (String)


221
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 221

required :number_order_id, String

#sub_number_order_idsArray<String>

Array of sub number order IDs

Returns:

  • (Array<String>)


227
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 227

required :sub_number_order_ids, Telnyx::Internal::Type::ArrayOf[String]