Class: Telnyx::Models::InfringementClaimContestResponse::Data::Dir
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::InfringementClaimContestResponse::Data::Dir
- Defined in:
- lib/telnyx/models/infringement_claim_contest_response.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
- #display_name ⇒ String?
- #enterprise_id ⇒ String?
-
#status ⇒ Symbol, ...
DIR lifecycle status.
Instance Method Summary collapse
-
#initialize(id: nil, display_name: nil, enterprise_id: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Dir for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, display_name: nil, enterprise_id: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::InfringementClaimContestResponse::Data::Dir for more details.
Snapshot of the DIR the claim is filed against, embedded for convenience.
|
|
# File 'lib/telnyx/models/infringement_claim_contest_response.rb', line 296
|
Instance Attribute Details
#display_name ⇒ String?
263 |
# File 'lib/telnyx/models/infringement_claim_contest_response.rb', line 263 optional :display_name, String |
#enterprise_id ⇒ String?
268 |
# File 'lib/telnyx/models/infringement_claim_contest_response.rb', line 268 optional :enterprise_id, String |
#status ⇒ Symbol, ...
DIR lifecycle status.
-
‘draft` - newly created; editable; not yet submitted.
-
‘submitted` / `in_review` - Telnyx is reviewing.
-
‘verified` - approved; phone numbers may be attached.
-
‘rejected` - Telnyx rejected this submission; `rejection_reasons` is populated; customer can edit and resubmit.
-
‘unsuccessful` - system-side error during processing; customer can edit and resubmit.
-
‘suspended` - temporarily disabled (e.g. by an active infringement claim).
-
‘expired` - verification expired; customer must resubmit.
-
‘infringement_claimed` - a trademark/impersonation claim is open against this DIR.
-
‘permanently_rejected` - terminal; cannot be resubmitted.
287 |
# File 'lib/telnyx/models/infringement_claim_contest_response.rb', line 287 optional :status, enum: -> { Telnyx::Models::InfringementClaimContestResponse::Data::Dir::Status } |