Class: Telnyx::Models::LedgerBillingGroupReport

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ledger_billing_group_report.rb

Defined Under Namespace

Modules: RecordType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, organization_id: nil, record_type: nil, report_url: nil, status: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Identifies the type of resource.

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • organization_id (String) (defaults to: nil)

    Uniquely identifies the organization that owns the resource.

  • record_type (Symbol, Telnyx::Models::LedgerBillingGroupReport::RecordType) (defaults to: nil)

    Identifies the type of the resource.

  • report_url (String, nil) (defaults to: nil)

    External url of the ledger billing group report, if the status is complete

  • status (Symbol, Telnyx::Models::LedgerBillingGroupReport::Status) (defaults to: nil)

    Status of the ledger billing group report

  • updated_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 48

Instance Attribute Details

#created_atTime?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (Time, nil)


16
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 16

optional :created_at, Time

#idString?

Identifies the type of resource.

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 10

optional :id, String

#organization_idString?

Uniquely identifies the organization that owns the resource.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 22

optional :organization_id, String

#record_typeSymbol, ...

Identifies the type of the resource.



28
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 28

optional :record_type, enum: -> { Telnyx::LedgerBillingGroupReport::RecordType }

#report_urlString?

External url of the ledger billing group report, if the status is complete

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 34

optional :report_url, String, nil?: true

#statusSymbol, ...

Status of the ledger billing group report



40
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 40

optional :status, enum: -> { Telnyx::LedgerBillingGroupReport::Status }

#updated_atTime?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (Time, nil)


46
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 46

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 71