Class: Telnyx::Models::Legacy::Reporting::BatchDetailRecords::VoiceRetrieveFieldsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing: nil, interaction_data: nil, number_information: nil, telephony_data: nil) ⇒ Object

Available CDR report fields grouped by category

Parameters:

  • billing (Array<String>) (defaults to: nil)

    Cost and billing related information

  • interaction_data (Array<String>) (defaults to: nil)

    Fields related to call interaction and basic call information

  • number_information (Array<String>) (defaults to: nil)

    Geographic and routing information for phone numbers

  • telephony_data (Array<String>) (defaults to: nil)

    Technical telephony and call control information



# File 'lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb', line 36

Instance Attribute Details

#billingArray<String>?

Cost and billing related information

Returns:

  • (Array<String>, nil)


14
# File 'lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb', line 14

optional :billing, Telnyx::Internal::Type::ArrayOf[String], api_name: :Billing

#interaction_dataArray<String>?

Fields related to call interaction and basic call information

Returns:

  • (Array<String>, nil)


20
# File 'lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb', line 20

optional :interaction_data, Telnyx::Internal::Type::ArrayOf[String], api_name: :"Interaction Data"

#number_informationArray<String>?

Geographic and routing information for phone numbers

Returns:

  • (Array<String>, nil)


26
27
28
# File 'lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb', line 26

optional :number_information,
Telnyx::Internal::Type::ArrayOf[String],
api_name: :"Number Information"

#telephony_dataArray<String>?

Technical telephony and call control information

Returns:

  • (Array<String>, nil)


34
# File 'lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb', line 34

optional :telephony_data, Telnyx::Internal::Type::ArrayOf[String], api_name: :"Telephony Data"