Class: Telnyx::Models::Legacy::Reporting::UsageReports::NumberLookupCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Legacy::Reporting::UsageReports::NumberLookupCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/legacy/reporting/usage_reports/number_lookup_create_params.rb
Overview
Defined Under Namespace
Modules: AggregationType
Instance Attribute Summary collapse
-
#aggregation_type ⇒ Symbol, ...
Type of aggregation for the report.
-
#end_date ⇒ Date?
End date for the usage report.
-
#managed_accounts ⇒ Array<String>?
List of managed accounts to include in the report.
-
#start_date ⇒ Date?
Start date for the usage report.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(aggregation_type: nil, end_date: nil, managed_accounts: nil, start_date: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/legacy/reporting/usage_reports/number_lookup_create_params.rb', line 41
|
Instance Attribute Details
#aggregation_type ⇒ Symbol, ...
Type of aggregation for the report
17 18 19 20 21 |
# File 'lib/telnyx/models/legacy/reporting/usage_reports/number_lookup_create_params.rb', line 17 optional :aggregation_type, enum: -> { Telnyx::Legacy::Reporting::UsageReports::NumberLookupCreateParams::AggregationType }, api_name: :aggregationType |
#end_date ⇒ Date?
End date for the usage report
27 |
# File 'lib/telnyx/models/legacy/reporting/usage_reports/number_lookup_create_params.rb', line 27 optional :end_date, Date, api_name: :endDate |
#managed_accounts ⇒ Array<String>?
List of managed accounts to include in the report
33 |
# File 'lib/telnyx/models/legacy/reporting/usage_reports/number_lookup_create_params.rb', line 33 optional :managed_accounts, Telnyx::Internal::Type::ArrayOf[String], api_name: :managedAccounts |
#start_date ⇒ Date?
Start date for the usage report
39 |
# File 'lib/telnyx/models/legacy/reporting/usage_reports/number_lookup_create_params.rb', line 39 optional :start_date, Date, api_name: :startDate |