Class: Telnyx::Models::ManagedAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ManagedAccount
- Defined in:
- lib/telnyx/models/managed_account.rb
Defined Under Namespace
Modules: RecordType
Instance Attribute Summary collapse
-
#api_key ⇒ String
The managed account’s V2 API access key.
-
#api_token ⇒ String
The managed account’s V1 API token.
-
#api_user ⇒ String
The manager account’s email, which serves as the V1 API user identifier.
- #balance ⇒ Telnyx::Models::ManagedAccountBalance?
-
#created_at ⇒ String
ISO 8601 formatted date indicating when the resource was created.
-
#email ⇒ String
The managed account’s email.
-
#id ⇒ String
Uniquely identifies the managed account.
-
#managed_account_allow_custom_pricing ⇒ Boolean?
Boolean value that indicates if the managed account is able to have custom pricing set for it or not.
-
#manager_account_id ⇒ String
The ID of the manager account associated with the managed account.
-
#organization_name ⇒ String?
The organization the managed account is associated with.
-
#record_type ⇒ Symbol, Telnyx::Models::ManagedAccount::RecordType
Identifies the type of the resource.
-
#rollup_billing ⇒ Boolean?
Boolean value that indicates if the billing information and charges to the managed account “roll up” to the manager account.
-
#updated_at ⇒ String
ISO 8601 formatted date indicating when the resource was updated.
Instance Method Summary collapse
-
#initialize(id:, api_key:, api_token:, api_user:, created_at:, email:, manager_account_id:, record_type:, updated_at:, balance: nil, managed_account_allow_custom_pricing: nil, organization_name: nil, rollup_billing: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ManagedAccount for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, api_key:, api_token:, api_user:, created_at:, email:, manager_account_id:, record_type:, updated_at:, balance: nil, managed_account_allow_custom_pricing: nil, organization_name: nil, rollup_billing: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ManagedAccount for more details.
|
|
# File 'lib/telnyx/models/managed_account.rb', line 91
|
Instance Attribute Details
#api_key ⇒ String
The managed account’s V2 API access key
16 |
# File 'lib/telnyx/models/managed_account.rb', line 16 required :api_key, String |
#api_token ⇒ String
The managed account’s V1 API token
22 |
# File 'lib/telnyx/models/managed_account.rb', line 22 required :api_token, String |
#api_user ⇒ String
The manager account’s email, which serves as the V1 API user identifier
28 |
# File 'lib/telnyx/models/managed_account.rb', line 28 required :api_user, String |
#balance ⇒ Telnyx::Models::ManagedAccountBalance?
63 |
# File 'lib/telnyx/models/managed_account.rb', line 63 optional :balance, -> { Telnyx::ManagedAccountBalance } |
#created_at ⇒ String
ISO 8601 formatted date indicating when the resource was created.
34 |
# File 'lib/telnyx/models/managed_account.rb', line 34 required :created_at, String |
#email ⇒ String
The managed account’s email.
40 |
# File 'lib/telnyx/models/managed_account.rb', line 40 required :email, String |
#id ⇒ String
Uniquely identifies the managed account.
10 |
# File 'lib/telnyx/models/managed_account.rb', line 10 required :id, String |
#managed_account_allow_custom_pricing ⇒ Boolean?
Boolean value that indicates if the managed account is able to have custom pricing set for it or not. If false, uses the pricing of the manager account. Defaults to false. There may be time lag between when the value is changed and pricing changes take effect.
72 |
# File 'lib/telnyx/models/managed_account.rb', line 72 optional :managed_account_allow_custom_pricing, Telnyx::Internal::Type::Boolean |
#manager_account_id ⇒ String
The ID of the manager account associated with the managed account.
46 |
# File 'lib/telnyx/models/managed_account.rb', line 46 required :manager_account_id, String |
#organization_name ⇒ String?
The organization the managed account is associated with.
78 |
# File 'lib/telnyx/models/managed_account.rb', line 78 optional :organization_name, String |
#record_type ⇒ Symbol, Telnyx::Models::ManagedAccount::RecordType
Identifies the type of the resource.
52 |
# File 'lib/telnyx/models/managed_account.rb', line 52 required :record_type, enum: -> { Telnyx::ManagedAccount::RecordType } |
#rollup_billing ⇒ Boolean?
Boolean value that indicates if the billing information and charges to the managed account “roll up” to the manager account. If true, the managed account will not have its own balance and will use the shared balance with the manager account. This value cannot be changed after account creation without going through Telnyx support as changes require manual updates to the account ledger. Defaults to false.
89 |
# File 'lib/telnyx/models/managed_account.rb', line 89 optional :rollup_billing, Telnyx::Internal::Type::Boolean |
#updated_at ⇒ String
ISO 8601 formatted date indicating when the resource was updated.
58 |
# File 'lib/telnyx/models/managed_account.rb', line 58 required :updated_at, String |