Class: Telnyx::Models::ManagedAccountCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/managed_account_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(business_name:, email: nil, managed_account_allow_custom_pricing: nil, password: nil, rollup_billing: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ManagedAccountCreateParams for more details.

Parameters:

  • business_name (String)

    The name of the business for which the new managed account is being created, tha

  • email (String) (defaults to: nil)

    The email address for the managed account. If not provided, the email address wi

  • managed_account_allow_custom_pricing (Boolean) (defaults to: nil)

    Boolean value that indicates if the managed account is able to have custom prici

  • password (String) (defaults to: nil)

    Password for the managed account. If a password is not supplied, the account wil

  • rollup_billing (Boolean) (defaults to: nil)

    Boolean value that indicates if the billing information and charges to the manag

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/managed_account_create_params.rb', line 52

Instance Attribute Details

#business_nameString

The name of the business for which the new managed account is being created, that will be used as the managed accounts’s organization’s name.

Returns:

  • (String)


15
# File 'lib/telnyx/models/managed_account_create_params.rb', line 15

required :business_name, String

#emailString?

The email address for the managed account. If not provided, the email address will be generated based on the email address of the manager account.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/managed_account_create_params.rb', line 22

optional :email, String

#managed_account_allow_custom_pricingBoolean?

Boolean value that indicates if the managed account is able to have custom pricing set for it or not. If false, uses the pricing of the manager account. Defaults to false. This value may be changed after creation, but there may be time lag between when the value is changed and pricing changes take effect.

Returns:

  • (Boolean, nil)


31
# File 'lib/telnyx/models/managed_account_create_params.rb', line 31

optional :managed_account_allow_custom_pricing, Telnyx::Internal::Type::Boolean

#passwordString?

Password for the managed account. If a password is not supplied, the account will not be able to be signed into directly. (A password reset may still be performed later to enable sign-in via password.)

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/managed_account_create_params.rb', line 39

optional :password, String

#rollup_billingBoolean?

Boolean value that indicates if the billing information and charges to the managed account “roll up” to the manager account. If true, the managed account will not have its own balance and will use the shared balance with the manager account. This value cannot be changed after account creation without going through Telnyx support as changes require manual updates to the account ledger. Defaults to false.

Returns:

  • (Boolean, nil)


50
# File 'lib/telnyx/models/managed_account_create_params.rb', line 50

optional :rollup_billing, Telnyx::Internal::Type::Boolean