Module: Telnyx::Models::ManagedAccountListParams::Sort

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/managed_account_list_params.rb,
sig/telnyx/models/managed_account_list_params.rbs

Overview

Specifies the sort order for results. By default sorting direction is ascending. To have the results sorted in descending order add the - prefix.

That is:

  • email: sorts the result by the email field in ascending order.
  • -email: sorts the result by the email field in descending order.

If not given, results are sorted by created_at in descending order.

Constant Summary collapse

CREATED_AT =

Returns:

  • (:created_at)
:created_at
EMAIL =

Returns:

  • (:email)
:email

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/managed_account_list_params.rb', line 161

Instance Method Details

#self?.values::Array[Telnyx::Models::ManagedAccountListParams::sort]

Returns:

  • (::Array[Telnyx::Models::ManagedAccountListParams::sort])


129
# File 'sig/telnyx/models/managed_account_list_params.rbs', line 129

def self?.values: -> ::Array[Telnyx::Models::ManagedAccountListParams::sort]