Class: Telnyx::Models::ManagedAccountUpdateGlobalChannelLimitResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/managed_account_update_global_channel_limit_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, channel_limit: nil, email: nil, manager_account_id: nil, record_type: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ManagedAccountUpdateGlobalChannelLimitResponse::Data for more details.

Parameters:

  • id (String) (defaults to: nil)

    The user ID of the managed account.

  • channel_limit (Integer) (defaults to: nil)

    Integer value that indicates the number of allocatable global outbound channels

  • email (String) (defaults to: nil)

    The email of the managed account.

  • manager_account_id (String) (defaults to: nil)

    The user ID of the manager of the account.

  • record_type (String) (defaults to: nil)

    The name of the type of data in the response.



# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 49

Instance Attribute Details

#channel_limitInteger?

Integer value that indicates the number of allocatable global outbound channels that are allocated to the managed account. If the value is 0 then the account will have no usable channels and will not be able to perform outbound calling.

Returns:

  • (Integer, nil)


29
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 29

optional :channel_limit, Integer

#emailString?

The email of the managed account.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 35

optional :email, String

#idString?

The user ID of the managed account.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 21

optional :id, String

#manager_account_idString?

The user ID of the manager of the account.

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 41

optional :manager_account_id, String

#record_typeString?

The name of the type of data in the response.

Returns:

  • (String, nil)


47
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 47

optional :record_type, String