Class: Telnyx::Models::MediaResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MediaResource
- Defined in:
- lib/telnyx/models/media_resource.rb
Instance Attribute Summary collapse
-
#content_type ⇒ String?
Content type of the file.
-
#created_at ⇒ String?
ISO 8601 formatted date of when the media resource was created.
-
#expires_at ⇒ String?
ISO 8601 formatted date of when the media resource will expire and be deleted.
-
#media_name ⇒ String?
Uniquely identifies a media resource.
-
#updated_at ⇒ String?
ISO 8601 formatted date of when the media resource was last updated.
Instance Method Summary collapse
- #initialize(content_type: nil, created_at: nil, expires_at: nil, media_name: nil, updated_at: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_type: nil, created_at: nil, expires_at: nil, media_name: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/media_resource.rb', line 36
|
Instance Attribute Details
#content_type ⇒ String?
Content type of the file
10 |
# File 'lib/telnyx/models/media_resource.rb', line 10 optional :content_type, String |
#created_at ⇒ String?
ISO 8601 formatted date of when the media resource was created
16 |
# File 'lib/telnyx/models/media_resource.rb', line 16 optional :created_at, String |
#expires_at ⇒ String?
ISO 8601 formatted date of when the media resource will expire and be deleted.
22 |
# File 'lib/telnyx/models/media_resource.rb', line 22 optional :expires_at, String |
#media_name ⇒ String?
Uniquely identifies a media resource.
28 |
# File 'lib/telnyx/models/media_resource.rb', line 28 optional :media_name, String |
#updated_at ⇒ String?
ISO 8601 formatted date of when the media resource was last updated
34 |
# File 'lib/telnyx/models/media_resource.rb', line 34 optional :updated_at, String |