Class: Telnyx::Models::MediaUploadParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/media_upload_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(media_url:, media_name: nil, ttl_secs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MediaUploadParams for more details.

Parameters:

  • media_url (String)

    The URL where the media to be stored in Telnyx network is currently hosted. The

  • media_name (String) (defaults to: nil)

    The unique identifier of a file.

  • ttl_secs (Integer) (defaults to: nil)

    The number of seconds after which the media resource will be deleted, defaults t

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/media_upload_params.rb', line 30

Instance Attribute Details

#media_nameString?

The unique identifier of a file.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/media_upload_params.rb', line 21

optional :media_name, String

#media_urlString

The URL where the media to be stored in Telnyx network is currently hosted. The maximum allowed size is 20 MB.

Returns:

  • (String)


15
# File 'lib/telnyx/models/media_upload_params.rb', line 15

required :media_url, String

#ttl_secsInteger?

The number of seconds after which the media resource will be deleted, defaults to 2 days. The maximum allowed vale is 630720000, which translates to 20 years.

Returns:

  • (Integer, nil)


28
# File 'lib/telnyx/models/media_upload_params.rb', line 28

optional :ttl_secs, Integer