Class: Telnyx::Models::MeetingSessionCreateParams::Assistant

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/meeting_session_create_params.rb,
sig/telnyx/models/meeting_session_create_params.rbs

Defined Under Namespace

Modules: AudioGate

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, call_control_connection_id:, from:, loopback_sip_uri:, audio_gate: nil) ⇒ Object

Request options for attaching a voice assistant to the session. Routing fields (call_control_connection_id, from, and loopback_sip_uri) are used only to establish the assistant call leg and are omitted from response objects. audio_gate is returned with id in the assistant response object.

Parameters:

  • id (String)

    Identifier of the assistant to attach.

  • call_control_connection_id (String)

    Call control connection used to bridge the assistant into the meeting audio.

  • from (String)

    E.164 calling number used as the originating party for the assistant call leg.

  • loopback_sip_uri (String)

    SIP URI to which the assistant media loopback is established.

  • audio_gate (Symbol, Telnyx::Models::MeetingSessionCreateParams::Assistant::AudioGate) (defaults to: nil)

    Audio gating strategy for the assistant call leg.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/telnyx/models/meeting_session_create_params.rb', line 138

class Assistant < Telnyx::Internal::Type::BaseModel
  # @!attribute id
  #   Identifier of the assistant to attach.
  #
  #   @return [String]
  required :id, String

  # @!attribute call_control_connection_id
  #   Call control connection used to bridge the assistant into the meeting audio.
  #
  #   @return [String]
  required :call_control_connection_id, String

  # @!attribute from
  #   E.164 calling number used as the originating party for the assistant call leg.
  #
  #   @return [String]
  required :from, String

  # @!attribute loopback_sip_uri
  #   SIP URI to which the assistant media loopback is established.
  #
  #   @return [String]
  required :loopback_sip_uri, String

  # @!attribute audio_gate
  #   Audio gating strategy for the assistant call leg.
  #
  #   @return [Symbol, Telnyx::Models::MeetingSessionCreateParams::Assistant::AudioGate, nil]
  optional :audio_gate, enum: -> { Telnyx::MeetingSessionCreateParams::Assistant::AudioGate }

  # @!method initialize(id:, call_control_connection_id:, from:, loopback_sip_uri:, audio_gate: nil)
  #   Request options for attaching a voice assistant to the session. Routing fields
  #   (`call_control_connection_id`, `from`, and `loopback_sip_uri`) are used only to
  #   establish the assistant call leg and are omitted from response objects.
  #   `audio_gate` is returned with `id` in the assistant response object.
  #
  #   @param id [String] Identifier of the assistant to attach.
  #
  #   @param call_control_connection_id [String] Call control connection used to bridge the assistant into the meeting audio.
  #
  #   @param from [String] E.164 calling number used as the originating party for the assistant call leg.
  #
  #   @param loopback_sip_uri [String] SIP URI to which the assistant media loopback is established.
  #
  #   @param audio_gate [Symbol, Telnyx::Models::MeetingSessionCreateParams::Assistant::AudioGate] Audio gating strategy for the assistant call leg.

  # Audio gating strategy for the assistant call leg.
  #
  # @see Telnyx::Models::MeetingSessionCreateParams::Assistant#audio_gate
  module AudioGate
    extend Telnyx::Internal::Type::Enum

    NONE = :none
    HALF_DUPLEX = :half_duplex

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#audio_gateSymbol, ...

Audio gating strategy for the assistant call leg.



167
# File 'lib/telnyx/models/meeting_session_create_params.rb', line 167

optional :audio_gate, enum: -> { Telnyx::MeetingSessionCreateParams::Assistant::AudioGate }

#call_control_connection_idString

Call control connection used to bridge the assistant into the meeting audio.

Parameters:

  • value (String)

Returns:

  • (String)


149
# File 'lib/telnyx/models/meeting_session_create_params.rb', line 149

required :call_control_connection_id, String

#fromString

E.164 calling number used as the originating party for the assistant call leg.

Parameters:

  • value (String)

Returns:

  • (String)


155
# File 'lib/telnyx/models/meeting_session_create_params.rb', line 155

required :from, String

#idString

Identifier of the assistant to attach.

Parameters:

  • value (String)

Returns:

  • (String)


143
# File 'lib/telnyx/models/meeting_session_create_params.rb', line 143

required :id, String

#loopback_sip_uriString

SIP URI to which the assistant media loopback is established.

Parameters:

  • value (String)

Returns:

  • (String)


161
# File 'lib/telnyx/models/meeting_session_create_params.rb', line 161

required :loopback_sip_uri, String

Instance Method Details

#to_hash{

Returns:

  • ({)


147
# File 'sig/telnyx/models/meeting_session_create_params.rbs', line 147

def to_hash: -> {