Class: Telnyx::Models::MeetingSessions::ActionSpeakParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/meeting_sessions/action_speak_params.rb,
sig/telnyx/models/meeting_sessions/action_speak_params.rbs

Overview

See Also:

  • Telnyx::Resources::MeetingSessions::Actions#speak

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, text:, interrupt: nil, voice: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MeetingSessions::ActionSpeakParams for more details.

Parameters:

  • id (String)
  • text (String)

    Text for the bot to speak.

  • interrupt (Boolean) (defaults to: nil)

    If true, interrupt any currently playing audio to speak this text immediately.

  • voice (String) (defaults to: nil)

    Voice identifier to use for this utterance. When supplied, it overrides the sess

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/meeting_sessions/action_speak_params.rb', line 36

Instance Attribute Details

#idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/telnyx/models/meeting_sessions/action_speak_params.rb', line 14

required :id, String

#interruptBoolean?

If true, interrupt any currently playing audio to speak this text immediately.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


26
# File 'lib/telnyx/models/meeting_sessions/action_speak_params.rb', line 26

optional :interrupt, Telnyx::Internal::Type::Boolean

#textString

Text for the bot to speak.

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/telnyx/models/meeting_sessions/action_speak_params.rb', line 20

required :text, String

#voiceString?

Voice identifier to use for this utterance. When supplied, it overrides the session-default voice configured at creation; otherwise the speak action uses that session default.

Parameters:

  • (String)

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/meeting_sessions/action_speak_params.rb', line 34

optional :voice, String

Instance Method Details

#to_hash{

Returns:

  • ({)


32
# File 'sig/telnyx/models/meeting_sessions/action_speak_params.rbs', line 32

def to_hash: -> {