Class: Telnyx::Models::MessageCancelScheduledResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MessageCancelScheduledResponse
- Defined in:
- lib/telnyx/models/message_cancel_scheduled_response.rb
Overview
Defined Under Namespace
Modules: Direction, RecordType, Type Classes: Cc, Cost, CostBreakdown, From, Media, To
Instance Attribute Summary collapse
- #cc ⇒ Array<Telnyx::Models::MessageCancelScheduledResponse::Cc>?
-
#completed_at ⇒ Time?
ISO 8601 formatted date indicating when the message was finalized.
- #cost ⇒ Telnyx::Models::MessageCancelScheduledResponse::Cost?
-
#cost_breakdown ⇒ Telnyx::Models::MessageCancelScheduledResponse::CostBreakdown?
Detailed breakdown of the message cost components.
-
#direction ⇒ Symbol, ...
The direction of the message.
-
#encoding ⇒ String?
Encoding scheme used for the message body.
-
#errors ⇒ Array<Telnyx::Models::MessagingError>?
These errors may point at addressees when referring to unsuccessful/unconfirmed delivery statuses.
- #from ⇒ Telnyx::Models::MessageCancelScheduledResponse::From?
-
#id ⇒ String?
Identifies the type of resource.
- #media ⇒ Array<Telnyx::Models::MessageCancelScheduledResponse::Media>?
-
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
-
#organization_id ⇒ String?
The id of the organization the messaging profile belongs to.
-
#parts ⇒ Integer?
Number of parts into which the message’s body must be split.
-
#received_at ⇒ Time?
ISO 8601 formatted date indicating when the message request was received.
-
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
-
#sent_at ⇒ Time?
ISO 8601 formatted date indicating when the message was sent.
-
#smart_encoding_applied ⇒ Boolean?
Indicates whether smart encoding was applied to this message.
-
#subject ⇒ String?
Subject of multimedia message.
-
#tags ⇒ Array<String>?
Tags associated with the resource.
-
#tcr_campaign_billable ⇒ Boolean?
Indicates whether the TCR campaign is billable.
-
#tcr_campaign_id ⇒ String?
The Campaign Registry (TCR) campaign ID associated with the message.
-
#tcr_campaign_registered ⇒ String?
The registration status of the TCR campaign.
-
#text ⇒ String?
Message body (i.e., content) as a non-empty string.
- #to ⇒ Array<Telnyx::Models::MessageCancelScheduledResponse::To>?
-
#type ⇒ Symbol, ...
The type of message.
-
#valid_until ⇒ Time?
Message must be out of the queue by this time or else it will be discarded and marked as ‘sending_failed’.
-
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.
-
#webhook_url ⇒ String?
The URL where webhooks related to this message will be sent.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_type: nil, sha256: nil, size: nil, url: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 328
|
Instance Attribute Details
#cc ⇒ Array<Telnyx::Models::MessageCancelScheduledResponse::Cc>?
16 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 16 optional :cc, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::MessageCancelScheduledResponse::Cc] } |
#completed_at ⇒ Time?
ISO 8601 formatted date indicating when the message was finalized.
22 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 22 optional :completed_at, Time, nil?: true |
#cost ⇒ Telnyx::Models::MessageCancelScheduledResponse::Cost?
27 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 27 optional :cost, -> { Telnyx::Models::MessageCancelScheduledResponse::Cost }, nil?: true |
#cost_breakdown ⇒ Telnyx::Models::MessageCancelScheduledResponse::CostBreakdown?
Detailed breakdown of the message cost components.
33 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 33 optional :cost_breakdown, -> { Telnyx::Models::MessageCancelScheduledResponse::CostBreakdown }, nil?: true |
#direction ⇒ Symbol, ...
The direction of the message. Inbound messages are sent to you whereas outbound messages are sent from you.
40 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 40 optional :direction, enum: -> { Telnyx::Models::MessageCancelScheduledResponse::Direction } |
#encoding ⇒ String?
Encoding scheme used for the message body.
46 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 46 optional :encoding, String |
#errors ⇒ Array<Telnyx::Models::MessagingError>?
These errors may point at addressees when referring to unsuccessful/unconfirmed delivery statuses.
53 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 53 optional :errors, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::MessagingError] } |
#from ⇒ Telnyx::Models::MessageCancelScheduledResponse::From?
58 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 58 optional :from, -> { Telnyx::Models::MessageCancelScheduledResponse::From } |
#id ⇒ String?
Identifies the type of resource.
11 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 11 optional :id, String |
#media ⇒ Array<Telnyx::Models::MessageCancelScheduledResponse::Media>?
63 64 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 63 optional :media, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::MessageCancelScheduledResponse::Media] } |
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
70 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 70 optional :messaging_profile_id, String |
#organization_id ⇒ String?
The id of the organization the messaging profile belongs to.
76 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 76 optional :organization_id, String |
#parts ⇒ Integer?
Number of parts into which the message’s body must be split.
82 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 82 optional :parts, Integer |
#received_at ⇒ Time?
ISO 8601 formatted date indicating when the message request was received.
88 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 88 optional :received_at, Time |
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
94 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 94 optional :record_type, enum: -> { Telnyx::Models::MessageCancelScheduledResponse::RecordType } |
#sent_at ⇒ Time?
ISO 8601 formatted date indicating when the message was sent.
100 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 100 optional :sent_at, Time, nil?: true |
#smart_encoding_applied ⇒ Boolean?
Indicates whether smart encoding was applied to this message. When ‘true`, one or more Unicode characters were automatically replaced with GSM-7 equivalents to reduce segment count and cost. The original message text is preserved in webhooks.
109 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 109 optional :smart_encoding_applied, Telnyx::Internal::Type::Boolean |
#subject ⇒ String?
Subject of multimedia message
115 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 115 optional :subject, String, nil?: true |
#tags ⇒ Array<String>?
Tags associated with the resource.
121 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 121 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#tcr_campaign_billable ⇒ Boolean?
Indicates whether the TCR campaign is billable.
127 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 127 optional :tcr_campaign_billable, Telnyx::Internal::Type::Boolean |
#tcr_campaign_id ⇒ String?
The Campaign Registry (TCR) campaign ID associated with the message.
133 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 133 optional :tcr_campaign_id, String, nil?: true |
#tcr_campaign_registered ⇒ String?
The registration status of the TCR campaign.
139 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 139 optional :tcr_campaign_registered, String, nil?: true |
#text ⇒ String?
Message body (i.e., content) as a non-empty string.
**Required for SMS**
147 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 147 optional :text, String |
#to ⇒ Array<Telnyx::Models::MessageCancelScheduledResponse::To>?
152 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 152 optional :to, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::MessageCancelScheduledResponse::To] } |
#type ⇒ Symbol, ...
The type of message.
158 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 158 optional :type, enum: -> { Telnyx::Models::MessageCancelScheduledResponse::Type } |
#valid_until ⇒ Time?
Message must be out of the queue by this time or else it will be discarded and marked as ‘sending_failed’. Once the message moves out of the queue, this field will be nulled
166 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 166 optional :valid_until, Time, nil?: true |
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.
173 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 173 optional :webhook_failover_url, String, nil?: true |
#webhook_url ⇒ String?
The URL where webhooks related to this message will be sent.
179 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 179 optional :webhook_url, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 309
|