Class: Telnyx::Models::MessageCancelScheduledResponse::Media
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MessageCancelScheduledResponse::Media
- Defined in:
- lib/telnyx/models/message_cancel_scheduled_response.rb
Instance Attribute Summary collapse
-
#content_type ⇒ String?
The MIME type of the requested media.
-
#sha256 ⇒ String?
The SHA256 hash of the requested media.
-
#size ⇒ Integer?
The size of the requested media.
-
#url ⇒ String?
The url of the media requested to be sent.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#content_type ⇒ String?
The MIME type of the requested media.
460 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 460 optional :content_type, String, nil?: true |
#sha256 ⇒ String?
The SHA256 hash of the requested media.
466 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 466 optional :sha256, String, nil?: true |
#size ⇒ Integer?
The size of the requested media.
472 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 472 optional :size, Integer, nil?: true |
#url ⇒ String?
The url of the media requested to be sent.
478 |
# File 'lib/telnyx/models/message_cancel_scheduled_response.rb', line 478 optional :url, String |