Class: Telnyx::Models::MessageSendGroupMmsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/message_send_group_mms_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(from:, to:, media_urls: nil, subject: nil, text: nil, use_profile_webhooks: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessageSendGroupMmsParams for more details.

Parameters:

  • from (String)

    Phone number, in +E.164 format, used to send the message.

  • to (Array<String>)

    A list of destinations. No more than 8 destinations are allowed.

  • media_urls (Array<String>) (defaults to: nil)

    A list of media URLs. The total media size must be less than 1 MB.

  • subject (String) (defaults to: nil)

    Subject of multimedia message

  • text (String) (defaults to: nil)

    Message body (i.e., content) as a non-empty string.

  • use_profile_webhooks (Boolean) (defaults to: nil)

    If the profile this number is associated with has webhooks, use them for deliver

  • webhook_failover_url (String) (defaults to: nil)

    The failover URL where webhooks related to this message will be sent if sending

  • webhook_url (String) (defaults to: nil)

    The URL where webhooks related to this message will be sent.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/message_send_group_mms_params.rb', line 61

Instance Attribute Details

#fromString

Phone number, in +E.164 format, used to send the message.

Returns:

  • (String)


14
# File 'lib/telnyx/models/message_send_group_mms_params.rb', line 14

required :from, String

#media_urlsArray<String>?

A list of media URLs. The total media size must be less than 1 MB.

Returns:

  • (Array<String>, nil)


26
# File 'lib/telnyx/models/message_send_group_mms_params.rb', line 26

optional :media_urls, Telnyx::Internal::Type::ArrayOf[String]

#subjectString?

Subject of multimedia message

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/message_send_group_mms_params.rb', line 32

optional :subject, String

#textString?

Message body (i.e., content) as a non-empty string.

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/message_send_group_mms_params.rb', line 38

optional :text, String

#toArray<String>

A list of destinations. No more than 8 destinations are allowed.

Returns:

  • (Array<String>)


20
# File 'lib/telnyx/models/message_send_group_mms_params.rb', line 20

required :to, Telnyx::Internal::Type::ArrayOf[String]

#use_profile_webhooksBoolean?

If the profile this number is associated with has webhooks, use them for delivery notifications. If webhooks are also specified on the message itself, they will be attempted first, then those on the profile.

Returns:

  • (Boolean, nil)


46
# File 'lib/telnyx/models/message_send_group_mms_params.rb', line 46

optional :use_profile_webhooks, Telnyx::Internal::Type::Boolean

#webhook_failover_urlString?

The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.

Returns:

  • (String, nil)


53
# File 'lib/telnyx/models/message_send_group_mms_params.rb', line 53

optional :webhook_failover_url, String

#webhook_urlString?

The URL where webhooks related to this message will be sent.

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/message_send_group_mms_params.rb', line 59

optional :webhook_url, String