Class: Telnyx::Models::MessageSendShortCodeParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MessageSendShortCodeParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/message_send_short_code_params.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#auto_detect ⇒ Boolean?
Automatically detect if an SMS message is unusually long and exceeds a recommended limit of message parts.
-
#from ⇒ String
Phone number, in +E.164 format, used to send the message.
-
#media_urls ⇒ Array<String>?
A list of media URLs.
-
#subject ⇒ String?
Subject of multimedia message.
-
#text ⇒ String?
Message body (i.e., content) as a non-empty string.
-
#to ⇒ String
Receiving address (+E.164 formatted phone number or short code).
-
#type ⇒ Symbol, ...
The protocol for sending the message, either SMS or MMS.
-
#use_profile_webhooks ⇒ Boolean?
If the profile this number is associated with has webhooks, use them for delivery notifications.
-
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.
-
#webhook_url ⇒ String?
The URL where webhooks related to this message will be sent.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(from:, to:, auto_detect: nil, media_urls: nil, subject: nil, text: nil, type: nil, use_profile_webhooks: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessageSendShortCodeParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(from:, to:, auto_detect: nil, media_urls: nil, subject: nil, text: nil, type: nil, use_profile_webhooks: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::MessageSendShortCodeParams for more details.
|
|
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 78
|
Instance Attribute Details
#auto_detect ⇒ Boolean?
Automatically detect if an SMS message is unusually long and exceeds a recommended limit of message parts.
27 |
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 27 optional :auto_detect, Telnyx::Internal::Type::Boolean |
#from ⇒ String
Phone number, in +E.164 format, used to send the message.
14 |
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 14 required :from, String |
#media_urls ⇒ Array<String>?
A list of media URLs. The total media size must be less than 1 MB.
**Required for MMS**
35 |
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 35 optional :media_urls, Telnyx::Internal::Type::ArrayOf[String] |
#subject ⇒ String?
Subject of multimedia message
41 |
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 41 optional :subject, String |
#text ⇒ String?
Message body (i.e., content) as a non-empty string.
**Required for SMS**
49 |
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 49 optional :text, String |
#to ⇒ String
Receiving address (+E.164 formatted phone number or short code).
20 |
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 20 required :to, String |
#type ⇒ Symbol, ...
The protocol for sending the message, either SMS or MMS.
55 |
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 55 optional :type, enum: -> { Telnyx::MessageSendShortCodeParams::Type } |
#use_profile_webhooks ⇒ Boolean?
If the profile this number is associated with has webhooks, use them for delivery notifications. If webhooks are also specified on the message itself, they will be attempted first, then those on the profile.
63 |
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 63 optional :use_profile_webhooks, Telnyx::Internal::Type::Boolean |
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.
70 |
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 70 optional :webhook_failover_url, String |
#webhook_url ⇒ String?
The URL where webhooks related to this message will be sent.
76 |
# File 'lib/telnyx/models/message_send_short_code_params.rb', line 76 optional :webhook_url, String |