Class: Telnyx::Models::MessageSendWhatsappParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MessageSendWhatsappParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/message_send_whatsapp_params.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#from ⇒ String
Phone number in +E.164 format associated with Whatsapp account.
-
#to ⇒ String
Phone number in +E.164 format.
-
#type ⇒ Symbol, ...
Message type - must be set to “WHATSAPP”.
-
#webhook_url ⇒ String?
The URL where webhooks related to this message will be sent.
- #whatsapp_message ⇒ Telnyx::Models::WhatsappMessageContent
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(from:, to:, whatsapp_message:, type: nil, webhook_url: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(from:, to:, whatsapp_message:, type: nil, webhook_url: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/message_send_whatsapp_params.rb', line 39
|
Instance Attribute Details
#from ⇒ String
Phone number in +E.164 format associated with Whatsapp account
14 |
# File 'lib/telnyx/models/message_send_whatsapp_params.rb', line 14 required :from, String |
#to ⇒ String
Phone number in +E.164 format
20 |
# File 'lib/telnyx/models/message_send_whatsapp_params.rb', line 20 required :to, String |
#type ⇒ Symbol, ...
Message type - must be set to “WHATSAPP”
31 |
# File 'lib/telnyx/models/message_send_whatsapp_params.rb', line 31 optional :type, enum: -> { Telnyx::MessageSendWhatsappParams::Type } |
#webhook_url ⇒ String?
The URL where webhooks related to this message will be sent.
37 |
# File 'lib/telnyx/models/message_send_whatsapp_params.rb', line 37 optional :webhook_url, String |
#whatsapp_message ⇒ Telnyx::Models::WhatsappMessageContent
25 |
# File 'lib/telnyx/models/message_send_whatsapp_params.rb', line 25 required :whatsapp_message, -> { Telnyx::WhatsappMessageContent } |