Class: Telnyx::Models::MessageSendWhatsappResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/message_send_whatsapp_response.rb

Overview

See Also:

Defined Under Namespace

Classes: From

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, body: nil, direction: nil, encoding: nil, from: nil, messaging_profile_id: nil, organization_id: nil, received_at: nil, record_type: nil, to: nil, type: nil, wait_seconds: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessageSendWhatsappResponse::Data for more details.

Parameters:

  • id (String) (defaults to: nil)

    message ID

  • body (Telnyx::Models::WhatsappMessageContent) (defaults to: nil)
  • direction (String) (defaults to: nil)
  • encoding (String) (defaults to: nil)
  • from (Telnyx::Models::MessageSendWhatsappResponse::Data::From) (defaults to: nil)
  • messaging_profile_id (String) (defaults to: nil)
  • organization_id (String) (defaults to: nil)
  • received_at (Time) (defaults to: nil)
  • record_type (String) (defaults to: nil)
  • to (Array<Telnyx::Models::RcsToItem>) (defaults to: nil)
  • type (String) (defaults to: nil)
  • wait_seconds (Float, nil) (defaults to: nil)

    Seconds the message is queued due to rate limiting before being sent to the carr



# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 81

Instance Attribute Details

#bodyTelnyx::Models::WhatsappMessageContent?



26
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 26

optional :body, -> { Telnyx::WhatsappMessageContent }

#directionString?

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 31

optional :direction, String

#encodingString?

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 36

optional :encoding, String

#fromTelnyx::Models::MessageSendWhatsappResponse::Data::From?



41
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 41

optional :from, -> { Telnyx::Models::MessageSendWhatsappResponse::Data::From }

#idString?

message ID

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 21

optional :id, String

#messaging_profile_idString?

Returns:

  • (String, nil)


46
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 46

optional :messaging_profile_id, String

#organization_idString?

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 51

optional :organization_id, String

#received_atTime?

Returns:

  • (Time, nil)


56
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 56

optional :received_at, Time

#record_typeString?

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 61

optional :record_type, String

#toArray<Telnyx::Models::RcsToItem>?

Returns:



66
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 66

optional :to, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::RcsToItem] }

#typeString?

Returns:

  • (String, nil)


71
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 71

optional :type, String

#wait_secondsFloat?

Seconds the message is queued due to rate limiting before being sent to the carrier. Represents the maximum wait across all applicable rate limits (account, carrier, campaign). 0.0 = no queuing delay.

Returns:

  • (Float, nil)


79
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 79

optional :wait_seconds, Float, nil?: true