Class: Telnyx::Models::Messages::RcSendResponse::Data
Overview
Defined Under Namespace
Classes: From
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(id: nil, body: nil, direction: nil, encoding: nil, from: nil, messaging_profile_id: nil, organization_id: nil, received_at: nil, record_type: nil, to: nil, type: nil, wait_seconds: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, body: nil, direction: nil, encoding: nil, from: nil, messaging_profile_id: nil, organization_id: nil, received_at: nil, record_type: nil, to: nil, type: nil, wait_seconds: nil) ⇒ Object
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 82
|
Instance Attribute Details
27
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 27
optional :body, -> { Telnyx::RcsAgentMessage }
|
#direction ⇒ String?
32
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 32
optional :direction, String
|
#encoding ⇒ String?
37
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 37
optional :encoding, String
|
#id ⇒ String?
22
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 22
optional :id, String
|
#messaging_profile_id ⇒ String?
47
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 47
optional :messaging_profile_id, String
|
#organization_id ⇒ String?
52
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 52
optional :organization_id, String
|
#received_at ⇒ Time?
57
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 57
optional :received_at, Time
|
#record_type ⇒ String?
62
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 62
optional :record_type, String
|
#type ⇒ String?
72
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 72
optional :type, String
|
#wait_seconds ⇒ Float?
Seconds the message is queued due to rate limiting before being sent to the carrier. Represents the maximum wait across all applicable rate limits (account, carrier, campaign). 0.0 = no queuing delay.
80
|
# File 'lib/telnyx/models/messages/rc_send_response.rb', line 80
optional :wait_seconds, Float, nil?: true
|