Class: Telnyx::Models::Messaging10dlc::Brand::ExternalVettingImportsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/messaging_10dlc/brand/external_vetting_imports_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(brand_id:, evp_id:, vetting_id:, vetting_token: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::Brand::ExternalVettingImportsParams for more details.

Parameters:

  • brand_id (String)
  • evp_id (String)

    External vetting provider ID for the brand.

  • vetting_id (String)

    Unique ID that identifies a vetting transaction performed by a vetting provider.

  • vetting_token (String) (defaults to: nil)

    Required by some providers for vetting record confirmation.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/messaging_10dlc/brand/external_vetting_imports_params.rb', line 36

Instance Attribute Details

#brand_idString

Returns:

  • (String)


15
# File 'lib/telnyx/models/messaging_10dlc/brand/external_vetting_imports_params.rb', line 15

required :brand_id, String

#evp_idString

External vetting provider ID for the brand.

Returns:

  • (String)


21
# File 'lib/telnyx/models/messaging_10dlc/brand/external_vetting_imports_params.rb', line 21

required :evp_id, String, api_name: :evpId

#vetting_idString

Unique ID that identifies a vetting transaction performed by a vetting provider. This ID is provided by the vetting provider at time of vetting.

Returns:

  • (String)


28
# File 'lib/telnyx/models/messaging_10dlc/brand/external_vetting_imports_params.rb', line 28

required :vetting_id, String, api_name: :vettingId

#vetting_tokenString?

Required by some providers for vetting record confirmation.

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/messaging_10dlc/brand/external_vetting_imports_params.rb', line 34

optional :vetting_token, String, api_name: :vettingToken