Class: Telnyx::Models::Messaging10dlc::BrandCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/messaging_10dlc/brand_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country:, display_name:, email:, entity_type:, vertical:, business_contact_email: nil, city: nil, company_name: nil, ein: nil, first_name: nil, ip_address: nil, is_reseller: nil, last_name: nil, mobile_phone: nil, mock: nil, phone: nil, postal_code: nil, state: nil, stock_exchange: nil, stock_symbol: nil, street: nil, webhook_failover_url: nil, webhook_url: nil, website: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::BrandCreateParams for more details.

Parameters:

  • country (String)

    ISO2 2 characters country code. Example: US - United States

  • display_name (String)

    Display name, marketing name, or DBA name of the brand.

  • email (String)

    Valid email address of brand support contact.

  • entity_type (Symbol, Telnyx::Models::Messaging10dlc::EntityType)

    Entity type behind the brand. This is the form of business establishment.

  • vertical (Symbol, Telnyx::Models::Messaging10dlc::Vertical)

    Vertical or industry segment of the brand or campaign.

  • business_contact_email (String) (defaults to: nil)

    Business contact email.

  • city (String) (defaults to: nil)

    City name

  • company_name (String) (defaults to: nil)

    (Required for Non-profit/private/public) Legal company name.

  • ein (String) (defaults to: nil)

    (Required for Non-profit) Government assigned corporate tax ID. EIN is 9-digits

  • first_name (String) (defaults to: nil)

    First name of business contact.

  • ip_address (String) (defaults to: nil)

    IP address of the browser requesting to create brand identity.

  • is_reseller (Boolean) (defaults to: nil)
  • last_name (String) (defaults to: nil)

    Last name of business contact.

  • mobile_phone (String) (defaults to: nil)

    Valid mobile phone number in e.164 international format.

  • mock (Boolean) (defaults to: nil)

    Mock brand for testing purposes. Defaults to false.

  • phone (String) (defaults to: nil)

    Valid phone number in e.164 international format.

  • postal_code (String) (defaults to: nil)

    Postal codes. Use 5 digit zipcode for United States

  • state (String) (defaults to: nil)

    State. Must be 2 letters code for United States.

  • stock_exchange (Symbol, Telnyx::Models::Messaging10dlc::StockExchange) (defaults to: nil)

    (Required for public company) stock exchange.

  • stock_symbol (String) (defaults to: nil)

    (Required for public company) stock symbol.

  • street (String) (defaults to: nil)

    Street number and name.

  • webhook_failover_url (String) (defaults to: nil)

    Webhook failover URL for brand status updates.

  • webhook_url (String) (defaults to: nil)

    Webhook URL for brand status updates.

  • website (String) (defaults to: nil)

    Brand website URL.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 158

Instance Attribute Details

#business_contact_emailString?

Business contact email.

Required if ‘entityType` is `PUBLIC_PROFIT`. Otherwise, it is recommended to either omit this field or set it to `null`.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 48

optional :business_contact_email, String, api_name: :businessContactEmail

#cityString?

City name

Returns:

  • (String, nil)


54
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 54

optional :city, String

#company_nameString?

(Required for Non-profit/private/public) Legal company name.

Returns:

  • (String, nil)


60
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 60

optional :company_name, String, api_name: :companyName

#countryString

ISO2 2 characters country code. Example: US - United States

Returns:

  • (String)


15
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 15

required :country, String

#display_nameString

Display name, marketing name, or DBA name of the brand.

Returns:

  • (String)


21
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 21

required :display_name, String, api_name: :displayName

#einString?

(Required for Non-profit) Government assigned corporate tax ID. EIN is 9-digits in U.S.

Returns:

  • (String, nil)


67
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 67

optional :ein, String

#emailString

Valid email address of brand support contact.

Returns:

  • (String)


27
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 27

required :email, String

#entity_typeSymbol, Telnyx::Models::Messaging10dlc::EntityType

Entity type behind the brand. This is the form of business establishment.



33
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 33

required :entity_type, enum: -> { Telnyx::Messaging10dlc::EntityType }, api_name: :entityType

#first_nameString?

First name of business contact.

Returns:

  • (String, nil)


73
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 73

optional :first_name, String, api_name: :firstName

#ip_addressString?

IP address of the browser requesting to create brand identity.

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 79

optional :ip_address, String, api_name: :ipAddress

#is_resellerBoolean?

Returns:

  • (Boolean, nil)


84
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 84

optional :is_reseller, Telnyx::Internal::Type::Boolean, api_name: :isReseller

#last_nameString?

Last name of business contact.

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 90

optional :last_name, String, api_name: :lastName

#mobile_phoneString?

Valid mobile phone number in e.164 international format.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 96

optional :mobile_phone, String, api_name: :mobilePhone

#mockBoolean?

Mock brand for testing purposes. Defaults to false.

Returns:

  • (Boolean, nil)


102
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 102

optional :mock, Telnyx::Internal::Type::Boolean

#phoneString?

Valid phone number in e.164 international format.

Returns:

  • (String, nil)


108
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 108

optional :phone, String

#postal_codeString?

Postal codes. Use 5 digit zipcode for United States

Returns:

  • (String, nil)


114
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 114

optional :postal_code, String, api_name: :postalCode

#stateString?

State. Must be 2 letters code for United States.

Returns:

  • (String, nil)


120
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 120

optional :state, String

#stock_exchangeSymbol, ...

(Required for public company) stock exchange.



126
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 126

optional :stock_exchange, enum: -> { Telnyx::Messaging10dlc::StockExchange }, api_name: :stockExchange

#stock_symbolString?

(Required for public company) stock symbol.

Returns:

  • (String, nil)


132
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 132

optional :stock_symbol, String, api_name: :stockSymbol

#streetString?

Street number and name.

Returns:

  • (String, nil)


138
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 138

optional :street, String

#verticalSymbol, Telnyx::Models::Messaging10dlc::Vertical

Vertical or industry segment of the brand or campaign.



39
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 39

required :vertical, enum: -> { Telnyx::Messaging10dlc::Vertical }

#webhook_failover_urlString?

Webhook failover URL for brand status updates.

Returns:

  • (String, nil)


144
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 144

optional :webhook_failover_url, String, api_name: :webhookFailoverURL

#webhook_urlString?

Webhook URL for brand status updates.

Returns:

  • (String, nil)


150
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 150

optional :webhook_url, String, api_name: :webhookURL

#websiteString?

Brand website URL.

Returns:

  • (String, nil)


156
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 156

optional :website, String