Class: Telnyx::Models::Messaging10dlc::BrandGetFeedbackResponse::Category
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::BrandGetFeedbackResponse::Category
- Defined in:
- lib/telnyx/models/messaging_10dlc/brand_get_feedback_response.rb
Instance Attribute Summary collapse
-
#description ⇒ String
Long-form description of the feedback with additional information.
-
#display_name ⇒ String
Human-readable version of the ‘id` field.
-
#fields ⇒ Array<String>
List of relevant fields in the originally-submitted brand json.
-
#id ⇒ String
One of ‘TAX_ID`, `STOCK_SYMBOL`, `GOVERNMENT_ENTITY`, `NONPROFIT`, and `OTHERS`.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, description:, display_name:, fields:) ⇒ Object
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/telnyx/models/messaging_10dlc/brand_get_feedback_response.rb', line 26 class Category < Telnyx::Internal::Type::BaseModel # @!attribute id # One of `TAX_ID`, `STOCK_SYMBOL`, `GOVERNMENT_ENTITY`, `NONPROFIT`, and `OTHERS` # # @return [String] required :id, String # @!attribute description # Long-form description of the feedback with additional information # # @return [String] required :description, String # @!attribute display_name # Human-readable version of the `id` field # # @return [String] required :display_name, String, api_name: :displayName # @!attribute fields # List of relevant fields in the originally-submitted brand json # # @return [Array<String>] required :fields, Telnyx::Internal::Type::ArrayOf[String] # @!method initialize(id:, description:, display_name:, fields:) # @param id [String] One of `TAX_ID`, `STOCK_SYMBOL`, `GOVERNMENT_ENTITY`, `NONPROFIT`, and `OTHERS` # # @param description [String] Long-form description of the feedback with additional information # # @param display_name [String] Human-readable version of the `id` field # # @param fields [Array<String>] List of relevant fields in the originally-submitted brand json end |
Instance Attribute Details
#description ⇒ String
Long-form description of the feedback with additional information
37 |
# File 'lib/telnyx/models/messaging_10dlc/brand_get_feedback_response.rb', line 37 required :description, String |
#display_name ⇒ String
Human-readable version of the ‘id` field
43 |
# File 'lib/telnyx/models/messaging_10dlc/brand_get_feedback_response.rb', line 43 required :display_name, String, api_name: :displayName |
#fields ⇒ Array<String>
List of relevant fields in the originally-submitted brand json
49 |
# File 'lib/telnyx/models/messaging_10dlc/brand_get_feedback_response.rb', line 49 required :fields, Telnyx::Internal::Type::ArrayOf[String] |
#id ⇒ String
One of ‘TAX_ID`, `STOCK_SYMBOL`, `GOVERNMENT_ENTITY`, `NONPROFIT`, and `OTHERS`
31 |
# File 'lib/telnyx/models/messaging_10dlc/brand_get_feedback_response.rb', line 31 required :id, String |