Class: Telnyx::Models::Messaging10dlc::BrandRetrieveSMSOtpStatusResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(brand_id:, delivery_status:, mobile_phone:, reference_id:, request_date:, delivery_status_date: nil, delivery_status_details: nil, verify_date: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::BrandRetrieveSMSOtpStatusResponse for more details.

Status information for an SMS OTP sent during Sole Proprietor brand verification

Parameters:

  • brand_id (String)

    The Brand ID associated with this OTP request

  • delivery_status (String)

    The current delivery status of the OTP SMS message. Common values include: ‘DELI

  • mobile_phone (String)

    The mobile phone number where the OTP was sent, in E.164 format

  • reference_id (String)

    The reference ID for this OTP request, used for status queries

  • request_date (Time)

    The timestamp when the OTP request was initiated

  • delivery_status_date (Time) (defaults to: nil)

    The timestamp when the delivery status was last updated

  • delivery_status_details (String) (defaults to: nil)

    Additional details about the delivery status

  • verify_date (Time) (defaults to: nil)

    The timestamp when the OTP was successfully verified (if applicable)



# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 57

Instance Attribute Details

#brand_idString

The Brand ID associated with this OTP request

Returns:

  • (String)


12
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 12

required :brand_id, String, api_name: :brandId

#delivery_statusString

The current delivery status of the OTP SMS message. Common values include: ‘DELIVERED_HANDSET`, `PENDING`, `FAILED`, `EXPIRED`

Returns:

  • (String)


19
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 19

required :delivery_status, String, api_name: :deliveryStatus

#delivery_status_dateTime?

The timestamp when the delivery status was last updated

Returns:

  • (Time, nil)


43
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 43

optional :delivery_status_date, Time, api_name: :deliveryStatusDate

#delivery_status_detailsString?

Additional details about the delivery status

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 49

optional :delivery_status_details, String, api_name: :deliveryStatusDetails

#mobile_phoneString

The mobile phone number where the OTP was sent, in E.164 format

Returns:

  • (String)


25
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 25

required :mobile_phone, String, api_name: :mobilePhone

#reference_idString

The reference ID for this OTP request, used for status queries

Returns:

  • (String)


31
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 31

required :reference_id, String, api_name: :referenceId

#request_dateTime

The timestamp when the OTP request was initiated

Returns:

  • (Time)


37
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 37

required :request_date, Time, api_name: :requestDate

#verify_dateTime?

The timestamp when the OTP was successfully verified (if applicable)

Returns:

  • (Time, nil)


55
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 55

optional :verify_date, Time, api_name: :verifyDate