Class: Telnyx::Models::Messaging10dlc::BrandUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/messaging_10dlc/brand_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(brand_id:, country:, display_name:, email:, entity_type:, vertical:, alt_business_id: nil, alt_business_id_type: nil, business_contact_email: nil, city: nil, company_name: nil, ein: nil, first_name: nil, identity_status: nil, ip_address: nil, is_reseller: nil, last_name: nil, phone: nil, postal_code: nil, state: nil, stock_exchange: nil, stock_symbol: nil, street: nil, webhook_failover_url: nil, webhook_url: nil, website: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::BrandUpdateParams for more details.

Parameters:

  • brand_id (String)
  • country (String)

    ISO2 2 characters country code. Example: US - United States

  • display_name (String)

    Display or marketing name of the brand.

  • email (String)

    Valid email address of brand support contact.

  • entity_type (Symbol, Telnyx::Models::Messaging10dlc::EntityType)

    Entity type behind the brand. This is the form of business establishment.

  • vertical (Symbol, Telnyx::Models::Messaging10dlc::Vertical)

    Vertical or industry segment of the brand or campaign.

  • alt_business_id (String) (defaults to: nil)

    Alternate business identifier such as DUNS, LEI, or GIIN

  • alt_business_id_type (Symbol, Telnyx::Models::Messaging10dlc::AltBusinessIDType) (defaults to: nil)

    An enumeration.

  • business_contact_email (String) (defaults to: nil)

    Business contact email.

  • city (String) (defaults to: nil)

    City name

  • company_name (String) (defaults to: nil)

    (Required for Non-profit/private/public) Legal company name.

  • ein (String) (defaults to: nil)

    (Required for Non-profit) Government assigned corporate tax ID. EIN is 9-digits

  • first_name (String) (defaults to: nil)

    First name of business contact.

  • identity_status (Symbol, Telnyx::Models::Messaging10dlc::BrandIdentityStatus) (defaults to: nil)

    The verification status of an active brand

  • ip_address (String) (defaults to: nil)

    IP address of the browser requesting to create brand identity.

  • is_reseller (Boolean) (defaults to: nil)
  • last_name (String) (defaults to: nil)

    Last name of business contact.

  • phone (String) (defaults to: nil)

    Valid phone number in e.164 international format.

  • postal_code (String) (defaults to: nil)

    Postal codes. Use 5 digit zipcode for United States

  • state (String) (defaults to: nil)

    State. Must be 2 letters code for United States.

  • stock_exchange (Symbol, Telnyx::Models::Messaging10dlc::StockExchange) (defaults to: nil)

    (Required for public company) stock exchange.

  • stock_symbol (String) (defaults to: nil)

    (Required for public company) stock symbol.

  • street (String) (defaults to: nil)

    Street number and name.

  • webhook_failover_url (String) (defaults to: nil)

    Webhook failover URL for brand status updates.

  • webhook_url (String) (defaults to: nil)

    Webhook URL for brand status updates.

  • website (String) (defaults to: nil)

    Brand website URL.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 173

Instance Attribute Details

#alt_business_idString?

Alternate business identifier such as DUNS, LEI, or GIIN

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 50

optional :alt_business_id, String, api_name: :altBusinessId

#alt_business_id_typeSymbol, ...

An enumeration.



56
57
58
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 56

optional :alt_business_id_type,
enum: -> { Telnyx::Messaging10dlc::AltBusinessIDType },
api_name: :altBusinessIdType

#brand_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 14

required :brand_id, String

#business_contact_emailString?

Business contact email.

Required if ‘entityType` will be changed to `PUBLIC_PROFIT`. Otherwise, it is recommended to either omit this field or set it to `null`.

Returns:

  • (String, nil)


67
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 67

optional :business_contact_email, String, api_name: :businessContactEmail

#cityString?

City name

Returns:

  • (String, nil)


73
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 73

optional :city, String

#company_nameString?

(Required for Non-profit/private/public) Legal company name.

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 79

optional :company_name, String, api_name: :companyName

#countryString

ISO2 2 characters country code. Example: US - United States

Returns:

  • (String)


20
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 20

required :country, String

#display_nameString

Display or marketing name of the brand.

Returns:

  • (String)


26
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 26

required :display_name, String, api_name: :displayName

#einString?

(Required for Non-profit) Government assigned corporate tax ID. EIN is 9-digits in U.S.

Returns:

  • (String, nil)


86
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 86

optional :ein, String

#emailString

Valid email address of brand support contact.

Returns:

  • (String)


32
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 32

required :email, String

#entity_typeSymbol, Telnyx::Models::Messaging10dlc::EntityType

Entity type behind the brand. This is the form of business establishment.



38
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 38

required :entity_type, enum: -> { Telnyx::Messaging10dlc::EntityType }, api_name: :entityType

#first_nameString?

First name of business contact.

Returns:

  • (String, nil)


92
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 92

optional :first_name, String, api_name: :firstName

#identity_statusSymbol, ...

The verification status of an active brand



98
99
100
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 98

optional :identity_status,
enum: -> { Telnyx::Messaging10dlc::BrandIdentityStatus },
api_name: :identityStatus

#ip_addressString?

IP address of the browser requesting to create brand identity.

Returns:

  • (String, nil)


106
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 106

optional :ip_address, String, api_name: :ipAddress

#is_resellerBoolean?

Returns:

  • (Boolean, nil)


111
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 111

optional :is_reseller, Telnyx::Internal::Type::Boolean, api_name: :isReseller

#last_nameString?

Last name of business contact.

Returns:

  • (String, nil)


117
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 117

optional :last_name, String, api_name: :lastName

#phoneString?

Valid phone number in e.164 international format.

Returns:

  • (String, nil)


123
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 123

optional :phone, String

#postal_codeString?

Postal codes. Use 5 digit zipcode for United States

Returns:

  • (String, nil)


129
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 129

optional :postal_code, String, api_name: :postalCode

#stateString?

State. Must be 2 letters code for United States.

Returns:

  • (String, nil)


135
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 135

optional :state, String

#stock_exchangeSymbol, ...

(Required for public company) stock exchange.



141
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 141

optional :stock_exchange, enum: -> { Telnyx::Messaging10dlc::StockExchange }, api_name: :stockExchange

#stock_symbolString?

(Required for public company) stock symbol.

Returns:

  • (String, nil)


147
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 147

optional :stock_symbol, String, api_name: :stockSymbol

#streetString?

Street number and name.

Returns:

  • (String, nil)


153
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 153

optional :street, String

#verticalSymbol, Telnyx::Models::Messaging10dlc::Vertical

Vertical or industry segment of the brand or campaign.



44
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 44

required :vertical, enum: -> { Telnyx::Messaging10dlc::Vertical }

#webhook_failover_urlString?

Webhook failover URL for brand status updates.

Returns:

  • (String, nil)


159
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 159

optional :webhook_failover_url, String, api_name: :webhookFailoverURL

#webhook_urlString?

Webhook URL for brand status updates.

Returns:

  • (String, nil)


165
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 165

optional :webhook_url, String, api_name: :webhookURL

#websiteString?

Brand website URL.

Returns:

  • (String, nil)


171
# File 'lib/telnyx/models/messaging_10dlc/brand_update_params.rb', line 171

optional :website, String