Class: Telnyx::Models::Messaging10dlc::CampaignListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::CampaignListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/messaging_10dlc/campaign_list_params.rb
Overview
Defined Under Namespace
Modules: Sort
Instance Attribute Summary collapse
- #brand_id ⇒ String
-
#page ⇒ Integer?
The 1-indexed page number to get.
-
#records_per_page ⇒ Integer?
The amount of records per page, limited to between 1 and 500 inclusive.
-
#sort ⇒ Symbol, ...
Specifies the sort order for results.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(brand_id:, page: nil, records_per_page: nil, sort: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CampaignListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(brand_id:, page: nil, records_per_page: nil, sort: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::CampaignListParams for more details.
|
|
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_params.rb', line 36
|
Instance Attribute Details
#brand_id ⇒ String
14 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_params.rb', line 14 required :brand_id, String |
#page ⇒ Integer?
The 1-indexed page number to get. The default value is ‘1`.
20 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_params.rb', line 20 optional :page, Integer |
#records_per_page ⇒ Integer?
The amount of records per page, limited to between 1 and 500 inclusive. The default value is ‘10`.
27 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_params.rb', line 27 optional :records_per_page, Integer |
#sort ⇒ Symbol, ...
Specifies the sort order for results. If not given, results are sorted by createdAt in descending order.
34 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_params.rb', line 34 optional :sort, enum: -> { Telnyx::Messaging10dlc::CampaignListParams::Sort } |