Class: Telnyx::Models::Messaging10dlc::CampaignListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/messaging_10dlc/campaign_list_response.rb

Overview

Defined Under Namespace

Modules: CampaignStatus, SubmissionStatus

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(age_gated: nil, assigned_phone_numbers_count: nil, auto_renewal: nil, billed_date: nil, brand_display_name: nil, brand_id: nil, campaign_id: nil, campaign_status: nil, create_date: nil, csp_id: nil, description: nil, direct_lending: nil, embedded_link: nil, embedded_link_sample: nil, embedded_phone: nil, failure_reasons: nil, help_keywords: nil, help_message: nil, is_t_mobile_number_pooling_enabled: nil, is_t_mobile_registered: nil, is_t_mobile_suspended: nil, message_flow: nil, mock: nil, next_renewal_or_expiration_date: nil, number_pool: nil, optin_keywords: nil, optin_message: nil, optout_keywords: nil, optout_message: nil, privacy_policy_link: nil, reference_id: nil, reseller_id: nil, sample1: nil, sample2: nil, sample3: nil, sample4: nil, sample5: nil, status: nil, submission_status: nil, subscriber_help: nil, subscriber_optin: nil, subscriber_optout: nil, sub_usecases: nil, tcr_brand_id: nil, tcr_campaign_id: nil, terms_and_conditions: nil, terms_and_conditions_link: nil, usecase: nil, vertical: nil, webhook_failover_url: nil, webhook_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::CampaignListResponse for more details.

Parameters:

  • age_gated (Boolean) (defaults to: nil)

    Age gated content in campaign.

  • assigned_phone_numbers_count (Float) (defaults to: nil)

    Number of phone numbers associated with the campaign

  • auto_renewal (Boolean) (defaults to: nil)

    Campaign subscription auto-renewal status.

  • billed_date (String) (defaults to: nil)

    Campaign recent billed date.

  • brand_display_name (String) (defaults to: nil)

    Display or marketing name of the brand.

  • brand_id (String) (defaults to: nil)

    Unique identifier assigned to the brand.

  • campaign_id (String) (defaults to: nil)

    Unique identifier for a campaign.

  • campaign_status (Symbol, Telnyx::Models::Messaging10dlc::CampaignListResponse::CampaignStatus) (defaults to: nil)

    Campaign status

  • create_date (String) (defaults to: nil)

    Unix timestamp when campaign was created.

  • csp_id (String) (defaults to: nil)

    Alphanumeric identifier of the CSP associated with this campaign.

  • description (String) (defaults to: nil)

    Summary description of this campaign.

  • direct_lending (Boolean) (defaults to: nil)
  • embedded_link (Boolean) (defaults to: nil)

    Does message generated by the campaign include URL link in SMS?

  • embedded_link_sample (String) (defaults to: nil)

    Sample of an embedded link that will be sent to subscribers.

  • embedded_phone (Boolean) (defaults to: nil)

    Does message generated by the campaign include phone number in SMS?

  • failure_reasons (String) (defaults to: nil)

    Failure reasons if campaign submission failed

  • help_keywords (String) (defaults to: nil)

    Subscriber help keywords. Multiple keywords are comma separated without space.

  • help_message (String) (defaults to: nil)

    Help message of the campaign.

  • is_t_mobile_number_pooling_enabled (Boolean) (defaults to: nil)

    Indicates whether the campaign has a T-Mobile number pool ID associated with it.

  • is_t_mobile_registered (Boolean) (defaults to: nil)

    Indicates whether the campaign is registered with T-Mobile.

  • is_t_mobile_suspended (Boolean) (defaults to: nil)

    Indicates whether the campaign is suspended with T-Mobile.

  • message_flow (String) (defaults to: nil)

    Message flow description.

  • mock (Boolean) (defaults to: nil)

    Campaign created from mock brand. Mocked campaign cannot be shared with an upstr

  • next_renewal_or_expiration_date (String) (defaults to: nil)

    When the campaign would be due for its next renew/bill date.

  • number_pool (Boolean) (defaults to: nil)

    Does campaign utilize pool of phone numbers?

  • optin_keywords (String) (defaults to: nil)

    Subscriber opt-in keywords. Multiple keywords are comma separated without space.

  • optin_message (String) (defaults to: nil)

    Subscriber opt-in message.

  • optout_keywords (String) (defaults to: nil)

    Subscriber opt-out keywords. Multiple keywords are comma separated without space

  • optout_message (String) (defaults to: nil)

    Subscriber opt-out message.

  • privacy_policy_link (String) (defaults to: nil)

    Link to the campaign’s privacy policy.

  • reference_id (String) (defaults to: nil)

    Caller supplied campaign reference ID. If supplied, the value must be unique acr

  • reseller_id (String) (defaults to: nil)

    Alphanumeric identifier of the reseller that you want to associate with this cam

  • sample1 (String) (defaults to: nil)

    Message sample. Some campaign tiers require 1 or more message samples.

  • sample2 (String) (defaults to: nil)

    Message sample. Some campaign tiers require 2 or more message samples.

  • sample3 (String) (defaults to: nil)

    Message sample. Some campaign tiers require 3 or more message samples.

  • sample4 (String) (defaults to: nil)

    Message sample. Some campaign tiers require 4 or more message samples.

  • sample5 (String) (defaults to: nil)

    Message sample. Some campaign tiers require 5 or more message samples.

  • status (String) (defaults to: nil)

    Current campaign status. Possible values: ACTIVE, EXPIRED. A newly created campa

  • submission_status (Symbol, Telnyx::Models::Messaging10dlc::CampaignListResponse::SubmissionStatus) (defaults to: nil)

    Campaign submission status

  • subscriber_help (Boolean) (defaults to: nil)

    Does campaign responds to help keyword(s)?

  • subscriber_optin (Boolean) (defaults to: nil)

    Does campaign require subscriber to opt-in before SMS is sent to subscriber?

  • subscriber_optout (Boolean) (defaults to: nil)

    Does campaign support subscriber opt-out keyword(s)?

  • sub_usecases (Array<String>) (defaults to: nil)

    Campaign sub-usecases. Must be of defined valid sub-usecase types. Use ‘/10dlc/e

  • tcr_brand_id (String) (defaults to: nil)

    Unique identifier assigned to the brand by the registry.

  • tcr_campaign_id (String) (defaults to: nil)

    Unique identifier assigned to the campaign by the registry.

  • terms_and_conditions (Boolean) (defaults to: nil)

    Is terms & conditions accepted?

  • terms_and_conditions_link (String) (defaults to: nil)

    Link to the campaign’s terms and conditions.

  • usecase (String) (defaults to: nil)

    Campaign usecase. Must be of defined valid types. Use ‘/10dlc/enum/usecase` oper

  • vertical (String) (defaults to: nil)

    Business/industry segment of this campaign (Deprecated). Must be of defined vali

  • webhook_failover_url (String) (defaults to: nil)

    Failover webhook to which campaign status updates are sent.

  • webhook_url (String) (defaults to: nil)

    Webhook to which campaign status updates are sent.



# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 333

Instance Attribute Details

#age_gatedBoolean?

Age gated content in campaign.

Returns:

  • (Boolean, nil)


12
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 12

optional :age_gated, Telnyx::Internal::Type::Boolean, api_name: :ageGated

#assigned_phone_numbers_countFloat?

Number of phone numbers associated with the campaign

Returns:

  • (Float, nil)


18
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 18

optional :assigned_phone_numbers_count, Float, api_name: :assignedPhoneNumbersCount

#auto_renewalBoolean?

Campaign subscription auto-renewal status.

Returns:

  • (Boolean, nil)


24
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 24

optional :auto_renewal, Telnyx::Internal::Type::Boolean, api_name: :autoRenewal

#billed_dateString?

Campaign recent billed date.

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 30

optional :billed_date, String, api_name: :billedDate

#brand_display_nameString?

Display or marketing name of the brand.

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 36

optional :brand_display_name, String, api_name: :brandDisplayName

#brand_idString?

Unique identifier assigned to the brand.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 42

optional :brand_id, String, api_name: :brandId

#campaign_idString?

Unique identifier for a campaign.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 48

optional :campaign_id, String, api_name: :campaignId

#campaign_statusSymbol, ...

Campaign status



54
55
56
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 54

optional :campaign_status,
enum: -> { Telnyx::Models::Messaging10dlc::CampaignListResponse::CampaignStatus },
api_name: :campaignStatus

#create_dateString?

Unix timestamp when campaign was created.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 62

optional :create_date, String, api_name: :createDate

#csp_idString?

Alphanumeric identifier of the CSP associated with this campaign.

Returns:

  • (String, nil)


68
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 68

optional :csp_id, String, api_name: :cspId

#descriptionString?

Summary description of this campaign.

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 74

optional :description, String

#direct_lendingBoolean?

Returns:

  • (Boolean, nil)


79
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 79

optional :direct_lending, Telnyx::Internal::Type::Boolean, api_name: :directLending

Does message generated by the campaign include URL link in SMS?

Returns:

  • (Boolean, nil)


85
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 85

optional :embedded_link, Telnyx::Internal::Type::Boolean, api_name: :embeddedLink

Sample of an embedded link that will be sent to subscribers.

Returns:

  • (String, nil)


91
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 91

optional :embedded_link_sample, String, api_name: :embeddedLinkSample

#embedded_phoneBoolean?

Does message generated by the campaign include phone number in SMS?

Returns:

  • (Boolean, nil)


97
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 97

optional :embedded_phone, Telnyx::Internal::Type::Boolean, api_name: :embeddedPhone

#failure_reasonsString?

Failure reasons if campaign submission failed

Returns:

  • (String, nil)


103
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 103

optional :failure_reasons, String, api_name: :failureReasons

#help_keywordsString?

Subscriber help keywords. Multiple keywords are comma separated without space.

Returns:

  • (String, nil)


109
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 109

optional :help_keywords, String, api_name: :helpKeywords

#help_messageString?

Help message of the campaign.

Returns:

  • (String, nil)


115
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 115

optional :help_message, String, api_name: :helpMessage

#is_t_mobile_number_pooling_enabledBoolean?

Indicates whether the campaign has a T-Mobile number pool ID associated with it.

Returns:

  • (Boolean, nil)


121
122
123
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 121

optional :is_t_mobile_number_pooling_enabled,
Telnyx::Internal::Type::Boolean,
api_name: :isTMobileNumberPoolingEnabled

#is_t_mobile_registeredBoolean?

Indicates whether the campaign is registered with T-Mobile.

Returns:

  • (Boolean, nil)


129
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 129

optional :is_t_mobile_registered, Telnyx::Internal::Type::Boolean, api_name: :isTMobileRegistered

#is_t_mobile_suspendedBoolean?

Indicates whether the campaign is suspended with T-Mobile.

Returns:

  • (Boolean, nil)


135
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 135

optional :is_t_mobile_suspended, Telnyx::Internal::Type::Boolean, api_name: :isTMobileSuspended

#message_flowString?

Message flow description.

Returns:

  • (String, nil)


141
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 141

optional :message_flow, String, api_name: :messageFlow

#mockBoolean?

Campaign created from mock brand. Mocked campaign cannot be shared with an upstream CNP.

Returns:

  • (Boolean, nil)


148
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 148

optional :mock, Telnyx::Internal::Type::Boolean

#next_renewal_or_expiration_dateString?

When the campaign would be due for its next renew/bill date.

Returns:

  • (String, nil)


154
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 154

optional :next_renewal_or_expiration_date, String, api_name: :nextRenewalOrExpirationDate

#number_poolBoolean?

Does campaign utilize pool of phone numbers?

Returns:

  • (Boolean, nil)


160
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 160

optional :number_pool, Telnyx::Internal::Type::Boolean, api_name: :numberPool

#optin_keywordsString?

Subscriber opt-in keywords. Multiple keywords are comma separated without space.

Returns:

  • (String, nil)


166
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 166

optional :optin_keywords, String, api_name: :optinKeywords

#optin_messageString?

Subscriber opt-in message.

Returns:

  • (String, nil)


172
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 172

optional :optin_message, String, api_name: :optinMessage

#optout_keywordsString?

Subscriber opt-out keywords. Multiple keywords are comma separated without space.

Returns:

  • (String, nil)


179
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 179

optional :optout_keywords, String, api_name: :optoutKeywords

#optout_messageString?

Subscriber opt-out message.

Returns:

  • (String, nil)


185
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 185

optional :optout_message, String, api_name: :optoutMessage

Link to the campaign’s privacy policy.

Returns:

  • (String, nil)


191
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 191

optional :privacy_policy_link, String, api_name: :privacyPolicyLink

#reference_idString?

Caller supplied campaign reference ID. If supplied, the value must be unique across all submitted campaigns. Can be used to prevent duplicate campaign registrations.

Returns:

  • (String, nil)


199
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 199

optional :reference_id, String, api_name: :referenceId

#reseller_idString?

Alphanumeric identifier of the reseller that you want to associate with this campaign.

Returns:

  • (String, nil)


206
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 206

optional :reseller_id, String, api_name: :resellerId

#sample1String?

Message sample. Some campaign tiers require 1 or more message samples.

Returns:

  • (String, nil)


212
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 212

optional :sample1, String

#sample2String?

Message sample. Some campaign tiers require 2 or more message samples.

Returns:

  • (String, nil)


218
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 218

optional :sample2, String

#sample3String?

Message sample. Some campaign tiers require 3 or more message samples.

Returns:

  • (String, nil)


224
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 224

optional :sample3, String

#sample4String?

Message sample. Some campaign tiers require 4 or more message samples.

Returns:

  • (String, nil)


230
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 230

optional :sample4, String

#sample5String?

Message sample. Some campaign tiers require 5 or more message samples.

Returns:

  • (String, nil)


236
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 236

optional :sample5, String

#statusString?

Current campaign status. Possible values: ACTIVE, EXPIRED. A newly created campaign defaults to ACTIVE status.

Returns:

  • (String, nil)


243
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 243

optional :status, String

#sub_usecasesArray<String>?

Campaign sub-usecases. Must be of defined valid sub-usecase types. Use ‘/10dlc/enum/usecase` operation to retrieve list of valid sub-usecases

Returns:

  • (Array<String>, nil)


276
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 276

optional :sub_usecases, Telnyx::Internal::Type::ArrayOf[String], api_name: :subUsecases

#submission_statusSymbol, ...

Campaign submission status



249
250
251
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 249

optional :submission_status,
enum: -> { Telnyx::Models::Messaging10dlc::CampaignListResponse::SubmissionStatus },
api_name: :submissionStatus

#subscriber_helpBoolean?

Does campaign responds to help keyword(s)?

Returns:

  • (Boolean, nil)


257
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 257

optional :subscriber_help, Telnyx::Internal::Type::Boolean, api_name: :subscriberHelp

#subscriber_optinBoolean?

Does campaign require subscriber to opt-in before SMS is sent to subscriber?

Returns:

  • (Boolean, nil)


263
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 263

optional :subscriber_optin, Telnyx::Internal::Type::Boolean, api_name: :subscriberOptin

#subscriber_optoutBoolean?

Does campaign support subscriber opt-out keyword(s)?

Returns:

  • (Boolean, nil)


269
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 269

optional :subscriber_optout, Telnyx::Internal::Type::Boolean, api_name: :subscriberOptout

#tcr_brand_idString?

Unique identifier assigned to the brand by the registry.

Returns:

  • (String, nil)


282
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 282

optional :tcr_brand_id, String, api_name: :tcrBrandId

#tcr_campaign_idString?

Unique identifier assigned to the campaign by the registry.

Returns:

  • (String, nil)


288
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 288

optional :tcr_campaign_id, String, api_name: :tcrCampaignId

#terms_and_conditionsBoolean?

Is terms & conditions accepted?

Returns:

  • (Boolean, nil)


294
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 294

optional :terms_and_conditions, Telnyx::Internal::Type::Boolean, api_name: :termsAndConditions

Link to the campaign’s terms and conditions.

Returns:

  • (String, nil)


300
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 300

optional :terms_and_conditions_link, String, api_name: :termsAndConditionsLink

#usecaseString?

Campaign usecase. Must be of defined valid types. Use ‘/10dlc/enum/usecase` operation to retrieve usecases available for given brand.

Returns:

  • (String, nil)


307
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 307

optional :usecase, String

#verticalString?

Deprecated.

This field is deprecated and will be removed soon

Business/industry segment of this campaign (Deprecated). Must be of defined valid types. Use ‘/registry/enum/vertical` operation to retrieve verticals available for given brand, vertical combination.

This field is deprecated.

Returns:

  • (String, nil)


319
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 319

optional :vertical, String

#webhook_failover_urlString?

Failover webhook to which campaign status updates are sent.

Returns:

  • (String, nil)


325
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 325

optional :webhook_failover_url, String, api_name: :webhookFailoverURL

#webhook_urlString?

Webhook to which campaign status updates are sent.

Returns:

  • (String, nil)


331
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 331

optional :webhook_url, String, api_name: :webhookURL

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 458