Class: Telnyx::Models::Messaging10dlc::CampaignSubmitAppealParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::CampaignSubmitAppealParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/messaging_10dlc/campaign_submit_appeal_params.rb
Overview
Instance Attribute Summary collapse
-
#appeal_reason ⇒ String
Detailed explanation of why the campaign should be reconsidered and what changes have been made to address the rejection reason.
- #campaign_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(campaign_id:, appeal_reason:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CampaignSubmitAppealParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(campaign_id:, appeal_reason:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::CampaignSubmitAppealParams for more details.
|
|
# File 'lib/telnyx/models/messaging_10dlc/campaign_submit_appeal_params.rb', line 23
|
Instance Attribute Details
#appeal_reason ⇒ String
Detailed explanation of why the campaign should be reconsidered and what changes have been made to address the rejection reason.
21 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_submit_appeal_params.rb', line 21 required :appeal_reason, String |
#campaign_id ⇒ String
14 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_submit_appeal_params.rb', line 14 required :campaign_id, String |