Class: Telnyx::Models::Messaging10dlc::CampaignUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::CampaignUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/messaging_10dlc/campaign_update_params.rb
Overview
Instance Attribute Summary collapse
-
#auto_renewal ⇒ Boolean?
Help message of the campaign.
- #campaign_id ⇒ String
-
#help_message ⇒ String?
Help message of the campaign.
-
#message_flow ⇒ String?
Message flow description.
-
#reseller_id ⇒ String?
Alphanumeric identifier of the reseller that you want to associate with this campaign.
-
#sample1 ⇒ String?
Message sample.
-
#sample2 ⇒ String?
Message sample.
-
#sample3 ⇒ String?
Message sample.
-
#sample4 ⇒ String?
Message sample.
-
#sample5 ⇒ String?
Message sample.
-
#webhook_failover_url ⇒ String?
Webhook failover to which campaign status updates are sent.
-
#webhook_url ⇒ String?
Webhook to which campaign status updates are sent.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(campaign_id:, auto_renewal: nil, help_message: nil, message_flow: nil, reseller_id: nil, sample1: nil, sample2: nil, sample3: nil, sample4: nil, sample5: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CampaignUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(campaign_id:, auto_renewal: nil, help_message: nil, message_flow: nil, reseller_id: nil, sample1: nil, sample2: nil, sample3: nil, sample4: nil, sample5: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::CampaignUpdateParams for more details.
|
|
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 83
|
Instance Attribute Details
#auto_renewal ⇒ Boolean?
Help message of the campaign.
20 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 20 optional :auto_renewal, Telnyx::Internal::Type::Boolean, api_name: :autoRenewal |
#campaign_id ⇒ String
14 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 14 required :campaign_id, String |
#help_message ⇒ String?
Help message of the campaign.
26 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 26 optional :help_message, String, api_name: :helpMessage |
#message_flow ⇒ String?
Message flow description.
32 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 32 optional :message_flow, String, api_name: :messageFlow |
#reseller_id ⇒ String?
Alphanumeric identifier of the reseller that you want to associate with this campaign.
39 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 39 optional :reseller_id, String, api_name: :resellerId |
#sample1 ⇒ String?
Message sample. Some campaign tiers require 1 or more message samples.
45 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 45 optional :sample1, String |
#sample2 ⇒ String?
Message sample. Some campaign tiers require 2 or more message samples.
51 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 51 optional :sample2, String |
#sample3 ⇒ String?
Message sample. Some campaign tiers require 3 or more message samples.
57 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 57 optional :sample3, String |
#sample4 ⇒ String?
Message sample. Some campaign tiers require 4 or more message samples.
63 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 63 optional :sample4, String |
#sample5 ⇒ String?
Message sample. Some campaign tiers require 5 or more message samples.
69 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 69 optional :sample5, String |
#webhook_failover_url ⇒ String?
Webhook failover to which campaign status updates are sent.
75 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 75 optional :webhook_failover_url, String, api_name: :webhookFailoverURL |
#webhook_url ⇒ String?
Webhook to which campaign status updates are sent.
81 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_update_params.rb', line 81 optional :webhook_url, String, api_name: :webhookURL |