Class: Telnyx::Models::Messaging10dlc::PartnerCampaignListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/messaging_10dlc/partner_campaign_list_params.rb

Overview

Defined Under Namespace

Modules: Sort

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(page: nil, records_per_page: nil, sort: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::PartnerCampaignListParams for more details.

Parameters:

  • page (Integer) (defaults to: nil)

    The 1-indexed page number to get. The default value is ‘1`.

  • records_per_page (Integer) (defaults to: nil)

    The amount of records per page, limited to between 1 and 500 inclusive. The defa

  • sort (Symbol, Telnyx::Models::Messaging10dlc::PartnerCampaignListParams::Sort) (defaults to: nil)

    Specifies the sort order for results. If not given, results are sorted by create

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_params.rb', line 31

Instance Attribute Details

#pageInteger?

The 1-indexed page number to get. The default value is ‘1`.

Returns:

  • (Integer, nil)


15
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_params.rb', line 15

optional :page, Integer

#records_per_pageInteger?

The amount of records per page, limited to between 1 and 500 inclusive. The default value is ‘10`.

Returns:

  • (Integer, nil)


22
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_params.rb', line 22

optional :records_per_page, Integer

#sortSymbol, ...

Specifies the sort order for results. If not given, results are sorted by createdAt in descending order.



29
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_params.rb', line 29

optional :sort, enum: -> { Telnyx::Messaging10dlc::PartnerCampaignListParams::Sort }