Class: Telnyx::Models::Messaging10dlc::PartnerCampaignListSharedByMeParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::PartnerCampaignListSharedByMeParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_params.rb
Overview
Instance Attribute Summary collapse
-
#page ⇒ Integer?
The 1-indexed page number to get.
-
#records_per_page ⇒ Integer?
The amount of records per page, limited to between 1 and 500 inclusive.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(page: nil, records_per_page: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PartnerCampaignListSharedByMeParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(page: nil, records_per_page: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::PartnerCampaignListSharedByMeParams for more details.
|
|
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_params.rb', line 24
|
Instance Attribute Details
#page ⇒ Integer?
The 1-indexed page number to get. The default value is ‘1`.
15 |
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_params.rb', line 15 optional :page, Integer |
#records_per_page ⇒ Integer?
The amount of records per page, limited to between 1 and 500 inclusive. The default value is ‘10`.
22 |
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_params.rb', line 22 optional :records_per_page, Integer |