Class: Telnyx::Models::Messaging10dlc::PartnerCampaignUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::PartnerCampaignUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/messaging_10dlc/partner_campaign_update_params.rb
Overview
Instance Attribute Summary collapse
- #campaign_id ⇒ String
-
#webhook_failover_url ⇒ String?
Webhook failover to which campaign status updates are sent.
-
#webhook_url ⇒ String?
Webhook to which campaign status updates are sent.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(campaign_id:, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(campaign_id:, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_update_params.rb', line 28
|
Instance Attribute Details
#campaign_id ⇒ String
14 |
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_update_params.rb', line 14 required :campaign_id, String |
#webhook_failover_url ⇒ String?
Webhook failover to which campaign status updates are sent.
20 |
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_update_params.rb', line 20 optional :webhook_failover_url, String, api_name: :webhookFailoverURL |
#webhook_url ⇒ String?
Webhook to which campaign status updates are sent.
26 |
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_update_params.rb', line 26 optional :webhook_url, String, api_name: :webhookURL |