Class: Telnyx::Models::Messaging10dlc::PhoneNumberAssignmentByProfileListPhoneNumberStatusResponse::Record

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_list_phone_number_status_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(phone_number:, status:, task_id:) ⇒ Object

Parameters:

  • phone_number (String)

    The phone number that the status is being checked for.

  • status (String)

    The status of the associated phone number assignment.

  • task_id (String)

    The ID of the task associated with the phone number.



17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_list_phone_number_status_response.rb', line 17

class Record < Telnyx::Internal::Type::BaseModel
  # @!attribute phone_number
  #   The phone number that the status is being checked for.
  #
  #   @return [String]
  required :phone_number, String, api_name: :phoneNumber

  # @!attribute status
  #   The status of the associated phone number assignment.
  #
  #   @return [String]
  required :status, String

  # @!attribute task_id
  #   The ID of the task associated with the phone number.
  #
  #   @return [String]
  required :task_id, String, api_name: :taskId

  # @!method initialize(phone_number:, status:, task_id:)
  #   @param phone_number [String] The phone number that the status is being checked for.
  #
  #   @param status [String] The status of the associated phone number assignment.
  #
  #   @param task_id [String] The ID of the task associated with the phone number.
end

Instance Attribute Details

#phone_numberString

The phone number that the status is being checked for.

Returns:

  • (String)


22
# File 'lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_list_phone_number_status_response.rb', line 22

required :phone_number, String, api_name: :phoneNumber

#statusString

The status of the associated phone number assignment.

Returns:

  • (String)


28
# File 'lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_list_phone_number_status_response.rb', line 28

required :status, String

#task_idString

The ID of the task associated with the phone number.

Returns:

  • (String)


34
# File 'lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_list_phone_number_status_response.rb', line 34

required :task_id, String, api_name: :taskId