Class: Telnyx::Models::Messaging10dlc::PhoneNumberCampaign

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb

Overview

Defined Under Namespace

Modules: AssignmentStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(campaign_id:, created_at:, phone_number:, updated_at:, assignment_status: nil, brand_id: nil, failure_reasons: nil, tcr_brand_id: nil, tcr_campaign_id: nil, telnyx_campaign_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::PhoneNumberCampaign for more details.

Parameters:

  • campaign_id (String)

    For shared campaigns, this is the TCR campaign ID, otherwise it is the campaign

  • created_at (String)
  • phone_number (String)
  • updated_at (String)
  • assignment_status (Symbol, Telnyx::Models::Messaging10dlc::PhoneNumberCampaign::AssignmentStatus) (defaults to: nil)

    The assignment status of the number.

  • brand_id (String) (defaults to: nil)

    Brand ID. Empty if the number is associated to a shared campaign.

  • failure_reasons (String) (defaults to: nil)

    Extra info about a failure to assign/unassign a number. Relevant only if the ass

  • tcr_brand_id (String) (defaults to: nil)

    TCR’s alphanumeric ID for the brand.

  • tcr_campaign_id (String) (defaults to: nil)

    TCR’s alphanumeric ID for the campaign.

  • telnyx_campaign_id (String) (defaults to: nil)

    Campaign ID. Empty if the number is associated to a shared campaign.



# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 69

Instance Attribute Details

#assignment_statusSymbol, ...

The assignment status of the number.



34
35
36
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 34

optional :assignment_status,
enum: -> { Telnyx::Messaging10dlc::PhoneNumberCampaign::AssignmentStatus },
api_name: :assignmentStatus

#brand_idString?

Brand ID. Empty if the number is associated to a shared campaign.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 42

optional :brand_id, String, api_name: :brandId

#campaign_idString

For shared campaigns, this is the TCR campaign ID, otherwise it is the campaign ID

Returns:

  • (String)


13
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 13

required :campaign_id, String, api_name: :campaignId

#created_atString

Returns:

  • (String)


18
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 18

required :created_at, String, api_name: :createdAt

#failure_reasonsString?

Extra info about a failure to assign/unassign a number. Relevant only if the assignmentStatus is either FAILED_ASSIGNMENT or FAILED_UNASSIGNMENT

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 49

optional :failure_reasons, String, api_name: :failureReasons

#phone_numberString

Returns:

  • (String)


23
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 23

required :phone_number, String, api_name: :phoneNumber

#tcr_brand_idString?

TCR’s alphanumeric ID for the brand.

Returns:

  • (String, nil)


55
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 55

optional :tcr_brand_id, String, api_name: :tcrBrandId

#tcr_campaign_idString?

TCR’s alphanumeric ID for the campaign.

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 61

optional :tcr_campaign_id, String, api_name: :tcrCampaignId

#telnyx_campaign_idString?

Campaign ID. Empty if the number is associated to a shared campaign.

Returns:

  • (String, nil)


67
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 67

optional :telnyx_campaign_id, String, api_name: :telnyxCampaignId

#updated_atString

Returns:

  • (String)


28
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign.rb', line 28

required :updated_at, String, api_name: :updatedAt