Class: Telnyx::Models::Messaging10dlc::PhoneNumberCampaignCreate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::PhoneNumberCampaignCreate
- Defined in:
- lib/telnyx/models/messaging_10dlc/phone_number_campaign_create.rb
Direct Known Subclasses
PhoneNumberCampaignCreateParams, PhoneNumberCampaignUpdateParams
Instance Attribute Summary collapse
-
#campaign_id ⇒ String
The ID of the campaign you want to link to the specified phone number.
-
#phone_number ⇒ String
The phone number you want to link to a specified campaign.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(campaign_id:, phone_number:) ⇒ Object
|
|
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign_create.rb', line 19
|
Instance Attribute Details
#campaign_id ⇒ String
The ID of the campaign you want to link to the specified phone number.
11 |
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign_create.rb', line 11 required :campaign_id, String, api_name: :campaignId |
#phone_number ⇒ String
The phone number you want to link to a specified campaign.
17 |
# File 'lib/telnyx/models/messaging_10dlc/phone_number_campaign_create.rb', line 17 required :phone_number, String, api_name: :phoneNumber |