Class: Telnyx::Models::Messaging10dlc::ProfileAssignmentPhoneNumbers
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::ProfileAssignmentPhoneNumbers
- Defined in:
- lib/telnyx/models/messaging_10dlc/profile_assignment_phone_numbers.rb
Instance Attribute Summary collapse
-
#phone_number ⇒ String
The phone number that the status is being checked for.
-
#status ⇒ String
The status of the associated phone number assignment.
-
#task_id ⇒ String
The ID of the task associated with the phone number.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(phone_number:, status:, task_id:) ⇒ Object
|
|
# File 'lib/telnyx/models/messaging_10dlc/profile_assignment_phone_numbers.rb', line 25
|
Instance Attribute Details
#phone_number ⇒ String
The phone number that the status is being checked for.
11 |
# File 'lib/telnyx/models/messaging_10dlc/profile_assignment_phone_numbers.rb', line 11 required :phone_number, String, api_name: :phoneNumber |
#status ⇒ String
The status of the associated phone number assignment.
17 |
# File 'lib/telnyx/models/messaging_10dlc/profile_assignment_phone_numbers.rb', line 17 required :status, String |
#task_id ⇒ String
The ID of the task associated with the phone number.
23 |
# File 'lib/telnyx/models/messaging_10dlc/profile_assignment_phone_numbers.rb', line 23 required :task_id, String, api_name: :taskId |