Class: Telnyx::Models::Messaging10dlc::TelnyxBrand

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/messaging_10dlc/telnyx_brand.rb

Overview

Direct Known Subclasses

BrandRetrieveResponse

Defined Under Namespace

Modules: BrandRelationship, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(brand_relationship:, country:, display_name:, email:, entity_type:, vertical:, alt_business_id: nil, alt_business_id_type: nil, brand_id: nil, business_contact_email: nil, city: nil, company_name: nil, created_at: nil, csp_id: nil, ein: nil, failure_reasons: nil, first_name: nil, identity_status: nil, ip_address: nil, is_reseller: nil, last_name: nil, mobile_phone: nil, mock: nil, optional_attributes: nil, phone: nil, postal_code: nil, reference_id: nil, state: nil, status: nil, stock_exchange: nil, stock_symbol: nil, street: nil, tcr_brand_id: nil, universal_ein: nil, updated_at: nil, webhook_failover_url: nil, webhook_url: nil, website: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::TelnyxBrand for more details.

Telnyx-specific extensions to The Campaign Registry’s ‘Brand` type

Parameters:

  • brand_relationship (Symbol, Telnyx::Models::Messaging10dlc::TelnyxBrand::BrandRelationship)

    Brand relationship to the CSP.

  • country (String)

    ISO2 2 characters country code. Example: US - United States

  • display_name (String)

    Display or marketing name of the brand.

  • email (String)

    Valid email address of brand support contact.

  • entity_type (Symbol, Telnyx::Models::Messaging10dlc::EntityType)

    Entity type behind the brand. This is the form of business establishment.

  • vertical (String)

    Vertical or industry segment of the brand.

  • alt_business_id (String) (defaults to: nil)

    Alternate business identifier such as DUNS, LEI, or GIIN

  • alt_business_id_type (Symbol, Telnyx::Models::Messaging10dlc::AltBusinessIDType) (defaults to: nil)

    An enumeration.

  • brand_id (String) (defaults to: nil)

    Unique identifier assigned to the brand.

  • business_contact_email (String) (defaults to: nil)

    Business contact email.

  • city (String) (defaults to: nil)

    City name

  • company_name (String) (defaults to: nil)

    (Required for Non-profit/private/public) Legal company name.

  • created_at (String) (defaults to: nil)

    Date and time that the brand was created at.

  • csp_id (String) (defaults to: nil)

    Unique identifier assigned to the csp by the registry.

  • ein (String) (defaults to: nil)

    (Required for Non-profit) Government assigned corporate tax ID. EIN is 9-digits

  • failure_reasons (String) (defaults to: nil)

    Failure reasons for brand

  • first_name (String) (defaults to: nil)

    First name of business contact.

  • identity_status (Symbol, Telnyx::Models::Messaging10dlc::BrandIdentityStatus) (defaults to: nil)

    The verification status of an active brand

  • ip_address (String) (defaults to: nil)

    IP address of the browser requesting to create brand identity.

  • is_reseller (Boolean) (defaults to: nil)

    Indicates whether this brand is known to be a reseller

  • last_name (String) (defaults to: nil)

    Last name of business contact.

  • mobile_phone (String) (defaults to: nil)

    Valid mobile phone number in e.164 international format.

  • mock (Boolean) (defaults to: nil)

    Mock brand for testing purposes

  • optional_attributes (Telnyx::Models::Messaging10dlc::BrandOptionalAttributes) (defaults to: nil)
  • phone (String) (defaults to: nil)

    Valid phone number in e.164 international format.

  • postal_code (String) (defaults to: nil)

    Postal codes. Use 5 digit zipcode for United States

  • reference_id (String) (defaults to: nil)

    Unique identifier Telnyx assigned to the brand - the brandId

  • state (String) (defaults to: nil)

    State. Must be 2 letters code for United States.

  • status (Symbol, Telnyx::Models::Messaging10dlc::TelnyxBrand::Status) (defaults to: nil)

    Status of the brand

  • stock_exchange (Symbol, Telnyx::Models::Messaging10dlc::StockExchange) (defaults to: nil)

    (Required for public company) stock exchange.

  • stock_symbol (String) (defaults to: nil)

    (Required for public company) stock symbol.

  • street (String) (defaults to: nil)

    Street number and name.

  • tcr_brand_id (String) (defaults to: nil)

    Unique identifier assigned to the brand by the registry.

  • universal_ein (String) (defaults to: nil)

    Universal EIN of Brand, Read Only.

  • updated_at (String) (defaults to: nil)

    Date and time that the brand was last updated at.

  • webhook_failover_url (String) (defaults to: nil)

    Failover webhook to which brand status updates are sent.

  • webhook_url (String) (defaults to: nil)

    Webhook to which brand status updates are sent.

  • website (String) (defaults to: nil)

    Brand website URL.



# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 246

Instance Attribute Details

#alt_business_idString?

Alternate business identifier such as DUNS, LEI, or GIIN

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 50

optional :alt_business_id, String, api_name: :altBusinessId

#alt_business_id_typeSymbol, ...

An enumeration.



56
57
58
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 56

optional :alt_business_id_type,
enum: -> { Telnyx::Messaging10dlc::AltBusinessIDType },
api_name: :altBusinessIdType

#brand_idString?

Unique identifier assigned to the brand.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 64

optional :brand_id, String, api_name: :brandId

#brand_relationshipSymbol, Telnyx::Models::Messaging10dlc::TelnyxBrand::BrandRelationship

Brand relationship to the CSP.



12
13
14
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 12

required :brand_relationship,
enum: -> { Telnyx::Messaging10dlc::TelnyxBrand::BrandRelationship },
api_name: :brandRelationship

#business_contact_emailString?

Business contact email.

Required if ‘entityType` is `PUBLIC_PROFIT`.

Returns:

  • (String, nil)


72
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 72

optional :business_contact_email, String, api_name: :businessContactEmail

#cityString?

City name

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 78

optional :city, String

#company_nameString?

(Required for Non-profit/private/public) Legal company name.

Returns:

  • (String, nil)


84
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 84

optional :company_name, String, api_name: :companyName

#countryString

ISO2 2 characters country code. Example: US - United States

Returns:

  • (String)


20
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 20

required :country, String

#created_atString?

Date and time that the brand was created at.

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 90

optional :created_at, String, api_name: :createdAt

#csp_idString?

Unique identifier assigned to the csp by the registry.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 96

optional :csp_id, String, api_name: :cspId

#display_nameString

Display or marketing name of the brand.

Returns:

  • (String)


26
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 26

required :display_name, String, api_name: :displayName

#einString?

(Required for Non-profit) Government assigned corporate tax ID. EIN is 9-digits in U.S.

Returns:

  • (String, nil)


103
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 103

optional :ein, String

#emailString

Valid email address of brand support contact.

Returns:

  • (String)


32
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 32

required :email, String

#entity_typeSymbol, Telnyx::Models::Messaging10dlc::EntityType

Entity type behind the brand. This is the form of business establishment.



38
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 38

required :entity_type, enum: -> { Telnyx::Messaging10dlc::EntityType }, api_name: :entityType

#failure_reasonsString?

Failure reasons for brand

Returns:

  • (String, nil)


109
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 109

optional :failure_reasons, String, api_name: :failureReasons

#first_nameString?

First name of business contact.

Returns:

  • (String, nil)


115
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 115

optional :first_name, String, api_name: :firstName

#identity_statusSymbol, ...

The verification status of an active brand



121
122
123
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 121

optional :identity_status,
enum: -> { Telnyx::Messaging10dlc::BrandIdentityStatus },
api_name: :identityStatus

#ip_addressString?

IP address of the browser requesting to create brand identity.

Returns:

  • (String, nil)


129
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 129

optional :ip_address, String, api_name: :ipAddress

#is_resellerBoolean?

Indicates whether this brand is known to be a reseller

Returns:

  • (Boolean, nil)


135
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 135

optional :is_reseller, Telnyx::Internal::Type::Boolean, api_name: :isReseller

#last_nameString?

Last name of business contact.

Returns:

  • (String, nil)


141
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 141

optional :last_name, String, api_name: :lastName

#mobile_phoneString?

Valid mobile phone number in e.164 international format.

Returns:

  • (String, nil)


147
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 147

optional :mobile_phone, String, api_name: :mobilePhone

#mockBoolean?

Mock brand for testing purposes

Returns:

  • (Boolean, nil)


153
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 153

optional :mock, Telnyx::Internal::Type::Boolean

#optional_attributesTelnyx::Models::Messaging10dlc::BrandOptionalAttributes?



158
159
160
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 158

optional :optional_attributes,
-> { Telnyx::Messaging10dlc::BrandOptionalAttributes },
api_name: :optionalAttributes

#phoneString?

Valid phone number in e.164 international format.

Returns:

  • (String, nil)


166
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 166

optional :phone, String

#postal_codeString?

Postal codes. Use 5 digit zipcode for United States

Returns:

  • (String, nil)


172
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 172

optional :postal_code, String, api_name: :postalCode

#reference_idString?

Unique identifier Telnyx assigned to the brand - the brandId

Returns:

  • (String, nil)


178
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 178

optional :reference_id, String, api_name: :referenceId

#stateString?

State. Must be 2 letters code for United States.

Returns:

  • (String, nil)


184
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 184

optional :state, String

#statusSymbol, ...

Status of the brand



190
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 190

optional :status, enum: -> { Telnyx::Messaging10dlc::TelnyxBrand::Status }

#stock_exchangeSymbol, ...

(Required for public company) stock exchange.



196
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 196

optional :stock_exchange, enum: -> { Telnyx::Messaging10dlc::StockExchange }, api_name: :stockExchange

#stock_symbolString?

(Required for public company) stock symbol.

Returns:

  • (String, nil)


202
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 202

optional :stock_symbol, String, api_name: :stockSymbol

#streetString?

Street number and name.

Returns:

  • (String, nil)


208
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 208

optional :street, String

#tcr_brand_idString?

Unique identifier assigned to the brand by the registry.

Returns:

  • (String, nil)


214
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 214

optional :tcr_brand_id, String, api_name: :tcrBrandId

#universal_einString?

Universal EIN of Brand, Read Only.

Returns:

  • (String, nil)


220
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 220

optional :universal_ein, String, api_name: :universalEin

#updated_atString?

Date and time that the brand was last updated at.

Returns:

  • (String, nil)


226
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 226

optional :updated_at, String, api_name: :updatedAt

#verticalString

Vertical or industry segment of the brand.

Returns:

  • (String)


44
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 44

required :vertical, String

#webhook_failover_urlString?

Failover webhook to which brand status updates are sent.

Returns:

  • (String, nil)


232
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 232

optional :webhook_failover_url, String, api_name: :webhookFailoverURL

#webhook_urlString?

Webhook to which brand status updates are sent.

Returns:

  • (String, nil)


238
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 238

optional :webhook_url, String, api_name: :webhookURL

#websiteString?

Brand website URL.

Returns:

  • (String, nil)


244
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 244

optional :website, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 340