Class: Telnyx::Models::Messaging10dlc::TelnyxCampaignCsp
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::TelnyxCampaignCsp
- Defined in:
- lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb
Overview
Defined Under Namespace
Modules: CampaignStatus, SubmissionStatus
Instance Attribute Summary collapse
-
#age_gated ⇒ Boolean?
Age gated content in campaign.
-
#auto_renewal ⇒ Boolean?
Campaign subscription auto-renewal status.
-
#billed_date ⇒ String?
Campaign recent billed date.
-
#brand_display_name ⇒ String?
Display or marketing name of the brand.
-
#brand_id ⇒ String
Unique identifier assigned to the brand.
-
#campaign_id ⇒ String
Unique identifier for a campaign.
-
#campaign_status ⇒ Symbol, ...
Campaign status.
-
#create_date ⇒ String?
Unix timestamp when campaign was created.
-
#csp_id ⇒ String
Alphanumeric identifier of the CSP associated with this campaign.
-
#description ⇒ String
Summary description of this campaign.
- #direct_lending ⇒ Boolean?
-
#embedded_link ⇒ Boolean?
Does message generated by the campaign include URL link in SMS?.
-
#embedded_link_sample ⇒ String?
Sample of an embedded link that will be sent to subscribers.
-
#embedded_phone ⇒ Boolean?
Does message generated by the campaign include phone number in SMS?.
-
#failure_reasons ⇒ String?
Failure reasons if campaign submission failed.
-
#help_keywords ⇒ String?
Subscriber help keywords.
-
#help_message ⇒ String?
Help message of the campaign.
-
#is_t_mobile_number_pooling_enabled ⇒ Boolean?
Indicates whether the campaign has a T-Mobile number pool ID associated with it.
-
#is_t_mobile_registered ⇒ Boolean?
Indicates whether the campaign is registered with T-Mobile.
-
#is_t_mobile_suspended ⇒ Boolean?
Indicates whether the campaign is suspended with T-Mobile.
-
#message_flow ⇒ String?
Message flow description.
-
#mock ⇒ Boolean
Campaign created from mock brand.
-
#next_renewal_or_expiration_date ⇒ String?
When the campaign would be due for its next renew/bill date.
-
#number_pool ⇒ Boolean?
Does campaign utilize pool of phone numbers?.
-
#optin_keywords ⇒ String?
Subscriber opt-in keywords.
-
#optin_message ⇒ String?
Subscriber opt-in message.
-
#optout_keywords ⇒ String?
Subscriber opt-out keywords.
-
#optout_message ⇒ String?
Subscriber opt-out message.
-
#privacy_policy_link ⇒ String?
Link to the campaign’s privacy policy.
-
#reference_id ⇒ String?
Caller supplied campaign reference ID.
-
#reseller_id ⇒ String?
Alphanumeric identifier of the reseller that you want to associate with this campaign.
-
#sample1 ⇒ String?
Message sample.
-
#sample2 ⇒ String?
Message sample.
-
#sample3 ⇒ String?
Message sample.
-
#sample4 ⇒ String?
Message sample.
-
#sample5 ⇒ String?
Message sample.
-
#status ⇒ String?
Current campaign status.
-
#sub_usecases ⇒ Array<String>
Campaign sub-usecases.
-
#submission_status ⇒ Symbol, ...
Campaign submission status.
-
#subscriber_help ⇒ Boolean?
Does campaign responds to help keyword(s)?.
-
#subscriber_optin ⇒ Boolean?
Does campaign require subscriber to opt-in before SMS is sent to subscriber?.
-
#subscriber_optout ⇒ Boolean?
Does campaign support subscriber opt-out keyword(s)?.
-
#tcr_brand_id ⇒ String?
Unique identifier assigned to the brand by the registry.
-
#tcr_campaign_id ⇒ String?
Unique identifier assigned to the campaign by the registry.
-
#terms_and_conditions ⇒ Boolean
Is terms & conditions accepted?.
-
#terms_and_conditions_link ⇒ String?
Link to the campaign’s terms and conditions.
-
#usecase ⇒ String
Campaign usecase.
-
#vertical ⇒ String?
deprecated
Deprecated.
This field is deprecated and will be removed soon
-
#webhook_failover_url ⇒ String?
Failover webhook to which campaign status updates are sent.
-
#webhook_url ⇒ String?
Webhook to which campaign status updates are sent.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(brand_id:, campaign_id:, csp_id:, description:, mock:, sub_usecases:, terms_and_conditions:, usecase:, age_gated: nil, auto_renewal: nil, billed_date: nil, brand_display_name: nil, campaign_status: nil, create_date: nil, direct_lending: nil, embedded_link: nil, embedded_link_sample: nil, embedded_phone: nil, failure_reasons: nil, help_keywords: nil, help_message: nil, is_t_mobile_number_pooling_enabled: nil, is_t_mobile_registered: nil, is_t_mobile_suspended: nil, message_flow: nil, next_renewal_or_expiration_date: nil, number_pool: nil, optin_keywords: nil, optin_message: nil, optout_keywords: nil, optout_message: nil, privacy_policy_link: nil, reference_id: nil, reseller_id: nil, sample1: nil, sample2: nil, sample3: nil, sample4: nil, sample5: nil, status: nil, submission_status: nil, subscriber_help: nil, subscriber_optin: nil, subscriber_optout: nil, tcr_brand_id: nil, tcr_campaign_id: nil, terms_and_conditions_link: nil, vertical: nil, webhook_failover_url: nil, webhook_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TelnyxCampaignCsp for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(brand_id:, campaign_id:, csp_id:, description:, mock:, sub_usecases:, terms_and_conditions:, usecase:, age_gated: nil, auto_renewal: nil, billed_date: nil, brand_display_name: nil, campaign_status: nil, create_date: nil, direct_lending: nil, embedded_link: nil, embedded_link_sample: nil, embedded_phone: nil, failure_reasons: nil, help_keywords: nil, help_message: nil, is_t_mobile_number_pooling_enabled: nil, is_t_mobile_registered: nil, is_t_mobile_suspended: nil, message_flow: nil, next_renewal_or_expiration_date: nil, number_pool: nil, optin_keywords: nil, optin_message: nil, optout_keywords: nil, optout_message: nil, privacy_policy_link: nil, reference_id: nil, reseller_id: nil, sample1: nil, sample2: nil, sample3: nil, sample4: nil, sample5: nil, status: nil, submission_status: nil, subscriber_help: nil, subscriber_optin: nil, subscriber_optout: nil, tcr_brand_id: nil, tcr_campaign_id: nil, terms_and_conditions_link: nil, vertical: nil, webhook_failover_url: nil, webhook_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::TelnyxCampaignCsp for more details.
Campaign is generated by the 10DLC registry once the corresponding campaign request is approved. Each campaign is assigned a unique identifier - campaignId. Once a campaign is activated, limited information is published to the NetNumber OSR service for consumption by members of the ecosystem. When a campaign is suspended(reversible) or expired(non-reversible), campaign data is deleted from the OSR service. Most attributes of campaignare immutable, including usecase, vertical, brandId and cspId.
|
|
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 327
|
Instance Attribute Details
#age_gated ⇒ Boolean?
Age gated content in campaign.
63 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 63 optional :age_gated, Telnyx::Internal::Type::Boolean, api_name: :ageGated |
#auto_renewal ⇒ Boolean?
Campaign subscription auto-renewal status.
69 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 69 optional :auto_renewal, Telnyx::Internal::Type::Boolean, api_name: :autoRenewal |
#billed_date ⇒ String?
Campaign recent billed date.
75 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 75 optional :billed_date, String, api_name: :billedDate |
#brand_display_name ⇒ String?
Display or marketing name of the brand.
81 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 81 optional :brand_display_name, String, api_name: :brandDisplayName |
#brand_id ⇒ String
Unique identifier assigned to the brand.
12 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 12 required :brand_id, String, api_name: :brandId |
#campaign_id ⇒ String
Unique identifier for a campaign.
18 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 18 required :campaign_id, String, api_name: :campaignId |
#campaign_status ⇒ Symbol, ...
Campaign status
87 88 89 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 87 optional :campaign_status, enum: -> { Telnyx::Messaging10dlc::TelnyxCampaignCsp::CampaignStatus }, api_name: :campaignStatus |
#create_date ⇒ String?
Unix timestamp when campaign was created.
95 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 95 optional :create_date, String, api_name: :createDate |
#csp_id ⇒ String
Alphanumeric identifier of the CSP associated with this campaign.
24 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 24 required :csp_id, String, api_name: :cspId |
#description ⇒ String
Summary description of this campaign.
30 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 30 required :description, String |
#direct_lending ⇒ Boolean?
100 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 100 optional :direct_lending, Telnyx::Internal::Type::Boolean, api_name: :directLending |
#embedded_link ⇒ Boolean?
Does message generated by the campaign include URL link in SMS?
106 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 106 optional :embedded_link, Telnyx::Internal::Type::Boolean, api_name: :embeddedLink |
#embedded_link_sample ⇒ String?
Sample of an embedded link that will be sent to subscribers.
112 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 112 optional :embedded_link_sample, String, api_name: :embeddedLinkSample |
#embedded_phone ⇒ Boolean?
Does message generated by the campaign include phone number in SMS?
118 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 118 optional :embedded_phone, Telnyx::Internal::Type::Boolean, api_name: :embeddedPhone |
#failure_reasons ⇒ String?
Failure reasons if campaign submission failed
124 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 124 optional :failure_reasons, String, api_name: :failureReasons |
#help_keywords ⇒ String?
Subscriber help keywords. Multiple keywords are comma separated without space.
130 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 130 optional :help_keywords, String, api_name: :helpKeywords |
#help_message ⇒ String?
Help message of the campaign.
136 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 136 optional :help_message, String, api_name: :helpMessage |
#is_t_mobile_number_pooling_enabled ⇒ Boolean?
Indicates whether the campaign has a T-Mobile number pool ID associated with it.
142 143 144 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 142 optional :is_t_mobile_number_pooling_enabled, Telnyx::Internal::Type::Boolean, api_name: :isTMobileNumberPoolingEnabled |
#is_t_mobile_registered ⇒ Boolean?
Indicates whether the campaign is registered with T-Mobile.
150 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 150 optional :is_t_mobile_registered, Telnyx::Internal::Type::Boolean, api_name: :isTMobileRegistered |
#is_t_mobile_suspended ⇒ Boolean?
Indicates whether the campaign is suspended with T-Mobile.
156 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 156 optional :is_t_mobile_suspended, Telnyx::Internal::Type::Boolean, api_name: :isTMobileSuspended |
#message_flow ⇒ String?
Message flow description.
162 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 162 optional :message_flow, String, api_name: :messageFlow |
#mock ⇒ Boolean
Campaign created from mock brand. Mocked campaign cannot be shared with an upstream CNP.
37 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 37 required :mock, Telnyx::Internal::Type::Boolean |
#next_renewal_or_expiration_date ⇒ String?
When the campaign would be due for its next renew/bill date.
168 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 168 optional :next_renewal_or_expiration_date, String, api_name: :nextRenewalOrExpirationDate |
#number_pool ⇒ Boolean?
Does campaign utilize pool of phone numbers?
174 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 174 optional :number_pool, Telnyx::Internal::Type::Boolean, api_name: :numberPool |
#optin_keywords ⇒ String?
Subscriber opt-in keywords. Multiple keywords are comma separated without space.
180 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 180 optional :optin_keywords, String, api_name: :optinKeywords |
#optin_message ⇒ String?
Subscriber opt-in message.
186 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 186 optional :optin_message, String, api_name: :optinMessage |
#optout_keywords ⇒ String?
Subscriber opt-out keywords. Multiple keywords are comma separated without space.
193 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 193 optional :optout_keywords, String, api_name: :optoutKeywords |
#optout_message ⇒ String?
Subscriber opt-out message.
199 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 199 optional :optout_message, String, api_name: :optoutMessage |
#privacy_policy_link ⇒ String?
Link to the campaign’s privacy policy.
205 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 205 optional :privacy_policy_link, String, api_name: :privacyPolicyLink |
#reference_id ⇒ String?
Caller supplied campaign reference ID. If supplied, the value must be unique across all submitted campaigns. Can be used to prevent duplicate campaign registrations.
213 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 213 optional :reference_id, String, api_name: :referenceId |
#reseller_id ⇒ String?
Alphanumeric identifier of the reseller that you want to associate with this campaign.
220 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 220 optional :reseller_id, String, api_name: :resellerId |
#sample1 ⇒ String?
Message sample. Some campaign tiers require 1 or more message samples.
226 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 226 optional :sample1, String |
#sample2 ⇒ String?
Message sample. Some campaign tiers require 2 or more message samples.
232 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 232 optional :sample2, String |
#sample3 ⇒ String?
Message sample. Some campaign tiers require 3 or more message samples.
238 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 238 optional :sample3, String |
#sample4 ⇒ String?
Message sample. Some campaign tiers require 4 or more message samples.
244 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 244 optional :sample4, String |
#sample5 ⇒ String?
Message sample. Some campaign tiers require 5 or more message samples.
250 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 250 optional :sample5, String |
#status ⇒ String?
Current campaign status. Possible values: ACTIVE, EXPIRED. A newly created campaign defaults to ACTIVE status.
257 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 257 optional :status, String |
#sub_usecases ⇒ Array<String>
Campaign sub-usecases. Must be of defined valid sub-usecase types. Use ‘/10dlc/enum/usecase` operation to retrieve list of valid sub-usecases
44 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 44 required :sub_usecases, Telnyx::Internal::Type::ArrayOf[String], api_name: :subUsecases |
#submission_status ⇒ Symbol, ...
Campaign submission status
263 264 265 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 263 optional :submission_status, enum: -> { Telnyx::Messaging10dlc::TelnyxCampaignCsp::SubmissionStatus }, api_name: :submissionStatus |
#subscriber_help ⇒ Boolean?
Does campaign responds to help keyword(s)?
271 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 271 optional :subscriber_help, Telnyx::Internal::Type::Boolean, api_name: :subscriberHelp |
#subscriber_optin ⇒ Boolean?
Does campaign require subscriber to opt-in before SMS is sent to subscriber?
277 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 277 optional :subscriber_optin, Telnyx::Internal::Type::Boolean, api_name: :subscriberOptin |
#subscriber_optout ⇒ Boolean?
Does campaign support subscriber opt-out keyword(s)?
283 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 283 optional :subscriber_optout, Telnyx::Internal::Type::Boolean, api_name: :subscriberOptout |
#tcr_brand_id ⇒ String?
Unique identifier assigned to the brand by the registry.
289 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 289 optional :tcr_brand_id, String, api_name: :tcrBrandId |
#tcr_campaign_id ⇒ String?
Unique identifier assigned to the campaign by the registry.
295 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 295 optional :tcr_campaign_id, String, api_name: :tcrCampaignId |
#terms_and_conditions ⇒ Boolean
Is terms & conditions accepted?
50 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 50 required :terms_and_conditions, Telnyx::Internal::Type::Boolean, api_name: :termsAndConditions |
#terms_and_conditions_link ⇒ String?
Link to the campaign’s terms and conditions.
301 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 301 optional :terms_and_conditions_link, String, api_name: :termsAndConditionsLink |
#usecase ⇒ String
Campaign usecase. Must be of defined valid types. Use ‘/10dlc/enum/usecase` operation to retrieve usecases available for given brand.
57 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 57 required :usecase, String |
#vertical ⇒ String?
This field is deprecated and will be removed soon
Business/industry segment of this campaign (Deprecated). Must be of defined valid types. Use ‘/registry/enum/vertical` operation to retrieve verticals available for given brand, vertical combination.
This field is deprecated.
313 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 313 optional :vertical, String |
#webhook_failover_url ⇒ String?
Failover webhook to which campaign status updates are sent.
319 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 319 optional :webhook_failover_url, String, api_name: :webhookFailoverURL |
#webhook_url ⇒ String?
Webhook to which campaign status updates are sent.
325 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 325 optional :webhook_url, String, api_name: :webhookURL |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/messaging_10dlc/telnyx_campaign_csp.rb', line 458
|