Class: Telnyx::Models::MessagingFeatureSet

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/messaging_feature_set.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(domestic_two_way:, international_inbound:, international_outbound:) ⇒ Object

The set of features available for a specific messaging use case (SMS or MMS). Features can vary depending on the characteristics the phone number, as well as its current product configuration.

Parameters:

  • domestic_two_way (Boolean)

    Send messages to and receive messages from numbers in the same country.

  • international_inbound (Boolean)

    Receive messages from numbers in other countries.

  • international_outbound (Boolean)

    Send messages to numbers in other countries.



# File 'lib/telnyx/models/messaging_feature_set.rb', line 24

Instance Attribute Details

#domestic_two_wayBoolean

Send messages to and receive messages from numbers in the same country.

Returns:

  • (Boolean)


10
# File 'lib/telnyx/models/messaging_feature_set.rb', line 10

required :domestic_two_way, Telnyx::Internal::Type::Boolean

#international_inboundBoolean

Receive messages from numbers in other countries.

Returns:

  • (Boolean)


16
# File 'lib/telnyx/models/messaging_feature_set.rb', line 16

required :international_inbound, Telnyx::Internal::Type::Boolean

#international_outboundBoolean

Send messages to numbers in other countries.

Returns:

  • (Boolean)


22
# File 'lib/telnyx/models/messaging_feature_set.rb', line 22

required :international_outbound, Telnyx::Internal::Type::Boolean