Class: Telnyx::Models::MessagingHostedNumberOrder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MessagingHostedNumberOrder
- Defined in:
- lib/telnyx/models/messaging_hosted_number_order.rb,
sig/telnyx/models/messaging_hosted_number_order.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#messaging_profile_id ⇒ String?
Automatically associate the number with this messaging profile ID when the order is complete.
- #phone_numbers ⇒ Array<Telnyx::Models::HostedNumber>?
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
- #status ⇒ Symbol, ...
Instance Method Summary collapse
- #id ⇒ String readonly
-
#initialize(id: nil, messaging_profile_id: nil, phone_numbers: nil, record_type: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessagingHostedNumberOrder for more details.
- #record_type ⇒ String readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, messaging_profile_id: nil, phone_numbers: nil, record_type: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::MessagingHostedNumberOrder for more details.
|
|
# File 'lib/telnyx/models/messaging_hosted_number_order.rb', line 37
|
Instance Attribute Details
#id ⇒ String? (readonly)
Returns the value of attribute id.
27 28 29 |
# File 'sig/telnyx/models/messaging_hosted_number_order.rbs', line 27 def id @id end |
#messaging_profile_id ⇒ String?
Automatically associate the number with this messaging profile ID when the order is complete.
11 |
# File 'lib/telnyx/models/messaging_hosted_number_order.rb', line 11 optional :messaging_profile_id, String, nil?: true |
#phone_numbers ⇒ Array<Telnyx::Models::HostedNumber>?
16 |
# File 'lib/telnyx/models/messaging_hosted_number_order.rb', line 16 optional :phone_numbers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::HostedNumber] } |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
31 32 33 |
# File 'sig/telnyx/models/messaging_hosted_number_order.rbs', line 31 def record_type @record_type end |
#status ⇒ Symbol, ...
21 |
# File 'lib/telnyx/models/messaging_hosted_number_order.rb', line 21 optional :status, enum: -> { Telnyx::MessagingHostedNumberOrder::Status } |
Instance Method Details
#id= ⇒ String (readonly)
29 |
# File 'sig/telnyx/models/messaging_hosted_number_order.rbs', line 29
def id=: (String) -> String
|
#record_type= ⇒ String (readonly)
33 |
# File 'sig/telnyx/models/messaging_hosted_number_order.rbs', line 33
def record_type=: (String) -> String
|
#to_hash ⇒ {
43 |
# File 'sig/telnyx/models/messaging_hosted_number_order.rbs', line 43
def to_hash: -> {
|