Class: Telnyx::Models::MessagingHostedNumberOrderCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/messaging_hosted_number_order_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(messaging_profile_id: nil, phone_numbers: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessagingHostedNumberOrderCreateParams for more details.

Parameters:

  • messaging_profile_id (String) (defaults to: nil)

    Automatically associate the number with this messaging profile ID when the order

  • phone_numbers (Array<String>) (defaults to: nil)

    Phone numbers to be used for hosted messaging.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/messaging_hosted_number_order_create_params.rb', line 23

Instance Attribute Details

#messaging_profile_idString?

Automatically associate the number with this messaging profile ID when the order is complete.

Returns:

  • (String, nil)


15
# File 'lib/telnyx/models/messaging_hosted_number_order_create_params.rb', line 15

optional :messaging_profile_id, String

#phone_numbersArray<String>?

Phone numbers to be used for hosted messaging.

Returns:

  • (Array<String>, nil)


21
# File 'lib/telnyx/models/messaging_hosted_number_order_create_params.rb', line 21

optional :phone_numbers, Telnyx::Internal::Type::ArrayOf[String]