Class: Telnyx::Models::MessagingHostedNumberOrders::ActionUploadFileParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/messaging_hosted_number_orders/action_upload_file_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, bill: nil, loa: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessagingHostedNumberOrders::ActionUploadFileParams for more details.

Parameters:

  • id (String)
  • bill (Pathname, StringIO, IO, String, Telnyx::FilePart) (defaults to: nil)

    Must be the last month’s bill with proof of ownership of all of the numbers in t

  • loa (Pathname, StringIO, IO, String, Telnyx::FilePart) (defaults to: nil)

    Must be a signed LOA for the numbers in the order in PDF format.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/messaging_hosted_number_orders/action_upload_file_params.rb', line 29

Instance Attribute Details

#billPathname, ...

Must be the last month’s bill with proof of ownership of all of the numbers in the order in PDF format.

Returns:



21
# File 'lib/telnyx/models/messaging_hosted_number_orders/action_upload_file_params.rb', line 21

optional :bill, Telnyx::Internal::Type::FileInput

#idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/messaging_hosted_number_orders/action_upload_file_params.rb', line 14

required :id, String

#loaPathname, ...

Must be a signed LOA for the numbers in the order in PDF format.

Returns:



27
# File 'lib/telnyx/models/messaging_hosted_number_orders/action_upload_file_params.rb', line 27

optional :loa, Telnyx::Internal::Type::FileInput