Class: Telnyx::Models::MessagingNumbersBulkUpdateCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/messaging_numbers_bulk_update_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(messaging_profile_id:, numbers:, assign_only: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessagingNumbersBulkUpdateCreateParams for more details.

Parameters:

  • messaging_profile_id (String)

    Configure the messaging profile these phone numbers are assigned to:

  • numbers (Array<String>)

    The list of phone numbers to update.

  • assign_only (Boolean) (defaults to: nil)

    If true, only assign numbers to the profile without changing other settings.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/messaging_numbers_bulk_update_create_params.rb', line 33

Instance Attribute Details

#assign_onlyBoolean?

If true, only assign numbers to the profile without changing other settings.

Returns:

  • (Boolean, nil)


31
# File 'lib/telnyx/models/messaging_numbers_bulk_update_create_params.rb', line 31

optional :assign_only, Telnyx::Internal::Type::Boolean

#messaging_profile_idString

Configure the messaging profile these phone numbers are assigned to:

  • Set this field to ‘“”` to unassign each number from their respective messaging profile

  • Set this field to a quoted UUID of a messaging profile to assign these numbers to that messaging profile

Returns:

  • (String)


19
# File 'lib/telnyx/models/messaging_numbers_bulk_update_create_params.rb', line 19

required :messaging_profile_id, String

#numbersArray<String>

The list of phone numbers to update.

Returns:

  • (Array<String>)


25
# File 'lib/telnyx/models/messaging_numbers_bulk_update_create_params.rb', line 25

required :numbers, Telnyx::Internal::Type::ArrayOf[String]