Class: Telnyx::Models::MessagingProfile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/messaging_profile.rb,
sig/telnyx/models/messaging_profile.rbs

Defined Under Namespace

Modules: RecordType, WebhookAPIVersion

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, ai_assistant_id: nil, alpha_sender: nil, created_at: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, enabled: nil, health_webhook_url: nil, mms_fall_back_to_sms: nil, mms_transcoding: nil, mobile_only: nil, name: nil, number_pool_settings: nil, organization_id: nil, record_type: nil, redaction_enabled: nil, redaction_level: nil, resource_group_id: nil, smart_encoding: nil, updated_at: nil, url_shortener_settings: nil, v1_secret: nil, webhook_api_version: nil, webhook_failover_url: nil, webhook_url: nil, whitelisted_destinations: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessagingProfile for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the type of resource.

  • ai_assistant_id (String, nil) (defaults to: nil)

    The AI assistant ID associated with this messaging profile.

  • alpha_sender (String, nil) (defaults to: nil)

    The alphanumeric sender ID to use when sending to destinations that require an a

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • daily_spend_limit (String) (defaults to: nil)

    The maximum amount of money (in USD) that can be spent by this profile before mi

  • daily_spend_limit_enabled (Boolean) (defaults to: nil)

    Whether to enforce the value configured by daily_spend_limit.

  • enabled (Boolean) (defaults to: nil)

    Specifies whether the messaging profile is enabled or not.

  • health_webhook_url (String, nil) (defaults to: nil)

    DEPRECATED: health check url service checking

  • mms_fall_back_to_sms (Boolean) (defaults to: nil)

    enables SMS fallback for MMS messages.

  • mms_transcoding (Boolean) (defaults to: nil)

    enables automated resizing of MMS media.

  • mobile_only (Boolean) (defaults to: nil)

    Send messages only to mobile phone numbers.

  • name (String) (defaults to: nil)

    A user friendly name for the messaging profile.

  • number_pool_settings (Telnyx::Models::NumberPoolSettings, nil) (defaults to: nil)

    Number Pool allows you to send messages from a pool of numbers of different type

  • organization_id (String) (defaults to: nil)

    The organization that owns this messaging profile.

  • record_type (Symbol, Telnyx::Models::MessagingProfile::RecordType) (defaults to: nil)

    Identifies the type of the resource.

  • redaction_enabled (Boolean) (defaults to: nil)

    Indicates whether message content redaction is enabled for this profile.

  • redaction_level (Integer) (defaults to: nil)

    Determines how much information is redacted in messages for privacy or complianc

  • resource_group_id (String, nil) (defaults to: nil)

    The resource group ID associated with this messaging profile.

  • smart_encoding (Boolean) (defaults to: nil)

    Enables automatic character encoding optimization for SMS messages. When enabled

  • updated_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.

  • url_shortener_settings (Telnyx::Models::URLShortenerSettings, nil) (defaults to: nil)

    The URL shortener feature allows automatic replacement of URLs that were generat

  • v1_secret (String) (defaults to: nil)

    Secret used to authenticate with v1 endpoints.

  • webhook_api_version (Symbol, Telnyx::Models::MessagingProfile::WebhookAPIVersion) (defaults to: nil)

    Determines which webhook format will be used, Telnyx API v1, v2, or a legacy 201

  • webhook_failover_url (String, nil) (defaults to: nil)

    The failover URL where webhooks related to this messaging profile will be sent i

  • webhook_url (String, nil) (defaults to: nil)

    The URL where webhooks related to this messaging profile will be sent.

  • whitelisted_destinations (Array<String>) (defaults to: nil)

    Destinations to which the messaging profile is allowed to send. The elements in



# File 'lib/telnyx/models/messaging_profile.rb', line 183

Instance Attribute Details

#ai_assistant_idString?

The AI assistant ID associated with this messaging profile.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/messaging_profile.rb', line 10

optional :ai_assistant_id, String, nil?: true

#alpha_senderString?

The alphanumeric sender ID to use when sending to destinations that require an alphanumeric sender ID.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/messaging_profile.rb', line 17

optional :alpha_sender, String, nil?: true

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


112
113
114
# File 'sig/telnyx/models/messaging_profile.rbs', line 112

def created_at
  @created_at
end

#daily_spend_limitString?

The maximum amount of money (in USD) that can be spent by this profile before midnight UTC.

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/messaging_profile.rb', line 24

optional :daily_spend_limit, String

#daily_spend_limit_enabledBoolean?

Whether to enforce the value configured by daily_spend_limit.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


30
# File 'lib/telnyx/models/messaging_profile.rb', line 30

optional :daily_spend_limit_enabled, Telnyx::Internal::Type::Boolean

#enabledBoolean?

Specifies whether the messaging profile is enabled or not.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


36
# File 'lib/telnyx/models/messaging_profile.rb', line 36

optional :enabled, Telnyx::Internal::Type::Boolean

#health_webhook_urlString?

DEPRECATED: health check url service checking

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/messaging_profile.rb', line 42

optional :health_webhook_url, String, nil?: true

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


108
109
110
# File 'sig/telnyx/models/messaging_profile.rbs', line 108

def id
  @id
end

#mms_fall_back_to_smsBoolean?

enables SMS fallback for MMS messages.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


48
# File 'lib/telnyx/models/messaging_profile.rb', line 48

optional :mms_fall_back_to_sms, Telnyx::Internal::Type::Boolean

#mms_transcodingBoolean?

enables automated resizing of MMS media.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


54
# File 'lib/telnyx/models/messaging_profile.rb', line 54

optional :mms_transcoding, Telnyx::Internal::Type::Boolean

#mobile_onlyBoolean?

Send messages only to mobile phone numbers.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


60
# File 'lib/telnyx/models/messaging_profile.rb', line 60

optional :mobile_only, Telnyx::Internal::Type::Boolean

#nameString?

A user friendly name for the messaging profile.

Parameters:

  • (String)

Returns:

  • (String, nil)


66
# File 'lib/telnyx/models/messaging_profile.rb', line 66

optional :name, String

#number_pool_settingsTelnyx::Models::NumberPoolSettings?

Number Pool allows you to send messages from a pool of numbers of different types, assigning weights to each type. The pool consists of all the long code and toll free numbers assigned to the messaging profile.

To disable this feature, set the object field to null.

Parameters:

Returns:



76
# File 'lib/telnyx/models/messaging_profile.rb', line 76

optional :number_pool_settings, -> { Telnyx::NumberPoolSettings }, nil?: true

#organization_idString?

The organization that owns this messaging profile.

Parameters:

  • (String)

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/messaging_profile.rb', line 82

optional :organization_id, String

#record_typeTelnyx::Models::MessagingProfile::record_type? (readonly)

Returns the value of attribute record_type.

Returns:

  • (Telnyx::Models::MessagingProfile::record_type, nil)


116
117
118
# File 'sig/telnyx/models/messaging_profile.rbs', line 116

def record_type
  @record_type
end

#redaction_enabledBoolean?

Indicates whether message content redaction is enabled for this profile.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


88
# File 'lib/telnyx/models/messaging_profile.rb', line 88

optional :redaction_enabled, Telnyx::Internal::Type::Boolean

#redaction_levelInteger?

Determines how much information is redacted in messages for privacy or compliance purposes.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


95
# File 'lib/telnyx/models/messaging_profile.rb', line 95

optional :redaction_level, Integer

#resource_group_idString?

The resource group ID associated with this messaging profile.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


101
# File 'lib/telnyx/models/messaging_profile.rb', line 101

optional :resource_group_id, String, nil?: true

#smart_encodingBoolean?

Enables automatic character encoding optimization for SMS messages. When enabled, the system automatically selects the most efficient encoding (GSM-7 or UCS-2) based on message content to maximize character limits and minimize costs.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


109
# File 'lib/telnyx/models/messaging_profile.rb', line 109

optional :smart_encoding, Telnyx::Internal::Type::Boolean

#updated_atTime? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (Time, nil)


122
123
124
# File 'sig/telnyx/models/messaging_profile.rbs', line 122

def updated_at
  @updated_at
end

#url_shortener_settingsTelnyx::Models::URLShortenerSettings?

The URL shortener feature allows automatic replacement of URLs that were generated using a public URL shortener service. Some examples include bit.do, bit.ly, goo.gl, ht.ly, is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com. Such URLs are replaced with with links generated by Telnyx. The use of custom links can improve branding and message deliverability.

To disable this feature, set the object field to null.

Parameters:

Returns:



121
# File 'lib/telnyx/models/messaging_profile.rb', line 121

optional :url_shortener_settings, -> { Telnyx::URLShortenerSettings }, nil?: true

#v1_secretString?

Secret used to authenticate with v1 endpoints.

Parameters:

  • (String)

Returns:

  • (String, nil)


127
# File 'lib/telnyx/models/messaging_profile.rb', line 127

optional :v1_secret, String

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1, v2, or a legacy 2010-04-01 format.



134
# File 'lib/telnyx/models/messaging_profile.rb', line 134

optional :webhook_api_version, enum: -> { Telnyx::MessagingProfile::WebhookAPIVersion }

#webhook_failover_urlString?

The failover URL where webhooks related to this messaging profile will be sent if sending to the primary URL fails.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


141
# File 'lib/telnyx/models/messaging_profile.rb', line 141

optional :webhook_failover_url, String, nil?: true

#webhook_urlString?

The URL where webhooks related to this messaging profile will be sent.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


147
# File 'lib/telnyx/models/messaging_profile.rb', line 147

optional :webhook_url, String, nil?: true

#whitelisted_destinationsArray<String>?

Destinations to which the messaging profile is allowed to send. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ["*"], all destinations will be allowed.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


155
# File 'lib/telnyx/models/messaging_profile.rb', line 155

optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/messaging_profile.rb', line 247

Instance Method Details

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


114
# File 'sig/telnyx/models/messaging_profile.rbs', line 114

def created_at=: (Time) -> Time

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


110
# File 'sig/telnyx/models/messaging_profile.rbs', line 110

def id=: (String) -> String

#record_type=Object (readonly)



118
# File 'sig/telnyx/models/messaging_profile.rbs', line 118

def record_type=: (

#to_hash{

Returns:

  • ({)


155
# File 'sig/telnyx/models/messaging_profile.rbs', line 155

def to_hash: -> {

#updated_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


124
# File 'sig/telnyx/models/messaging_profile.rbs', line 124

def updated_at=: (Time) -> Time