Class: Telnyx::Models::MessagingProfileCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/messaging_profile_create_params.rb

Overview

Defined Under Namespace

Modules: WebhookAPIVersion

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, whitelisted_destinations:, ai_assistant_id: nil, alpha_sender: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, enabled: nil, health_webhook_url: nil, mms_fall_back_to_sms: nil, mms_transcoding: nil, mobile_only: nil, number_pool_settings: nil, resource_group_id: nil, smart_encoding: nil, url_shortener_settings: nil, webhook_api_version: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessagingProfileCreateParams for more details.

Parameters:

  • name (String)

    A user friendly name for the messaging profile.

  • whitelisted_destinations (Array<String>)

    Destinations to which the messaging profile is allowed to send. The elements in

  • ai_assistant_id (String, nil) (defaults to: nil)

    The AI assistant ID to associate with this messaging profile.

  • alpha_sender (String, nil) (defaults to: nil)

    The alphanumeric sender ID to use when sending to destinations that require an a

  • daily_spend_limit (String) (defaults to: nil)

    The maximum amount of money (in USD) that can be spent by this profile before mi

  • daily_spend_limit_enabled (Boolean) (defaults to: nil)

    Whether to enforce the value configured by ‘daily_spend_limit`.

  • enabled (Boolean) (defaults to: nil)

    Specifies whether the messaging profile is enabled or not.

  • health_webhook_url (String, nil) (defaults to: nil)

    A URL to receive health check webhooks for numbers in this profile.

  • mms_fall_back_to_sms (Boolean) (defaults to: nil)

    enables SMS fallback for MMS messages.

  • mms_transcoding (Boolean) (defaults to: nil)

    enables automated resizing of MMS media.

  • mobile_only (Boolean) (defaults to: nil)

    Send messages only to mobile phone numbers.

  • number_pool_settings (Telnyx::Models::NumberPoolSettings, nil) (defaults to: nil)

    Number Pool allows you to send messages from a pool of numbers of different type

  • resource_group_id (String, nil) (defaults to: nil)

    The resource group ID to associate with this messaging profile.

  • smart_encoding (Boolean) (defaults to: nil)

    Enables automatic character encoding optimization for SMS messages. When enabled

  • url_shortener_settings (Telnyx::Models::URLShortenerSettings, nil) (defaults to: nil)

    The URL shortener feature allows automatic replacement of URLs that were generat

  • webhook_api_version (Symbol, Telnyx::Models::MessagingProfileCreateParams::WebhookAPIVersion) (defaults to: nil)

    Determines which webhook format will be used, Telnyx API v1, v2, or a legacy 201

  • webhook_failover_url (String, nil) (defaults to: nil)

    The failover URL where webhooks related to this messaging profile will be sent i

  • webhook_url (String, nil) (defaults to: nil)

    The URL where webhooks related to this messaging profile will be sent.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 136

Instance Attribute Details

#ai_assistant_idString?

The AI assistant ID to associate with this messaging profile.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 28

optional :ai_assistant_id, String, nil?: true

#alpha_senderString?

The alphanumeric sender ID to use when sending to destinations that require an alphanumeric sender ID.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 35

optional :alpha_sender, String, nil?: true

#daily_spend_limitString?

The maximum amount of money (in USD) that can be spent by this profile before midnight UTC.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 42

optional :daily_spend_limit, String

#daily_spend_limit_enabledBoolean?

Whether to enforce the value configured by ‘daily_spend_limit`.

Returns:

  • (Boolean, nil)


48
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 48

optional :daily_spend_limit_enabled, Telnyx::Internal::Type::Boolean

#enabledBoolean?

Specifies whether the messaging profile is enabled or not.

Returns:

  • (Boolean, nil)


54
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 54

optional :enabled, Telnyx::Internal::Type::Boolean

#health_webhook_urlString?

A URL to receive health check webhooks for numbers in this profile.

Returns:

  • (String, nil)


60
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 60

optional :health_webhook_url, String, nil?: true

#mms_fall_back_to_smsBoolean?

enables SMS fallback for MMS messages.

Returns:

  • (Boolean, nil)


66
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 66

optional :mms_fall_back_to_sms, Telnyx::Internal::Type::Boolean

#mms_transcodingBoolean?

enables automated resizing of MMS media.

Returns:

  • (Boolean, nil)


72
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 72

optional :mms_transcoding, Telnyx::Internal::Type::Boolean

#mobile_onlyBoolean?

Send messages only to mobile phone numbers.

Returns:

  • (Boolean, nil)


78
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 78

optional :mobile_only, Telnyx::Internal::Type::Boolean

#nameString

A user friendly name for the messaging profile.

Returns:

  • (String)


14
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 14

required :name, String

#number_pool_settingsTelnyx::Models::NumberPoolSettings?

Number Pool allows you to send messages from a pool of numbers of different types, assigning weights to each type. The pool consists of all the long code and toll free numbers assigned to the messaging profile.

To disable this feature, set the object field to ‘null`.



88
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 88

optional :number_pool_settings, -> { Telnyx::NumberPoolSettings }, nil?: true

#resource_group_idString?

The resource group ID to associate with this messaging profile.

Returns:

  • (String, nil)


94
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 94

optional :resource_group_id, String, nil?: true

#smart_encodingBoolean?

Enables automatic character encoding optimization for SMS messages. When enabled, the system automatically selects the most efficient encoding (GSM-7 or UCS-2) based on message content to maximize character limits and minimize costs.

Returns:

  • (Boolean, nil)


102
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 102

optional :smart_encoding, Telnyx::Internal::Type::Boolean

#url_shortener_settingsTelnyx::Models::URLShortenerSettings?

The URL shortener feature allows automatic replacement of URLs that were generated using a public URL shortener service. Some examples include bit.do, bit.ly, goo.gl, ht.ly, is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com. Such URLs are replaced with with links generated by Telnyx. The use of custom links can improve branding and message deliverability.

To disable this feature, set the object field to ‘null`.



114
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 114

optional :url_shortener_settings, -> { Telnyx::URLShortenerSettings }, nil?: true

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1, v2, or a legacy 2010-04-01 format.



121
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 121

optional :webhook_api_version, enum: -> { Telnyx::MessagingProfileCreateParams::WebhookAPIVersion }

#webhook_failover_urlString?

The failover URL where webhooks related to this messaging profile will be sent if sending to the primary URL fails.

Returns:

  • (String, nil)


128
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 128

optional :webhook_failover_url, String, nil?: true

#webhook_urlString?

The URL where webhooks related to this messaging profile will be sent.

Returns:

  • (String, nil)


134
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 134

optional :webhook_url, String, nil?: true

#whitelisted_destinationsArray<String>

Destinations to which the messaging profile is allowed to send. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ‘[“*”]` all destinations will be allowed.

Returns:

  • (Array<String>)


22
# File 'lib/telnyx/models/messaging_profile_create_params.rb', line 22

required :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String]