Class: Telnyx::Models::MessagingTollfree::Verification::RequestRetrieveStatusHistoryResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MessagingTollfree::Verification::RequestRetrieveStatusHistoryResponse
- Defined in:
- lib/telnyx/models/messaging_tollfree/verification/request_retrieve_status_history_response.rb
Overview
Defined Under Namespace
Classes: Record
Instance Attribute Summary collapse
-
#records ⇒ Array<Telnyx::Models::MessagingTollfree::Verification::RequestRetrieveStatusHistoryResponse::Record>
The records yielded by this request.
-
#total_records ⇒ Integer
The total amount of records for these query parameters.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#records ⇒ Array<Telnyx::Models::MessagingTollfree::Verification::RequestRetrieveStatusHistoryResponse::Record>
The records yielded by this request
13 14 |
# File 'lib/telnyx/models/messaging_tollfree/verification/request_retrieve_status_history_response.rb', line 13 required :records, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::MessagingTollfree::Verification::RequestRetrieveStatusHistoryResponse::Record] } |
#total_records ⇒ Integer
The total amount of records for these query parameters
20 |
# File 'lib/telnyx/models/messaging_tollfree/verification/request_retrieve_status_history_response.rb', line 20 required :total_records, Integer |