Class: Telnyx::Models::MessagingTollfree::Verification::RequestRetrieveStatusHistoryResponse::Record

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/telnyx/models/messaging_tollfree/verification/request_retrieve_status_history_response.rb,
sig/telnyx/models/messaging_tollfree/verification/request_retrieve_status_history_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(updated_at:, verification_status:, reason: nil) ⇒ Object

A single entry in the verification request status history

Parameters:

  • The timestamp at which this status change occurred

  • Tollfree verification status

  • (defaults to: nil)

    An explanation of why this request has its current status.



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/telnyx/models/messaging_tollfree/verification/request_retrieve_status_history_response.rb', line 29

class Record < Telnyx::Internal::Type::BaseModel
  # @!attribute updated_at
  #   The timestamp at which this status change occurred
  #
  #   @return [Time]
  required :updated_at, Time, api_name: :updatedAt

  # @!attribute verification_status
  #   Tollfree verification status
  #
  #   @return [Symbol, Telnyx::Models::MessagingTollfree::Verification::TfVerificationStatus]
  required :verification_status,
           enum: -> { Telnyx::MessagingTollfree::Verification::TfVerificationStatus },
           api_name: :verificationStatus

  # @!attribute reason
  #   An explanation of why this request has its current status.
  #
  #   @return [String, nil]
  optional :reason, String, nil?: true

  # @!method initialize(updated_at:, verification_status:, reason: nil)
  #   A single entry in the verification request status history
  #
  #   @param updated_at [Time] The timestamp at which this status change occurred
  #
  #   @param verification_status [Symbol, Telnyx::Models::MessagingTollfree::Verification::TfVerificationStatus] Tollfree verification status
  #
  #   @param reason [String, nil] An explanation of why this request has its current status.
end

Instance Attribute Details

#reasonString?

An explanation of why this request has its current status.

Parameters:

Returns:



48
# File 'lib/telnyx/models/messaging_tollfree/verification/request_retrieve_status_history_response.rb', line 48

optional :reason, String, nil?: true

#updated_atTime

The timestamp at which this status change occurred

Parameters:

Returns:



34
# File 'lib/telnyx/models/messaging_tollfree/verification/request_retrieve_status_history_response.rb', line 34

required :updated_at, Time, api_name: :updatedAt

#verification_statusSymbol, Telnyx::Models::MessagingTollfree::Verification::TfVerificationStatus

Tollfree verification status

Parameters:

Returns:



40
41
42
# File 'lib/telnyx/models/messaging_tollfree/verification/request_retrieve_status_history_response.rb', line 40

required :verification_status,
enum: -> { Telnyx::MessagingTollfree::Verification::TfVerificationStatus },
api_name: :verificationStatus

Instance Method Details

#to_hash{

Returns:



46
# File 'sig/telnyx/models/messaging_tollfree/verification/request_retrieve_status_history_response.rbs', line 46

def to_hash: -> {