Class: Telnyx::Models::MessagingTollfree::Verification::TfVerificationRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb

Direct Known Subclasses

RequestCreateParams, RequestUpdateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(additional_information:, business_addr1:, business_city:, business_contact_email:, business_contact_first_name:, business_contact_last_name:, business_contact_phone:, business_name:, business_state:, business_zip:, corporate_website:, message_volume:, opt_in_workflow:, opt_in_workflow_image_urls:, phone_numbers:, production_message_content:, use_case:, use_case_summary:, age_gated_content: nil, business_addr2: nil, business_registration_country: nil, business_registration_number: nil, business_registration_type: nil, campaign_verify_authorization_token: nil, doing_business_as: nil, entity_type: nil, help_message_response: nil, isv_reseller: nil, opt_in_confirmation_response: nil, opt_in_keywords: nil, privacy_policy_url: nil, terms_and_condition_url: nil, webhook_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessagingTollfree::Verification::TfVerificationRequest for more details.

The body of a tollfree verification request

Parameters:

  • additional_information (String)

    Any additional information

  • business_addr1 (String)

    Line 1 of the business address

  • business_city (String)

    The city of the business address; the first letter should be capitalized

  • business_contact_email (String)

    The email address of the business contact

  • business_contact_first_name (String)

    First name of the business contact; there are no specific requirements on format

  • business_contact_last_name (String)

    Last name of the business contact; there are no specific requirements on formatt

  • business_contact_phone (String)

    The phone number of the business contact in E.164 format

  • business_name (String)

    Name of the business; there are no specific formatting requirements

  • business_state (String)

    The full name of the state (not the 2 letter code) of the business address; the

  • business_zip (String)

    The ZIP code of the business address

  • corporate_website (String)

    A URL, including the scheme, pointing to the corporate website

  • message_volume (Symbol, Telnyx::Models::MessagingTollfree::Verification::Volume)

    Message Volume Enums

  • opt_in_workflow (String)

    Human-readable description of how end users will opt into receiving messages fro

  • opt_in_workflow_image_urls (Array<Telnyx::Models::MessagingTollfree::Verification::URL>)

    Images showing the opt-in workflow

  • phone_numbers (Array<Telnyx::Models::MessagingTollfree::Verification::TfPhoneNumber>)

    The phone numbers to request the verification of

  • production_message_content (String)

    An example of a message that will be sent from the given phone numbers

  • use_case (Symbol, Telnyx::Models::MessagingTollfree::Verification::UseCaseCategories)

    Tollfree usecase categories

  • use_case_summary (String)

    Human-readable summary of the desired use-case

  • age_gated_content (Boolean) (defaults to: nil)

    Indicates if messaging content requires age gating (e.g., 18+). Defaults to fals

  • business_addr2 (String) (defaults to: nil)

    Line 2 of the business address

  • business_registration_country (String, nil) (defaults to: nil)

    ISO 3166-1 alpha-2 country code of the issuing business authority. Must be exact

  • business_registration_number (String, nil) (defaults to: nil)

    Official business registration number (e.g., Employer Identification Number (EIN

  • business_registration_type (String, nil) (defaults to: nil)

    Type of business registration being provided. Required from January 2026.

  • campaign_verify_authorization_token (String, nil) (defaults to: nil)

    Campaign Verify Authorization Token required for Political use case submissions

  • doing_business_as (String, nil) (defaults to: nil)

    Doing Business As (DBA) name if different from legal name

  • entity_type (Symbol, Telnyx::Models::MessagingTollfree::Verification::TollFreeVerificationEntityType, nil) (defaults to: nil)

    Business entity classification

  • help_message_response (String, nil) (defaults to: nil)

    The message returned when users text ‘HELP’

  • isv_reseller (String, nil) (defaults to: nil)

    ISV name

  • opt_in_confirmation_response (String, nil) (defaults to: nil)

    Message sent to users confirming their opt-in to receive messages

  • opt_in_keywords (String, nil) (defaults to: nil)

    Keywords used to collect and process consumer opt-ins

  • privacy_policy_url (String, nil) (defaults to: nil)

    URL pointing to the business’s privacy policy. Plain string, no URL format valid

  • terms_and_condition_url (String, nil) (defaults to: nil)

    URL pointing to the business’s terms and conditions. Plain string, no URL format

  • webhook_url (String) (defaults to: nil)

    URL that should receive webhooks relating to this verification request



# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 234

Instance Attribute Details

#additional_informationString

Any additional information

Returns:

  • (String)


12
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 12

required :additional_information, String, api_name: :additionalInformation

#age_gated_contentBoolean?

Indicates if messaging content requires age gating (e.g., 18+). Defaults to false if not provided.

Returns:

  • (Boolean, nil)


135
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 135

optional :age_gated_content, Telnyx::Internal::Type::Boolean, api_name: :ageGatedContent

#business_addr1String

Line 1 of the business address

Returns:

  • (String)


18
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 18

required :business_addr1, String, api_name: :businessAddr1

#business_addr2String?

Line 2 of the business address

Returns:

  • (String, nil)


141
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 141

optional :business_addr2, String, api_name: :businessAddr2

#business_cityString

The city of the business address; the first letter should be capitalized

Returns:

  • (String)


24
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 24

required :business_city, String, api_name: :businessCity

#business_contact_emailString

The email address of the business contact

Returns:

  • (String)


30
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 30

required :business_contact_email, String, api_name: :businessContactEmail

#business_contact_first_nameString

First name of the business contact; there are no specific requirements on formatting

Returns:

  • (String)


37
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 37

required :business_contact_first_name, String, api_name: :businessContactFirstName

#business_contact_last_nameString

Last name of the business contact; there are no specific requirements on formatting

Returns:

  • (String)


44
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 44

required :business_contact_last_name, String, api_name: :businessContactLastName

#business_contact_phoneString

The phone number of the business contact in E.164 format

Returns:

  • (String)


50
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 50

required :business_contact_phone, String, api_name: :businessContactPhone

#business_nameString

Name of the business; there are no specific formatting requirements

Returns:

  • (String)


56
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 56

required :business_name, String, api_name: :businessName

#business_registration_countryString?

ISO 3166-1 alpha-2 country code of the issuing business authority. Must be exactly 2 letters. Automatically converted to uppercase. Required from January 2026.

Returns:

  • (String, nil)


149
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 149

optional :business_registration_country, String, api_name: :businessRegistrationCountry, nil?: true

#business_registration_numberString?

Official business registration number (e.g., Employer Identification Number (EIN) in the U.S.). Required from January 2026.

Returns:

  • (String, nil)


156
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 156

optional :business_registration_number, String, api_name: :businessRegistrationNumber, nil?: true

#business_registration_typeString?

Type of business registration being provided. Required from January 2026.

Returns:

  • (String, nil)


162
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 162

optional :business_registration_type, String, api_name: :businessRegistrationType, nil?: true

#business_stateString

The full name of the state (not the 2 letter code) of the business address; the first letter should be capitalized

Returns:

  • (String)


63
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 63

required :business_state, String, api_name: :businessState

#business_zipString

The ZIP code of the business address

Returns:

  • (String)


69
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 69

required :business_zip, String, api_name: :businessZip

#campaign_verify_authorization_tokenString?

Campaign Verify Authorization Token required for Political use case submissions starting February 17, 2026. This token is validated by Zipwhip and must be provided for all Political use case verifications after the deadline.

Returns:

  • (String, nil)


170
171
172
173
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 170

optional :campaign_verify_authorization_token,
String,
api_name: :campaignVerifyAuthorizationToken,
nil?: true

#corporate_websiteString

A URL, including the scheme, pointing to the corporate website

Returns:

  • (String)


75
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 75

required :corporate_website, String, api_name: :corporateWebsite

#doing_business_asString?

Doing Business As (DBA) name if different from legal name

Returns:

  • (String, nil)


179
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 179

optional :doing_business_as, String, api_name: :doingBusinessAs, nil?: true

#entity_typeSymbol, ...

Business entity classification



185
186
187
188
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 185

optional :entity_type,
enum: -> { Telnyx::MessagingTollfree::Verification::TollFreeVerificationEntityType },
api_name: :entityType,
nil?: true

#help_message_responseString?

The message returned when users text ‘HELP’

Returns:

  • (String, nil)


194
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 194

optional :help_message_response, String, api_name: :helpMessageResponse, nil?: true

#isv_resellerString?

ISV name

Returns:

  • (String, nil)


200
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 200

optional :isv_reseller, String, api_name: :isvReseller, nil?: true

#message_volumeSymbol, Telnyx::Models::MessagingTollfree::Verification::Volume

Message Volume Enums



81
82
83
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 81

required :message_volume,
enum: -> { Telnyx::MessagingTollfree::Verification::Volume },
api_name: :messageVolume

#opt_in_confirmation_responseString?

Message sent to users confirming their opt-in to receive messages

Returns:

  • (String, nil)


206
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 206

optional :opt_in_confirmation_response, String, api_name: :optInConfirmationResponse, nil?: true

#opt_in_keywordsString?

Keywords used to collect and process consumer opt-ins

Returns:

  • (String, nil)


212
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 212

optional :opt_in_keywords, String, api_name: :optInKeywords, nil?: true

#opt_in_workflowString

Human-readable description of how end users will opt into receiving messages from the given phone numbers

Returns:

  • (String)


90
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 90

required :opt_in_workflow, String, api_name: :optInWorkflow

#opt_in_workflow_image_urlsArray<Telnyx::Models::MessagingTollfree::Verification::URL>

Images showing the opt-in workflow



96
97
98
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 96

required :opt_in_workflow_image_urls,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::MessagingTollfree::Verification::URL] },
api_name: :optInWorkflowImageURLs

#phone_numbersArray<Telnyx::Models::MessagingTollfree::Verification::TfPhoneNumber>

The phone numbers to request the verification of



104
105
106
107
108
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 104

required :phone_numbers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::MessagingTollfree::Verification::TfPhoneNumber]
},
api_name: :phoneNumbers

#privacy_policy_urlString?

URL pointing to the business’s privacy policy. Plain string, no URL format validation.

Returns:

  • (String, nil)


219
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 219

optional :privacy_policy_url, String, api_name: :privacyPolicyURL, nil?: true

#production_message_contentString

An example of a message that will be sent from the given phone numbers

Returns:

  • (String)


114
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 114

required :production_message_content, String, api_name: :productionMessageContent

#terms_and_condition_urlString?

URL pointing to the business’s terms and conditions. Plain string, no URL format validation.

Returns:

  • (String, nil)


226
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 226

optional :terms_and_condition_url, String, api_name: :termsAndConditionURL, nil?: true

#use_caseSymbol, Telnyx::Models::MessagingTollfree::Verification::UseCaseCategories

Tollfree usecase categories



120
121
122
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 120

required :use_case,
enum: -> { Telnyx::MessagingTollfree::Verification::UseCaseCategories },
api_name: :useCase

#use_case_summaryString

Human-readable summary of the desired use-case

Returns:

  • (String)


128
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 128

required :use_case_summary, String, api_name: :useCaseSummary

#webhook_urlString?

URL that should receive webhooks relating to this verification request

Returns:

  • (String, nil)


232
# File 'lib/telnyx/models/messaging_tollfree/verification/tf_verification_request.rb', line 232

optional :webhook_url, String, api_name: :webhookUrl