Class: Telnyx::Models::MinimaxVoiceSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/minimax_voice_settings.rb

Defined Under Namespace

Modules: LanguageBoost, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, language_boost: nil, pitch: nil, speed: nil, vol: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MinimaxVoiceSettings for more details.

Parameters:

  • type (Symbol, Telnyx::Models::MinimaxVoiceSettings::Type)

    Voice settings provider type

  • language_boost (Symbol, Telnyx::Models::MinimaxVoiceSettings::LanguageBoost, nil) (defaults to: nil)

    Enhances recognition for specific languages and dialects during MiniMax TTS synt

  • pitch (Integer) (defaults to: nil)

    Voice pitch adjustment. Default is 0.

  • speed (Float) (defaults to: nil)

    Speech speed multiplier. Default is 1.0.

  • vol (Float) (defaults to: nil)

    Speech volume multiplier. Default is 1.0.



# File 'lib/telnyx/models/minimax_voice_settings.rb', line 38

Instance Attribute Details

#language_boostSymbol, ...

Enhances recognition for specific languages and dialects during MiniMax TTS synthesis. Default is null (no boost). Set to ‘auto’ for automatic language detection.



18
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 18

optional :language_boost, enum: -> { Telnyx::MinimaxVoiceSettings::LanguageBoost }, nil?: true

#pitchInteger?

Voice pitch adjustment. Default is 0.

Returns:

  • (Integer, nil)


24
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 24

optional :pitch, Integer

#speedFloat?

Speech speed multiplier. Default is 1.0.

Returns:

  • (Float, nil)


30
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 30

optional :speed, Float

#typeSymbol, Telnyx::Models::MinimaxVoiceSettings::Type

Voice settings provider type



10
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 10

required :type, enum: -> { Telnyx::MinimaxVoiceSettings::Type }

#volFloat?

Speech volume multiplier. Default is 1.0.

Returns:

  • (Float, nil)


36
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 36

optional :vol, Float

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/minimax_voice_settings.rb', line 60