Class: Telnyx::Models::MobileNetworkOperatorListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MobileNetworkOperatorListResponse
- Defined in:
- lib/telnyx/models/mobile_network_operator_list_response.rb,
sig/telnyx/models/mobile_network_operator_list_response.rbs
Overview
Instance Attribute Summary collapse
-
#country_code ⇒ String?
The mobile operator two-character (ISO 3166-1 alpha-2) origin country code.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#mcc ⇒ String?
MCC stands for Mobile Country Code.
-
#mnc ⇒ String?
MNC stands for Mobile Network Code.
-
#name ⇒ String?
The network operator name.
-
#network_preferences_enabled ⇒ Boolean?
readonly
Returns the value of attribute network_preferences_enabled.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#tadig ⇒ String?
TADIG stands for Transferred Account Data Interchange Group.
Instance Method Summary collapse
- #id ⇒ String readonly
-
#initialize(id: nil, country_code: nil, mcc: nil, mnc: nil, name: nil, network_preferences_enabled: nil, record_type: nil, tadig: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MobileNetworkOperatorListResponse for more details.
- #network_preferences_enabled ⇒ Boolean readonly
- #record_type ⇒ String readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, country_code: nil, mcc: nil, mnc: nil, name: nil, network_preferences_enabled: nil, record_type: nil, tadig: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::MobileNetworkOperatorListResponse for more details.
|
|
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 65
|
Instance Attribute Details
#country_code ⇒ String?
The mobile operator two-character (ISO 3166-1 alpha-2) origin country code.
11 |
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 11 optional :country_code, String |
#id ⇒ String? (readonly)
Returns the value of attribute id.
36 37 38 |
# File 'sig/telnyx/models/mobile_network_operator_list_response.rbs', line 36 def id @id end |
#mcc ⇒ String?
MCC stands for Mobile Country Code. It's a three decimal digit that identifies a
country.
This code is commonly seen joined with a Mobile Network Code
(MNC) in a tuple that allows identifying a carrier known as PLMN (Public Land
Mobile Network) code.
20 |
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 20 optional :mcc, String |
#mnc ⇒ String?
MNC stands for Mobile Network Code. It's a two to three decimal digits that
identify a network.
This code is commonly seen joined with a Mobile
Country Code (MCC) in a tuple that allows identifying a carrier known as PLMN
(Public Land Mobile Network) code.
29 |
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 29 optional :mnc, String |
#name ⇒ String?
The network operator name.
35 |
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 35 optional :name, String |
#network_preferences_enabled ⇒ Boolean? (readonly)
Returns the value of attribute network_preferences_enabled.
40 41 42 |
# File 'sig/telnyx/models/mobile_network_operator_list_response.rbs', line 40 def network_preferences_enabled @network_preferences_enabled end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
44 45 46 |
# File 'sig/telnyx/models/mobile_network_operator_list_response.rbs', line 44 def record_type @record_type end |
#tadig ⇒ String?
TADIG stands for Transferred Account Data Interchange Group. The TADIG code is a unique identifier for network operators in GSM mobile networks.
42 |
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 42 optional :tadig, String |
Instance Method Details
#id= ⇒ String (readonly)
38 |
# File 'sig/telnyx/models/mobile_network_operator_list_response.rbs', line 38
def id=: (String) -> String
|
#network_preferences_enabled= ⇒ Boolean (readonly)
42 |
# File 'sig/telnyx/models/mobile_network_operator_list_response.rbs', line 42
def network_preferences_enabled=: (bool) -> bool
|
#record_type= ⇒ String (readonly)
46 |
# File 'sig/telnyx/models/mobile_network_operator_list_response.rbs', line 46
def record_type=: (String) -> String
|
#to_hash ⇒ {
59 |
# File 'sig/telnyx/models/mobile_network_operator_list_response.rbs', line 59
def to_hash: -> {
|