Class: Telnyx::Models::MobilePhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/mobile_phone_number.rb,
sig/telnyx/models/mobile_phone_number.rbs

Overview

See Also:

  • Telnyx::Resources::MobilePhoneNumbers#list

Defined Under Namespace

Modules: InboundCallScreening, NoiseSuppression Classes: CallForwarding, CallRecording, CnamListing, Inbound, Outbound

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(interception_app_id: nil, interception_app_name: nil) ⇒ Object

Parameters:

  • interception_app_id (String, nil) (defaults to: nil)

    The ID of the app that will intercept inbound calls.

  • interception_app_name (String, nil) (defaults to: nil)

    The name of the app that will intercept inbound calls.



# File 'lib/telnyx/models/mobile_phone_number.rb', line 140

Instance Attribute Details

#call_forwardingTelnyx::Models::MobilePhoneNumber::CallForwarding?



10
# File 'lib/telnyx/models/mobile_phone_number.rb', line 10

optional :call_forwarding, -> { Telnyx::MobilePhoneNumber::CallForwarding }

#call_recordingTelnyx::Models::MobilePhoneNumber::CallRecording?



15
# File 'lib/telnyx/models/mobile_phone_number.rb', line 15

optional :call_recording, -> { Telnyx::MobilePhoneNumber::CallRecording }

#caller_id_name_enabledBoolean?

Indicates if caller ID name is enabled.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


21
# File 'lib/telnyx/models/mobile_phone_number.rb', line 21

optional :caller_id_name_enabled, Telnyx::Internal::Type::Boolean

#cnam_listingTelnyx::Models::MobilePhoneNumber::CnamListing?



26
# File 'lib/telnyx/models/mobile_phone_number.rb', line 26

optional :cnam_listing, -> { Telnyx::MobilePhoneNumber::CnamListing }

#connection_idString?

The ID of the connection associated with this number.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/mobile_phone_number.rb', line 32

optional :connection_id, String, nil?: true

#connection_nameString?

Returns the value of attribute connection_name.

Returns:

  • (String, nil)


84
85
86
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 84

def connection_name
  @connection_name
end

#connection_typeString?

Returns the value of attribute connection_type.

Returns:

  • (String, nil)


86
87
88
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 86

def connection_type
  @connection_type
end

#country_iso_alpha2String? (readonly)

Returns the value of attribute country_iso_alpha2.

Returns:

  • (String, nil)


88
89
90
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 88

def country_iso_alpha2
  @country_iso_alpha2
end

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


92
93
94
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 92

def created_at
  @created_at
end

#customer_referenceString?

A customer reference string.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/mobile_phone_number.rb', line 38

optional :customer_reference, String, nil?: true

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


80
81
82
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 80

def id
  @id
end

#inboundTelnyx::Models::MobilePhoneNumber::Inbound?



43
# File 'lib/telnyx/models/mobile_phone_number.rb', line 43

optional :inbound, -> { Telnyx::MobilePhoneNumber::Inbound }

#inbound_call_screeningSymbol, ...

The inbound call screening setting.

Parameters:

  • value (Telnyx::Models::MobilePhoneNumber::inbound_call_screening, nil)

Returns:



49
50
51
52
53
# File 'lib/telnyx/models/mobile_phone_number.rb', line 49

optional :inbound_call_screening,
enum: -> {
  Telnyx::MobilePhoneNumber::InboundCallScreening
},
nil?: true

#mobile_voice_enabledBoolean? (readonly)

Returns the value of attribute mobile_voice_enabled.

Returns:

  • (Boolean, nil)


96
97
98
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 96

def mobile_voice_enabled
  @mobile_voice_enabled
end

#noise_suppressionSymbol, ...

The noise suppression setting.



59
# File 'lib/telnyx/models/mobile_phone_number.rb', line 59

optional :noise_suppression, enum: -> { Telnyx::MobilePhoneNumber::NoiseSuppression }

#outboundTelnyx::Models::MobilePhoneNumber::Outbound?



64
# File 'lib/telnyx/models/mobile_phone_number.rb', line 64

optional :outbound, -> { Telnyx::MobilePhoneNumber::Outbound }

#phone_numberString? (readonly)

Returns the value of attribute phone_number.

Returns:

  • (String, nil)


100
101
102
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 100

def phone_number
  @phone_number
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


104
105
106
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 104

def record_type
  @record_type
end

#sim_card_idString? (readonly)

Returns the value of attribute sim_card_id.

Returns:

  • (String, nil)


108
109
110
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 108

def sim_card_id
  @sim_card_id
end

#statusString? (readonly)

Returns the value of attribute status.

Returns:

  • (String, nil)


112
113
114
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 112

def status
  @status
end

#tagsArray<String>?

A list of tags associated with the number.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


70
# File 'lib/telnyx/models/mobile_phone_number.rb', line 70

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#updated_atTime? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (Time, nil)


116
117
118
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 116

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/mobile_phone_number.rb', line 216

Instance Method Details

#country_iso_alpha2=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


90
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 90

def country_iso_alpha2=: (String) -> String

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


94
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 94

def created_at=: (Time) -> Time

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


82
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 82

def id=: (String) -> String

#mobile_voice_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


98
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 98

def mobile_voice_enabled=: (bool) -> bool

#phone_number=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


102
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 102

def phone_number=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


106
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 106

def record_type=: (String) -> String

#sim_card_id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


110
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 110

def sim_card_id=: (String) -> String

#status=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


114
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 114

def status=: (String) -> String

#to_hash{

Returns:

  • ({)


145
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 145

def to_hash: -> {

#updated_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


118
# File 'sig/telnyx/models/mobile_phone_number.rbs', line 118

def updated_at=: (Time) -> Time