Class: Telnyx::Models::MobilePhoneNumber::Outbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/mobile_phone_number.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(interception_app_id: nil, interception_app_name: nil) ⇒ Object

Parameters:

  • interception_app_id (String, nil) (defaults to: nil)

    The ID of the app that will intercept outbound calls.

  • interception_app_name (String, nil) (defaults to: nil)

    The name of the app that will intercept outbound calls.



# File 'lib/telnyx/models/mobile_phone_number.rb', line 352

Instance Attribute Details

#interception_app_idString?

The ID of the app that will intercept outbound calls.

Returns:

  • (String, nil)


342
# File 'lib/telnyx/models/mobile_phone_number.rb', line 342

optional :interception_app_id, String, nil?: true