Class: Telnyx::Models::MobilePhoneNumberUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MobilePhoneNumberUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/mobile_phone_number_update_params.rb
Overview
Defined Under Namespace
Modules: InboundCallScreening Classes: CallForwarding, CallRecording, CnamListing, Inbound, Outbound
Instance Attribute Summary collapse
- #call_forwarding ⇒ Telnyx::Models::MobilePhoneNumberUpdateParams::CallForwarding?
- #call_recording ⇒ Telnyx::Models::MobilePhoneNumberUpdateParams::CallRecording?
- #caller_id_name_enabled ⇒ Boolean?
- #cnam_listing ⇒ Telnyx::Models::MobilePhoneNumberUpdateParams::CnamListing?
- #connection_id ⇒ String?
- #customer_reference ⇒ String?
- #id ⇒ String
- #inbound ⇒ Telnyx::Models::MobilePhoneNumberUpdateParams::Inbound?
- #inbound_call_screening ⇒ Symbol, ...
- #noise_suppression ⇒ Boolean?
- #outbound ⇒ Telnyx::Models::MobilePhoneNumberUpdateParams::Outbound?
- #tags ⇒ Array<String>?
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(interception_app_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Inbound for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(interception_app_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Inbound for more details.
|
|
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 177
|
Instance Attribute Details
#call_forwarding ⇒ Telnyx::Models::MobilePhoneNumberUpdateParams::CallForwarding?
18 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 18 optional :call_forwarding, -> { Telnyx::MobilePhoneNumberUpdateParams::CallForwarding } |
#call_recording ⇒ Telnyx::Models::MobilePhoneNumberUpdateParams::CallRecording?
23 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 23 optional :call_recording, -> { Telnyx::MobilePhoneNumberUpdateParams::CallRecording } |
#caller_id_name_enabled ⇒ Boolean?
28 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 28 optional :caller_id_name_enabled, Telnyx::Internal::Type::Boolean |
#cnam_listing ⇒ Telnyx::Models::MobilePhoneNumberUpdateParams::CnamListing?
33 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 33 optional :cnam_listing, -> { Telnyx::MobilePhoneNumberUpdateParams::CnamListing } |
#connection_id ⇒ String?
38 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 38 optional :connection_id, String, nil?: true |
#customer_reference ⇒ String?
43 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 43 optional :customer_reference, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 13 required :id, String |
#inbound ⇒ Telnyx::Models::MobilePhoneNumberUpdateParams::Inbound?
48 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 48 optional :inbound, -> { Telnyx::MobilePhoneNumberUpdateParams::Inbound } |
#inbound_call_screening ⇒ Symbol, ...
53 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 53 optional :inbound_call_screening, enum: -> { Telnyx::MobilePhoneNumberUpdateParams::InboundCallScreening } |
#noise_suppression ⇒ Boolean?
58 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 58 optional :noise_suppression, Telnyx::Internal::Type::Boolean |
#outbound ⇒ Telnyx::Models::MobilePhoneNumberUpdateParams::Outbound?
63 |
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 63 optional :outbound, -> { Telnyx::MobilePhoneNumberUpdateParams::Outbound } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/mobile_phone_number_update_params.rb', line 115
|