Class: Telnyx::Models::MobilePhoneNumbers::MessagingRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MobilePhoneNumbers::MessagingRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/mobile_phone_numbers/messaging_retrieve_response.rb
Overview
Defined Under Namespace
Modules: RecordType, Type Classes: Features
Instance Attribute Summary collapse
-
#messaging_product ⇒ String?
The messaging product that the number is registered to use.
-
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
-
#organization_id ⇒ String?
The organization that owns this phone number.
-
#tags ⇒ Array<String>?
Tags associated with this phone number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(sms: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Features for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(sms: nil) ⇒ Object
Some parameter documentations has been truncated, see Features for more details.
|
|
# File 'lib/telnyx/models/mobile_phone_numbers/messaging_retrieve_response.rb', line 98
|
Instance Attribute Details
#messaging_product ⇒ String?
The messaging product that the number is registered to use
22 |
# File 'lib/telnyx/models/mobile_phone_numbers/messaging_retrieve_response.rb', line 22 optional :messaging_product, String |
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
28 |
# File 'lib/telnyx/models/mobile_phone_numbers/messaging_retrieve_response.rb', line 28 optional :messaging_profile_id, String, nil?: true |
#organization_id ⇒ String?
The organization that owns this phone number.
34 |
# File 'lib/telnyx/models/mobile_phone_numbers/messaging_retrieve_response.rb', line 34 optional :organization_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/mobile_phone_numbers/messaging_retrieve_response.rb', line 152
|