Class: Telnyx::Models::MobilePhoneNumbers::MessagingRetrieveResponse::Data::Features

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/mobile_phone_numbers/messaging_retrieve_response.rb

Overview

See Also:

  • #features

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#smsTelnyx::Models::MessagingFeatureSet?

The set of features available for a specific messaging use case (SMS or MMS). Features can vary depending on the characteristics the phone number, as well as its current product configuration.



133
# File 'lib/telnyx/models/mobile_phone_numbers/messaging_retrieve_response.rb', line 133

optional :sms, -> { Telnyx::MessagingFeatureSet }, nil?: true