Class: Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb,
sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs

Overview

See Also:

  • Telnyx::Resources::MobilePhoneNumbers::Messaging#list

Defined Under Namespace

Modules: RecordType, Type Classes: Features

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(sms: nil) ⇒ Object

Some parameter documentations has been truncated, see Features for more details.

Parameters:



# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 88

Instance Attribute Details

#country_codeString? (readonly)

Returns the value of attribute country_code.

Returns:

  • (String, nil)


42
43
44
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 42

def country_code
  @country_code
end

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


46
47
48
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 46

def created_at
  @created_at
end

#featuresTelnyx::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::Features? (readonly)

Returns the value of attribute features.

Returns:

  • (Telnyx::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::Features, nil)


50
51
52
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 50

def features
  @features
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


38
39
40
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 38

def id
  @id
end

#messaging_productString?

The messaging product that the number is registered to use

Parameters:

  • (String)

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 12

optional :messaging_product, String

#messaging_profile_idString?

Unique identifier for a messaging profile.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 18

optional :messaging_profile_id, String, nil?: true

#organization_idString?

The organization that owns this phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 24

optional :organization_id, String

#phone_numberString? (readonly)

Returns the value of attribute phone_number.

Returns:

  • (String, nil)


56
57
58
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 56

def phone_number
  @phone_number
end

#record_typeTelnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::record_type? (readonly)

Returns the value of attribute record_type.

Returns:

  • (Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::record_type, nil)


60
61
62
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 60

def record_type
  @record_type
end

#tagsArray<String>?

Tags associated with this phone number.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


30
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 30

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#traffic_typeString? (readonly)

Returns the value of attribute traffic_type.

Returns:

  • (String, nil)


66
67
68
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 66

def traffic_type
  @traffic_type
end

#typeTelnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::type_? (readonly)

Returns the value of attribute type.

Returns:

  • (Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::type_, nil)


70
71
72
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 70

def type
  @type
end

#updated_atTime? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (Time, nil)


76
77
78
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 76

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 142

Instance Method Details

#country_code=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


44
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 44

def country_code=: (String) -> String

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


48
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 48

def created_at=: (Time) -> Time

#features=Object (readonly)



52
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 52

def features=: (

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


40
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 40

def id=: (String) -> String

#phone_number=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


58
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 58

def phone_number=: (String) -> String

#record_type=Object (readonly)



62
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 62

def record_type=: (

#to_hash{

Returns:

  • ({)


96
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 96

def to_hash: -> {

#traffic_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


68
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 68

def traffic_type=: (String) -> String

#type=Object (readonly)



72
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 72

def type=: (

#updated_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


78
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 78

def updated_at=: (Time) -> Time