Class: Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::Features
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::Features
- Defined in:
- lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb,
sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs
Overview
Instance Attribute Summary collapse
-
#sms ⇒ Telnyx::Models::MessagingFeatureSet?
The set of features available for a specific messaging use case (SMS or MMS).
Instance Method Summary collapse
-
#initialize ⇒ Features
constructor
A new instance of Features.
- #to_hash ⇒ { sms: Telnyx::MessagingFeatureSet? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Features
Returns a new instance of Features.
117 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 117
def initialize: (?sms: Telnyx::MessagingFeatureSet?) -> void
|
Instance Attribute Details
#sms ⇒ Telnyx::Models::MessagingFeatureSet?
The set of features available for a specific messaging use case (SMS or MMS). Features can vary depending on the characteristics the phone number, as well as its current product configuration.
123 |
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 123 optional :sms, -> { Telnyx::MessagingFeatureSet }, nil?: true |
Instance Method Details
#to_hash ⇒ { sms: Telnyx::MessagingFeatureSet? }
119 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 119
def to_hash: -> { sms: Telnyx::MessagingFeatureSet? }
|