Class: Telnyx::Models::MobilePushCredentialCreateParams::CreateMobilePushCredentialRequest::Ios
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MobilePushCredentialCreateParams::CreateMobilePushCredentialRequest::Ios
- Defined in:
- lib/telnyx/models/mobile_push_credential_create_params.rb
Instance Attribute Summary collapse
-
#alias_ ⇒ String
Alias to uniquely identify the credential.
-
#certificate ⇒ String
Certificate as received from APNs.
-
#private_key ⇒ String
Corresponding private key to the certificate as received from APNs.
-
#type ⇒ Symbol, :ios
Type of mobile push credential.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#alias_ ⇒ String
Alias to uniquely identify the credential
36 |
# File 'lib/telnyx/models/mobile_push_credential_create_params.rb', line 36 required :alias_, String, api_name: :alias |
#certificate ⇒ String
Certificate as received from APNs
42 |
# File 'lib/telnyx/models/mobile_push_credential_create_params.rb', line 42 required :certificate, String |
#private_key ⇒ String
Corresponding private key to the certificate as received from APNs
48 |
# File 'lib/telnyx/models/mobile_push_credential_create_params.rb', line 48 required :private_key, String |
#type ⇒ Symbol, :ios
Type of mobile push credential. Should be ios here
54 |
# File 'lib/telnyx/models/mobile_push_credential_create_params.rb', line 54 required :type, const: :ios |