Class: Telnyx::Models::NetworkListInterfacesResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/network_list_interfaces_response.rb,
sig/telnyx/models/network_list_interfaces_response.rbs

Overview

See Also:

  • Telnyx::Resources::Networks#list_interfaces

Defined Under Namespace

Classes: Region

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, name: nil, network_id: nil, record_type: nil, region: nil, region_code: nil, status: nil, type: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • region (Telnyx::Models::NetworkListInterfacesResponse::Region) (defaults to: nil)
  • region_code (String) (defaults to: nil)

    The region interface is deployed to.

  • status (Symbol, Telnyx::Models::InterfaceStatus) (defaults to: nil)

    The current status of the interface deployment.

  • type (String) (defaults to: nil)

    Identifies the type of the interface.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/network_list_interfaces_response.rb', line 68

Instance Attribute Details

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


40
41
42
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 40

def created_at
  @created_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


36
37
38
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 36

def id
  @id
end

#nameString?

A user specified name for the interface.

Parameters:

  • (String)

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/network_list_interfaces_response.rb', line 11

optional :name, String

#network_idString?

The id of the network associated with the interface.

Parameters:

  • (String)

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/network_list_interfaces_response.rb', line 17

optional :network_id, String

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


44
45
46
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 44

def record_type
  @record_type
end

#regionTelnyx::Models::NetworkListInterfacesResponse::Region?



22
# File 'lib/telnyx/models/network_list_interfaces_response.rb', line 22

optional :region, -> { Telnyx::Models::NetworkListInterfacesResponse::Region }

#region_codeString?

The region interface is deployed to.

Parameters:

  • (String)

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/network_list_interfaces_response.rb', line 28

optional :region_code, String

#statusTelnyx::Models::interface_status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::interface_status, nil)


48
49
50
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 48

def status
  @status
end

#typeString? (readonly)

Returns the value of attribute type.

Returns:

  • (String, nil)


54
55
56
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 54

def type
  @type
end

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


58
59
60
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 58

def updated_at
  @updated_at
end

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


42
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 42

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


38
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 38

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


46
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 46

def record_type=: (String) -> String

#status=Object (readonly)



50
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 50

def status=: (

#to_hash{

Returns:

  • ({)


75
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 75

def to_hash: -> {

#type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


56
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 56

def type=: (String) -> String

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


60
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 60

def updated_at=: (String) -> String