Class: Telnyx::Models::NotificationEventConditionListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/notification_event_condition_list_response.rb

Overview

Defined Under Namespace

Modules: AssociatedRecordType Classes: Parameter

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, allow_multiple_channels: nil, associated_record_type: nil, asynchronous: nil, created_at: nil, description: nil, enabled: nil, name: nil, notification_event_id: nil, parameters: nil, supported_channels: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::NotificationEventConditionListResponse for more details.

Parameters:

  • id (String) (defaults to: nil)

    A UUID.

  • allow_multiple_channels (Boolean) (defaults to: nil)

    Dictates whether a notification channel id needs to be provided when creating a

  • associated_record_type (Symbol, Telnyx::Models::NotificationEventConditionListResponse::AssociatedRecordType) (defaults to: nil)
  • asynchronous (Boolean) (defaults to: nil)

    Dictates whether a notification setting will take effect immediately.

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • description (String) (defaults to: nil)
  • enabled (Boolean) (defaults to: nil)
  • name (String) (defaults to: nil)
  • notification_event_id (String) (defaults to: nil)
  • parameters (Array<Telnyx::Models::NotificationEventConditionListResponse::Parameter>) (defaults to: nil)
  • supported_channels (Array<String>) (defaults to: nil)

    Dictates the supported notification channel types that can be emitted.

  • updated_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 78

Instance Attribute Details

#allow_multiple_channelsBoolean?

Dictates whether a notification channel id needs to be provided when creating a notficiation setting.

Returns:

  • (Boolean, nil)


12
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 12

optional :allow_multiple_channels, Telnyx::Internal::Type::Boolean

#associated_record_typeSymbol, ...



17
18
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 17

optional :associated_record_type,
enum: -> { Telnyx::Models::NotificationEventConditionListResponse::AssociatedRecordType }

#asynchronousBoolean?

Dictates whether a notification setting will take effect immediately.

Returns:

  • (Boolean, nil)


24
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 24

optional :asynchronous, Telnyx::Internal::Type::Boolean

#created_atTime?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (Time, nil)


30
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 30

optional :created_at, Time

#descriptionString?

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 35

optional :description, String

#enabledBoolean?

Returns:

  • (Boolean, nil)


40
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 40

optional :enabled, Telnyx::Internal::Type::Boolean

#nameString?

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 45

optional :name, String

#notification_event_idString?

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 50

optional :notification_event_id, String

#parametersArray<Telnyx::Models::NotificationEventConditionListResponse::Parameter>?



55
56
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 55

optional :parameters,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::NotificationEventConditionListResponse::Parameter] }

#supported_channelsArray<String>?

Dictates the supported notification channel types that can be emitted.

Returns:

  • (Array<String>, nil)


62
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 62

optional :supported_channels, Telnyx::Internal::Type::ArrayOf[String]

#updated_atTime?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (Time, nil)


68
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 68

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 113