Class: Telnyx::Models::NotificationSettingListParams::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NotificationSettingListParams::Filter
- Defined in:
- lib/telnyx/models/notification_setting_list_params.rb,
sig/telnyx/models/notification_setting_list_params.rbs
Defined Under Namespace
Classes: AssociatedRecordType, ChannelTypeID, NotificationChannel, NotificationEventConditionID, NotificationProfileID, Status
Instance Attribute Summary collapse
- #associated_record_type ⇒ Telnyx::Models::NotificationSettingListParams::Filter::AssociatedRecordType?
- #channel_type_id ⇒ Telnyx::Models::NotificationSettingListParams::Filter::ChannelTypeID?
- #notification_channel ⇒ Telnyx::Models::NotificationSettingListParams::Filter::NotificationChannel?
- #notification_event_condition_id ⇒ Telnyx::Models::NotificationSettingListParams::Filter::NotificationEventConditionID?
- #notification_profile_id ⇒ Telnyx::Models::NotificationSettingListParams::Filter::NotificationProfileID?
- #status ⇒ Telnyx::Models::NotificationSettingListParams::Filter::Status?
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(eq: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(eq: nil) ⇒ Object
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/telnyx/models/notification_setting_list_params.rb', line 42 class Filter < Telnyx::Internal::Type::BaseModel # @!attribute associated_record_type # # @return [Telnyx::Models::NotificationSettingListParams::Filter::AssociatedRecordType, nil] optional :associated_record_type, -> { Telnyx::NotificationSettingListParams::Filter::AssociatedRecordType } # @!attribute channel_type_id # # @return [Telnyx::Models::NotificationSettingListParams::Filter::ChannelTypeID, nil] optional :channel_type_id, -> { Telnyx::NotificationSettingListParams::Filter::ChannelTypeID } # @!attribute notification_channel # # @return [Telnyx::Models::NotificationSettingListParams::Filter::NotificationChannel, nil] optional :notification_channel, -> { Telnyx::NotificationSettingListParams::Filter::NotificationChannel } # @!attribute notification_event_condition_id # # @return [Telnyx::Models::NotificationSettingListParams::Filter::NotificationEventConditionID, nil] optional :notification_event_condition_id, -> { Telnyx::NotificationSettingListParams::Filter::NotificationEventConditionID } # @!attribute notification_profile_id # # @return [Telnyx::Models::NotificationSettingListParams::Filter::NotificationProfileID, nil] optional :notification_profile_id, -> { Telnyx::NotificationSettingListParams::Filter::NotificationProfileID } # @!attribute status # # @return [Telnyx::Models::NotificationSettingListParams::Filter::Status, nil] optional :status, -> { Telnyx::NotificationSettingListParams::Filter::Status } # @!method initialize(associated_record_type: nil, channel_type_id: nil, notification_channel: nil, notification_event_condition_id: nil, notification_profile_id: nil, status: nil) # Consolidated filter parameter (deepObject style). Originally: # filter[associated_record_type][eq], filter[channel_type_id][eq], # filter[notification_profile_id][eq], filter[notification_channel][eq], # filter[notification_event_condition_id][eq], filter[status][eq] # # @param associated_record_type [Telnyx::Models::NotificationSettingListParams::Filter::AssociatedRecordType] # @param channel_type_id [Telnyx::Models::NotificationSettingListParams::Filter::ChannelTypeID] # @param notification_channel [Telnyx::Models::NotificationSettingListParams::Filter::NotificationChannel] # @param notification_event_condition_id [Telnyx::Models::NotificationSettingListParams::Filter::NotificationEventConditionID] # @param notification_profile_id [Telnyx::Models::NotificationSettingListParams::Filter::NotificationProfileID] # @param status [Telnyx::Models::NotificationSettingListParams::Filter::Status] # @see Telnyx::Models::NotificationSettingListParams::Filter#associated_record_type class AssociatedRecordType < Telnyx::Internal::Type::BaseModel # @!attribute eq # Filter by the associated record type # # @return [Symbol, Telnyx::Models::NotificationSettingListParams::Filter::AssociatedRecordType::Eq, nil] optional :eq, enum: -> { Telnyx::NotificationSettingListParams::Filter::AssociatedRecordType::Eq } # @!method initialize(eq: nil) # @param eq [Symbol, Telnyx::Models::NotificationSettingListParams::Filter::AssociatedRecordType::Eq] Filter by the associated record type # Filter by the associated record type # # @see Telnyx::Models::NotificationSettingListParams::Filter::AssociatedRecordType#eq module Eq extend Telnyx::Internal::Type::Enum ACCOUNT = :account PHONE_NUMBER = :phone_number # @!method self.values # @return [Array<Symbol>] end end # @see Telnyx::Models::NotificationSettingListParams::Filter#channel_type_id class ChannelTypeID < Telnyx::Internal::Type::BaseModel # @!attribute eq # Filter by the id of a channel type # # @return [Symbol, Telnyx::Models::NotificationSettingListParams::Filter::ChannelTypeID::Eq, nil] optional :eq, enum: -> { Telnyx::NotificationSettingListParams::Filter::ChannelTypeID::Eq } # @!method initialize(eq: nil) # @param eq [Symbol, Telnyx::Models::NotificationSettingListParams::Filter::ChannelTypeID::Eq] Filter by the id of a channel type # Filter by the id of a channel type # # @see Telnyx::Models::NotificationSettingListParams::Filter::ChannelTypeID#eq module Eq extend Telnyx::Internal::Type::Enum WEBHOOK = :webhook SMS = :sms EMAIL = :email VOICE = :voice # @!method self.values # @return [Array<Symbol>] end end # @see Telnyx::Models::NotificationSettingListParams::Filter#notification_channel class NotificationChannel < Telnyx::Internal::Type::BaseModel # @!attribute eq # Filter by the id of a notification channel # # @return [String, nil] optional :eq, String # @!method initialize(eq: nil) # @param eq [String] Filter by the id of a notification channel end # @see Telnyx::Models::NotificationSettingListParams::Filter#notification_event_condition_id class NotificationEventConditionID < Telnyx::Internal::Type::BaseModel # @!attribute eq # Filter by the id of a notification channel # # @return [String, nil] optional :eq, String # @!method initialize(eq: nil) # @param eq [String] Filter by the id of a notification channel end # @see Telnyx::Models::NotificationSettingListParams::Filter#notification_profile_id class NotificationProfileID < Telnyx::Internal::Type::BaseModel # @!attribute eq # Filter by the id of a notification profile # # @return [String, nil] optional :eq, String # @!method initialize(eq: nil) # @param eq [String] Filter by the id of a notification profile end # @see Telnyx::Models::NotificationSettingListParams::Filter#status class Status < Telnyx::Internal::Type::BaseModel # @!attribute eq # The status of a notification setting # # @return [Symbol, Telnyx::Models::NotificationSettingListParams::Filter::Status::Eq, nil] optional :eq, enum: -> { Telnyx::NotificationSettingListParams::Filter::Status::Eq } # @!method initialize(eq: nil) # @param eq [Symbol, Telnyx::Models::NotificationSettingListParams::Filter::Status::Eq] The status of a notification setting # The status of a notification setting # # @see Telnyx::Models::NotificationSettingListParams::Filter::Status#eq module Eq extend Telnyx::Internal::Type::Enum ENABLED = :enabled ENABLE_RECEIVED = :"enable-received" ENABLE_PENDING = :"enable-pending" ENABLE_SUBMTITED = :"enable-submtited" DELETE_RECEIVED = :"delete-received" DELETE_PENDING = :"delete-pending" DELETE_SUBMITTED = :"delete-submitted" DELETED = :deleted # @!method self.values # @return [Array<Symbol>] end end end |
Instance Attribute Details
#associated_record_type ⇒ Telnyx::Models::NotificationSettingListParams::Filter::AssociatedRecordType?
46 47 |
# File 'lib/telnyx/models/notification_setting_list_params.rb', line 46 optional :associated_record_type, -> { Telnyx::NotificationSettingListParams::Filter::AssociatedRecordType } |
#channel_type_id ⇒ Telnyx::Models::NotificationSettingListParams::Filter::ChannelTypeID?
52 |
# File 'lib/telnyx/models/notification_setting_list_params.rb', line 52 optional :channel_type_id, -> { Telnyx::NotificationSettingListParams::Filter::ChannelTypeID } |
#notification_channel ⇒ Telnyx::Models::NotificationSettingListParams::Filter::NotificationChannel?
57 |
# File 'lib/telnyx/models/notification_setting_list_params.rb', line 57 optional :notification_channel, -> { Telnyx::NotificationSettingListParams::Filter::NotificationChannel } |
#notification_event_condition_id ⇒ Telnyx::Models::NotificationSettingListParams::Filter::NotificationEventConditionID?
62 63 |
# File 'lib/telnyx/models/notification_setting_list_params.rb', line 62 optional :notification_event_condition_id, -> { Telnyx::NotificationSettingListParams::Filter::NotificationEventConditionID } |
#notification_profile_id ⇒ Telnyx::Models::NotificationSettingListParams::Filter::NotificationProfileID?
68 69 |
# File 'lib/telnyx/models/notification_setting_list_params.rb', line 68 optional :notification_profile_id, -> { Telnyx::NotificationSettingListParams::Filter::NotificationProfileID } |
#status ⇒ Telnyx::Models::NotificationSettingListParams::Filter::Status?
74 |
# File 'lib/telnyx/models/notification_setting_list_params.rb', line 74 optional :status, -> { Telnyx::NotificationSettingListParams::Filter::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/notification_setting_list_params.rb', line 109
|
Instance Method Details
#to_hash ⇒ {
99 |
# File 'sig/telnyx/models/notification_setting_list_params.rbs', line 99
def to_hash: -> {
|