Class: Telnyx::Models::NumberBlockOrder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/number_block_order.rb,
sig/telnyx/models/number_block_order.rbs

Overview

See Also:

  • Telnyx::Resources::NumberBlockOrders#list

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers_count: nil, range: nil, record_type: nil, requirements_met: nil, starting_number: nil, status: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::NumberBlockOrder for more details.

Parameters:

  • id (String) (defaults to: nil)
  • connection_id (String) (defaults to: nil)

    Identifies the connection associated to all numbers in the phone number block.

  • created_at (Time) (defaults to: nil)

    An ISO 8901 datetime string denoting when the number order was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • messaging_profile_id (String) (defaults to: nil)

    Identifies the messaging profile associated to all numbers in the phone number b

  • phone_numbers_count (Integer) (defaults to: nil)

    The count of phone numbers in the number order.

  • range (Integer) (defaults to: nil)

    The phone number range included in the block.

  • record_type (String) (defaults to: nil)
  • requirements_met (Boolean) (defaults to: nil)

    True if all requirements are met for every phone number, false otherwise.

  • starting_number (String) (defaults to: nil)

    Starting phone number block

  • status (Symbol, Telnyx::Models::NumberBlockOrder::Status) (defaults to: nil)

    The status of the order.

  • updated_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the number order was updated.



# File 'lib/telnyx/models/number_block_order.rb', line 80

Instance Attribute Details

#connection_idString?

Identifies the connection associated to all numbers in the phone number block.

Parameters:

  • (String)

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/number_block_order.rb', line 11

optional :connection_id, String

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


44
45
46
# File 'sig/telnyx/models/number_block_order.rbs', line 44

def created_at
  @created_at
end

#customer_referenceString?

A customer reference string for customer look ups.

Parameters:

  • (String)

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/number_block_order.rb', line 17

optional :customer_reference, String

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


40
41
42
# File 'sig/telnyx/models/number_block_order.rbs', line 40

def id
  @id
end

#messaging_profile_idString?

Identifies the messaging profile associated to all numbers in the phone number block.

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/number_block_order.rb', line 24

optional :messaging_profile_id, String

#phone_numbers_countInteger? (readonly)

Returns the value of attribute phone_numbers_count.

Returns:

  • (Integer, nil)


48
49
50
# File 'sig/telnyx/models/number_block_order.rbs', line 48

def phone_numbers_count
  @phone_numbers_count
end

#rangeInteger?

The phone number range included in the block.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


30
# File 'lib/telnyx/models/number_block_order.rb', line 30

optional :range, Integer

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


52
53
54
# File 'sig/telnyx/models/number_block_order.rbs', line 52

def record_type
  @record_type
end

#requirements_metBoolean? (readonly)

Returns the value of attribute requirements_met.

Returns:

  • (Boolean, nil)


56
57
58
# File 'sig/telnyx/models/number_block_order.rbs', line 56

def requirements_met
  @requirements_met
end

#starting_numberString?

Starting phone number block

Parameters:

  • (String)

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/number_block_order.rb', line 36

optional :starting_number, String

#statusTelnyx::Models::NumberBlockOrder::status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::NumberBlockOrder::status, nil)


60
61
62
# File 'sig/telnyx/models/number_block_order.rbs', line 60

def status
  @status
end

#updated_atTime? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (Time, nil)


66
67
68
# File 'sig/telnyx/models/number_block_order.rbs', line 66

def updated_at
  @updated_at
end

Instance Method Details

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


46
# File 'sig/telnyx/models/number_block_order.rbs', line 46

def created_at=: (Time) -> Time

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


42
# File 'sig/telnyx/models/number_block_order.rbs', line 42

def id=: (String) -> String

#phone_numbers_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


50
# File 'sig/telnyx/models/number_block_order.rbs', line 50

def phone_numbers_count=: (Integer) -> Integer

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


54
# File 'sig/telnyx/models/number_block_order.rbs', line 54

def record_type=: (String) -> String

#requirements_met=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


58
# File 'sig/telnyx/models/number_block_order.rbs', line 58

def requirements_met=: (bool) -> bool

#status=Object (readonly)



62
# File 'sig/telnyx/models/number_block_order.rbs', line 62

def status=: (

#to_hash{

Returns:

  • ({)


85
# File 'sig/telnyx/models/number_block_order.rbs', line 85

def to_hash: -> {

#updated_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


68
# File 'sig/telnyx/models/number_block_order.rbs', line 68

def updated_at=: (Time) -> Time