Class: Telnyx::Models::NumberBlockOrderCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/number_block_order_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(range:, starting_number:, connection_id: nil, customer_reference: nil, messaging_profile_id: nil, request_options: {}) ⇒ Object

Parameters:

  • range (Integer)

    The phone number range included in the block.

  • starting_number (String)

    Starting phone number block

  • connection_id (String) (defaults to: nil)

    Identifies the connection associated with this phone number.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • messaging_profile_id (String) (defaults to: nil)

    Identifies the messaging profile associated with the phone number.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/number_block_order_create_params.rb', line 40

Instance Attribute Details

#connection_idString?

Identifies the connection associated with this phone number.

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/number_block_order_create_params.rb', line 26

optional :connection_id, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/number_block_order_create_params.rb', line 32

optional :customer_reference, String

#messaging_profile_idString?

Identifies the messaging profile associated with the phone number.

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/number_block_order_create_params.rb', line 38

optional :messaging_profile_id, String

#rangeInteger

The phone number range included in the block.

Returns:

  • (Integer)


14
# File 'lib/telnyx/models/number_block_order_create_params.rb', line 14

required :range, Integer

#starting_numberString

Starting phone number block

Returns:

  • (String)


20
# File 'lib/telnyx/models/number_block_order_create_params.rb', line 20

required :starting_number, String