Class: Telnyx::Models::NumberHealthMetrics

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/number_health_metrics.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(inbound_outbound_ratio:, message_count:, spam_ratio:, success_ratio:) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::NumberHealthMetrics for more details.

High level health metrics about the number and it’s messaging sending patterns.

Parameters:

  • inbound_outbound_ratio (Float)

    The ratio of messages received to the number of messages sent.

  • message_count (Integer)

    The number of messages analyzed for the health metrics.

  • spam_ratio (Float)

    The ratio of messages blocked for spam to the number of messages attempted.

  • success_ratio (Float)

    The ratio of messages sucessfully delivered to the number of messages attempted.



# File 'lib/telnyx/models/number_health_metrics.rb', line 30

Instance Attribute Details

#inbound_outbound_ratioFloat

The ratio of messages received to the number of messages sent.

Returns:

  • (Float)


10
# File 'lib/telnyx/models/number_health_metrics.rb', line 10

required :inbound_outbound_ratio, Float

#message_countInteger

The number of messages analyzed for the health metrics.

Returns:

  • (Integer)


16
# File 'lib/telnyx/models/number_health_metrics.rb', line 16

required :message_count, Integer

#spam_ratioFloat

The ratio of messages blocked for spam to the number of messages attempted.

Returns:

  • (Float)


22
# File 'lib/telnyx/models/number_health_metrics.rb', line 22

required :spam_ratio, Float

#success_ratioFloat

The ratio of messages sucessfully delivered to the number of messages attempted.

Returns:

  • (Float)


28
# File 'lib/telnyx/models/number_health_metrics.rb', line 28

required :success_ratio, Float