Class: Telnyx::Models::NumberLookupRetrieveResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/number_lookup_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Classes: CallerName, Carrier, Portability

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_name: nil, error_code: nil) ⇒ Object

Some parameter documentations has been truncated, see CallerName for more details.

Parameters:

  • caller_name (String) (defaults to: nil)

    The name of the requested phone number’s owner as per the CNAM database

  • error_code (String) (defaults to: nil)

    A caller-name lookup specific error code, expressed as a stringified 5-digit int



# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 63

Instance Attribute Details

#caller_nameTelnyx::Models::NumberLookupRetrieveResponse::Data::CallerName?



20
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 20

optional :caller_name, -> { Telnyx::Models::NumberLookupRetrieveResponse::Data::CallerName }

#carrierTelnyx::Models::NumberLookupRetrieveResponse::Data::Carrier?



25
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 25

optional :carrier, -> { Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier }

#country_codeString?

Region code that matches the specific country calling code

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 31

optional :country_code, String

#fraudString?

Unused

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 37

optional :fraud, String, nil?: true

#national_formatString?

Hyphen-separated national number, preceded by the national destination code (NDC), with a 0 prefix, if an NDC is found

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 44

optional :national_format, String

#phone_numberString?

E164-formatted phone number

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 50

optional :phone_number, String

#portabilityTelnyx::Models::NumberLookupRetrieveResponse::Data::Portability?



55
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 55

optional :portability, -> { Telnyx::Models::NumberLookupRetrieveResponse::Data::Portability }

#record_typeString?

Identifies the type of record

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 61

optional :record_type, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 186