Class: Telnyx::Models::NumberLookupRetrieveResponse::Data::CallerName
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberLookupRetrieveResponse::Data::CallerName
- Defined in:
- lib/telnyx/models/number_lookup_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#caller_name ⇒ String?
The name of the requested phone number’s owner as per the CNAM database.
-
#error_code ⇒ String?
A caller-name lookup specific error code, expressed as a stringified 5-digit integer.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#caller_name ⇒ String?
The name of the requested phone number’s owner as per the CNAM database
89 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 89 optional :caller_name, String |
#error_code ⇒ String?
A caller-name lookup specific error code, expressed as a stringified 5-digit integer
96 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 96 optional :error_code, String |