Class: Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/number_lookup_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(error_code: nil, mobile_country_code: nil, mobile_network_code: nil, name: nil, normalized_carrier: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier for more details.

Parameters:

  • error_code (String, nil) (defaults to: nil)

    Unused

  • mobile_country_code (String) (defaults to: nil)

    Region code that matches the specific country calling code if the requested phon

  • mobile_network_code (String) (defaults to: nil)

    National destination code (NDC), with a 0 prefix, if an NDC is found and the req

  • name (String) (defaults to: nil)

    SPID (Service Provider ID) name, if the requested phone number has been ported;

  • normalized_carrier (String) (defaults to: nil)

    If known to Telnyx and applicable, the primary network carrier.

  • type (Symbol, Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier::Type) (defaults to: nil)

    A phone number type that identifies the type of service associated with the requ



# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 150

Instance Attribute Details

#error_codeString?

Unused

Returns:

  • (String, nil)


114
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 114

optional :error_code, String, nil?: true

#mobile_country_codeString?

Region code that matches the specific country calling code if the requested phone number type is mobile

Returns:

  • (String, nil)


121
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 121

optional :mobile_country_code, String

#mobile_network_codeString?

National destination code (NDC), with a 0 prefix, if an NDC is found and the requested phone number type is mobile

Returns:

  • (String, nil)


128
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 128

optional :mobile_network_code, String

#nameString?

SPID (Service Provider ID) name, if the requested phone number has been ported; otherwise, the name of carrier who owns the phone number block

Returns:

  • (String, nil)


135
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 135

optional :name, String

#normalized_carrierString?

If known to Telnyx and applicable, the primary network carrier.

Returns:

  • (String, nil)


141
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 141

optional :normalized_carrier, String

#typeSymbol, ...

A phone number type that identifies the type of service associated with the requested phone number



148
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 148

optional :type, enum: -> { Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier::Type }