Class: Telnyx::Models::NumberLookupRetrieveResponse::Data::Portability
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberLookupRetrieveResponse::Data::Portability
- Defined in:
- lib/telnyx/models/number_lookup_retrieve_response.rb
Overview
Defined Under Namespace
Modules: PortedStatus
Instance Attribute Summary collapse
-
#altspid ⇒ String?
Alternative SPID (Service Provider ID).
-
#altspid_carrier_name ⇒ String?
Alternative service provider name.
-
#altspid_carrier_type ⇒ String?
Alternative service provider type.
-
#city ⇒ String?
City name extracted from the locality in the Local Exchange Routing Guide (LERG) database.
-
#line_type ⇒ String?
Type of number.
-
#lrn ⇒ String?
Local Routing Number, if assigned to the requested phone number.
-
#ocn ⇒ String?
Operating Company Name (OCN) as per the Local Exchange Routing Guide (LERG) database.
-
#ported_date ⇒ String?
ISO-formatted date when the requested phone number has been ported.
-
#ported_status ⇒ Symbol, ...
Indicates whether or not the requested phone number has been ported.
-
#spid ⇒ String?
SPID (Service Provider ID).
-
#spid_carrier_name ⇒ String?
Service provider name.
-
#spid_carrier_type ⇒ String?
Service provider type.
- #state ⇒ String?
Instance Method Summary collapse
-
#initialize(altspid: nil, altspid_carrier_name: nil, altspid_carrier_type: nil, city: nil, line_type: nil, lrn: nil, ocn: nil, ported_date: nil, ported_status: nil, spid: nil, spid_carrier_name: nil, spid_carrier_type: nil, state: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Portability for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(altspid: nil, altspid_carrier_name: nil, altspid_carrier_type: nil, city: nil, line_type: nil, lrn: nil, ocn: nil, ported_date: nil, ported_status: nil, spid: nil, spid_carrier_name: nil, spid_carrier_type: nil, state: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::NumberLookupRetrieveResponse::Data::Portability for more details.
|
|
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 274
|
Instance Attribute Details
#altspid ⇒ String?
Alternative SPID (Service Provider ID). Often used when a carrier is using a number from another carrier
198 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 198 optional :altspid, String |
#altspid_carrier_name ⇒ String?
Alternative service provider name
204 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 204 optional :altspid_carrier_name, String |
#altspid_carrier_type ⇒ String?
Alternative service provider type
210 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 210 optional :altspid_carrier_type, String |
#city ⇒ String?
City name extracted from the locality in the Local Exchange Routing Guide (LERG) database
217 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 217 optional :city, String |
#line_type ⇒ String?
Type of number
223 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 223 optional :line_type, String |
#lrn ⇒ String?
Local Routing Number, if assigned to the requested phone number
229 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 229 optional :lrn, String |
#ocn ⇒ String?
Operating Company Name (OCN) as per the Local Exchange Routing Guide (LERG) database
236 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 236 optional :ocn, String |
#ported_date ⇒ String?
ISO-formatted date when the requested phone number has been ported
242 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 242 optional :ported_date, String |
#ported_status ⇒ Symbol, ...
Indicates whether or not the requested phone number has been ported
248 249 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 248 optional :ported_status, enum: -> { Telnyx::Models::NumberLookupRetrieveResponse::Data::Portability::PortedStatus } |
#spid ⇒ String?
SPID (Service Provider ID)
255 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 255 optional :spid, String |
#spid_carrier_name ⇒ String?
Service provider name
261 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 261 optional :spid_carrier_name, String |
#spid_carrier_type ⇒ String?
Service provider type
267 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 267 optional :spid_carrier_type, String |
#state ⇒ String?
272 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 272 optional :state, String |