Class: Telnyx::Models::NumberOrderCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/number_order_create_params.rb

Overview

Defined Under Namespace

Classes: PhoneNumber

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#billing_group_idString?

Identifies the billing group associated with the phone number.

Returns:

  • (String, nil)


14
# File 'lib/telnyx/models/number_order_create_params.rb', line 14

optional :billing_group_id, String

#connection_idString?

Identifies the connection associated with this phone number.

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/number_order_create_params.rb', line 20

optional :connection_id, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/number_order_create_params.rb', line 26

optional :customer_reference, String

#messaging_profile_idString?

Identifies the messaging profile associated with the phone number.

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/number_order_create_params.rb', line 32

optional :messaging_profile_id, String

#phone_numbersArray<Telnyx::Models::NumberOrderCreateParams::PhoneNumber>?



37
38
# File 'lib/telnyx/models/number_order_create_params.rb', line 37

optional :phone_numbers,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::NumberOrderCreateParams::PhoneNumber] }