Class: Telnyx::Models::NumberOrderCreateParams::PhoneNumber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberOrderCreateParams::PhoneNumber
- Defined in:
- lib/telnyx/models/number_order_create_params.rb
Instance Attribute Summary collapse
-
#bundle_id ⇒ String?
ID of bundle to associate the number to.
-
#phone_number ⇒ String
e164_phone_number.
-
#requirement_group_id ⇒ String?
ID of requirement group to use to satisfy number requirements.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(phone_number:, bundle_id: nil, requirement_group_id: nil) ⇒ Object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/telnyx/models/number_order_create_params.rb', line 53 class PhoneNumber < Telnyx::Internal::Type::BaseModel # @!attribute phone_number # e164_phone_number # # @return [String] required :phone_number, String # @!attribute bundle_id # ID of bundle to associate the number to # # @return [String, nil] optional :bundle_id, String # @!attribute requirement_group_id # ID of requirement group to use to satisfy number requirements # # @return [String, nil] optional :requirement_group_id, String # @!method initialize(phone_number:, bundle_id: nil, requirement_group_id: nil) # @param phone_number [String] e164_phone_number # # @param bundle_id [String] ID of bundle to associate the number to # # @param requirement_group_id [String] ID of requirement group to use to satisfy number requirements end |
Instance Attribute Details
#bundle_id ⇒ String?
ID of bundle to associate the number to
64 |
# File 'lib/telnyx/models/number_order_create_params.rb', line 64 optional :bundle_id, String |
#phone_number ⇒ String
e164_phone_number
58 |
# File 'lib/telnyx/models/number_order_create_params.rb', line 58 required :phone_number, String |
#requirement_group_id ⇒ String?
ID of requirement group to use to satisfy number requirements
70 |
# File 'lib/telnyx/models/number_order_create_params.rb', line 70 optional :requirement_group_id, String |