Class: Telnyx::Models::NumberOrderListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberOrderListResponse
- Defined in:
- lib/telnyx/models/number_order_list_response.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Identifies the messaging profile associated with the phone number.
-
#connection_id ⇒ String?
Identifies the connection associated with this phone number.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
- #phone_numbers ⇒ Array<Telnyx::Models::PhoneNumbersJobPhoneNumber>?
- #sub_number_orders_ids ⇒ Array<String>?
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, billing_group_id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers: nil, phone_numbers_count: nil, record_type: nil, requirements_met: nil, status: nil, sub_number_orders_ids: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/number_order_list_response.rb', line 83
|
Instance Attribute Details
#billing_group_id ⇒ String?
Identifies the messaging profile associated with the phone number.
11 |
# File 'lib/telnyx/models/number_order_list_response.rb', line 11 optional :billing_group_id, String |
#connection_id ⇒ String?
Identifies the connection associated with this phone number.
17 |
# File 'lib/telnyx/models/number_order_list_response.rb', line 17 optional :connection_id, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
23 |
# File 'lib/telnyx/models/number_order_list_response.rb', line 23 optional :customer_reference, String |
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
29 |
# File 'lib/telnyx/models/number_order_list_response.rb', line 29 optional :messaging_profile_id, String |
#phone_numbers ⇒ Array<Telnyx::Models::PhoneNumbersJobPhoneNumber>?
34 |
# File 'lib/telnyx/models/number_order_list_response.rb', line 34 optional :phone_numbers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PhoneNumbersJobPhoneNumber] } |