Class: Telnyx::Models::NumberOrderListResponse::PhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/number_order_list_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, billing_group_id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers: nil, phone_numbers_count: nil, record_type: nil, requirements_met: nil, status: nil, sub_number_orders_ids: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)
  • billing_group_id (String) (defaults to: nil)

    Identifies the messaging profile associated with the phone number.

  • connection_id (String) (defaults to: nil)

    Identifies the connection associated with this phone number.

  • created_at (Time) (defaults to: nil)

    An ISO 8901 datetime string denoting when the number order was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • messaging_profile_id (String) (defaults to: nil)

    Identifies the messaging profile associated with the phone number.

  • phone_numbers (Array<Telnyx::Models::NumberOrderListResponse::PhoneNumber>) (defaults to: nil)
  • phone_numbers_count (Integer) (defaults to: nil)

    The count of phone numbers in the number order.

  • record_type (String) (defaults to: nil)
  • requirements_met (Boolean) (defaults to: nil)

    True if all requirements are met for every phone number, false otherwise.

  • status (Symbol, Telnyx::Models::NumberOrderListResponse::Status) (defaults to: nil)

    The status of the order.

  • sub_number_orders_ids (Array<String>) (defaults to: nil)
  • updated_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the number order was updated.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/telnyx/models/number_order_list_response.rb', line 111

class PhoneNumber < Telnyx::Internal::Type::BaseModel
  # @!attribute id
  #   The phone number's ID
  #
  #   @return [String, nil]
  optional :id, String

  # @!attribute phone_number
  #   The phone number in e164 format.
  #
  #   @return [String, nil]
  optional :phone_number, String

  # @!method initialize(id: nil, phone_number: nil)
  #   The unique phone numbers given as arguments in the job creation.
  #
  #   @param id [String] The phone number's ID
  #
  #   @param phone_number [String] The phone number in e164 format.
end

Instance Attribute Details

#idString?

The phone number’s ID

Returns:

  • (String, nil)


116
# File 'lib/telnyx/models/number_order_list_response.rb', line 116

optional :id, String

#phone_numberString?

The phone number in e164 format.

Returns:

  • (String, nil)


122
# File 'lib/telnyx/models/number_order_list_response.rb', line 122

optional :phone_number, String