Class: Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data
- Defined in:
- lib/telnyx/models/number_order_status_update_webhook_event.rb,
sig/telnyx/models/number_order_status_update_webhook_event.rbs
Overview
Defined Under Namespace
Classes: Payload
Instance Attribute Summary collapse
-
#event_type ⇒ String
The type of event being sent.
-
#id ⇒ String
Unique identifier for the event.
-
#occurred_at ⇒ Time
ISO 8601 timestamp of when the event occurred.
-
#payload ⇒ Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload
Number order data delivered in a webhook.
-
#record_type ⇒ String
Type of record.
Instance Method Summary collapse
-
#initialize(id:, event_type:, occurred_at:, payload:, record_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, event_type:, occurred_at:, payload:, record_type:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data for more details.
|
|
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 53
|
Instance Attribute Details
#event_type ⇒ String
The type of event being sent
32 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 32 required :event_type, String |
#id ⇒ String
Unique identifier for the event
26 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 26 required :id, String |
#occurred_at ⇒ Time
ISO 8601 timestamp of when the event occurred
38 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 38 required :occurred_at, Time |
#payload ⇒ Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload
Number order data delivered in a webhook. Server-generated fields are valid in this outbound webhook request.
45 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 45 required :payload, -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload } |
#record_type ⇒ String
Type of record
51 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 51 required :record_type, String |
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/telnyx/models/number_order_status_update_webhook_event.rbs', line 52
def to_hash: -> {
|