Class: Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/number_order_status_update_webhook_event.rb,
sig/telnyx/models/number_order_status_update_webhook_event.rbs

Overview

See Also:

  • Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data#payload

Defined Under Namespace

Modules: Status Classes: PhoneNumber

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



134
# File 'sig/telnyx/models/number_order_status_update_webhook_event.rbs', line 134

def initialize: (

Instance Attribute Details

#billing_group_idString?

Identifies the messaging profile associated with the phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 78

optional :billing_group_id, String

#connection_idString?

Identifies the connection associated with this phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


84
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 84

optional :connection_id, String

#created_atTime?

An ISO 8901 datetime string denoting when the number order was created.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


90
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 90

optional :created_at, Time

#customer_referenceString?

A customer reference string for customer look ups.

Parameters:

  • (String)

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 96

optional :customer_reference, String

#idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


72
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 72

optional :id, String

#messaging_profile_idString?

Identifies the messaging profile associated with the phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


102
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 102

optional :messaging_profile_id, String

#phone_numbersArray<Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber>?



107
108
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 107

optional :phone_numbers,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber] }

#phone_numbers_countInteger?

The count of phone numbers in the number order.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


114
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 114

optional :phone_numbers_count, Integer

#record_typeString?

Parameters:

  • (String)

Returns:

  • (String, nil)


119
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 119

optional :record_type, String

#requirements_metBoolean?

True if all requirements are met for every phone number, false otherwise.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


125
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 125

optional :requirements_met, Telnyx::Internal::Type::Boolean

#statusSymbol, ...

The status of the order.



131
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 131

optional :status, enum: -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::Status }

#sub_number_orders_idsArray<String>?

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


136
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 136

optional :sub_number_orders_ids, Telnyx::Internal::Type::ArrayOf[String]

#updated_atTime?

An ISO 8901 datetime string for when the number order was updated.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


142
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 142

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 363

Instance Method Details

#to_hash{

Returns:

  • ({)


150
# File 'sig/telnyx/models/number_order_status_update_webhook_event.rbs', line 150

def to_hash: -> {