Class: Telnyx::Models::NumberOrderWithPhoneNumbers

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/number_order_with_phone_numbers.rb,
sig/telnyx/models/number_order_with_phone_numbers.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, billing_group_id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers: nil, phone_numbers_count: nil, record_type: nil, requirements_met: nil, status: nil, sub_number_orders_ids: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)
  • billing_group_id (String) (defaults to: nil)

    Identifies the messaging profile associated with the phone number.

  • connection_id (String) (defaults to: nil)

    Identifies the connection associated with this phone number.

  • created_at (Time) (defaults to: nil)

    An ISO 8901 datetime string denoting when the number order was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • messaging_profile_id (String) (defaults to: nil)

    Identifies the messaging profile associated with the phone number.

  • phone_numbers (Array<Telnyx::Models::PhoneNumber>) (defaults to: nil)
  • phone_numbers_count (Integer) (defaults to: nil)

    The count of phone numbers in the number order.

  • record_type (String) (defaults to: nil)
  • requirements_met (Boolean) (defaults to: nil)

    True if all requirements are met for every phone number, false otherwise.

  • status (Symbol, Telnyx::Models::NumberOrderWithPhoneNumbers::Status) (defaults to: nil)

    The status of the order.

  • sub_number_orders_ids (Array<String>) (defaults to: nil)
  • updated_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the number order was updated.



# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 82

Instance Attribute Details

#billing_group_idString?

Identifies the messaging profile associated with the phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 10

optional :billing_group_id, String

#connection_idString?

Identifies the connection associated with this phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 16

optional :connection_id, String

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


51
52
53
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 51

def created_at
  @created_at
end

#customer_referenceString?

A customer reference string for customer look ups.

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 22

optional :customer_reference, String

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


47
48
49
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 47

def id
  @id
end

#messaging_profile_idString?

Identifies the messaging profile associated with the phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 28

optional :messaging_profile_id, String

#phone_numbersArray<Telnyx::Models::PhoneNumber>?

Returns:



33
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 33

optional :phone_numbers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PhoneNumber] }

#phone_numbers_countInteger? (readonly)

Returns the value of attribute phone_numbers_count.

Returns:

  • (Integer, nil)


55
56
57
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 55

def phone_numbers_count
  @phone_numbers_count
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


59
60
61
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 59

def record_type
  @record_type
end

#requirements_metBoolean? (readonly)

Returns the value of attribute requirements_met.

Returns:

  • (Boolean, nil)


63
64
65
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 63

def requirements_met
  @requirements_met
end

#statusTelnyx::Models::NumberOrderWithPhoneNumbers::status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::NumberOrderWithPhoneNumbers::status, nil)


67
68
69
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 67

def status
  @status
end

#sub_number_orders_idsArray<String>?

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


38
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 38

optional :sub_number_orders_ids, Telnyx::Internal::Type::ArrayOf[String]

#updated_atTime? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (Time, nil)


73
74
75
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 73

def updated_at
  @updated_at
end

Instance Method Details

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


53
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 53

def created_at=: (Time) -> Time

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


49
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 49

def id=: (String) -> String

#phone_numbers_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


57
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 57

def phone_numbers_count=: (Integer) -> Integer

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


61
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 61

def record_type=: (String) -> String

#requirements_met=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


65
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 65

def requirements_met=: (bool) -> bool

#status=Object (readonly)



69
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 69

def status=: (

#to_hash{

Returns:

  • ({)


93
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 93

def to_hash: -> {

#updated_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


75
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 75

def updated_at=: (Time) -> Time