Class: Telnyx::Models::NumberPoolSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberPoolSettings
- Defined in:
- lib/telnyx/models/number_pool_settings.rb
Instance Attribute Summary collapse
-
#geomatch ⇒ Boolean?
If set to true, Number Pool will try to choose a sending number with the same area code as the destination number.
-
#long_code_weight ⇒ Float
Defines the probability weight for a Long Code number to be selected when sending a message.
-
#skip_unhealthy ⇒ Boolean
If set to true all unhealthy numbers will be automatically excluded from the pool.
-
#sticky_sender ⇒ Boolean?
If set to true, Number Pool will try to choose the same sending number for all messages to a particular recipient.
-
#toll_free_weight ⇒ Float
Defines the probability weight for a Toll Free number to be selected when sending a message.
Instance Method Summary collapse
-
#initialize(long_code_weight:, skip_unhealthy:, toll_free_weight:, geomatch: nil, sticky_sender: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see NumberPoolSettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(long_code_weight:, skip_unhealthy:, toll_free_weight:, geomatch: nil, sticky_sender: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::NumberPoolSettings for more details.
Number Pool allows you to send messages from a pool of numbers of different types, assigning weights to each type. The pool consists of all the long code and toll free numbers assigned to the messaging profile.
To disable this feature, set the object field to ‘null`.
|
|
# File 'lib/telnyx/models/number_pool_settings.rb', line 53
|
Instance Attribute Details
#geomatch ⇒ Boolean?
If set to true, Number Pool will try to choose a sending number with the same area code as the destination number. If there are no such numbers available, a nunber with a different area code will be chosen. Currently only NANP numbers are supported.
43 |
# File 'lib/telnyx/models/number_pool_settings.rb', line 43 optional :geomatch, Telnyx::Internal::Type::Boolean |
#long_code_weight ⇒ Float
Defines the probability weight for a Long Code number to be selected when sending a message. The higher the weight the higher the probability. The sum of the weights for all number types does not necessarily need to add to 100. Weight must be a non-negative number, and when equal to zero it will remove the number type from the pool.
14 |
# File 'lib/telnyx/models/number_pool_settings.rb', line 14 required :long_code_weight, Float |
#skip_unhealthy ⇒ Boolean
If set to true all unhealthy numbers will be automatically excluded from the pool. Health metrics per number are calculated on a regular basis, taking into account the deliverability rate and the amount of messages marked as spam by upstream carriers. Numbers with a deliverability rate below 25% or spam ratio over 75% will be considered unhealthy.
24 |
# File 'lib/telnyx/models/number_pool_settings.rb', line 24 required :skip_unhealthy, Telnyx::Internal::Type::Boolean |
#sticky_sender ⇒ Boolean?
If set to true, Number Pool will try to choose the same sending number for all messages to a particular recipient. If the sending number becomes unhealthy and ‘skip_unhealthy` is set to true, a new number will be chosen.
51 |
# File 'lib/telnyx/models/number_pool_settings.rb', line 51 optional :sticky_sender, Telnyx::Internal::Type::Boolean |
#toll_free_weight ⇒ Float
Defines the probability weight for a Toll Free number to be selected when sending a message. The higher the weight the higher the probability. The sum of the weights for all number types does not necessarily need to add to 100. Weight must be a non-negative number, and when equal to zero it will remove the number type from the pool.
34 |
# File 'lib/telnyx/models/number_pool_settings.rb', line 34 required :toll_free_weight, Float |