Class: Telnyx::Models::NumberReservation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/number_reservation.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, customer_reference: nil, errors: nil, phone_numbers: nil, record_type: nil, status: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)
  • created_at (Time) (defaults to: nil)

    An ISO 8901 datetime string denoting when the numbers reservation was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • errors (String) (defaults to: nil)

    Errors the reservation could happen upon

  • phone_numbers (Array<Telnyx::Models::ReservedPhoneNumber>) (defaults to: nil)
  • record_type (String) (defaults to: nil)
  • status (Symbol, Telnyx::Models::NumberReservation::Status) (defaults to: nil)

    The status of the entire reservation.

  • updated_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the number reservation was updated.



# File 'lib/telnyx/models/number_reservation.rb', line 54

Instance Attribute Details

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/number_reservation.rb', line 11

optional :customer_reference, String

#phone_numbersArray<Telnyx::Models::ReservedPhoneNumber>?

Returns:



16
# File 'lib/telnyx/models/number_reservation.rb', line 16

optional :phone_numbers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::ReservedPhoneNumber] }