Class: Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement
- Defined in:
- lib/telnyx/models/numbers_sub_number_order.rb,
sig/telnyx/models/numbers_sub_number_order.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#field_type ⇒ Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement::field_type?
readonly
Returns the value of attribute field_type.
-
#field_value ⇒ String?
The value of the requirement, this could be an id to a resource or a string value.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#requirement_id ⇒ String?
Unique id for a requirement.
-
#status ⇒ Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement::status?
readonly
Returns the value of attribute status.
Class Method Summary collapse
Instance Method Summary collapse
- #field_type ⇒ Object readonly
-
#initialize(field_type: nil, field_value: nil, record_type: nil, requirement_id: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RegulatoryRequirement for more details.
- #record_type ⇒ String readonly
- #status ⇒ Object readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field_type: nil, field_value: nil, record_type: nil, requirement_id: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement for more details.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/telnyx/models/numbers_sub_number_order.rb', line 208 class RegulatoryRequirement < Telnyx::Internal::Type::BaseModel # @!attribute field_value # The value of the requirement, this could be an id to a resource or a string # value. # # @return [String, nil] optional :field_value, String # @!attribute requirement_id # Unique id for a requirement. # # @return [String, nil] optional :requirement_id, String response_only do # @!attribute field_type # # @return [Symbol, Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement::FieldType, nil] optional :field_type, enum: -> { Telnyx::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement::FieldType } # @!attribute record_type # # @return [String, nil] optional :record_type, String # @!attribute status # The status of the regulatory requirement for this phone number. # # @return [Symbol, Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement::Status, nil] optional :status, enum: -> { Telnyx::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement::Status } end # @!method initialize(field_type: nil, field_value: nil, record_type: nil, requirement_id: nil, status: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement} for # more details. # # @param field_type [Symbol, Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement::FieldType] # # @param field_value [String] The value of the requirement, this could be an id to a resource or a string valu # # @param record_type [String] # # @param requirement_id [String] Unique id for a requirement. # # @param status [Symbol, Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement::Status] The status of the regulatory requirement for this phone number. # @see Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement#field_type module FieldType extend Telnyx::Internal::Type::Enum TEXTUAL = :textual DATETIME = :datetime ADDRESS = :address DOCUMENT = :document # @!method self.values # @return [Array<Symbol>] end # The status of the regulatory requirement for this phone number. # # @see Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement#status module Status extend Telnyx::Internal::Type::Enum APPROVED = :approved DECLINED = :declined AWAITING_VALUE = :"awaiting-value" PENDING_APPROVAL = :"pending-approval" # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#field_type ⇒ Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement::field_type? (readonly)
Returns the value of attribute field_type.
242 243 244 |
# File 'sig/telnyx/models/numbers_sub_number_order.rbs', line 242 def field_type @field_type end |
#field_value ⇒ String?
The value of the requirement, this could be an id to a resource or a string value.
214 |
# File 'lib/telnyx/models/numbers_sub_number_order.rb', line 214 optional :field_value, String |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
248 249 250 |
# File 'sig/telnyx/models/numbers_sub_number_order.rbs', line 248 def record_type @record_type end |
#requirement_id ⇒ String?
Unique id for a requirement.
220 |
# File 'lib/telnyx/models/numbers_sub_number_order.rb', line 220 optional :requirement_id, String |
#status ⇒ Telnyx::Models::NumbersSubNumberOrder::PhoneNumber::RegulatoryRequirement::status? (readonly)
Returns the value of attribute status.
252 253 254 |
# File 'sig/telnyx/models/numbers_sub_number_order.rbs', line 252 def status @status end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/numbers_sub_number_order.rb', line 265
|
Instance Method Details
#field_type= ⇒ Object (readonly)
244 |
# File 'sig/telnyx/models/numbers_sub_number_order.rbs', line 244
def field_type=: (
|
#record_type= ⇒ String (readonly)
250 |
# File 'sig/telnyx/models/numbers_sub_number_order.rbs', line 250
def record_type=: (String) -> String
|
#status= ⇒ Object (readonly)
254 |
# File 'sig/telnyx/models/numbers_sub_number_order.rbs', line 254
def status=: (
|
#to_hash ⇒ {
266 |
# File 'sig/telnyx/models/numbers_sub_number_order.rbs', line 266
def to_hash: -> {
|