Class: Telnyx::Models::Organizations::OrganizationUser

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/organizations/organization_user.rb

Overview

Defined Under Namespace

Modules: UserStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, email: nil, groups: nil, last_sign_in_at: nil, organization_user_bypasses_sso: nil, record_type: nil, user_status: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Organizations::OrganizationUser for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the specific resource.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • email (String) (defaults to: nil)

    The email address of the user.

  • groups (Array<Telnyx::Models::Organizations::UserGroupReference>) (defaults to: nil)

    The groups the user belongs to. Only included when include_groups parameter is t

  • last_sign_in_at (String, nil) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource last signed into the portal

  • organization_user_bypasses_sso (Boolean) (defaults to: nil)

    Indicates whether this user is allowed to bypass SSO and use password authentica

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource. Can be ‘organization_owner’ or ‘organizatio

  • user_status (Symbol, Telnyx::Models::Organizations::OrganizationUser::UserStatus) (defaults to: nil)

    The status of the account.



# File 'lib/telnyx/models/organizations/organization_user.rb', line 60

Instance Attribute Details

#created_atString?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/organizations/organization_user.rb', line 18

optional :created_at, String

#emailString?

The email address of the user.

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/organizations/organization_user.rb', line 24

optional :email, String

#groupsArray<Telnyx::Models::Organizations::UserGroupReference>?

The groups the user belongs to. Only included when include_groups parameter is true.



31
# File 'lib/telnyx/models/organizations/organization_user.rb', line 31

optional :groups, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Organizations::UserGroupReference] }

#idString?

Identifies the specific resource.

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/organizations/organization_user.rb', line 12

optional :id, String

#last_sign_in_atString?

ISO 8601 formatted date indicating when the resource last signed into the portal. Null if the user has never signed in.

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/organizations/organization_user.rb', line 38

optional :last_sign_in_at, String, nil?: true

#organization_user_bypasses_ssoBoolean?

Indicates whether this user is allowed to bypass SSO and use password authentication.

Returns:

  • (Boolean, nil)


45
# File 'lib/telnyx/models/organizations/organization_user.rb', line 45

optional :organization_user_bypasses_sso, Telnyx::Internal::Type::Boolean

#record_typeString?

Identifies the type of the resource. Can be ‘organization_owner’ or ‘organization_sub_user’.

Returns:

  • (String, nil)


52
# File 'lib/telnyx/models/organizations/organization_user.rb', line 52

optional :record_type, String

#user_statusSymbol, ...

The status of the account.



58
# File 'lib/telnyx/models/organizations/organization_user.rb', line 58

optional :user_status, enum: -> { Telnyx::Organizations::OrganizationUser::UserStatus }