Class: Telnyx::Models::Organizations::UserGetGroupsReportResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/organizations/user_get_groups_report_response.rb

Defined Under Namespace

Modules: UserStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, email:, groups:, record_type:, user_status:, last_sign_in_at: nil, organization_user_bypasses_sso: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Organizations::UserGetGroupsReportResponse::Data for more details.

An organization user with their group memberships always included.

Parameters:

  • id (String)

    Identifies the specific resource.

  • created_at (String)

    ISO 8601 formatted date indicating when the resource was created.

  • email (String)

    The email address of the user.

  • groups (Array<Telnyx::Models::Organizations::UserGroupReference>)

    The groups the user belongs to.

  • record_type (String)

    Identifies the type of the resource. Can be ‘organization_owner’ or ‘organizatio

  • user_status (Symbol, Telnyx::Models::Organizations::UserGetGroupsReportResponse::Data::UserStatus)

    The status of the account.

  • last_sign_in_at (String, nil) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource last signed into the portal

  • organization_user_bypasses_sso (Boolean) (defaults to: nil)

    Indicates whether this user is allowed to bypass SSO and use password authentica



17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/telnyx/models/organizations/user_get_groups_report_response.rb', line 17

class Data < Telnyx::Internal::Type::BaseModel
  # @!attribute id
  #   Identifies the specific resource.
  #
  #   @return [String]
  required :id, String

  # @!attribute created_at
  #   ISO 8601 formatted date indicating when the resource was created.
  #
  #   @return [String]
  required :created_at, String

  # @!attribute email
  #   The email address of the user.
  #
  #   @return [String]
  required :email, String

  # @!attribute groups
  #   The groups the user belongs to.
  #
  #   @return [Array<Telnyx::Models::Organizations::UserGroupReference>]
  required :groups, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Organizations::UserGroupReference] }

  # @!attribute record_type
  #   Identifies the type of the resource. Can be 'organization_owner' or
  #   'organization_sub_user'.
  #
  #   @return [String]
  required :record_type, String

  # @!attribute user_status
  #   The status of the account.
  #
  #   @return [Symbol, Telnyx::Models::Organizations::UserGetGroupsReportResponse::Data::UserStatus]
  required :user_status,
           enum: -> { Telnyx::Models::Organizations::UserGetGroupsReportResponse::Data::UserStatus }

  # @!attribute last_sign_in_at
  #   ISO 8601 formatted date indicating when the resource last signed into the
  #   portal. Null if the user has never signed in.
  #
  #   @return [String, nil]
  optional :last_sign_in_at, String, nil?: true

  # @!attribute organization_user_bypasses_sso
  #   Indicates whether this user is allowed to bypass SSO and use password
  #   authentication.
  #
  #   @return [Boolean, nil]
  optional :organization_user_bypasses_sso, Telnyx::Internal::Type::Boolean

  # @!method initialize(id:, created_at:, email:, groups:, record_type:, user_status:, last_sign_in_at: nil, organization_user_bypasses_sso: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::Organizations::UserGetGroupsReportResponse::Data} for more
  #   details.
  #
  #   An organization user with their group memberships always included.
  #
  #   @param id [String] Identifies the specific resource.
  #
  #   @param created_at [String] ISO 8601 formatted date indicating when the resource was created.
  #
  #   @param email [String] The email address of the user.
  #
  #   @param groups [Array<Telnyx::Models::Organizations::UserGroupReference>] The groups the user belongs to.
  #
  #   @param record_type [String] Identifies the type of the resource. Can be 'organization_owner' or 'organizatio
  #
  #   @param user_status [Symbol, Telnyx::Models::Organizations::UserGetGroupsReportResponse::Data::UserStatus] The status of the account.
  #
  #   @param last_sign_in_at [String, nil] ISO 8601 formatted date indicating when the resource last signed into the portal
  #
  #   @param organization_user_bypasses_sso [Boolean] Indicates whether this user is allowed to bypass SSO and use password authentica

  # The status of the account.
  #
  # @see Telnyx::Models::Organizations::UserGetGroupsReportResponse::Data#user_status
  module UserStatus
    extend Telnyx::Internal::Type::Enum

    ENABLED = :enabled
    DISABLED = :disabled
    BLOCKED = :blocked

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#created_atString

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (String)


28
# File 'lib/telnyx/models/organizations/user_get_groups_report_response.rb', line 28

required :created_at, String

#emailString

The email address of the user.

Returns:

  • (String)


34
# File 'lib/telnyx/models/organizations/user_get_groups_report_response.rb', line 34

required :email, String

#groupsArray<Telnyx::Models::Organizations::UserGroupReference>

The groups the user belongs to.



40
# File 'lib/telnyx/models/organizations/user_get_groups_report_response.rb', line 40

required :groups, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Organizations::UserGroupReference] }

#idString

Identifies the specific resource.

Returns:

  • (String)


22
# File 'lib/telnyx/models/organizations/user_get_groups_report_response.rb', line 22

required :id, String

#last_sign_in_atString?

ISO 8601 formatted date indicating when the resource last signed into the portal. Null if the user has never signed in.

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/organizations/user_get_groups_report_response.rb', line 61

optional :last_sign_in_at, String, nil?: true

#organization_user_bypasses_ssoBoolean?

Indicates whether this user is allowed to bypass SSO and use password authentication.

Returns:

  • (Boolean, nil)


68
# File 'lib/telnyx/models/organizations/user_get_groups_report_response.rb', line 68

optional :organization_user_bypasses_sso, Telnyx::Internal::Type::Boolean

#record_typeString

Identifies the type of the resource. Can be ‘organization_owner’ or ‘organization_sub_user’.

Returns:

  • (String)


47
# File 'lib/telnyx/models/organizations/user_get_groups_report_response.rb', line 47

required :record_type, String

#user_statusSymbol, Telnyx::Models::Organizations::UserGetGroupsReportResponse::Data::UserStatus

The status of the account.



53
54
# File 'lib/telnyx/models/organizations/user_get_groups_report_response.rb', line 53

required :user_status,
enum: -> { Telnyx::Models::Organizations::UserGetGroupsReportResponse::Data::UserStatus }