Class: Telnyx::Models::Organizations::UserGroupReference
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Organizations::UserGroupReference
- Defined in:
- lib/telnyx/models/organizations/user_group_reference.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier of the group.
-
#name ⇒ String
The name of the group.
Instance Method Summary collapse
-
#initialize(id:, name:) ⇒ Object
constructor
A reference to a group that a user belongs to.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:) ⇒ Object
A reference to a group that a user belongs to.
|
|
# File 'lib/telnyx/models/organizations/user_group_reference.rb', line 19
|
Instance Attribute Details
#id ⇒ String
The unique identifier of the group.
11 |
# File 'lib/telnyx/models/organizations/user_group_reference.rb', line 11 required :id, String |
#name ⇒ String
The name of the group.
17 |
# File 'lib/telnyx/models/organizations/user_group_reference.rb', line 17 required :name, String |