Class: Telnyx::Models::Organizations::UserRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/organizations/user_retrieve_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, include_groups: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Organizations::UserRetrieveParams for more details.

Parameters:

  • id (String)
  • include_groups (Boolean) (defaults to: nil)

    When set to true, includes the groups array for each user in the response. The g

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/organizations/user_retrieve_params.rb', line 24

Instance Attribute Details

#idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/organizations/user_retrieve_params.rb', line 14

required :id, String

#include_groupsBoolean?

When set to true, includes the groups array for each user in the response. The groups array contains objects with id and name for each group the user belongs to.

Returns:

  • (Boolean, nil)


22
# File 'lib/telnyx/models/organizations/user_retrieve_params.rb', line 22

optional :include_groups, Telnyx::Internal::Type::Boolean