Class: Telnyx::Models::Organizations::UserRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Organizations::UserRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/organizations/user_retrieve_response.rb
Overview
Defined Under Namespace
Modules: UserStatus
Instance Attribute Summary collapse
-
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
-
#email ⇒ String?
The email address of the user.
-
#groups ⇒ Array<Telnyx::Models::Organizations::UserGroupReference>?
The groups the user belongs to.
-
#id ⇒ String?
Identifies the specific resource.
-
#last_sign_in_at ⇒ String?
ISO 8601 formatted date indicating when the resource last signed into the portal.
-
#organization_user_bypasses_sso ⇒ Boolean?
Indicates whether this user is allowed to bypass SSO and use password authentication.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#user_status ⇒ Symbol, ...
The status of the account.
Instance Method Summary collapse
-
#initialize(id: nil, created_at: nil, email: nil, groups: nil, last_sign_in_at: nil, organization_user_bypasses_sso: nil, record_type: nil, user_status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, email: nil, groups: nil, last_sign_in_at: nil, organization_user_bypasses_sso: nil, record_type: nil, user_status: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Organizations::UserRetrieveResponse::Data for more details.
|
|
# File 'lib/telnyx/models/organizations/user_retrieve_response.rb', line 70
|
Instance Attribute Details
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
28 |
# File 'lib/telnyx/models/organizations/user_retrieve_response.rb', line 28 optional :created_at, String |
#email ⇒ String?
The email address of the user.
34 |
# File 'lib/telnyx/models/organizations/user_retrieve_response.rb', line 34 optional :email, String |
#groups ⇒ Array<Telnyx::Models::Organizations::UserGroupReference>?
The groups the user belongs to. Only included when include_groups parameter is true.
41 |
# File 'lib/telnyx/models/organizations/user_retrieve_response.rb', line 41 optional :groups, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Organizations::UserGroupReference] } |
#id ⇒ String?
Identifies the specific resource.
22 |
# File 'lib/telnyx/models/organizations/user_retrieve_response.rb', line 22 optional :id, String |
#last_sign_in_at ⇒ String?
ISO 8601 formatted date indicating when the resource last signed into the portal. Null if the user has never signed in.
48 |
# File 'lib/telnyx/models/organizations/user_retrieve_response.rb', line 48 optional :last_sign_in_at, String, nil?: true |
#organization_user_bypasses_sso ⇒ Boolean?
Indicates whether this user is allowed to bypass SSO and use password authentication.
55 |
# File 'lib/telnyx/models/organizations/user_retrieve_response.rb', line 55 optional :organization_user_bypasses_sso, Telnyx::Internal::Type::Boolean |
#record_type ⇒ String?
Identifies the type of the resource. Can be ‘organization_owner’ or ‘organization_sub_user’.
62 |
# File 'lib/telnyx/models/organizations/user_retrieve_response.rb', line 62 optional :record_type, String |
#user_status ⇒ Symbol, ...
The status of the account.
68 |
# File 'lib/telnyx/models/organizations/user_retrieve_response.rb', line 68 optional :user_status, enum: -> { Telnyx::Models::Organizations::UserRetrieveResponse::Data::UserStatus } |