Class: Telnyx::Models::OtaUpdateListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ota_update_list_response.rb,
sig/telnyx/models/ota_update_list_response.rbs

Overview

See Also:

  • Telnyx::Resources::OtaUpdates#list

Defined Under Namespace

Modules: Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, record_type: nil, sim_card_id: nil, status: nil, type: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::OtaUpdateListResponse for more details.

This object represents an Over the Air (OTA) update request. It allows tracking the current status of a operation that apply settings in a particular SIM card.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • record_type (String) (defaults to: nil)
  • sim_card_id (String) (defaults to: nil)

    The identification UUID of the related SIM card resource.

  • status (Symbol, Telnyx::Models::OtaUpdateListResponse::Status) (defaults to: nil)
  • type (Symbol, Telnyx::Models::OtaUpdateListResponse::Type) (defaults to: nil)

    Represents the type of the operation requested. This will relate directly to the

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/ota_update_list_response.rb', line 50

Instance Attribute Details

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


35
36
37
# File 'sig/telnyx/models/ota_update_list_response.rbs', line 35

def created_at
  @created_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


31
32
33
# File 'sig/telnyx/models/ota_update_list_response.rbs', line 31

def id
  @id
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


39
40
41
# File 'sig/telnyx/models/ota_update_list_response.rbs', line 39

def record_type
  @record_type
end

#sim_card_idString?

The identification UUID of the related SIM card resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/ota_update_list_response.rb', line 11

optional :sim_card_id, String

#statusSymbol, ...



16
# File 'lib/telnyx/models/ota_update_list_response.rb', line 16

optional :status, enum: -> { Telnyx::Models::OtaUpdateListResponse::Status }

#typeSymbol, ...

Represents the type of the operation requested. This will relate directly to the source of the request.



23
# File 'lib/telnyx/models/ota_update_list_response.rb', line 23

optional :type, enum: -> { Telnyx::Models::OtaUpdateListResponse::Type }

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


43
44
45
# File 'sig/telnyx/models/ota_update_list_response.rbs', line 43

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ota_update_list_response.rb', line 80

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


37
# File 'sig/telnyx/models/ota_update_list_response.rbs', line 37

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


33
# File 'sig/telnyx/models/ota_update_list_response.rbs', line 33

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


41
# File 'sig/telnyx/models/ota_update_list_response.rbs', line 41

def record_type=: (String) -> String

#to_hash{

Returns:

  • ({)


57
# File 'sig/telnyx/models/ota_update_list_response.rbs', line 57

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


45
# File 'sig/telnyx/models/ota_update_list_response.rbs', line 45

def updated_at=: (String) -> String