Class: Telnyx::Models::OtaUpdateRetrieveResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ota_update_retrieve_response.rb,
sig/telnyx/models/ota_update_retrieve_response.rbs

Overview

See Also:

  • Telnyx::Models::OtaUpdateRetrieveResponse#data

Defined Under Namespace

Modules: Status, Type Classes: Settings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mobile_network_operator_id: nil, mobile_network_operator_name: nil, priority: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings::MobileNetworkOperatorsPreference for more details.

Parameters:

  • mobile_network_operator_id (String) (defaults to: nil)

    The mobile network operator resource identification UUID.

  • mobile_network_operator_name (String) (defaults to: nil)

    The mobile network operator resource name.

  • priority (Integer) (defaults to: nil)

    It determines what is the priority of a specific network operator that should be



# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 73

Instance Attribute Details

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


58
59
60
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 58

def created_at
  @created_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


54
55
56
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 54

def id
  @id
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


62
63
64
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 62

def record_type
  @record_type
end

#settingsTelnyx::Models::OtaUpdateRetrieveResponse::Data::Settings?

A JSON object representation of the operation. The information present here will relate directly to the source of the OTA request.



28
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 28

optional :settings, -> { Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings }

#sim_card_idString?

The identification UUID of the related SIM card resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 34

optional :sim_card_id, String

#statusSymbol, ...



39
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 39

optional :status, enum: -> { Telnyx::Models::OtaUpdateRetrieveResponse::Data::Status }

#typeSymbol, ...

Represents the type of the operation requested. This will relate directly to the source of the request.



46
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 46

optional :type, enum: -> { Telnyx::Models::OtaUpdateRetrieveResponse::Data::Type }

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


66
67
68
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 66

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 158

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


60
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 60

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


56
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 56

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


64
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 64

def record_type=: (String) -> String

#to_hash{

Returns:

  • ({)


81
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 81

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


68
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 68

def updated_at=: (String) -> String