Class: Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings
- Defined in:
- lib/telnyx/models/ota_update_retrieve_response.rb,
sig/telnyx/models/ota_update_retrieve_response.rbs
Overview
Defined Under Namespace
Classes: MobileNetworkOperatorsPreference
Instance Attribute Summary collapse
-
#mobile_network_operators_preferences ⇒ Array<Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings::MobileNetworkOperatorsPreference>?
A list of mobile network operators and the priority that should be applied when the SIM is connecting to the network.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
104 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 104
def initialize: (
|
Instance Attribute Details
#mobile_network_operators_preferences ⇒ Array<Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings::MobileNetworkOperatorsPreference>?
A list of mobile network operators and the priority that should be applied when the SIM is connecting to the network.
104 105 |
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 104 optional :mobile_network_operators_preferences, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings::MobileNetworkOperatorsPreference] } |
Instance Method Details
#to_hash ⇒ {
108 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 108
def to_hash: -> {
|