Class: Telnyx::Models::OutboundCallRecording

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/outbound_call_recording.rb

Defined Under Namespace

Modules: CallRecordingChannels, CallRecordingFormat, CallRecordingType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_recording_caller_phone_numbers: nil, call_recording_channels: nil, call_recording_format: nil, call_recording_type: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::OutboundCallRecording for more details.

Parameters:



# File 'lib/telnyx/models/outbound_call_recording.rb', line 32

Instance Attribute Details

#call_recording_caller_phone_numbersArray<String>?

When call_recording_type is ‘by_caller_phone_number’, only outbound calls using one of these numbers will be recorded. Numbers must be specified in E164 format.

Returns:

  • (Array<String>, nil)


11
# File 'lib/telnyx/models/outbound_call_recording.rb', line 11

optional :call_recording_caller_phone_numbers, Telnyx::Internal::Type::ArrayOf[String]

#call_recording_channelsSymbol, ...

When using ‘dual’ channels, the final audio file will be a stereo recording with the first leg on channel A, and the rest on channel B.



18
# File 'lib/telnyx/models/outbound_call_recording.rb', line 18

optional :call_recording_channels, enum: -> { Telnyx::OutboundCallRecording::CallRecordingChannels }

#call_recording_formatSymbol, ...

The audio file format for calls being recorded.



24
# File 'lib/telnyx/models/outbound_call_recording.rb', line 24

optional :call_recording_format, enum: -> { Telnyx::OutboundCallRecording::CallRecordingFormat }

#call_recording_typeSymbol, ...

Specifies which calls are recorded.



30
# File 'lib/telnyx/models/outbound_call_recording.rb', line 30

optional :call_recording_type, enum: -> { Telnyx::OutboundCallRecording::CallRecordingType }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/outbound_call_recording.rb', line 54