Module: Telnyx::Models::OutboundCallRecording::CallRecordingChannels

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/outbound_call_recording.rb,
sig/telnyx/models/outbound_call_recording.rbs

Overview

When using 'dual' channels, the final audio file will be a stereo recording with the first leg on channel A, and the rest on channel B.

See Also:

  • Telnyx::Models::OutboundCallRecording#call_recording_channels

Constant Summary collapse

SINGLE =

Returns:

  • (:single)
:single
DUAL =

Returns:

  • (:dual)
:dual

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Telnyx::Models::OutboundCallRecording::call_recording_channels]

Returns:

  • (::Array[Telnyx::Models::OutboundCallRecording::call_recording_channels])


58
# File 'sig/telnyx/models/outbound_call_recording.rbs', line 58

def self?.values: -> ::Array[Telnyx::Models::OutboundCallRecording::call_recording_channels]