Module: Telnyx::Models::OutboundFqdn::T38ReinviteSource

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/outbound_fqdn.rb,
sig/telnyx/models/outbound_fqdn.rbs

Overview

This setting only affects connections with Fax-type Outbound Voice Profiles. The setting dictates whether or not Telnyx sends a t.38 reinvite. By default, Telnyx will send the re-invite. If set to customer, the caller is expected to send the t.38 reinvite.

See Also:

  • Telnyx::Models::OutboundFqdn#t38_reinvite_source

Constant Summary collapse

TELNYX =

Returns:

  • (:telnyx)
:telnyx
CUSTOMER =

Returns:

  • (:customer)
:customer
DISABLED =

Returns:

  • (:disabled)
:disabled
PASSTHRU =

Returns:

  • (:passthru)
:passthru
CALLER_PASSTHRU =

Returns:

  • (:"caller-passthru")
:"caller-passthru"
CALLEE_PASSTHRU =

Returns:

  • (:"callee-passthru")
:"callee-passthru"

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/outbound_fqdn.rb', line 184

Instance Method Details

#self?.values::Array[Telnyx::Models::OutboundFqdn::t38_reinvite_source]

Returns:

  • (::Array[Telnyx::Models::OutboundFqdn::t38_reinvite_source])


163
# File 'sig/telnyx/models/outbound_fqdn.rbs', line 163

def self?.values: -> ::Array[Telnyx::Models::OutboundFqdn::t38_reinvite_source]