Class: Telnyx::Models::OutboundMessagePayload::Media
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::OutboundMessagePayload::Media
- Defined in:
- lib/telnyx/models/outbound_message_payload.rb,
sig/telnyx/models/outbound_message_payload.rbs
Instance Attribute Summary collapse
-
#content_type ⇒ String?
The MIME type of the requested media.
-
#sha256 ⇒ String?
The SHA256 hash of the requested media.
-
#size ⇒ Integer?
The size of the requested media.
-
#url ⇒ String?
The url of the media requested to be sent.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
459 |
# File 'sig/telnyx/models/outbound_message_payload.rbs', line 459
def initialize: (
|
Instance Attribute Details
#content_type ⇒ String?
The MIME type of the requested media.
470 |
# File 'lib/telnyx/models/outbound_message_payload.rb', line 470 optional :content_type, String, nil?: true |
#sha256 ⇒ String?
The SHA256 hash of the requested media.
476 |
# File 'lib/telnyx/models/outbound_message_payload.rb', line 476 optional :sha256, String, nil?: true |
#size ⇒ Integer?
The size of the requested media.
482 |
# File 'lib/telnyx/models/outbound_message_payload.rb', line 482 optional :size, Integer, nil?: true |
#url ⇒ String?
The url of the media requested to be sent.
488 |
# File 'lib/telnyx/models/outbound_message_payload.rb', line 488 optional :url, String |
Instance Method Details
#to_hash ⇒ {
466 |
# File 'sig/telnyx/models/outbound_message_payload.rbs', line 466
def to_hash: -> {
|