Class: Telnyx::Models::OutboundVoiceProfile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/outbound_voice_profile.rb

Overview

Defined Under Namespace

Classes: CallingWindow

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, id: nil, billing_group_id: nil, call_recording: nil, calling_window: nil, concurrent_call_limit: nil, connections_count: nil, created_at: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, enabled: nil, max_destination_rate: nil, record_type: nil, service_plan: nil, tags: nil, traffic_type: nil, updated_at: nil, usage_payment_method: nil, whitelisted_destinations: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::OutboundVoiceProfile for more details.

Parameters:

  • name (String)

    A user-supplied name to help with organization.

  • id (String) (defaults to: nil)

    Identifies the resource.

  • billing_group_id (String, nil) (defaults to: nil)

    The ID of the billing group associated with the outbound proflile. Defaults to n

  • call_recording (Telnyx::Models::OutboundCallRecording) (defaults to: nil)
  • calling_window (Telnyx::Models::OutboundVoiceProfile::CallingWindow) (defaults to: nil)

    (BETA) Specifies the time window and call limits for calls made using this outbo

  • concurrent_call_limit (Integer, nil) (defaults to: nil)

    Must be no more than your global concurrent call limit. Null means no limit.

  • connections_count (Integer) (defaults to: nil)

    Amount of connections associated with this outbound voice profile.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • daily_spend_limit (String) (defaults to: nil)

    The maximum amount of usage charges, in USD, you want Telnyx to allow on this ou

  • daily_spend_limit_enabled (Boolean) (defaults to: nil)

    Specifies whether to enforce the daily_spend_limit on this outbound voice profil

  • enabled (Boolean) (defaults to: nil)

    Specifies whether the outbound voice profile can be used. Disabled profiles will

  • max_destination_rate (Float) (defaults to: nil)

    Maximum rate (price per minute) for a Destination to be allowed when making outb

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • service_plan (Symbol, Telnyx::Models::ServicePlan) (defaults to: nil)

    Indicates the coverage of the termination regions.

  • tags (Array<String>) (defaults to: nil)
  • traffic_type (Symbol, Telnyx::Models::TrafficType) (defaults to: nil)

    Specifies the type of traffic allowed in this profile.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.

  • usage_payment_method (Symbol, Telnyx::Models::UsagePaymentMethod) (defaults to: nil)

    Setting for how costs for outbound profile are calculated.

  • whitelisted_destinations (Array<String>) (defaults to: nil)

    The list of destinations you want to be able to call using this outbound voice p



# File 'lib/telnyx/models/outbound_voice_profile.rb', line 126

Instance Attribute Details

#billing_group_idString?

The ID of the billing group associated with the outbound proflile. Defaults to null (for no group assigned).

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 24

optional :billing_group_id, String, nil?: true

#call_recordingTelnyx::Models::OutboundCallRecording?



29
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 29

optional :call_recording, -> { Telnyx::OutboundCallRecording }

#calling_windowTelnyx::Models::OutboundVoiceProfile::CallingWindow?

(BETA) Specifies the time window and call limits for calls made using this outbound voice profile. Note that all times are UTC in 24-hour clock time.



36
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 36

optional :calling_window, -> { Telnyx::OutboundVoiceProfile::CallingWindow }

#concurrent_call_limitInteger?

Must be no more than your global concurrent call limit. Null means no limit.

Returns:

  • (Integer, nil)


42
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 42

optional :concurrent_call_limit, Integer, nil?: true

#connections_countInteger?

Amount of connections associated with this outbound voice profile.

Returns:

  • (Integer, nil)


48
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 48

optional :connections_count, Integer

#created_atString?

ISO 8601 formatted date-time indicating when the resource was created.

Returns:

  • (String, nil)


54
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 54

optional :created_at, String

#daily_spend_limitString?

The maximum amount of usage charges, in USD, you want Telnyx to allow on this outbound voice profile in a day before disallowing new calls.

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 61

optional :daily_spend_limit, String

#daily_spend_limit_enabledBoolean?

Specifies whether to enforce the daily_spend_limit on this outbound voice profile.

Returns:

  • (Boolean, nil)


68
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 68

optional :daily_spend_limit_enabled, Telnyx::Internal::Type::Boolean

#enabledBoolean?

Specifies whether the outbound voice profile can be used. Disabled profiles will result in outbound calls being blocked for the associated Connections.

Returns:

  • (Boolean, nil)


75
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 75

optional :enabled, Telnyx::Internal::Type::Boolean

#idString?

Identifies the resource.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 17

optional :id, String

#max_destination_rateFloat?

Maximum rate (price per minute) for a Destination to be allowed when making outbound calls.

Returns:

  • (Float, nil)


82
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 82

optional :max_destination_rate, Float

#nameString

A user-supplied name to help with organization.

Returns:

  • (String)


11
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 11

required :name, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 88

optional :record_type, String

#service_planSymbol, ...

Indicates the coverage of the termination regions.

Returns:



94
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 94

optional :service_plan, enum: -> { Telnyx::ServicePlan }

#tagsArray<String>?

Returns:

  • (Array<String>, nil)


99
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 99

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#traffic_typeSymbol, ...

Specifies the type of traffic allowed in this profile.

Returns:



105
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 105

optional :traffic_type, enum: -> { Telnyx::TrafficType }

#updated_atString?

ISO 8601 formatted date-time indicating when the resource was updated.

Returns:

  • (String, nil)


111
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 111

optional :updated_at, String

#usage_payment_methodSymbol, ...

Setting for how costs for outbound profile are calculated.

Returns:



117
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 117

optional :usage_payment_method, enum: -> { Telnyx::UsagePaymentMethod }

#whitelisted_destinationsArray<String>?

The list of destinations you want to be able to call using this outbound voice profile formatted in alpha2.

Returns:

  • (Array<String>, nil)


124
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 124

optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String]