Class: Telnyx::Models::OutboundVoiceProfile::CallingWindow

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/outbound_voice_profile.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(calls_per_cld: nil, end_time: nil, start_time: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::OutboundVoiceProfile::CallingWindow for more details.

(BETA) Specifies the time window and call limits for calls made using this outbound voice profile. Note that all times are UTC in 24-hour clock time.

Parameters:

  • calls_per_cld (Integer) (defaults to: nil)

    (BETA) The maximum number of calls that can be initiated to a single called part

  • end_time (String) (defaults to: nil)

    (BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are no lo

  • start_time (String) (defaults to: nil)

    (BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are allow



# File 'lib/telnyx/models/outbound_voice_profile.rb', line 191

Instance Attribute Details

#calls_per_cldInteger?

(BETA) The maximum number of calls that can be initiated to a single called party (CLD) within the calling window. A null value means no limit.

Returns:

  • (Integer, nil)


175
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 175

optional :calls_per_cld, Integer

#end_timeString?

(BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are no longer allowed to start.

Returns:

  • (String, nil)


182
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 182

optional :end_time, String

#start_timeString?

(BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are allowed to start.

Returns:

  • (String, nil)


189
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 189

optional :start_time, String