Class: Telnyx::Models::OutboundVoiceProfileCreateParams::CallingWindow

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/outbound_voice_profile_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(calls_per_cld: nil, end_time: nil, start_time: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::OutboundVoiceProfileCreateParams::CallingWindow for more details.

(BETA) Specifies the time window and call limits for calls made using this outbound voice profile. Note that all times are UTC in 24-hour clock time.

Parameters:

  • calls_per_cld (Integer) (defaults to: nil)

    (BETA) The maximum number of calls that can be initiated to a single called part

  • end_time (Time) (defaults to: nil)

    (BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are no lo

  • start_time (Time) (defaults to: nil)

    (BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are allow



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 133

class CallingWindow < Telnyx::Internal::Type::BaseModel
  # @!attribute calls_per_cld
  #   (BETA) The maximum number of calls that can be initiated to a single called
  #   party (CLD) within the calling window. A null value means no limit.
  #
  #   @return [Integer, nil]
  optional :calls_per_cld, Integer

  # @!attribute end_time
  #   (BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are no
  #   longer allowed to start.
  #
  #   @return [Time, nil]
  optional :end_time, Time

  # @!attribute start_time
  #   (BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are
  #   allowed to start.
  #
  #   @return [Time, nil]
  optional :start_time, Time

  # @!method initialize(calls_per_cld: nil, end_time: nil, start_time: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::OutboundVoiceProfileCreateParams::CallingWindow} for more
  #   details.
  #
  #   (BETA) Specifies the time window and call limits for calls made using this
  #   outbound voice profile. Note that all times are UTC in 24-hour clock time.
  #
  #   @param calls_per_cld [Integer] (BETA) The maximum number of calls that can be initiated to a single called part
  #
  #   @param end_time [Time] (BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are no lo
  #
  #   @param start_time [Time] (BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are allow
end

Instance Attribute Details

#calls_per_cldInteger?

(BETA) The maximum number of calls that can be initiated to a single called party (CLD) within the calling window. A null value means no limit.

Returns:

  • (Integer, nil)


139
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 139

optional :calls_per_cld, Integer

#end_timeTime?

(BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are no longer allowed to start.

Returns:

  • (Time, nil)


146
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 146

optional :end_time, Time

#start_timeTime?

(BETA) The UTC time of day (in HH:MM format, 24-hour clock) when calls are allowed to start.

Returns:

  • (Time, nil)


153
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 153

optional :start_time, Time