Module: Telnyx::Models::OutboundVoiceProfileListParams::Sort

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/outbound_voice_profile_list_params.rb,
sig/telnyx/models/outbound_voice_profile_list_params.rbs

Overview

Specifies the sort order for results. By default sorting direction is ascending. To have the results sorted in descending order add the - prefix.

That is:

  • name: sorts the result by the name field in ascending order.
  • -name: sorts the result by the name field in descending order.

Constant Summary collapse

ENABLED =

Returns:

  • (:enabled)
:enabled
ENABLED_DESC =

Returns:

  • (:"-enabled")
:"-enabled"
CREATED_AT =

Returns:

  • (:created_at)
:created_at
CREATED_AT_DESC =

Returns:

  • (:"-created_at")
:"-created_at"
NAME =

Returns:

  • (:name)
:name
NAME_DESC =

Returns:

  • (:"-name")
:"-name"
SERVICE_PLAN =

Returns:

  • (:service_plan)
:service_plan
SERVICE_PLAN_DESC =

Returns:

  • (:"-service_plan")
:"-service_plan"
TRAFFIC_TYPE =

Returns:

  • (:traffic_type)
:traffic_type
TRAFFIC_TYPE_DESC =

Returns:

  • (:"-traffic_type")
:"-traffic_type"
USAGE_PAYMENT_METHOD =

Returns:

  • (:usage_payment_method)
:usage_payment_method
USAGE_PAYMENT_METHOD_DESC =

Returns:

  • (:"-usage_payment_method")
:"-usage_payment_method"

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/outbound_voice_profile_list_params.rb', line 118

Instance Method Details

#self?.values::Array[Telnyx::Models::OutboundVoiceProfileListParams::sort]

Returns:

  • (::Array[Telnyx::Models::OutboundVoiceProfileListParams::sort])


113
# File 'sig/telnyx/models/outbound_voice_profile_list_params.rbs', line 113

def self?.values: -> ::Array[Telnyx::Models::OutboundVoiceProfileListParams::sort]