Class: Telnyx::Models::OutboundVoiceProfileUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/outbound_voice_profile_update_params.rb

Overview

Defined Under Namespace

Classes: CallingWindow

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#billing_group_idString?

The ID of the billing group associated with the outbound proflile. Defaults to null (for no group assigned).

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 26

optional :billing_group_id, String, nil?: true

#call_recordingTelnyx::Models::OutboundCallRecording?



31
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 31

optional :call_recording, -> { Telnyx::OutboundCallRecording }

#calling_windowTelnyx::Models::OutboundVoiceProfileUpdateParams::CallingWindow?

(BETA) Specifies the time window and call limits for calls made using this outbound voice profile.



38
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 38

optional :calling_window, -> { Telnyx::OutboundVoiceProfileUpdateParams::CallingWindow }

#concurrent_call_limitInteger?

Must be no more than your global concurrent call limit. Null means no limit.

Returns:

  • (Integer, nil)


44
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 44

optional :concurrent_call_limit, Integer, nil?: true

#daily_spend_limitString?

The maximum amount of usage charges, in USD, you want Telnyx to allow on this outbound voice profile in a day before disallowing new calls.

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 51

optional :daily_spend_limit, String

#daily_spend_limit_enabledBoolean?

Specifies whether to enforce the daily_spend_limit on this outbound voice profile.

Returns:

  • (Boolean, nil)


58
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 58

optional :daily_spend_limit_enabled, Telnyx::Internal::Type::Boolean

#enabledBoolean?

Specifies whether the outbound voice profile can be used. Disabled profiles will result in outbound calls being blocked for the associated Connections.

Returns:

  • (Boolean, nil)


65
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 65

optional :enabled, Telnyx::Internal::Type::Boolean

#idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 13

required :id, String

#max_destination_rateFloat?

Maximum rate (price per minute) for a Destination to be allowed when making outbound calls.

Returns:

  • (Float, nil)


72
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 72

optional :max_destination_rate, Float

#nameString

A user-supplied name to help with organization.

Returns:

  • (String)


19
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 19

required :name, String

#service_planSymbol, ...

Indicates the coverage of the termination regions.

Returns:



78
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 78

optional :service_plan, enum: -> { Telnyx::ServicePlan }

#tagsArray<String>?

Returns:

  • (Array<String>, nil)


83
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 83

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#traffic_typeSymbol, ...

Specifies the type of traffic allowed in this profile.

Returns:



89
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 89

optional :traffic_type, enum: -> { Telnyx::TrafficType }

#usage_payment_methodSymbol, ...

Setting for how costs for outbound profile are calculated.

Returns:



95
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 95

optional :usage_payment_method, enum: -> { Telnyx::UsagePaymentMethod }

#whitelisted_destinationsArray<String>?

The list of destinations you want to be able to call using this outbound voice profile formatted in alpha2.

Returns:

  • (Array<String>, nil)


102
# File 'lib/telnyx/models/outbound_voice_profile_update_params.rb', line 102

optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String]