Class: Telnyx::Models::Payment::AutoRechargePref

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/payment/auto_recharge_pref.rb

Defined Under Namespace

Modules: Preference

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, enabled: nil, invoice_enabled: nil, preference: nil, recharge_amount: nil, record_type: nil, threshold_amount: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Payment::AutoRechargePref for more details.

Parameters:

  • id (String) (defaults to: nil)

    The unique identifier for the auto recharge preference.

  • enabled (Boolean) (defaults to: nil)

    Whether auto recharge is enabled.

  • invoice_enabled (Boolean) (defaults to: nil)
  • preference (Symbol, Telnyx::Models::Payment::AutoRechargePref::Preference) (defaults to: nil)

    The payment preference for auto recharge.

  • recharge_amount (String) (defaults to: nil)

    The amount to recharge the account, the actual recharge amount will be the amoun

  • record_type (String) (defaults to: nil)

    The record type.

  • threshold_amount (String) (defaults to: nil)

    The threshold amount at which the account will be recharged.



# File 'lib/telnyx/models/payment/auto_recharge_pref.rb', line 49

Instance Attribute Details

#enabledBoolean?

Whether auto recharge is enabled.

Returns:

  • (Boolean, nil)


17
# File 'lib/telnyx/models/payment/auto_recharge_pref.rb', line 17

optional :enabled, Telnyx::Internal::Type::Boolean

#idString?

The unique identifier for the auto recharge preference.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/payment/auto_recharge_pref.rb', line 11

optional :id, String

#invoice_enabledBoolean?

Returns:

  • (Boolean, nil)


22
# File 'lib/telnyx/models/payment/auto_recharge_pref.rb', line 22

optional :invoice_enabled, Telnyx::Internal::Type::Boolean

#preferenceSymbol, ...

The payment preference for auto recharge.



28
# File 'lib/telnyx/models/payment/auto_recharge_pref.rb', line 28

optional :preference, enum: -> { Telnyx::Payment::AutoRechargePref::Preference }

#recharge_amountString?

The amount to recharge the account, the actual recharge amount will be the amount necessary to reach the threshold amount plus the recharge amount.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/payment/auto_recharge_pref.rb', line 35

optional :recharge_amount, String

#record_typeString?

The record type.

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/payment/auto_recharge_pref.rb', line 41

optional :record_type, String

#threshold_amountString?

The threshold amount at which the account will be recharged.

Returns:

  • (String, nil)


47
# File 'lib/telnyx/models/payment/auto_recharge_pref.rb', line 47

optional :threshold_amount, String