Class: Telnyx::Models::Payment::AutoRechargePrefUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/payment/auto_recharge_pref_update_params.rb

Overview

Defined Under Namespace

Modules: Preference

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enabled: nil, invoice_enabled: nil, preference: nil, recharge_amount: nil, threshold_amount: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Payment::AutoRechargePrefUpdateParams for more details.

Parameters:

  • enabled (Boolean) (defaults to: nil)

    Whether auto recharge is enabled.

  • invoice_enabled (Boolean) (defaults to: nil)
  • preference (Symbol, Telnyx::Models::Payment::AutoRechargePrefUpdateParams::Preference) (defaults to: nil)

    The payment preference for auto recharge.

  • recharge_amount (String) (defaults to: nil)

    The amount to recharge the account, the actual recharge amount will be the amoun

  • threshold_amount (String) (defaults to: nil)

    The threshold amount at which the account will be recharged.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 41

Instance Attribute Details

#enabledBoolean?

Whether auto recharge is enabled.

Returns:

  • (Boolean, nil)


15
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 15

optional :enabled, Telnyx::Internal::Type::Boolean

#invoice_enabledBoolean?

Returns:

  • (Boolean, nil)


20
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 20

optional :invoice_enabled, Telnyx::Internal::Type::Boolean

#preferenceSymbol, ...

The payment preference for auto recharge.



26
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 26

optional :preference, enum: -> { Telnyx::Payment::AutoRechargePrefUpdateParams::Preference }

#recharge_amountString?

The amount to recharge the account, the actual recharge amount will be the amount necessary to reach the threshold amount plus the recharge amount.

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 33

optional :recharge_amount, String

#threshold_amountString?

The threshold amount at which the account will be recharged.

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 39

optional :threshold_amount, String