Class: Telnyx::Models::PhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_number.rb

Defined Under Namespace

Modules: PhoneNumberType, RequirementsStatus, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, bundle_id: nil, country_code: nil, country_iso_alpha2: nil, phone_number: nil, phone_number_type: nil, record_type: nil, regulatory_requirements: nil, requirements_met: nil, requirements_status: nil, status: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)
  • bundle_id (String) (defaults to: nil)
  • country_code (String) (defaults to: nil)

    Country code of the phone number

  • country_iso_alpha2 (String) (defaults to: nil)

    The ISO 3166-1 alpha-2 country code of the phone number.

  • phone_number (String) (defaults to: nil)
  • phone_number_type (Symbol, Telnyx::Models::PhoneNumber::PhoneNumberType) (defaults to: nil)

    Phone number type

  • record_type (String) (defaults to: nil)
  • regulatory_requirements (Array<Telnyx::Models::SubNumberOrderRegulatoryRequirementWithValue>) (defaults to: nil)
  • requirements_met (Boolean) (defaults to: nil)

    True if all requirements are met for a phone number, false otherwise.

  • requirements_status (Symbol, Telnyx::Models::PhoneNumber::RequirementsStatus) (defaults to: nil)

    Status of document requirements (if applicable)

  • status (Symbol, Telnyx::Models::PhoneNumber::Status) (defaults to: nil)

    The status of the phone number in the order.



# File 'lib/telnyx/models/phone_number.rb', line 70

Instance Attribute Details

#phone_numberString?

Returns:

  • (String, nil)


9
# File 'lib/telnyx/models/phone_number.rb', line 9

optional :phone_number, String

#regulatory_requirementsArray<Telnyx::Models::SubNumberOrderRegulatoryRequirementWithValue>?



14
15
# File 'lib/telnyx/models/phone_number.rb', line 14

optional :regulatory_requirements,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::SubNumberOrderRegulatoryRequirementWithValue] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_number.rb', line 105