Class: Telnyx::Models::PhoneNumberDeleteResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_number_delete_response.rb,
sig/telnyx/models/phone_number_delete_response.rbs

Overview

See Also:

  • Telnyx::Models::PhoneNumberDeleteResponse#data

Defined Under Namespace

Modules: PhoneNumberType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, activated_at: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, created_at: nil, customer_reference: nil, deletion_lock_enabled: nil, emergency_address_id: nil, emergency_enabled: nil, external_pin: nil, hd_voice_enabled: nil, messaging_profile_id: nil, messaging_profile_name: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, tags: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberDeleteResponse::Data for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • activated_at (Time, nil) (defaults to: nil)

    ISO 8601 formatted date indicating when the phone number was first activated (tr

  • billing_group_id (String) (defaults to: nil)

    Identifies the billing group associated with the phone number.

  • call_forwarding_enabled (Boolean) (defaults to: nil)

    Indicates if call forwarding will be enabled for this number if forwards_to and

  • call_recording_enabled (Boolean) (defaults to: nil)

    Indicates whether call recording is enabled for this number.

  • caller_id_name_enabled (Boolean) (defaults to: nil)

    Indicates whether caller ID is enabled for this number.

  • cnam_listing_enabled (Boolean) (defaults to: nil)

    Indicates whether a CNAM listing is enabled for this number.

  • connection_id (String) (defaults to: nil)

    Identifies the connection associated with the phone number.

  • connection_name (String) (defaults to: nil)

    The user-assigned name of the connection to be associated with this phone number

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the time it took to activate after the p

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • deletion_lock_enabled (Boolean) (defaults to: nil)

    Indicates whether deletion lock is enabled for this number. When enabled, this p

  • emergency_address_id (String) (defaults to: nil)

    Identifies the emergency address associated with the phone number.

  • emergency_enabled (Boolean) (defaults to: nil)

    Indicates whether emergency services are enabled for this number.

  • external_pin (String) (defaults to: nil)

    If someone attempts to port your phone number away from Telnyx and your phone nu

  • hd_voice_enabled (Boolean) (defaults to: nil)

    Indicates whether HD voice is enabled for this number.

  • messaging_profile_id (String) (defaults to: nil)

    Identifies the messaging profile associated with the phone number.

  • messaging_profile_name (String) (defaults to: nil)

    The name of the messaging profile associated with the phone number.

  • phone_number (String) (defaults to: nil)

    The +E.164-formatted phone number associated with this record.

  • phone_number_type (Symbol, Telnyx::Models::PhoneNumberDeleteResponse::Data::PhoneNumberType) (defaults to: nil)

    The phone number's type.

  • purchased_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating the time the request was made to purchase the

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • status (Symbol, Telnyx::Models::PhoneNumberDeleteResponse::Data::Status) (defaults to: nil)

    The phone number's current status.

  • t38_fax_gateway_enabled (Boolean) (defaults to: nil)

    Indicates whether T38 Fax Gateway for inbound calls to this number.

  • tags (Array<String>) (defaults to: nil)

    A list of user-assigned tags to help manage the phone number.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/phone_number_delete_response.rb', line 187

Instance Attribute Details

#activated_atTime?

Returns the value of attribute activated_at.

Returns:

  • (Time, nil)


82
83
84
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 82

def activated_at
  @activated_at
end

#billing_group_idString?

Identifies the billing group associated with the phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 21

optional :billing_group_id, String

#call_forwarding_enabledBoolean? (readonly)

Returns the value of attribute call_forwarding_enabled.

Returns:

  • (Boolean, nil)


84
85
86
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 84

def call_forwarding_enabled
  @call_forwarding_enabled
end

#call_recording_enabledBoolean? (readonly)

Returns the value of attribute call_recording_enabled.

Returns:

  • (Boolean, nil)


88
89
90
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 88

def call_recording_enabled
  @call_recording_enabled
end

#caller_id_name_enabledBoolean? (readonly)

Returns the value of attribute caller_id_name_enabled.

Returns:

  • (Boolean, nil)


92
93
94
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 92

def caller_id_name_enabled
  @caller_id_name_enabled
end

#cnam_listing_enabledBoolean? (readonly)

Returns the value of attribute cnam_listing_enabled.

Returns:

  • (Boolean, nil)


96
97
98
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 96

def cnam_listing_enabled
  @cnam_listing_enabled
end

#connection_idString?

Identifies the connection associated with the phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 27

optional :connection_id, String

#connection_nameString? (readonly)

Returns the value of attribute connection_name.

Returns:

  • (String, nil)


100
101
102
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 100

def connection_name
  @connection_name
end

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


104
105
106
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 104

def created_at
  @created_at
end

#customer_referenceString?

A customer reference string for customer look ups.

Parameters:

  • (String)

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 33

optional :customer_reference, String

#deletion_lock_enabledBoolean? (readonly)

Returns the value of attribute deletion_lock_enabled.

Returns:

  • (Boolean, nil)


108
109
110
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 108

def deletion_lock_enabled
  @deletion_lock_enabled
end

#emergency_address_idString? (readonly)

Returns the value of attribute emergency_address_id.

Returns:

  • (String, nil)


112
113
114
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 112

def emergency_address_id
  @emergency_address_id
end

#emergency_enabledBoolean? (readonly)

Returns the value of attribute emergency_enabled.

Returns:

  • (Boolean, nil)


116
117
118
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 116

def emergency_enabled
  @emergency_enabled
end

#external_pinString?

If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.

Parameters:

  • (String)

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 42

optional :external_pin, String

#hd_voice_enabledBoolean? (readonly)

Returns the value of attribute hd_voice_enabled.

Returns:

  • (Boolean, nil)


120
121
122
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 120

def hd_voice_enabled
  @hd_voice_enabled
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


78
79
80
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 78

def id
  @id
end

#messaging_profile_idString?

Identifies the messaging profile associated with the phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 48

optional :messaging_profile_id, String

#messaging_profile_nameString?

The name of the messaging profile associated with the phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


54
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 54

optional :messaging_profile_name, String

#phone_numberString? (readonly)

Returns the value of attribute phone_number.

Returns:

  • (String, nil)


124
125
126
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 124

def phone_number
  @phone_number
end

#phone_number_typeTelnyx::Models::PhoneNumberDeleteResponse::Data::phone_number_type? (readonly)

Returns the value of attribute phone_number_type.

Returns:

  • (Telnyx::Models::PhoneNumberDeleteResponse::Data::phone_number_type, nil)


128
129
130
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 128

def phone_number_type
  @phone_number_type
end

#purchased_atString? (readonly)

Returns the value of attribute purchased_at.

Returns:

  • (String, nil)


134
135
136
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 134

def purchased_at
  @purchased_at
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


138
139
140
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 138

def record_type
  @record_type
end

#statusTelnyx::Models::PhoneNumberDeleteResponse::Data::status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::PhoneNumberDeleteResponse::Data::status, nil)


142
143
144
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 142

def status
  @status
end

#t38_fax_gateway_enabledBoolean? (readonly)

Returns the value of attribute t38_fax_gateway_enabled.

Returns:

  • (Boolean, nil)


148
149
150
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 148

def t38_fax_gateway_enabled
  @t38_fax_gateway_enabled
end

#tagsArray<String>?

A list of user-assigned tags to help manage the phone number.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


60
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 60

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


152
153
154
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 152

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_number_delete_response.rb', line 256

Instance Method Details

#call_forwarding_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


86
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 86

def call_forwarding_enabled=: (bool) -> bool

#call_recording_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


90
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 90

def call_recording_enabled=: (bool) -> bool

#caller_id_name_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


94
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 94

def caller_id_name_enabled=: (bool) -> bool

#cnam_listing_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


98
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 98

def cnam_listing_enabled=: (bool) -> bool

#connection_name=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


102
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 102

def connection_name=: (String) -> String

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


106
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 106

def created_at=: (String) -> String

#deletion_lock_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


110
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 110

def deletion_lock_enabled=: (bool) -> bool

#emergency_address_id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


114
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 114

def emergency_address_id=: (String) -> String

#emergency_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


118
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 118

def emergency_enabled=: (bool) -> bool

#hd_voice_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


122
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 122

def hd_voice_enabled=: (bool) -> bool

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


80
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 80

def id=: (String) -> String

#phone_number=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


126
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 126

def phone_number=: (String) -> String

#phone_number_type=Object (readonly)



130
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 130

def phone_number_type=: (

#purchased_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


136
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 136

def purchased_at=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


140
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 140

def record_type=: (String) -> String

#status=Object (readonly)



144
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 144

def status=: (

#t38_fax_gateway_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


150
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 150

def t38_fax_gateway_enabled=: (bool) -> bool

#to_hash{

Returns:

  • ({)


185
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 185

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


154
# File 'sig/telnyx/models/phone_number_delete_response.rbs', line 154

def updated_at=: (String) -> String