Module: Telnyx::Models::PhoneNumberDetailed::PhoneNumberType

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/phone_number_detailed.rb,
sig/telnyx/models/phone_number_detailed.rbs

Overview

The phone number's type. Note: For numbers purchased prior to July 2023 or when fetching a number's details immediately after a purchase completes, the legacy values tollfree, shortcode or longcode may be returned instead.

See Also:

  • Telnyx::Models::PhoneNumberDetailed#phone_number_type

Constant Summary collapse

LOCAL =

Returns:

  • (:local)
:local
TOLL_FREE =

Returns:

  • (:toll_free)
:toll_free
MOBILE =

Returns:

  • (:mobile)
:mobile
NATIONAL =

Returns:

  • (:national)
:national
SHARED_COST =

Returns:

  • (:shared_cost)
:shared_cost
LANDLINE =

Returns:

  • (:landline)
:landline
TOLLFREE =

Returns:

  • (:tollfree)
:tollfree
SHORTCODE =

Returns:

  • (:shortcode)
:shortcode
LONGCODE =

Returns:

  • (:longcode)
:longcode

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Telnyx::Models::PhoneNumberDetailed::phone_number_type]

Returns:

  • (::Array[Telnyx::Models::PhoneNumberDetailed::phone_number_type])


207
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 207

def self?.values: -> ::Array[Telnyx::Models::PhoneNumberDetailed::phone_number_type]