Module: Telnyx::Models::PhoneNumberDetailed::SourceType
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/phone_number_detailed.rb
Overview
Indicates if the phone number was purchased or ported in. For some numbers this information may not be available.
Constant Summary collapse
- NUMBER_ORDER =
:number_order- PORT_REQUEST =
:port_request
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_detailed.rb', line 353
|