Class: Telnyx::Models::PhoneNumberListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/phone_number_list_params.rb,
sig/telnyx/models/phone_number_list_params.rbs

Overview

See Also:

  • Telnyx::Resources::PhoneNumbers#list

Defined Under Namespace

Modules: HandleMessagingProfileError, Sort Classes: Filter

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



43
# File 'sig/telnyx/models/phone_number_list_params.rbs', line 43

def initialize: (

Instance Attribute Details

#filterTelnyx::Models::PhoneNumberListParams::Filter?

Consolidated filter parameter (deepObject style). Originally: filter, filter, filter, filter, filter, filter, filter, filter, filter, filter, filter, filter



19
# File 'lib/telnyx/models/phone_number_list_params.rb', line 19

optional :filter, -> { Telnyx::PhoneNumberListParams::Filter }

#handle_messaging_profile_errorSymbol, ...

Although it is an infrequent occurrence, due to the highly distributed nature of the Telnyx platform, it is possible that there will be an issue when loading in Messaging Profile information. As such, when this parameter is set to true and an error in fetching this information occurs, messaging profile related fields will be omitted in the response and an error message will be included instead of returning a 503 error.



30
31
# File 'lib/telnyx/models/phone_number_list_params.rb', line 30

optional :handle_messaging_profile_error,
enum: -> { Telnyx::PhoneNumberListParams::HandleMessagingProfileError }

#page_numberInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


36
# File 'lib/telnyx/models/phone_number_list_params.rb', line 36

optional :page_number, Integer

#page_sizeInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


41
# File 'lib/telnyx/models/phone_number_list_params.rb', line 41

optional :page_size, Integer

#sortSymbol, ...

Specifies the sort order for results. If not given, results are sorted by created_at in descending order.



48
# File 'lib/telnyx/models/phone_number_list_params.rb', line 48

optional :sort, enum: -> { Telnyx::PhoneNumberListParams::Sort }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_number_list_params.rb', line 337

Instance Method Details

#to_hash{

Returns:

  • ({)


52
# File 'sig/telnyx/models/phone_number_list_params.rbs', line 52

def to_hash: -> {