Module: Telnyx::Models::PhoneNumberListParams::HandleMessagingProfileError
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/phone_number_list_params.rb,
sig/telnyx/models/phone_number_list_params.rbs
Overview
Although it is an infrequent occurrence, due to the highly distributed nature of
the Telnyx platform, it is possible that there will be an issue when loading in
Messaging Profile information. As such, when this parameter is set to true and
an error in fetching this information occurs, messaging profile related fields
will be omitted in the response and an error message will be included instead of
returning a 503 error.
Constant Summary collapse
- TRUE =
:true- FALSE =
:false
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::PhoneNumberListParams::handle_messaging_profile_error]
329 |
# File 'sig/telnyx/models/phone_number_list_params.rbs', line 329
def self?.values: -> ::Array[Telnyx::Models::PhoneNumberListParams::handle_messaging_profile_error]
|