Class: Telnyx::Models::PhoneNumberSlimListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_number_slim_list_response.rb,
sig/telnyx/models/phone_number_slim_list_response.rbs

Overview

See Also:

  • Telnyx::Resources::PhoneNumbers#slim_list

Defined Under Namespace

Modules: EmergencyStatus, InboundCallScreening, PhoneNumberType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, activated_at: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, country_iso_alpha2: nil, created_at: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, external_pin: nil, hd_voice_enabled: nil, inbound_call_screening: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberSlimListResponse for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • activated_at (Time, nil) (defaults to: nil)

    ISO 8601 formatted date indicating when the phone number was first activated (tr

  • billing_group_id (String) (defaults to: nil)

    Identifies the billing group associated with the phone number.

  • call_forwarding_enabled (Boolean) (defaults to: nil)

    Indicates if call forwarding will be enabled for this number if forwards_to and

  • call_recording_enabled (Boolean) (defaults to: nil)

    Indicates whether call recording is enabled for this number.

  • caller_id_name_enabled (Boolean) (defaults to: nil)

    Indicates whether caller ID is enabled for this number.

  • cnam_listing_enabled (Boolean) (defaults to: nil)

    Indicates whether a CNAM listing is enabled for this number.

  • connection_id (String) (defaults to: nil)

    Identifies the connection associated with the phone number.

  • country_iso_alpha2 (String) (defaults to: nil)

    The ISO 3166-1 alpha-2 country code of the phone number.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • emergency_address_id (String) (defaults to: nil)

    Identifies the emergency address associated with the phone number.

  • emergency_enabled (Boolean) (defaults to: nil)

    Indicates whether emergency services are enabled for this number.

  • emergency_status (Symbol, Telnyx::Models::PhoneNumberSlimListResponse::EmergencyStatus) (defaults to: nil)

    Indicates the status of the provisioning of emergency services for the phone num

  • external_pin (String) (defaults to: nil)

    If someone attempts to port your phone number away from Telnyx and your phone nu

  • hd_voice_enabled (Boolean) (defaults to: nil)

    Indicates whether HD voice is enabled for this number.

  • inbound_call_screening (Symbol, Telnyx::Models::PhoneNumberSlimListResponse::InboundCallScreening) (defaults to: nil)

    The inbound_call_screening setting is a phone number configuration option variab

  • phone_number (String) (defaults to: nil)

    The +E.164-formatted phone number associated with this record.

  • phone_number_type (Symbol, Telnyx::Models::PhoneNumberSlimListResponse::PhoneNumberType) (defaults to: nil)

    The phone number's type.

  • purchased_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was purchased.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • status (Symbol, Telnyx::Models::PhoneNumberSlimListResponse::Status) (defaults to: nil)

    The phone number's current status.

  • t38_fax_gateway_enabled (Boolean) (defaults to: nil)

    Indicates whether T38 Fax Gateway for inbound calls to this number.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 170

Instance Attribute Details

#activated_atTime?

Returns the value of attribute activated_at.

Returns:

  • (Time, nil)


64
65
66
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 64

def activated_at
  @activated_at
end

#billing_group_idString?

Identifies the billing group associated with the phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 11

optional :billing_group_id, String

#call_forwarding_enabledBoolean? (readonly)

Returns the value of attribute call_forwarding_enabled.

Returns:

  • (Boolean, nil)


66
67
68
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 66

def call_forwarding_enabled
  @call_forwarding_enabled
end

#call_recording_enabledBoolean? (readonly)

Returns the value of attribute call_recording_enabled.

Returns:

  • (Boolean, nil)


70
71
72
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 70

def call_recording_enabled
  @call_recording_enabled
end

#caller_id_name_enabledBoolean? (readonly)

Returns the value of attribute caller_id_name_enabled.

Returns:

  • (Boolean, nil)


74
75
76
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 74

def caller_id_name_enabled
  @caller_id_name_enabled
end

#cnam_listing_enabledBoolean? (readonly)

Returns the value of attribute cnam_listing_enabled.

Returns:

  • (Boolean, nil)


78
79
80
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 78

def cnam_listing_enabled
  @cnam_listing_enabled
end

#connection_idString?

Identifies the connection associated with the phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 17

optional :connection_id, String

#country_iso_alpha2String? (readonly)

Returns the value of attribute country_iso_alpha2.

Returns:

  • (String, nil)


82
83
84
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 82

def country_iso_alpha2
  @country_iso_alpha2
end

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


86
87
88
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 86

def created_at
  @created_at
end

#customer_referenceString?

A customer reference string for customer look ups.

Parameters:

  • (String)

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 23

optional :customer_reference, String

#emergency_address_idString? (readonly)

Returns the value of attribute emergency_address_id.

Returns:

  • (String, nil)


90
91
92
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 90

def emergency_address_id
  @emergency_address_id
end

#emergency_enabledBoolean? (readonly)

Returns the value of attribute emergency_enabled.

Returns:

  • (Boolean, nil)


94
95
96
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 94

def emergency_enabled
  @emergency_enabled
end

#emergency_statusSymbol, ...

Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.



32
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 32

optional :emergency_status, enum: -> { Telnyx::Models::PhoneNumberSlimListResponse::EmergencyStatus }

#external_pinString?

If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 41

optional :external_pin, String

#hd_voice_enabledBoolean? (readonly)

Returns the value of attribute hd_voice_enabled.

Returns:

  • (Boolean, nil)


98
99
100
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 98

def hd_voice_enabled
  @hd_voice_enabled
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


60
61
62
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 60

def id
  @id
end

#inbound_call_screeningSymbol, ...

The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.



50
51
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 50

optional :inbound_call_screening,
enum: -> { Telnyx::Models::PhoneNumberSlimListResponse::InboundCallScreening }

#phone_numberString? (readonly)

Returns the value of attribute phone_number.

Returns:

  • (String, nil)


102
103
104
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 102

def phone_number
  @phone_number
end

#phone_number_typeTelnyx::Models::PhoneNumberSlimListResponse::phone_number_type? (readonly)

Returns the value of attribute phone_number_type.

Returns:

  • (Telnyx::Models::PhoneNumberSlimListResponse::phone_number_type, nil)


106
107
108
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 106

def phone_number_type
  @phone_number_type
end

#purchased_atString? (readonly)

Returns the value of attribute purchased_at.

Returns:

  • (String, nil)


112
113
114
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 112

def purchased_at
  @purchased_at
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


116
117
118
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 116

def record_type
  @record_type
end

#statusTelnyx::Models::PhoneNumberSlimListResponse::status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::PhoneNumberSlimListResponse::status, nil)


120
121
122
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 120

def status
  @status
end

#t38_fax_gateway_enabledBoolean? (readonly)

Returns the value of attribute t38_fax_gateway_enabled.

Returns:

  • (Boolean, nil)


126
127
128
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 126

def t38_fax_gateway_enabled
  @t38_fax_gateway_enabled
end

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


130
131
132
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 130

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 237

Instance Method Details

#call_forwarding_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


68
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 68

def call_forwarding_enabled=: (bool) -> bool

#call_recording_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


72
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 72

def call_recording_enabled=: (bool) -> bool

#caller_id_name_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


76
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 76

def caller_id_name_enabled=: (bool) -> bool

#cnam_listing_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


80
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 80

def cnam_listing_enabled=: (bool) -> bool

#country_iso_alpha2=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


84
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 84

def country_iso_alpha2=: (String) -> String

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


88
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 88

def created_at=: (String) -> String

#emergency_address_id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


92
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 92

def emergency_address_id=: (String) -> String

#emergency_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


96
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 96

def emergency_enabled=: (bool) -> bool

#hd_voice_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


100
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 100

def hd_voice_enabled=: (bool) -> bool

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


62
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 62

def id=: (String) -> String

#phone_number=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


104
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 104

def phone_number=: (String) -> String

#phone_number_type=Object (readonly)



108
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 108

def phone_number_type=: (

#purchased_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


114
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 114

def purchased_at=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


118
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 118

def record_type=: (String) -> String

#status=Object (readonly)



122
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 122

def status=: (

#t38_fax_gateway_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


128
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 128

def t38_fax_gateway_enabled=: (bool) -> bool

#to_hash{

Returns:

  • ({)


161
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 161

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


132
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 132

def updated_at=: (String) -> String