Class: Telnyx::Models::PhoneNumberUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/phone_number_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(phone_number_id:, address_id: nil, billing_group_id: nil, connection_id: nil, customer_reference: nil, external_pin: nil, hd_voice_enabled: nil, tags: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberUpdateParams for more details.

Parameters:

  • phone_number_id (String)
  • address_id (String) (defaults to: nil)

    Identifies the address associated with the phone number.

  • billing_group_id (String) (defaults to: nil)

    Identifies the billing group associated with the phone number.

  • connection_id (String) (defaults to: nil)

    Identifies the connection associated with the phone number.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • external_pin (String) (defaults to: nil)

    If someone attempts to port your phone number away from Telnyx and your phone nu

  • hd_voice_enabled (Boolean) (defaults to: nil)

    Indicates whether HD voice is enabled for this number.

  • tags (Array<String>) (defaults to: nil)

    A list of user-assigned tags to help organize phone numbers.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/phone_number_update_params.rb', line 60

Instance Attribute Details

#address_idString?

Identifies the address associated with the phone number.

Returns:

  • (String, nil)


19
# File 'lib/telnyx/models/phone_number_update_params.rb', line 19

optional :address_id, String

#billing_group_idString?

Identifies the billing group associated with the phone number.

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/phone_number_update_params.rb', line 25

optional :billing_group_id, String

#connection_idString?

Identifies the connection associated with the phone number.

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/phone_number_update_params.rb', line 31

optional :connection_id, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/phone_number_update_params.rb', line 37

optional :customer_reference, String

#external_pinString?

If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, we will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.

Returns:

  • (String, nil)


46
# File 'lib/telnyx/models/phone_number_update_params.rb', line 46

optional :external_pin, String

#hd_voice_enabledBoolean?

Indicates whether HD voice is enabled for this number.

Returns:

  • (Boolean, nil)


52
# File 'lib/telnyx/models/phone_number_update_params.rb', line 52

optional :hd_voice_enabled, Telnyx::Internal::Type::Boolean

#phone_number_idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/phone_number_update_params.rb', line 13

required :phone_number_id, String

#tagsArray<String>?

A list of user-assigned tags to help organize phone numbers.

Returns:

  • (Array<String>, nil)


58
# File 'lib/telnyx/models/phone_number_update_params.rb', line 58

optional :tags, Telnyx::Internal::Type::ArrayOf[String]