Class: Telnyx::Models::PhoneNumbers::ActionChangeBundleStatusParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumbers::ActionChangeBundleStatusParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/phone_numbers/action_change_bundle_status_params.rb
Overview
Instance Attribute Summary collapse
-
#bundle_id ⇒ String
The new bundle_id setting for the number.
- #id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, bundle_id:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionChangeBundleStatusParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, bundle_id:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumbers::ActionChangeBundleStatusParams for more details.
|
|
# File 'lib/telnyx/models/phone_numbers/action_change_bundle_status_params.rb', line 26
|
Instance Attribute Details
#bundle_id ⇒ String
The new bundle_id setting for the number. If you are assigning the number to a bundle, this is the unique ID of the bundle you wish to use. If you are removing the number from a bundle, this must be null. You cannot assign a number from one bundle to another directly. You must first remove it from a bundle, and then assign it to a new bundle.
24 |
# File 'lib/telnyx/models/phone_numbers/action_change_bundle_status_params.rb', line 24 required :bundle_id, String |
#id ⇒ String
14 |
# File 'lib/telnyx/models/phone_numbers/action_change_bundle_status_params.rb', line 14 required :id, String |