Class: Telnyx::Models::PhoneNumbers::ActionEnableEmergencyParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumbers::ActionEnableEmergencyParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/phone_numbers/action_enable_emergency_params.rb
Overview
Instance Attribute Summary collapse
-
#emergency_address_id ⇒ String
Identifies the address to be used with emergency services.
-
#emergency_enabled ⇒ Boolean
Indicates whether to enable emergency services on this number.
- #id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(id:, emergency_address_id:, emergency_enabled:, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, emergency_address_id:, emergency_enabled:, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/phone_numbers/action_enable_emergency_params.rb', line 28
|
Instance Attribute Details
#emergency_address_id ⇒ String
Identifies the address to be used with emergency services.
20 |
# File 'lib/telnyx/models/phone_numbers/action_enable_emergency_params.rb', line 20 required :emergency_address_id, String |
#emergency_enabled ⇒ Boolean
Indicates whether to enable emergency services on this number.
26 |
# File 'lib/telnyx/models/phone_numbers/action_enable_emergency_params.rb', line 26 required :emergency_enabled, Telnyx::Internal::Type::Boolean |
#id ⇒ String
14 |
# File 'lib/telnyx/models/phone_numbers/action_enable_emergency_params.rb', line 14 required :id, String |