Class: Telnyx::Models::PhoneNumbers::ActionVerifyOwnershipResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumbers::ActionVerifyOwnershipResponse::Data
- Defined in:
- lib/telnyx/models/phone_numbers/action_verify_ownership_response.rb,
sig/telnyx/models/phone_numbers/action_verify_ownership_response.rbs
Overview
Defined Under Namespace
Classes: Found
Instance Attribute Summary collapse
-
#found ⇒ Array<Telnyx::Models::PhoneNumbers::ActionVerifyOwnershipResponse::Data::Found>?
The list of phone numbers which you own and are in an editable state.
-
#not_found ⇒ Array<String>?
Phone numbers that are not found in the account.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #record_type ⇒ String readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
46 |
# File 'sig/telnyx/models/phone_numbers/action_verify_ownership_response.rbs', line 46
def initialize: (
|
Instance Attribute Details
#found ⇒ Array<Telnyx::Models::PhoneNumbers::ActionVerifyOwnershipResponse::Data::Found>?
The list of phone numbers which you own and are in an editable state
22 23 |
# File 'lib/telnyx/models/phone_numbers/action_verify_ownership_response.rb', line 22 optional :found, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::PhoneNumbers::ActionVerifyOwnershipResponse::Data::Found] } |
#not_found ⇒ Array<String>?
Phone numbers that are not found in the account
29 |
# File 'lib/telnyx/models/phone_numbers/action_verify_ownership_response.rb', line 29 optional :not_found, Telnyx::Internal::Type::ArrayOf[String] |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
42 43 44 |
# File 'sig/telnyx/models/phone_numbers/action_verify_ownership_response.rbs', line 42 def record_type @record_type end |
Instance Method Details
#record_type= ⇒ String (readonly)
44 |
# File 'sig/telnyx/models/phone_numbers/action_verify_ownership_response.rbs', line 44
def record_type=: (String) -> String
|
#to_hash ⇒ {
52 |
# File 'sig/telnyx/models/phone_numbers/action_verify_ownership_response.rbs', line 52
def to_hash: -> {
|