Class: Telnyx::Models::PhoneNumbers::JobUpdateBatchParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/phone_numbers/job_update_batch_params.rb

Overview

Defined Under Namespace

Classes: Filter

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#billing_group_idString?

Identifies the billing group associated with the phone number.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 35

optional :billing_group_id, String

#connection_idString?

Identifies the connection associated with the phone number.

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 41

optional :connection_id, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


47
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 47

optional :customer_reference, String

#deletion_lock_enabledBoolean?

Indicates whether to enable or disable the deletion lock on each phone number. When enabled, this prevents the phone number from being deleted via the API or Telnyx portal.

Returns:

  • (Boolean, nil)


55
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 55

optional :deletion_lock_enabled, Telnyx::Internal::Type::Boolean

#external_pinString?

If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, we will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 64

optional :external_pin, String

#filterTelnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter?

Consolidated filter parameter (deepObject style). Originally: filter, filter, filter, filter, filter, filter, filter, filter, filter, filter



29
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 29

optional :filter, -> { Telnyx::PhoneNumbers::JobUpdateBatchParams::Filter }

#hd_voice_enabledBoolean?

Indicates whether to enable or disable HD Voice on each phone number. HD Voice is a paid feature and may not be available for all phone numbers, more details about it can be found in the Telnyx support documentation.

Returns:

  • (Boolean, nil)


72
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 72

optional :hd_voice_enabled, Telnyx::Internal::Type::Boolean

#phone_numbersArray<String>

Array of phone number ids and/or phone numbers in E164 format to update. This parameter is required if no filter parameters are provided. If you want to update specific numbers rather than all numbers matching a filter, you must use this parameter. Each item must be either a valid phone number ID or a phone number in E164 format (e.g., ‘+13127367254’).

Returns:

  • (Array<String>)


19
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 19

required :phone_numbers, Telnyx::Internal::Type::ArrayOf[String]

#tagsArray<String>?

A list of user-assigned tags to help organize phone numbers.

Returns:

  • (Array<String>, nil)


78
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 78

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#voiceTelnyx::Models::PhoneNumbers::UpdateVoiceSettings?



83
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 83

optional :voice, -> { Telnyx::PhoneNumbers::UpdateVoiceSettings }