Class: Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_numbers/job_update_batch_params.rb

Defined Under Namespace

Modules: Status, VoiceUsagePaymentMethod Classes: VoiceConnectionName

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(contains: nil, ends_with: nil, eq: nil, starts_with: nil) ⇒ Object

Filter by voice connection name pattern matching.

Parameters:

  • contains (String) (defaults to: nil)

    Filter contains connection name. Requires at least three characters.

  • ends_with (String) (defaults to: nil)

    Filter ends with connection name. Requires at least three characters.

  • eq (String) (defaults to: nil)

    Filter by connection name.

  • starts_with (String) (defaults to: nil)

    Filter starts with connection name. Requires at least three characters.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 111

class Filter < Telnyx::Internal::Type::BaseModel
  # @!attribute billing_group_id
  #   Filter by the billing_group_id associated with phone numbers. To filter to only
  #   phone numbers that have no billing group associated them, set the value of this
  #   filter to the string 'null'.
  #
  #   @return [String, nil]
  optional :billing_group_id, String

  # @!attribute connection_id
  #   Filter by connection_id.
  #
  #   @return [String, nil]
  optional :connection_id, String

  # @!attribute customer_reference
  #   Filter numbers via the customer_reference set.
  #
  #   @return [String, nil]
  optional :customer_reference, String

  # @!attribute emergency_address_id
  #   Filter by the emergency_address_id associated with phone numbers. To filter only
  #   phone numbers that have no emergency address associated with them, set the value
  #   of this filter to the string 'null'.
  #
  #   @return [String, nil]
  optional :emergency_address_id, String

  # @!attribute has_bundle
  #   Filter by phone number that have bundles.
  #
  #   @return [String, nil]
  optional :has_bundle, String

  # @!attribute phone_number
  #   Filter by phone number. Requires at least three digits. Non-numerical characters
  #   will result in no values being returned.
  #
  #   @return [String, nil]
  optional :phone_number, String

  # @!attribute status
  #   Filter by phone number status.
  #
  #   @return [Symbol, Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter::Status, nil]
  optional :status, enum: -> { Telnyx::PhoneNumbers::JobUpdateBatchParams::Filter::Status }

  # @!attribute tag
  #   Filter by phone number tags.
  #
  #   @return [String, nil]
  optional :tag, String

  # @!attribute voice_connection_name
  #   Filter by voice connection name pattern matching.
  #
  #   @return [Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter::VoiceConnectionName, nil]
  optional :voice_connection_name,
           -> { Telnyx::PhoneNumbers::JobUpdateBatchParams::Filter::VoiceConnectionName },
           api_name: :"voice.connection_name"

  # @!attribute voice_usage_payment_method
  #   Filter by usage_payment_method.
  #
  #   @return [Symbol, Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter::VoiceUsagePaymentMethod, nil]
  optional :voice_usage_payment_method,
           enum: -> { Telnyx::PhoneNumbers::JobUpdateBatchParams::Filter::VoiceUsagePaymentMethod },
           api_name: :"voice.usage_payment_method"

  # @!method initialize(billing_group_id: nil, connection_id: nil, customer_reference: nil, emergency_address_id: nil, has_bundle: nil, phone_number: nil, status: nil, tag: nil, voice_connection_name: nil, voice_usage_payment_method: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter} for more details.
  #
  #   Consolidated filter parameter (deepObject style). Originally:
  #   filter[has_bundle], filter[tag], filter[connection_id], filter[phone_number],
  #   filter[status], filter[voice.connection_name],
  #   filter[voice.usage_payment_method], filter[billing_group_id],
  #   filter[emergency_address_id], filter[customer_reference]
  #
  #   @param billing_group_id [String] Filter by the billing_group_id associated with phone numbers. To filter to only
  #
  #   @param connection_id [String] Filter by connection_id.
  #
  #   @param customer_reference [String] Filter numbers via the customer_reference set.
  #
  #   @param emergency_address_id [String] Filter by the emergency_address_id associated with phone numbers. To filter only
  #
  #   @param has_bundle [String] Filter by phone number that have bundles.
  #
  #   @param phone_number [String] Filter by phone number. Requires at least three digits.
  #
  #   @param status [Symbol, Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter::Status] Filter by phone number status.
  #
  #   @param tag [String] Filter by phone number tags.
  #
  #   @param voice_connection_name [Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter::VoiceConnectionName] Filter by voice connection name pattern matching.
  #
  #   @param voice_usage_payment_method [Symbol, Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter::VoiceUsagePaymentMethod] Filter by usage_payment_method.

  # Filter by phone number status.
  #
  # @see Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter#status
  module Status
    extend Telnyx::Internal::Type::Enum

    PURCHASE_PENDING = :"purchase-pending"
    PURCHASE_FAILED = :"purchase-failed"
    PORT_PENDING = :"port-pending"
    ACTIVE = :active
    DELETED = :deleted
    PORT_FAILED = :"port-failed"
    EMERGENCY_ONLY = :"emergency-only"
    PORTED_OUT = :"ported-out"
    PORT_OUT_PENDING = :"port-out-pending"

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # @see Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter#voice_connection_name
  class VoiceConnectionName < Telnyx::Internal::Type::BaseModel
    # @!attribute contains
    #   Filter contains connection name. Requires at least three characters.
    #
    #   @return [String, nil]
    optional :contains, String

    # @!attribute ends_with
    #   Filter ends with connection name. Requires at least three characters.
    #
    #   @return [String, nil]
    optional :ends_with, String

    # @!attribute eq
    #   Filter by connection name.
    #
    #   @return [String, nil]
    optional :eq, String

    # @!attribute starts_with
    #   Filter starts with connection name. Requires at least three characters.
    #
    #   @return [String, nil]
    optional :starts_with, String

    # @!method initialize(contains: nil, ends_with: nil, eq: nil, starts_with: nil)
    #   Filter by voice connection name pattern matching.
    #
    #   @param contains [String] Filter contains connection name. Requires at least three characters.
    #
    #   @param ends_with [String] Filter ends with connection name. Requires at least three characters.
    #
    #   @param eq [String] Filter by connection name.
    #
    #   @param starts_with [String] Filter starts with connection name. Requires at least three characters.
  end

  # Filter by usage_payment_method.
  #
  # @see Telnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter#voice_usage_payment_method
  module VoiceUsagePaymentMethod
    extend Telnyx::Internal::Type::Enum

    PAY_PER_MINUTE = :"pay-per-minute"
    CHANNEL = :channel

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#billing_group_idString?

Filter by the billing_group_id associated with phone numbers. To filter to only phone numbers that have no billing group associated them, set the value of this filter to the string ‘null’.

Returns:

  • (String, nil)


118
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 118

optional :billing_group_id, String

#connection_idString?

Filter by connection_id.

Returns:

  • (String, nil)


124
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 124

optional :connection_id, String

#customer_referenceString?

Filter numbers via the customer_reference set.

Returns:

  • (String, nil)


130
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 130

optional :customer_reference, String

#emergency_address_idString?

Filter by the emergency_address_id associated with phone numbers. To filter only phone numbers that have no emergency address associated with them, set the value of this filter to the string ‘null’.

Returns:

  • (String, nil)


138
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 138

optional :emergency_address_id, String

#has_bundleString?

Filter by phone number that have bundles.

Returns:

  • (String, nil)


144
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 144

optional :has_bundle, String

#phone_numberString?

Filter by phone number. Requires at least three digits. Non-numerical characters will result in no values being returned.

Returns:

  • (String, nil)


151
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 151

optional :phone_number, String

#statusSymbol, ...

Filter by phone number status.



157
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 157

optional :status, enum: -> { Telnyx::PhoneNumbers::JobUpdateBatchParams::Filter::Status }

#tagString?

Filter by phone number tags.

Returns:

  • (String, nil)


163
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 163

optional :tag, String

#voice_connection_nameTelnyx::Models::PhoneNumbers::JobUpdateBatchParams::Filter::VoiceConnectionName?

Filter by voice connection name pattern matching.



169
170
171
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 169

optional :voice_connection_name,
-> { Telnyx::PhoneNumbers::JobUpdateBatchParams::Filter::VoiceConnectionName },
api_name: :"voice.connection_name"

#voice_usage_payment_methodSymbol, ...

Filter by usage_payment_method.



177
178
179
# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 177

optional :voice_usage_payment_method,
enum: -> { Telnyx::PhoneNumbers::JobUpdateBatchParams::Filter::VoiceUsagePaymentMethod },
api_name: :"voice.usage_payment_method"

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_numbers/job_update_batch_params.rb', line 227