Class: Telnyx::Models::PhoneNumbers::JobUpdateEmergencySettingsBatchParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/phone_numbers/job_update_emergency_settings_batch_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(emergency_enabled:, phone_numbers:, emergency_address_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumbers::JobUpdateEmergencySettingsBatchParams for more details.

Parameters:

  • emergency_enabled (Boolean)

    Indicates whether to enable or disable emergency services on the numbers.

  • phone_numbers (Array<String>)
  • emergency_address_id (String, nil) (defaults to: nil)

    Identifies the address to be used with emergency services. Required if emergency

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/phone_numbers/job_update_emergency_settings_batch_params.rb', line 30

Instance Attribute Details

#emergency_address_idString?

Identifies the address to be used with emergency services. Required if emergency_enabled is true, must be null or omitted if emergency_enabled is false.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/phone_numbers/job_update_emergency_settings_batch_params.rb', line 28

optional :emergency_address_id, String, nil?: true

#emergency_enabledBoolean

Indicates whether to enable or disable emergency services on the numbers.

Returns:

  • (Boolean)


15
# File 'lib/telnyx/models/phone_numbers/job_update_emergency_settings_batch_params.rb', line 15

required :emergency_enabled, Telnyx::Internal::Type::Boolean

#phone_numbersArray<String>

Returns:

  • (Array<String>)


20
# File 'lib/telnyx/models/phone_numbers/job_update_emergency_settings_batch_params.rb', line 20

required :phone_numbers, Telnyx::Internal::Type::ArrayOf[String]