Class: Telnyx::Models::PhoneNumbers::PhoneNumberWithVoiceSettings::Emergency

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb

Overview

See Also:

Defined Under Namespace

Modules: EmergencyStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumbers::PhoneNumberWithVoiceSettings::Emergency for more details.

The emergency services settings for a phone number.

Parameters:

  • emergency_address_id (String) (defaults to: nil)

    Identifies the address to be used with emergency services.

  • emergency_enabled (Boolean) (defaults to: nil)

    Allows you to enable or disable emergency services on the phone number. In order

  • emergency_status (Symbol, Telnyx::Models::PhoneNumbers::PhoneNumberWithVoiceSettings::Emergency::EmergencyStatus) (defaults to: nil)

    Represents the state of the number regarding emergency activation.



# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 154

Instance Attribute Details

#emergency_address_idString?

Identifies the address to be used with emergency services.

Returns:

  • (String, nil)


138
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 138

optional :emergency_address_id, String

#emergency_enabledBoolean?

Allows you to enable or disable emergency services on the phone number. In order to enable emergency services, you must also set an emergency_address_id.

Returns:

  • (Boolean, nil)


145
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 145

optional :emergency_enabled, Telnyx::Internal::Type::Boolean

#emergency_statusSymbol, ...

Represents the state of the number regarding emergency activation.



151
152
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 151

optional :emergency_status,
enum: -> { Telnyx::PhoneNumbers::PhoneNumberWithVoiceSettings::Emergency::EmergencyStatus }