Module: Telnyx::Models::PhoneNumbers::PhoneNumberWithVoiceSettings::InboundCallScreening
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb
Overview
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.
Constant Summary collapse
- DISABLED =
:disabled- REJECT_CALLS =
:reject_calls- FLAG_CALLS =
:flag_calls
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info