Class: Telnyx::Models::PhoneNumbers::UpdateVoiceSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_numbers/update_voice_settings.rb

Direct Known Subclasses

VoiceUpdateParams

Defined Under Namespace

Modules: InboundCallScreening, UsagePaymentMethod

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_forwarding: nil, call_recording: nil, caller_id_name_enabled: nil, cnam_listing: nil, inbound_call_screening: nil, media_features: nil, tech_prefix_enabled: nil, translated_number: nil, usage_payment_method: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumbers::UpdateVoiceSettings for more details.

Parameters:



# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 67

Instance Attribute Details

#call_forwardingTelnyx::Models::PhoneNumbers::CallForwarding?

The call forwarding settings for a phone number.



11
# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 11

optional :call_forwarding, -> { Telnyx::PhoneNumbers::CallForwarding }

#call_recordingTelnyx::Models::PhoneNumbers::CallRecording?

The call recording settings for a phone number.



17
# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 17

optional :call_recording, -> { Telnyx::PhoneNumbers::CallRecording }

#caller_id_name_enabledBoolean?

Controls whether the caller ID name is enabled for this phone number.

Returns:

  • (Boolean, nil)


23
# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 23

optional :caller_id_name_enabled, Telnyx::Internal::Type::Boolean

#cnam_listingTelnyx::Models::PhoneNumbers::CnamListing?

The CNAM listing settings for a phone number.



29
# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 29

optional :cnam_listing, -> { Telnyx::PhoneNumbers::CnamListing }

#inbound_call_screeningSymbol, ...

The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.



38
39
# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 38

optional :inbound_call_screening,
enum: -> { Telnyx::PhoneNumbers::UpdateVoiceSettings::InboundCallScreening }

#media_featuresTelnyx::Models::PhoneNumbers::MediaFeatures?

The media features settings for a phone number.



45
# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 45

optional :media_features, -> { Telnyx::PhoneNumbers::MediaFeatures }

#tech_prefix_enabledBoolean?

Controls whether a tech prefix is enabled for this phone number.

Returns:

  • (Boolean, nil)


51
# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 51

optional :tech_prefix_enabled, Telnyx::Internal::Type::Boolean

#translated_numberString?

This field allows you to rewrite the destination number of an inbound call before the call is routed to you. The value of this field may be any alphanumeric value, and the value will replace the number originally dialed.

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 59

optional :translated_number, String

#usage_payment_methodSymbol, ...

Controls whether a number is billed per minute or uses your concurrent channels.



65
# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 65

optional :usage_payment_method, enum: -> { Telnyx::PhoneNumbers::UpdateVoiceSettings::UsagePaymentMethod }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_numbers/update_voice_settings.rb', line 102