Module: Telnyx::Models::PhoneNumbers::UpdateVoiceSettings::InboundCallScreening
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/phone_numbers/update_voice_settings.rb,
sig/telnyx/models/phone_numbers/update_voice_settings.rbs
Overview
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.
Constant Summary collapse
- DISABLED =
:disabled- REJECT_CALLS =
:reject_calls- FLAG_CALLS =
:flag_calls
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::PhoneNumbers::UpdateVoiceSettings::inbound_call_screening]
99 |
# File 'sig/telnyx/models/phone_numbers/update_voice_settings.rbs', line 99
def self?.values: -> ::Array[Telnyx::Models::PhoneNumbers::UpdateVoiceSettings::inbound_call_screening]
|