Class: Telnyx::Models::PhoneNumbers::VoicemailRequest::Greeting

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_numbers/voicemail_request.rb,
sig/telnyx/models/phone_numbers/voicemail_request.rbs

Overview

See Also:

  • Telnyx::Models::PhoneNumbers::VoicemailRequest#greeting

Defined Under Namespace

Modules: Mode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(media_name: nil, mode: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumbers::VoicemailRequest::Greeting for more details.

Controls the greeting a caller hears before leaving a voicemail. Set mode to default to play the standard system greeting, or to custom_greeting to play your own audio. When mode is custom_greeting, media_name is required and must reference an audio file already uploaded to your account through the Media Storage API.

Parameters:



# File 'lib/telnyx/models/phone_numbers/voicemail_request.rb', line 57

Instance Attribute Details

#media_nameString?

The name of the media file to play as the greeting. Required when mode is custom_greeting; ignored when mode is default. The value must match the media_name of a file you previously uploaded with the Media Storage API (POST /v2/media).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/phone_numbers/voicemail_request.rb', line 48

optional :media_name, String, nil?: true

#modeSymbol, ...

The greeting mode. default plays the standard system greeting. custom_greeting plays the audio referenced by media_name.



55
# File 'lib/telnyx/models/phone_numbers/voicemail_request.rb', line 55

optional :mode, enum: -> { Telnyx::PhoneNumbers::VoicemailRequest::Greeting::Mode }

Instance Method Details

#to_hash{

Returns:

  • ({)


58
# File 'sig/telnyx/models/phone_numbers/voicemail_request.rbs', line 58

def to_hash: -> {