Class: Telnyx::Models::Porting::EventListResponse::PortingEventDeletedPayload::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting/event_list_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#created_atTime?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (Time, nil)


117
# File 'lib/telnyx/models/porting/event_list_response.rb', line 117

optional :created_at, Time

#customer_referenceString?

Identifies the customer reference associated with the porting order.

Returns:

  • (String, nil)


123
# File 'lib/telnyx/models/porting/event_list_response.rb', line 123

optional :customer_reference, String

#deleted_atTime?

ISO 8601 formatted date indicating when the porting order was deleted.

Returns:

  • (Time, nil)


129
# File 'lib/telnyx/models/porting/event_list_response.rb', line 129

optional :deleted_at, Time

#idString?

Identifies the porting order that was deleted.

Returns:

  • (String, nil)


111
# File 'lib/telnyx/models/porting/event_list_response.rb', line 111

optional :id, String

#updated_atTime?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (Time, nil)


135
# File 'lib/telnyx/models/porting/event_list_response.rb', line 135

optional :updated_at, Time