Class: Telnyx::Models::Porting::EventListResponse::PortingEventMessagingChangedPayload::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Porting::EventListResponse::PortingEventMessagingChangedPayload::Payload
- Defined in:
- lib/telnyx/models/porting/event_list_response.rb
Overview
Defined Under Namespace
Classes: Messaging
Instance Attribute Summary collapse
-
#customer_reference ⇒ String?
Identifies the customer reference associated with the porting order.
-
#id ⇒ String?
Identifies the porting order that was moved.
-
#messaging ⇒ Telnyx::Models::Porting::EventListResponse::PortingEventMessagingChangedPayload::Payload::Messaging?
The messaging portability status of the porting order.
-
#support_key ⇒ String?
Identifies the support key associated with the porting order.
Instance Method Summary collapse
-
#initialize(id: nil, customer_reference: nil, messaging: nil, support_key: nil) ⇒ Object
constructor
The webhook payload for the porting_order.messaging_changed event.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, customer_reference: nil, messaging: nil, support_key: nil) ⇒ Object
The webhook payload for the porting_order.messaging_changed event
|
|
# File 'lib/telnyx/models/porting/event_list_response.rb', line 313
|
Instance Attribute Details
#customer_reference ⇒ String?
Identifies the customer reference associated with the porting order.
298 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 298 optional :customer_reference, String |
#id ⇒ String?
Identifies the porting order that was moved.
292 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 292 optional :id, String |
#messaging ⇒ Telnyx::Models::Porting::EventListResponse::PortingEventMessagingChangedPayload::Payload::Messaging?
The messaging portability status of the porting order.
304 305 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 304 optional :messaging, -> { Telnyx::Models::Porting::EventListResponse::PortingEventMessagingChangedPayload::Payload::Messaging } |
#support_key ⇒ String?
Identifies the support key associated with the porting order.
311 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 311 optional :support_key, String |