Class: Telnyx::Models::Porting::EventListResponse::PortingEventSplitEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Porting::EventListResponse::PortingEventSplitEvent
- Defined in:
- lib/telnyx/models/porting/event_list_response.rb
Defined Under Namespace
Modules: AvailableNotificationMethod, EventType, PayloadStatus Classes: Payload
Instance Attribute Summary collapse
-
#available_notification_methods ⇒ Array<Symbol, Telnyx::Models::Porting::EventListResponse::PortingEventSplitEvent::AvailableNotificationMethod>?
Indicates the notification methods used.
-
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
-
#event_type ⇒ Symbol, ...
Identifies the event type.
-
#id ⇒ String?
Uniquely identifies the event.
-
#payload ⇒ Telnyx::Models::Porting::EventListResponse::PortingEventSplitEvent::Payload?
The webhook payload for the porting_order.split event.
-
#payload_status ⇒ Symbol, ...
The status of the payload generation.
-
#porting_order_id ⇒ String?
Identifies the porting order associated with the event.
-
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ Object
constructor
The new porting order that the phone numbers was moved to.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil) ⇒ Object
The new porting order that the phone numbers was moved to.
|
|
# File 'lib/telnyx/models/porting/event_list_response.rb', line 968
|
Instance Attribute Details
#available_notification_methods ⇒ Array<Symbol, Telnyx::Models::Porting::EventListResponse::PortingEventSplitEvent::AvailableNotificationMethod>?
Indicates the notification methods used.
808 809 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 808 optional :available_notification_methods, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::Porting::EventListResponse::PortingEventSplitEvent::AvailableNotificationMethod] } |
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
815 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 815 optional :created_at, Time |
#event_type ⇒ Symbol, ...
Identifies the event type
821 822 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 821 optional :event_type, enum: -> { Telnyx::Models::Porting::EventListResponse::PortingEventSplitEvent::EventType } |
#id ⇒ String?
Uniquely identifies the event.
802 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 802 optional :id, String |
#payload ⇒ Telnyx::Models::Porting::EventListResponse::PortingEventSplitEvent::Payload?
The webhook payload for the porting_order.split event
828 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 828 optional :payload, -> { Telnyx::Models::Porting::EventListResponse::PortingEventSplitEvent::Payload } |
#payload_status ⇒ Symbol, ...
The status of the payload generation.
834 835 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 834 optional :payload_status, enum: -> { Telnyx::Models::Porting::EventListResponse::PortingEventSplitEvent::PayloadStatus } |
#porting_order_id ⇒ String?
Identifies the porting order associated with the event.
841 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 841 optional :porting_order_id, String |
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
847 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 847 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/porting/event_list_response.rb', line 883
|