Class: Telnyx::Models::Porting::EventListResponse::PortingEventStatusChangedEvent::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Porting::EventListResponse::PortingEventStatusChangedEvent::Payload
- Defined in:
- lib/telnyx/models/porting/event_list_response.rb
Overview
Instance Attribute Summary collapse
-
#customer_reference ⇒ String?
Identifies the customer reference associated with the porting order.
-
#id ⇒ String?
Identifies the porting order that was moved.
-
#status ⇒ Telnyx::Models::PortingOrderStatus?
Porting order status.
-
#support_key ⇒ String?
Identifies the support key associated with the porting order.
-
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the porting order was moved.
-
#webhook_url ⇒ String?
The URL to send the webhook to.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#customer_reference ⇒ String?
Identifies the customer reference associated with the porting order.
527 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 527 optional :customer_reference, String |
#id ⇒ String?
Identifies the porting order that was moved.
521 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 521 optional :id, String |
#status ⇒ Telnyx::Models::PortingOrderStatus?
Porting order status
533 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 533 optional :status, -> { Telnyx::PortingOrderStatus } |
#support_key ⇒ String?
Identifies the support key associated with the porting order.
539 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 539 optional :support_key, String |
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the porting order was moved.
545 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 545 optional :updated_at, Time |
#webhook_url ⇒ String?
The URL to send the webhook to.
551 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 551 optional :webhook_url, String |