Class: Telnyx::Models::Porting::EventRetrieveResponse::Data::PortingEventNewCommentEvent::Payload::Comment

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/telnyx/models/porting/event_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Modules: UserType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, body: nil, inserted_at: nil, user_id: nil, user_type: nil) ⇒ Object

The comment that was added to the porting order.

Parameters:



# File 'lib/telnyx/models/porting/event_retrieve_response.rb', line 774

Instance Attribute Details

#bodyString?

The body of the comment.

Returns:

  • (String, nil)


753
# File 'lib/telnyx/models/porting/event_retrieve_response.rb', line 753

optional :body, String

#idString?

Identifies the comment.

Returns:

  • (String, nil)


747
# File 'lib/telnyx/models/porting/event_retrieve_response.rb', line 747

optional :id, String

#inserted_atTime?

ISO 8601 formatted date indicating when the comment was created.

Returns:

  • (Time, nil)


759
# File 'lib/telnyx/models/porting/event_retrieve_response.rb', line 759

optional :inserted_at, Time

#user_idString?

Identifies the user that create the comment.

Returns:

  • (String, nil)


765
# File 'lib/telnyx/models/porting/event_retrieve_response.rb', line 765

optional :user_id, String

#user_typeSymbol, ...

Identifies the type of the user that created the comment.



771
772
# File 'lib/telnyx/models/porting/event_retrieve_response.rb', line 771

optional :user_type,
enum: -> { Telnyx::Models::Porting::EventRetrieveResponse::Data::PortingEventNewCommentEvent::Payload::Comment::UserType }