Class: Telnyx::Models::Porting::PortingEventDeletedPayload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting/porting_event_deleted_payload.rb

Defined Under Namespace

Modules: AvailableNotificationMethod, EventType, PayloadStatus Classes: Payload

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, customer_reference: nil, deleted_at: nil, record_type: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Identifies the porting order that was deleted.

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • customer_reference (String) (defaults to: nil)

    Identifies the customer reference associated with the porting order.

  • deleted_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the porting order was deleted.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • updated_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/porting/porting_event_deleted_payload.rb', line 119

Instance Attribute Details

#available_notification_methodsArray<Symbol, Telnyx::Models::Porting::PortingEventDeletedPayload::AvailableNotificationMethod>?

Indicates the notification methods used.



17
18
# File 'lib/telnyx/models/porting/porting_event_deleted_payload.rb', line 17

optional :available_notification_methods,
-> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Porting::PortingEventDeletedPayload::AvailableNotificationMethod] }

#event_typeSymbol, ...

Identifies the event type



24
# File 'lib/telnyx/models/porting/porting_event_deleted_payload.rb', line 24

optional :event_type, enum: -> { Telnyx::Porting::PortingEventDeletedPayload::EventType }

#idString?

Uniquely identifies the event.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/porting/porting_event_deleted_payload.rb', line 11

optional :id, String

#payloadTelnyx::Models::Porting::PortingEventDeletedPayload::Payload?



29
# File 'lib/telnyx/models/porting/porting_event_deleted_payload.rb', line 29

optional :payload, -> { Telnyx::Porting::PortingEventDeletedPayload::Payload }

#payload_statusSymbol, ...

The status of the payload generation.



35
# File 'lib/telnyx/models/porting/porting_event_deleted_payload.rb', line 35

optional :payload_status, enum: -> { Telnyx::Porting::PortingEventDeletedPayload::PayloadStatus }

#porting_order_idString?

Identifies the porting order associated with the event.

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/porting/porting_event_deleted_payload.rb', line 41

optional :porting_order_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/porting/porting_event_deleted_payload.rb', line 63