Class: Telnyx::Models::Porting::PortingEventMessagingChangedPayload::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb

Overview

See Also:

Defined Under Namespace

Classes: Messaging

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, customer_reference: nil, messaging: nil, support_key: nil) ⇒ Object

The webhook payload for the porting_order.messaging_changed event

Parameters:

  • id (String) (defaults to: nil)

    Identifies the porting order that was moved.

  • customer_reference (String) (defaults to: nil)

    Identifies the customer reference associated with the porting order.

  • messaging (Telnyx::Models::Porting::PortingEventMessagingChangedPayload::Payload::Messaging) (defaults to: nil)

    The messaging portability status of the porting order.

  • support_key (String) (defaults to: nil)

    Identifies the support key associated with the porting order.



# File 'lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb', line 132

Instance Attribute Details

#customer_referenceString?

Identifies the customer reference associated with the porting order.

Returns:

  • (String, nil)


118
# File 'lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb', line 118

optional :customer_reference, String

#idString?

Identifies the porting order that was moved.

Returns:

  • (String, nil)


112
# File 'lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb', line 112

optional :id, String

#messagingTelnyx::Models::Porting::PortingEventMessagingChangedPayload::Payload::Messaging?

The messaging portability status of the porting order.



124
# File 'lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb', line 124

optional :messaging, -> { Telnyx::Porting::PortingEventMessagingChangedPayload::Payload::Messaging }

#support_keyString?

Identifies the support key associated with the porting order.

Returns:

  • (String, nil)


130
# File 'lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb', line 130

optional :support_key, String