Class: Telnyx::Models::Porting::PortingEventNewCommentEvent::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting/porting_event_new_comment_event.rb

Overview

See Also:

Defined Under Namespace

Classes: Comment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(comment: nil, porting_order_id: nil, support_key: nil) ⇒ Object

The webhook payload for the porting_order.new_comment event

Parameters:

  • comment (Telnyx::Models::Porting::PortingEventNewCommentEvent::Payload::Comment) (defaults to: nil)

    The comment that was added to the porting order.

  • porting_order_id (String) (defaults to: nil)

    Identifies the porting order that the comment was added to.

  • support_key (String) (defaults to: nil)

    Identifies the support key associated with the porting order.



# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 126

Instance Attribute Details

#commentTelnyx::Models::Porting::PortingEventNewCommentEvent::Payload::Comment?

The comment that was added to the porting order.



112
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 112

optional :comment, -> { Telnyx::Porting::PortingEventNewCommentEvent::Payload::Comment }

#porting_order_idString?

Identifies the porting order that the comment was added to.

Returns:

  • (String, nil)


118
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 118

optional :porting_order_id, String

#support_keyString?

Identifies the support key associated with the porting order.

Returns:

  • (String, nil)


124
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 124

optional :support_key, String