Class: Telnyx::Models::Porting::PortingEventNewCommentEvent::Payload::Comment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting/porting_event_new_comment_event.rb

Overview

See Also:

Defined Under Namespace

Modules: UserType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, body: nil, inserted_at: nil, user_id: nil, user_type: nil) ⇒ Object

The comment that was added to the porting order.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the comment.

  • body (String) (defaults to: nil)

    The body of the comment.

  • inserted_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the comment was created.

  • user_id (String) (defaults to: nil)

    Identifies the user that create the comment.

  • user_type (Symbol, Telnyx::Models::Porting::PortingEventNewCommentEvent::Payload::Comment::UserType) (defaults to: nil)

    Identifies the type of the user that created the comment.



# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 167

Instance Attribute Details

#bodyString?

The body of the comment.

Returns:

  • (String, nil)


147
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 147

optional :body, String

#idString?

Identifies the comment.

Returns:

  • (String, nil)


141
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 141

optional :id, String

#inserted_atTime?

ISO 8601 formatted date indicating when the comment was created.

Returns:

  • (Time, nil)


153
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 153

optional :inserted_at, Time

#user_idString?

Identifies the user that create the comment.

Returns:

  • (String, nil)


159
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 159

optional :user_id, String

#user_typeSymbol, ...

Identifies the type of the user that created the comment.



165
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 165

optional :user_type, enum: -> { Telnyx::Porting::PortingEventNewCommentEvent::Payload::Comment::UserType }