Class: Telnyx::Models::Porting::PortingEventStatusChangedEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting/porting_event_status_changed_event.rb

Defined Under Namespace

Modules: AvailableNotificationMethod, EventType, PayloadStatus Classes: Payload

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, customer_reference: nil, status: nil, support_key: nil, updated_at: nil, webhook_url: nil) ⇒ Object

The webhook payload for the porting_order.status_changed event

Parameters:

  • id (String) (defaults to: nil)

    Identifies the porting order that was moved.

  • customer_reference (String) (defaults to: nil)

    Identifies the customer reference associated with the porting order.

  • status (Telnyx::Models::PortingOrderStatus) (defaults to: nil)

    Porting order status

  • support_key (String) (defaults to: nil)

    Identifies the support key associated with the porting order.

  • updated_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the porting order was moved.

  • webhook_url (String) (defaults to: nil)

    The URL to send the webhook to.



# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 144

Instance Attribute Details

#available_notification_methodsArray<Symbol, Telnyx::Models::Porting::PortingEventStatusChangedEvent::AvailableNotificationMethod>?

Indicates the notification methods used.



17
18
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 17

optional :available_notification_methods,
-> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Porting::PortingEventStatusChangedEvent::AvailableNotificationMethod] }

#created_atTime?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (Time, nil)


24
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 24

optional :created_at, Time

#event_typeSymbol, ...

Identifies the event type



30
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 30

optional :event_type, enum: -> { Telnyx::Porting::PortingEventStatusChangedEvent::EventType }

#idString?

Uniquely identifies the event.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 11

optional :id, String

#payloadTelnyx::Models::Porting::PortingEventStatusChangedEvent::Payload?

The webhook payload for the porting_order.status_changed event



36
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 36

optional :payload, -> { Telnyx::Porting::PortingEventStatusChangedEvent::Payload }

#payload_statusSymbol, ...

The status of the payload generation.



42
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 42

optional :payload_status, enum: -> { Telnyx::Porting::PortingEventStatusChangedEvent::PayloadStatus }

#porting_order_idString?

Identifies the porting order associated with the event.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 48

optional :porting_order_id, String

#updated_atTime?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (Time, nil)


54
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 54

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 90