Class: Telnyx::Models::Porting::PortingEventStatusChangedEvent::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting/porting_event_status_changed_event.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#customer_referenceString?

Identifies the customer reference associated with the porting order.

Returns:

  • (String, nil)


118
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 118

optional :customer_reference, String

#idString?

Identifies the porting order that was moved.

Returns:

  • (String, nil)


112
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 112

optional :id, String

#statusTelnyx::Models::PortingOrderStatus?

Porting order status



124
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 124

optional :status, -> { Telnyx::PortingOrderStatus }

#support_keyString?

Identifies the support key associated with the porting order.

Returns:

  • (String, nil)


130
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 130

optional :support_key, String

#updated_atTime?

ISO 8601 formatted date indicating when the porting order was moved.

Returns:

  • (Time, nil)


136
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 136

optional :updated_at, Time

#webhook_urlString?

The URL to send the webhook to.

Returns:

  • (String, nil)


142
# File 'lib/telnyx/models/porting/porting_event_status_changed_event.rb', line 142

optional :webhook_url, String