Class: Telnyx::Models::Porting::PortingReport

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting/porting_report.rb,
sig/telnyx/models/porting/porting_report.rbs

Overview

See Also:

  • Telnyx::Resources::Porting::Reports#list

Defined Under Namespace

Modules: ReportType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, document_id: nil, params: nil, record_type: nil, report_type: nil, status: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Porting::PortingReport for more details.

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the report.

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • document_id (String) (defaults to: nil)

    Identifies the document that was uploaded when report was generated. This field

  • params (Telnyx::Models::Porting::ExportPortingOrdersCsvReport) (defaults to: nil)

    The parameters for generating a porting orders CSV report.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • report_type (Symbol, Telnyx::Models::Porting::PortingReport::ReportType) (defaults to: nil)

    Identifies the type of report

  • status (Symbol, Telnyx::Models::Porting::PortingReport::Status) (defaults to: nil)

    The current status of the report generation.

  • updated_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/porting/porting_report.rb', line 59

Instance Attribute Details

#created_atTime?

ISO 8601 formatted date indicating when the resource was created.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


18
# File 'lib/telnyx/models/porting/porting_report.rb', line 18

optional :created_at, Time

#document_idString?

Identifies the document that was uploaded when report was generated. This field is only populated when the report is under completed status.

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/porting/porting_report.rb', line 25

optional :document_id, String

#idString?

Uniquely identifies the report.

Parameters:

  • (String)

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/porting/porting_report.rb', line 12

optional :id, String

#paramsTelnyx::Models::Porting::ExportPortingOrdersCsvReport?

The parameters for generating a porting orders CSV report.



31
# File 'lib/telnyx/models/porting/porting_report.rb', line 31

optional :params, -> { Telnyx::Porting::ExportPortingOrdersCsvReport }

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


53
54
55
# File 'sig/telnyx/models/porting/porting_report.rbs', line 53

def record_type
  @record_type
end

#report_typeSymbol, ...

Identifies the type of report



37
# File 'lib/telnyx/models/porting/porting_report.rb', line 37

optional :report_type, enum: -> { Telnyx::Porting::PortingReport::ReportType }

#statusSymbol, ...

The current status of the report generation.



43
# File 'lib/telnyx/models/porting/porting_report.rb', line 43

optional :status, enum: -> { Telnyx::Porting::PortingReport::Status }

#updated_atTime?

ISO 8601 formatted date indicating when the resource was updated.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


49
# File 'lib/telnyx/models/porting/porting_report.rb', line 49

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/porting/porting_report.rb', line 87

Instance Method Details

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


55
# File 'sig/telnyx/models/porting/porting_report.rbs', line 55

def record_type=: (String) -> String

#to_hash{

Returns:

  • ({)


68
# File 'sig/telnyx/models/porting/porting_report.rbs', line 68

def to_hash: -> {