Class: Telnyx::Models::PortingListUkCarriersResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingListUkCarriersResponse::Data
- Defined in:
- lib/telnyx/models/porting_list_uk_carriers_response.rb
Instance Attribute Summary collapse
-
#alternative_cupids ⇒ Array<String>?
Alternative CUPIDs of the carrier.
-
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
-
#cupid ⇒ String?
The CUPID of the carrier.
-
#id ⇒ String?
Identifies the UK carrier.
-
#name ⇒ String?
The name of the carrier.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
Instance Method Summary collapse
-
#initialize(id: nil, alternative_cupids: nil, created_at: nil, cupid: nil, name: nil, record_type: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, alternative_cupids: nil, created_at: nil, cupid: nil, name: nil, record_type: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PortingListUkCarriersResponse::Data for more details.
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/telnyx/models/porting_list_uk_carriers_response.rb', line 16 class Data < Telnyx::Internal::Type::BaseModel # @!attribute id # Identifies the UK carrier. # # @return [String, nil] optional :id, String # @!attribute alternative_cupids # Alternative CUPIDs of the carrier. # # @return [Array<String>, nil] optional :alternative_cupids, Telnyx::Internal::Type::ArrayOf[String] # @!attribute created_at # ISO 8601 formatted date indicating when the resource was created. # # @return [Time, nil] optional :created_at, Time # @!attribute cupid # The CUPID of the carrier. This is a 3 digit number code that identifies the # carrier in the UK. # # @return [String, nil] optional :cupid, String # @!attribute name # The name of the carrier. # # @return [String, nil] optional :name, String # @!attribute record_type # Identifies the type of the resource. # # @return [String, nil] optional :record_type, String # @!attribute updated_at # ISO 8601 formatted date indicating when the resource was updated. # # @return [Time, nil] optional :updated_at, Time # @!method initialize(id: nil, alternative_cupids: nil, created_at: nil, cupid: nil, name: nil, record_type: nil, updated_at: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::PortingListUkCarriersResponse::Data} for more details. # # @param id [String] Identifies the UK carrier. # # @param alternative_cupids [Array<String>] Alternative CUPIDs of the carrier. # # @param created_at [Time] ISO 8601 formatted date indicating when the resource was created. # # @param cupid [String] The CUPID of the carrier. This is a 3 digit number code that identifies the carr # # @param name [String] The name of the carrier. # # @param record_type [String] Identifies the type of the resource. # # @param updated_at [Time] ISO 8601 formatted date indicating when the resource was updated. end |
Instance Attribute Details
#alternative_cupids ⇒ Array<String>?
Alternative CUPIDs of the carrier.
27 |
# File 'lib/telnyx/models/porting_list_uk_carriers_response.rb', line 27 optional :alternative_cupids, Telnyx::Internal::Type::ArrayOf[String] |
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
33 |
# File 'lib/telnyx/models/porting_list_uk_carriers_response.rb', line 33 optional :created_at, Time |
#cupid ⇒ String?
The CUPID of the carrier. This is a 3 digit number code that identifies the carrier in the UK.
40 |
# File 'lib/telnyx/models/porting_list_uk_carriers_response.rb', line 40 optional :cupid, String |
#id ⇒ String?
Identifies the UK carrier.
21 |
# File 'lib/telnyx/models/porting_list_uk_carriers_response.rb', line 21 optional :id, String |
#name ⇒ String?
The name of the carrier.
46 |
# File 'lib/telnyx/models/porting_list_uk_carriers_response.rb', line 46 optional :name, String |
#record_type ⇒ String?
Identifies the type of the resource.
52 |
# File 'lib/telnyx/models/porting_list_uk_carriers_response.rb', line 52 optional :record_type, String |
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
58 |
# File 'lib/telnyx/models/porting_list_uk_carriers_response.rb', line 58 optional :updated_at, Time |