Module: Telnyx::Models::PortingOrder::AdditionalStep

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/porting_order.rb

Constant Summary collapse

ASSOCIATED_PHONE_NUMBERS =
:associated_phone_numbers
PHONE_NUMBER_VERIFICATION_CODES =
:phone_number_verification_codes

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id: nil, activation_settings: nil, additional_steps: nil, created_at: nil, customer_group_reference: nil, customer_reference: nil, description: nil, documents: nil, end_user: nil, messaging: nil, misc: nil, old_service_provider_ocn: nil, parent_support_key: nil, phone_number_configuration: nil, phone_number_type: nil, phone_numbers: nil, porting_phone_numbers_count: nil, record_type: nil, requirements: nil, requirements_met: nil, status: nil, support_key: nil, updated_at: nil, user_feedback: nil, user_id: nil, webhook_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortingOrder for more details.

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies this porting order

  • activation_settings (Telnyx::Models::PortingOrderActivationSettings) (defaults to: nil)
  • additional_steps (Array<Symbol, Telnyx::Models::PortingOrder::AdditionalStep>) (defaults to: nil)

    For specific porting orders, we may require additional steps to be taken before

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • customer_group_reference (String, nil) (defaults to: nil)

    A customer-specified group reference for customer bookkeeping purposes

  • customer_reference (String, nil) (defaults to: nil)

    A customer-specified reference number for customer bookkeeping purposes

  • description (String) (defaults to: nil)

    A description of the porting order

  • documents (Telnyx::Models::PortingOrderDocuments) (defaults to: nil)

    Can be specified directly or via the ‘requirement_group_id` parameter.

  • end_user (Telnyx::Models::PortingOrderEndUser) (defaults to: nil)
  • messaging (Telnyx::Models::PortingOrderMessaging) (defaults to: nil)

    Information about messaging porting process.

  • misc (Telnyx::Models::PortingOrderMisc, nil) (defaults to: nil)
  • old_service_provider_ocn (String) (defaults to: nil)

    Identifies the old service provider

  • parent_support_key (String, nil) (defaults to: nil)

    A key to reference for the porting order group when contacting Telnyx customer s

  • phone_number_configuration (Telnyx::Models::PortingOrderPhoneNumberConfiguration) (defaults to: nil)
  • phone_number_type (Symbol, Telnyx::Models::PortingOrder::PhoneNumberType) (defaults to: nil)

    The type of the phone number

  • phone_numbers (Array<Telnyx::Models::PortingOrder::PhoneNumber>) (defaults to: nil)

    List of phone numbers associated with this porting order

  • porting_phone_numbers_count (Integer) (defaults to: nil)

    Count of phone numbers associated with this porting order

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • requirements (Array<Telnyx::Models::PortingOrderRequirement>) (defaults to: nil)

    List of documentation requirements for porting numbers. Can be set directly or v

  • requirements_met (Boolean) (defaults to: nil)

    Is true when the required documentation is met

  • status (Telnyx::Models::PortingOrderStatus) (defaults to: nil)

    Porting order status

  • support_key (String, nil) (defaults to: nil)

    A key to reference this porting order when contacting Telnyx customer support. T

  • updated_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • user_feedback (Telnyx::Models::PortingOrderUserFeedback) (defaults to: nil)
  • user_id (String) (defaults to: nil)

    Identifies the user (or organization) who requested the porting order

  • webhook_url (String, nil) (defaults to: nil)


220
221
222
223
224
225
226
227
228
# File 'lib/telnyx/models/porting_order.rb', line 220

module AdditionalStep
  extend Telnyx::Internal::Type::Enum

  ASSOCIATED_PHONE_NUMBERS = :associated_phone_numbers
  PHONE_NUMBER_VERIFICATION_CODES = :phone_number_verification_codes

  # @!method self.values
  #   @return [Array<Symbol>]
end