Class: Telnyx::Models::PortingOrder::PhoneNumber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrder::PhoneNumber
- Defined in:
- lib/telnyx/models/porting_order.rb
Defined Under Namespace
Modules: ActivationStatus, PhoneNumberType, PortabilityStatus, PortingOrderStatus, RequirementsStatus
Instance Attribute Summary collapse
-
#activation_status ⇒ Symbol, ...
Activation status.
-
#phone_number ⇒ String?
E164 formatted phone number.
-
#phone_number_type ⇒ Symbol, ...
The type of the phone number.
-
#portability_status ⇒ Symbol, ...
Specifies whether Telnyx is able to confirm portability this number in the United States & Canada.
-
#porting_order_id ⇒ String?
Identifies the associated port request.
-
#porting_order_status ⇒ Symbol, ...
The current status of the porting order.
-
#requirements_status ⇒ Symbol, ...
The current status of the requirements in a INTL porting order.
-
#support_key ⇒ String?
A key to reference this porting order when contacting Telnyx customer support.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(activation_status: nil, phone_number: nil, phone_number_type: nil, portability_status: nil, porting_order_id: nil, porting_order_status: nil, record_type: nil, requirements_status: nil, support_key: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumber for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(activation_status: nil, phone_number: nil, phone_number_type: nil, portability_status: nil, porting_order_id: nil, porting_order_status: nil, record_type: nil, requirements_status: nil, support_key: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PortingOrder::PhoneNumber for more details.
|
|
# File 'lib/telnyx/models/porting_order.rb', line 305
|
Instance Attribute Details
#activation_status ⇒ Symbol, ...
Activation status
252 |
# File 'lib/telnyx/models/porting_order.rb', line 252 optional :activation_status, enum: -> { Telnyx::PortingOrder::PhoneNumber::ActivationStatus } |
#phone_number ⇒ String?
E164 formatted phone number
258 |
# File 'lib/telnyx/models/porting_order.rb', line 258 optional :phone_number, String |
#phone_number_type ⇒ Symbol, ...
The type of the phone number
264 |
# File 'lib/telnyx/models/porting_order.rb', line 264 optional :phone_number_type, enum: -> { Telnyx::PortingOrder::PhoneNumber::PhoneNumberType } |
#portability_status ⇒ Symbol, ...
Specifies whether Telnyx is able to confirm portability this number in the United States & Canada. International phone numbers are provisional by default.
271 |
# File 'lib/telnyx/models/porting_order.rb', line 271 optional :portability_status, enum: -> { Telnyx::PortingOrder::PhoneNumber::PortabilityStatus } |
#porting_order_id ⇒ String?
Identifies the associated port request
277 |
# File 'lib/telnyx/models/porting_order.rb', line 277 optional :porting_order_id, String |
#porting_order_status ⇒ Symbol, ...
The current status of the porting order
283 |
# File 'lib/telnyx/models/porting_order.rb', line 283 optional :porting_order_status, enum: -> { Telnyx::PortingOrder::PhoneNumber::PortingOrderStatus } |
#requirements_status ⇒ Symbol, ...
The current status of the requirements in a INTL porting order
289 |
# File 'lib/telnyx/models/porting_order.rb', line 289 optional :requirements_status, enum: -> { Telnyx::PortingOrder::PhoneNumber::RequirementsStatus } |
#support_key ⇒ String?
A key to reference this porting order when contacting Telnyx customer support
295 |
# File 'lib/telnyx/models/porting_order.rb', line 295 optional :support_key, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/porting_order.rb', line 347
|