Class: Telnyx::Models::PortingOrderDocuments

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_order_documents.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(invoice: nil, loa: nil) ⇒ Object

Can be specified directly or via the ‘requirement_group_id` parameter.

Parameters:

  • invoice (String, nil) (defaults to: nil)

    Returned ID of the submitted Invoice via the Documents endpoint

  • loa (String, nil) (defaults to: nil)

    Returned ID of the submitted LOA via the Documents endpoint



# File 'lib/telnyx/models/porting_order_documents.rb', line 18

Instance Attribute Details

#invoiceString?

Returned ID of the submitted Invoice via the Documents endpoint

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/porting_order_documents.rb', line 10

optional :invoice, String, nil?: true

#loaString?

Returned ID of the submitted LOA via the Documents endpoint

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/porting_order_documents.rb', line 16

optional :loa, String, nil?: true