Class: Telnyx::Models::PortingOrderEndUserAdmin

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_order_end_user_admin.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number: nil, auth_person_name: nil, billing_phone_number: nil, business_identifier: nil, entity_name: nil, pin_passcode: nil, tax_identifier: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortingOrderEndUserAdmin for more details.

Parameters:

  • account_number (String, nil) (defaults to: nil)

    The authorized person’s account number with the current service provider

  • auth_person_name (String, nil) (defaults to: nil)

    Name of person authorizing the porting order

  • billing_phone_number (String, nil) (defaults to: nil)

    Billing phone number associated with these phone numbers

  • business_identifier (String, nil) (defaults to: nil)

    European business identification number. Applicable only in the European Union

  • entity_name (String, nil) (defaults to: nil)

    Person Name or Company name requesting the port

  • pin_passcode (String, nil) (defaults to: nil)

    PIN/passcode possibly required by the old service provider for extra verificatio

  • tax_identifier (String, nil) (defaults to: nil)

    European tax identification number. Applicable only in the European Union



# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 49

Instance Attribute Details

#account_numberString?

The authorized person’s account number with the current service provider

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 10

optional :account_number, String, nil?: true

#auth_person_nameString?

Name of person authorizing the porting order

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 16

optional :auth_person_name, String, nil?: true

#billing_phone_numberString?

Billing phone number associated with these phone numbers

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 22

optional :billing_phone_number, String, nil?: true

#business_identifierString?

European business identification number. Applicable only in the European Union

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 28

optional :business_identifier, String, nil?: true

#entity_nameString?

Person Name or Company name requesting the port

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 34

optional :entity_name, String, nil?: true

#pin_passcodeString?

PIN/passcode possibly required by the old service provider for extra verification

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 41

optional :pin_passcode, String, nil?: true

#tax_identifierString?

European tax identification number. Applicable only in the European Union

Returns:

  • (String, nil)


47
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 47

optional :tax_identifier, String, nil?: true