Class: Telnyx::Models::PortingOrderMessaging

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_order_messaging.rb

Defined Under Namespace

Modules: MessagingPortStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enable_messaging: nil, messaging_capable: nil, messaging_port_completed: nil, messaging_port_status: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortingOrderMessaging for more details.

Information about messaging porting process.

Parameters:

  • enable_messaging (Boolean) (defaults to: nil)

    Indicates whether Telnyx will port messaging capabilities from the losing carrie

  • messaging_capable (Boolean) (defaults to: nil)

    Indicates whether the porting order can also port messaging capabilities.

  • messaging_port_completed (Boolean) (defaults to: nil)

    Indicates whether the messaging porting has been completed.

  • messaging_port_status (Symbol, Telnyx::Models::PortingOrderMessaging::MessagingPortStatus) (defaults to: nil)

    The current status of the messaging porting.



# File 'lib/telnyx/models/porting_order_messaging.rb', line 32

Instance Attribute Details

#enable_messagingBoolean?

Indicates whether Telnyx will port messaging capabilities from the losing carrier. If false, any messaging capabilities will stay with their current provider.

Returns:

  • (Boolean, nil)


12
# File 'lib/telnyx/models/porting_order_messaging.rb', line 12

optional :enable_messaging, Telnyx::Internal::Type::Boolean

#messaging_capableBoolean?

Indicates whether the porting order can also port messaging capabilities.

Returns:

  • (Boolean, nil)


18
# File 'lib/telnyx/models/porting_order_messaging.rb', line 18

optional :messaging_capable, Telnyx::Internal::Type::Boolean

#messaging_port_completedBoolean?

Indicates whether the messaging porting has been completed.

Returns:

  • (Boolean, nil)


24
# File 'lib/telnyx/models/porting_order_messaging.rb', line 24

optional :messaging_port_completed, Telnyx::Internal::Type::Boolean

#messaging_port_statusSymbol, ...

The current status of the messaging porting.



30
# File 'lib/telnyx/models/porting_order_messaging.rb', line 30

optional :messaging_port_status, enum: -> { Telnyx::PortingOrderMessaging::MessagingPortStatus }