Class: Telnyx::Models::PortingOrderMisc

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_order_misc.rb

Defined Under Namespace

Modules: RemainingNumbersAction

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(new_billing_phone_number: nil, remaining_numbers_action: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortingOrderMisc for more details.

Parameters:

  • new_billing_phone_number (String, nil) (defaults to: nil)

    New billing phone number for the remaining numbers. Used in case the current bil

  • remaining_numbers_action (Symbol, Telnyx::Models::PortingOrderMisc::RemainingNumbersAction, nil) (defaults to: nil)

    Remaining numbers can be either kept with their current service provider or disc

  • type (Symbol, Telnyx::Models::PortingOrderType) (defaults to: nil)

    A port can be either ‘full’ or ‘partial’. When type is ‘full’ the other attribut



# File 'lib/telnyx/models/porting_order_misc.rb', line 32

Instance Attribute Details

#new_billing_phone_numberString?

New billing phone number for the remaining numbers. Used in case the current billing phone number is being ported to Telnyx. This will be set on your account with your current service provider and should be one of the numbers remaining on that account.

Returns:

  • (String, nil)


13
# File 'lib/telnyx/models/porting_order_misc.rb', line 13

optional :new_billing_phone_number, String, nil?: true

#remaining_numbers_actionSymbol, ...

Remaining numbers can be either kept with their current service provider or disconnected. ‘new_billing_telephone_number’ is required when ‘remaining_numbers_action’ is ‘keep’.



21
22
23
# File 'lib/telnyx/models/porting_order_misc.rb', line 21

optional :remaining_numbers_action,
enum: -> { Telnyx::PortingOrderMisc::RemainingNumbersAction },
nil?: true

#typeSymbol, ...

A port can be either ‘full’ or ‘partial’. When type is ‘full’ the other attributes should be omitted.

Returns:



30
# File 'lib/telnyx/models/porting_order_misc.rb', line 30

optional :type, enum: -> { Telnyx::PortingOrderType }