Class: Telnyx::Models::PortingOrderPhoneNumberConfiguration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_order_phone_number_configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_group_id: nil, connection_id: nil, emergency_address_id: nil, messaging_profile_id: nil, tags: nil) ⇒ Object

Parameters:

  • billing_group_id (String, nil) (defaults to: nil)

    identifies the billing group to set on the numbers when ported

  • connection_id (String, nil) (defaults to: nil)

    identifies the connection to set on the numbers when ported

  • emergency_address_id (String, nil) (defaults to: nil)

    identifies the emergency address to set on the numbers when ported

  • messaging_profile_id (String, nil) (defaults to: nil)

    identifies the messaging profile to set on the numbers when ported

  • tags (Array<String>) (defaults to: nil)


# File 'lib/telnyx/models/porting_order_phone_number_configuration.rb', line 35

Instance Attribute Details

#billing_group_idString?

identifies the billing group to set on the numbers when ported

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/porting_order_phone_number_configuration.rb', line 10

optional :billing_group_id, String, nil?: true

#connection_idString?

identifies the connection to set on the numbers when ported

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/porting_order_phone_number_configuration.rb', line 16

optional :connection_id, String, nil?: true

#emergency_address_idString?

identifies the emergency address to set on the numbers when ported

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/porting_order_phone_number_configuration.rb', line 22

optional :emergency_address_id, String, nil?: true

#messaging_profile_idString?

identifies the messaging profile to set on the numbers when ported

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/porting_order_phone_number_configuration.rb', line 28

optional :messaging_profile_id, String, nil?: true

#tagsArray<String>?

Returns:

  • (Array<String>, nil)


33
# File 'lib/telnyx/models/porting_order_phone_number_configuration.rb', line 33

optional :tags, Telnyx::Internal::Type::ArrayOf[String]