Class: Telnyx::Models::PortingOrderRetrieveAllowedFocWindowsResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_order_retrieve_allowed_foc_windows_response.rb,
sig/telnyx/models/porting_order_retrieve_allowed_foc_windows_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ended_at: nil, record_type: nil, started_at: nil) ⇒ Object



22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/telnyx/models/porting_order_retrieve_allowed_foc_windows_response.rb', line 22

class Data < Telnyx::Internal::Type::BaseModel
  response_only do
    # @!attribute ended_at
    #   ISO 8601 formatted date indicating the end of the range of foc window
    #
    #   @return [Time, nil]
    optional :ended_at, Time

    # @!attribute record_type
    #   Identifies the type of the resource.
    #
    #   @return [String, nil]
    optional :record_type, String

    # @!attribute started_at
    #   ISO 8601 formatted date indicating the start of the range of foc window.
    #
    #   @return [Time, nil]
    optional :started_at, Time
  end

  # @!method initialize(ended_at: nil, record_type: nil, started_at: nil)
  #   @param ended_at [Time] ISO 8601 formatted date indicating the end of the range of foc window
  #
  #   @param record_type [String] Identifies the type of the resource.
  #
  #   @param started_at [Time] ISO 8601 formatted date indicating the start of the range of foc window.
end

Instance Attribute Details

#ended_atTime? (readonly)

Returns the value of attribute ended_at.



33
34
35
# File 'sig/telnyx/models/porting_order_retrieve_allowed_foc_windows_response.rbs', line 33

def ended_at
  @ended_at
end

#record_typeString? (readonly)

Returns the value of attribute record_type.



37
38
39
# File 'sig/telnyx/models/porting_order_retrieve_allowed_foc_windows_response.rbs', line 37

def record_type
  @record_type
end

#started_atTime? (readonly)

Returns the value of attribute started_at.



41
42
43
# File 'sig/telnyx/models/porting_order_retrieve_allowed_foc_windows_response.rbs', line 41

def started_at
  @started_at
end

Instance Method Details

#ended_at=Time (readonly)



35
# File 'sig/telnyx/models/porting_order_retrieve_allowed_foc_windows_response.rbs', line 35

def ended_at=: (Time) -> Time

#record_type=String (readonly)



39
# File 'sig/telnyx/models/porting_order_retrieve_allowed_foc_windows_response.rbs', line 39

def record_type=: (String) -> String

#started_at=Time (readonly)



43
# File 'sig/telnyx/models/porting_order_retrieve_allowed_foc_windows_response.rbs', line 43

def started_at=: (Time) -> Time

#to_hash{



51
# File 'sig/telnyx/models/porting_order_retrieve_allowed_foc_windows_response.rbs', line 51

def to_hash: -> {