Class: Telnyx::Models::PortingOrderRetrieveSubRequestResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_order_retrieve_sub_request_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(port_request_id: nil, sub_request_id: nil) ⇒ Object

Parameters:

  • port_request_id (String) (defaults to: nil)

    Identifies the Port Request associated with the Porting Order

  • sub_request_id (String) (defaults to: nil)

    Identifies the Sub Request associated with the Porting Order



# File 'lib/telnyx/models/porting_order_retrieve_sub_request_response.rb', line 29

Instance Attribute Details

#port_request_idString?

Identifies the Port Request associated with the Porting Order

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/porting_order_retrieve_sub_request_response.rb', line 21

optional :port_request_id, String

#sub_request_idString?

Identifies the Sub Request associated with the Porting Order

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/porting_order_retrieve_sub_request_response.rb', line 27

optional :sub_request_id, String