Class: Telnyx::Models::PortingOrderUpdateParams
Overview
Defined Under Namespace
Classes: ActivationSettings, Messaging, Requirement
Constant Summary
collapse
- Telnyx =
Instance Attribute Summary collapse
#request_options
Instance Method Summary
collapse
dump_request
included
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(enable_messaging: nil) ⇒ Object
Some parameter documentations has been truncated, see
Messaging for more details.
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 122
|
Instance Attribute Details
18
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 18
optional :activation_settings, -> { Telnyx::PortingOrderUpdateParams::ActivationSettings }
|
#customer_group_reference ⇒ String?
23
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 23
optional :customer_group_reference, String
|
#customer_reference ⇒ String?
28
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 28
optional :customer_reference, String
|
Can be specified directly or via the requirement_group_id parameter.
34
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 34
optional :documents, -> { Telnyx::PortingOrderDocuments }
|
39
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 39
optional :end_user, -> { Telnyx::PortingOrderEndUser }
|
#id ⇒ String
13
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 13
required :id, String
|
44
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 44
optional :messaging, -> { Telnyx::PortingOrderUpdateParams::Messaging }
|
49
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 49
optional :misc, -> { Telnyx::PortingOrderMisc }, nil?: true
|
54
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 54
optional :phone_number_configuration, -> { Telnyx::PortingOrderPhoneNumberConfiguration }
|
#requirement_group_id ⇒ String?
If present, we will read the current values from the specified Requirement Group
into the Documents and Requirements for this Porting Order. Note that any future
changes in the Requirement Group would have no impact on this Porting Order. We
will return an error if a specified Requirement Group conflicts with documents
or requirements in the same request.
64
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 64
optional :requirement_group_id, String
|
List of requirements for porting numbers.
70
71
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 70
optional :requirements,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::PortingOrderUpdateParams::Requirement] }
|
76
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 76
optional :user_feedback, -> { Telnyx::PortingOrderUserFeedback }
|
#webhook_url ⇒ String?
81
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 81
optional :webhook_url, String
|
Instance Method Details
#to_hash ⇒ {
104
|
# File 'sig/telnyx/models/porting_order_update_params.rbs', line 104
def to_hash: -> {
|