Class: Telnyx::Models::PortingOrderUpdateParams::Messaging

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_order_update_params.rb,
sig/telnyx/models/porting_order_update_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeMessaging

Returns a new instance of Messaging.

Parameters:

  • enable_messaging: (Boolean)


140
# File 'sig/telnyx/models/porting_order_update_params.rbs', line 140

def initialize: (?enable_messaging: bool) -> void

Instance Attribute Details

#enable_messagingBoolean?

Indicates whether Telnyx will port messaging capabilities from the losing carrier. If false, any messaging capabilities will stay with their current provider.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


133
# File 'lib/telnyx/models/porting_order_update_params.rb', line 133

optional :enable_messaging, Telnyx::Internal::Type::Boolean

Instance Method Details

#to_hash{ enable_messaging: bool }

Returns:

  • ({ enable_messaging: bool })


142
# File 'sig/telnyx/models/porting_order_update_params.rbs', line 142

def to_hash: -> { enable_messaging: bool }