Class: Telnyx::Models::PortingOrderUpdateParams::Requirement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_order_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(field_value:, requirement_type_id:) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortingOrderUpdateParams::Requirement for more details.

Specifies a value for a requirement on the Porting Order.

Parameters:

  • field_value (String)

    identifies the document or provides the text value that satisfies this requireme

  • requirement_type_id (String)

    Identifies the requirement type that the ‘field_value` fulfills



# File 'lib/telnyx/models/porting_order_update_params.rb', line 156

Instance Attribute Details

#field_valueString

identifies the document or provides the text value that satisfies this requirement

Returns:

  • (String)


148
# File 'lib/telnyx/models/porting_order_update_params.rb', line 148

required :field_value, String

#requirement_type_idString

Identifies the requirement type that the ‘field_value` fulfills

Returns:

  • (String)


154
# File 'lib/telnyx/models/porting_order_update_params.rb', line 154

required :requirement_type_id, String