Class: Telnyx::Models::PortingOrders::ActionRequirementInitiateResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::ActionRequirementInitiateResponse::Data
- Defined in:
- lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb
Overview
Defined Under Namespace
Modules: RecordType, Status
Instance Attribute Summary collapse
-
#action_type ⇒ String?
The type of action required.
-
#action_url ⇒ String?
Optional URL for the action.
-
#cancel_reason ⇒ String?
Reason for cancellation if status is ‘cancelled’.
-
#created_at ⇒ Time?
ISO 8601 formatted date-time indicating when the resource was created.
-
#id ⇒ String?
Identifies the action requirement.
-
#porting_order_id ⇒ String?
The ID of the porting order this action requirement belongs to.
-
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
-
#requirement_type_id ⇒ String?
The ID of the requirement type.
-
#status ⇒ Symbol, ...
Current status of the action requirement.
-
#updated_at ⇒ Time?
ISO 8601 formatted date-time indicating when the resource was updated.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, action_type: nil, action_url: nil, cancel_reason: nil, created_at: nil, porting_order_id: nil, record_type: nil, requirement_type_id: nil, status: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 80
|
Instance Attribute Details
#action_type ⇒ String?
The type of action required
28 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 28 optional :action_type, String |
#action_url ⇒ String?
Optional URL for the action
34 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 34 optional :action_url, String, nil?: true |
#cancel_reason ⇒ String?
Reason for cancellation if status is ‘cancelled’
40 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 40 optional :cancel_reason, String, nil?: true |
#created_at ⇒ Time?
ISO 8601 formatted date-time indicating when the resource was created
46 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 46 optional :created_at, Time |
#id ⇒ String?
Identifies the action requirement
22 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 22 optional :id, String |
#porting_order_id ⇒ String?
The ID of the porting order this action requirement belongs to
52 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 52 optional :porting_order_id, String |
#record_type ⇒ Symbol, ...
Identifies the type of the resource
58 59 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 58 optional :record_type, enum: -> { Telnyx::Models::PortingOrders::ActionRequirementInitiateResponse::Data::RecordType } |
#requirement_type_id ⇒ String?
The ID of the requirement type
65 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 65 optional :requirement_type_id, String |
#status ⇒ Symbol, ...
Current status of the action requirement
71 72 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 71 optional :status, enum: -> { Telnyx::Models::PortingOrders::ActionRequirementInitiateResponse::Data::Status } |
#updated_at ⇒ Time?
ISO 8601 formatted date-time indicating when the resource was updated
78 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 78 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_response.rb', line 109
|