Class: Telnyx::Models::PortingOrders::ActionRequirementListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders/action_requirement_list_response.rb

Overview

Defined Under Namespace

Modules: RecordType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, action_type: nil, action_url: nil, cancel_reason: nil, created_at: nil, porting_order_id: nil, record_type: nil, requirement_type_id: nil, status: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Identifies the action requirement

  • action_type (String) (defaults to: nil)

    The type of action required

  • action_url (String, nil) (defaults to: nil)

    Optional URL for the action

  • cancel_reason (String, nil) (defaults to: nil)

    Reason for cancellation if status is ‘cancelled’

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created

  • porting_order_id (String) (defaults to: nil)

    The ID of the porting order this action requirement belongs to

  • record_type (Symbol, Telnyx::Models::PortingOrders::ActionRequirementListResponse::RecordType) (defaults to: nil)

    Identifies the type of the resource

  • requirement_type_id (String) (defaults to: nil)

    The ID of the requirement type

  • status (Symbol, Telnyx::Models::PortingOrders::ActionRequirementListResponse::Status) (defaults to: nil)

    Current status of the action requirement

  • updated_at (Time) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated



# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 69

Instance Attribute Details

#action_typeString?

The type of action required

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 18

optional :action_type, String

#action_urlString?

Optional URL for the action

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 24

optional :action_url, String, nil?: true

#cancel_reasonString?

Reason for cancellation if status is ‘cancelled’

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 30

optional :cancel_reason, String, nil?: true

#created_atTime?

ISO 8601 formatted date-time indicating when the resource was created

Returns:

  • (Time, nil)


36
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 36

optional :created_at, Time

#idString?

Identifies the action requirement

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 12

optional :id, String

#porting_order_idString?

The ID of the porting order this action requirement belongs to

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 42

optional :porting_order_id, String

#record_typeSymbol, ...

Identifies the type of the resource



48
49
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 48

optional :record_type,
enum: -> { Telnyx::Models::PortingOrders::ActionRequirementListResponse::RecordType }

#requirement_type_idString?

The ID of the requirement type

Returns:

  • (String, nil)


55
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 55

optional :requirement_type_id, String

#statusSymbol, ...

Current status of the action requirement



61
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 61

optional :status, enum: -> { Telnyx::Models::PortingOrders::ActionRequirementListResponse::Status }

#updated_atTime?

ISO 8601 formatted date-time indicating when the resource was updated

Returns:

  • (Time, nil)


67
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 67

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 98