Module: Telnyx::Models::PortingOrders::ActionShareResponse::Data::Permission

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/porting_orders/action_share_response.rb

Constant Summary collapse

PORTING_ORDER_DOCUMENT_READ =
:"porting_order.document.read"
PORTING_ORDER_DOCUMENT_UPDATE =
:"porting_order.document.update"

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/porting_orders/action_share_response.rb', line 92

Instance Method Details

#initialize(id: nil, token: nil, created_at: nil, expires_at: nil, expires_in_seconds: nil, permissions: nil, porting_order_id: nil, record_type: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies this sharing token

  • token (String) (defaults to: nil)

    A signed JWT token that can be used to access the shared resource

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • expires_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the sharing token expires.

  • expires_in_seconds (Integer) (defaults to: nil)

    The number of seconds until the sharing token expires

  • permissions (Array<Symbol, Telnyx::Models::PortingOrders::ActionShareResponse::Data::Permission>) (defaults to: nil)

    The permissions granted to the sharing token

  • porting_order_id (String) (defaults to: nil)

    Identifies the porting order resource being shared

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.



86
87
88
89
90
91
92
93
94
# File 'lib/telnyx/models/porting_orders/action_share_response.rb', line 86

module Permission
  extend Telnyx::Internal::Type::Enum

  PORTING_ORDER_DOCUMENT_READ = :"porting_order.document.read"
  PORTING_ORDER_DOCUMENT_UPDATE = :"porting_order.document.update"

  # @!method self.values
  #   @return [Array<Symbol>]
end