Class: Telnyx::Models::PortingOrders::AssociatedPhoneNumberCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::AssociatedPhoneNumberCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/porting_orders/associated_phone_number_create_params.rb
Overview
Defined Under Namespace
Modules: Action Classes: PhoneNumberRange
Instance Attribute Summary collapse
-
#action ⇒ Symbol, Telnyx::Models::PortingOrders::AssociatedPhoneNumberCreateParams::Action
Specifies the action to take with this phone number during partial porting.
- #phone_number_range ⇒ Telnyx::Models::PortingOrders::AssociatedPhoneNumberCreateParams::PhoneNumberRange
- #porting_order_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(porting_order_id:, action:, phone_number_range:, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(porting_order_id:, action:, phone_number_range:, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/porting_orders/associated_phone_number_create_params.rb', line 28
|
Instance Attribute Details
#action ⇒ Symbol, Telnyx::Models::PortingOrders::AssociatedPhoneNumberCreateParams::Action
Specifies the action to take with this phone number during partial porting.
20 |
# File 'lib/telnyx/models/porting_orders/associated_phone_number_create_params.rb', line 20 required :action, enum: -> { Telnyx::PortingOrders::AssociatedPhoneNumberCreateParams::Action } |
#phone_number_range ⇒ Telnyx::Models::PortingOrders::AssociatedPhoneNumberCreateParams::PhoneNumberRange
25 26 |
# File 'lib/telnyx/models/porting_orders/associated_phone_number_create_params.rb', line 25 required :phone_number_range, -> { Telnyx::PortingOrders::AssociatedPhoneNumberCreateParams::PhoneNumberRange } |
#porting_order_id ⇒ String
14 |
# File 'lib/telnyx/models/porting_orders/associated_phone_number_create_params.rb', line 14 required :porting_order_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/porting_orders/associated_phone_number_create_params.rb', line 44
|