Class: Telnyx::Models::PortingOrders::AssociatedPhoneNumberCreateParams::PhoneNumberRange
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::AssociatedPhoneNumberCreateParams::PhoneNumberRange
- Defined in:
- lib/telnyx/models/porting_orders/associated_phone_number_create_params.rb
Instance Attribute Summary collapse
-
#end_at ⇒ String?
Specifies the end of the phone number range for this associated phone number.
-
#start_at ⇒ String?
Specifies the start of the phone number range for this associated phone number.
Instance Method Summary collapse
- #initialize(end_at: nil, start_at: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_at: nil, start_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/porting_orders/associated_phone_number_create_params.rb', line 61
|
Instance Attribute Details
#end_at ⇒ String?
Specifies the end of the phone number range for this associated phone number.
53 |
# File 'lib/telnyx/models/porting_orders/associated_phone_number_create_params.rb', line 53 optional :end_at, String |
#start_at ⇒ String?
Specifies the start of the phone number range for this associated phone number.
59 |
# File 'lib/telnyx/models/porting_orders/associated_phone_number_create_params.rb', line 59 optional :start_at, String |