Class: Telnyx::Models::PortingOrders::CommentCreateResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders/comment_create_response.rb

Overview

See Also:

Defined Under Namespace

Modules: UserType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, body: nil, created_at: nil, porting_order_id: nil, record_type: nil, user_type: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)
  • body (String) (defaults to: nil)

    Body of comment

  • created_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • porting_order_id (String) (defaults to: nil)
  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • user_type (Symbol, Telnyx::Models::PortingOrders::CommentCreateResponse::Data::UserType) (defaults to: nil)

    Indicates whether this comment was created by a Telnyx Admin, user, or system



# File 'lib/telnyx/models/porting_orders/comment_create_response.rb', line 52

Instance Attribute Details

#bodyString?

Body of comment

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/porting_orders/comment_create_response.rb', line 27

optional :body, String

#created_atTime?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (Time, nil)


33
# File 'lib/telnyx/models/porting_orders/comment_create_response.rb', line 33

optional :created_at, Time

#idString?

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/porting_orders/comment_create_response.rb', line 21

optional :id, String

#porting_order_idString?

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/porting_orders/comment_create_response.rb', line 38

optional :porting_order_id, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/porting_orders/comment_create_response.rb', line 44

optional :record_type, String

#user_typeSymbol, ...

Indicates whether this comment was created by a Telnyx Admin, user, or system



50
# File 'lib/telnyx/models/porting_orders/comment_create_response.rb', line 50

optional :user_type, enum: -> { Telnyx::Models::PortingOrders::CommentCreateResponse::Data::UserType }