Class: Telnyx::Models::PortingOrders::PhoneNumberBlockCreateParams::PhoneNumberRange

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders/phone_number_block_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_at:, start_at:) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortingOrders::PhoneNumberBlockCreateParams::PhoneNumberRange for more details.

Parameters:

  • end_at (String)

    Specifies the end of the phone number range for this porting phone number block.

  • start_at (String)

    Specifies the start of the phone number range for this porting phone number bloc



# File 'lib/telnyx/models/porting_orders/phone_number_block_create_params.rb', line 81

Instance Attribute Details

#end_atString

Specifies the end of the phone number range for this porting phone number block.

Returns:

  • (String)


72
# File 'lib/telnyx/models/porting_orders/phone_number_block_create_params.rb', line 72

required :end_at, String

#start_atString

Specifies the start of the phone number range for this porting phone number block.

Returns:

  • (String)


79
# File 'lib/telnyx/models/porting_orders/phone_number_block_create_params.rb', line 79

required :start_at, String