Class: Telnyx::Models::PortingOrders::PhoneNumberConfigurationCreateParams::PhoneNumberConfiguration

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/telnyx/models/porting_orders/phone_number_configuration_create_params.rb,
sig/telnyx/models/porting_orders/phone_number_configuration_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(porting_phone_number_id:, user_bundle_id:) ⇒ Object

Parameters:

  • Identifies the porting phone number to be configured.

  • Identifies the user bundle to be associated with the porting phone number.



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
# File 'lib/telnyx/models/porting_orders/phone_number_configuration_create_params.rb', line 21

class PhoneNumberConfiguration < Telnyx::Internal::Type::BaseModel
  # @!attribute porting_phone_number_id
  #   Identifies the porting phone number to be configured.
  #
  #   @return [String]
  required :porting_phone_number_id, String

  # @!attribute user_bundle_id
  #   Identifies the user bundle to be associated with the porting phone number.
  #
  #   @return [String]
  required :user_bundle_id, String

  # @!method initialize(porting_phone_number_id:, user_bundle_id:)
  #   @param porting_phone_number_id [String] Identifies the porting phone number to be configured.
  #
  #   @param user_bundle_id [String] Identifies the user bundle to be associated with the porting phone number.
end

Instance Attribute Details

#porting_phone_number_idString

Identifies the porting phone number to be configured.

Parameters:

Returns:



26
# File 'lib/telnyx/models/porting_orders/phone_number_configuration_create_params.rb', line 26

required :porting_phone_number_id, String

#user_bundle_idString

Identifies the user bundle to be associated with the porting phone number.

Parameters:

Returns:



32
# File 'lib/telnyx/models/porting_orders/phone_number_configuration_create_params.rb', line 32

required :user_bundle_id, String

Instance Method Details

#to_hash{

Returns:



43
# File 'sig/telnyx/models/porting_orders/phone_number_configuration_create_params.rbs', line 43

def to_hash: -> {