Class: Telnyx::Models::PortingOrders::PhoneNumberExtensionCreateParams::ActivationRange

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders/phone_number_extension_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(porting_order_id:, activation_ranges:, extension_range:, porting_phone_number_id:, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortingOrders::PhoneNumberExtensionCreateParams for more details.

Parameters:



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/telnyx/models/porting_orders/phone_number_extension_create_params.rb', line 52

class ActivationRange < Telnyx::Internal::Type::BaseModel
  # @!attribute end_at
  #   Specifies the end of the activation range. It must be no more than the end of
  #   the extension range.
  #
  #   @return [Integer]
  required :end_at, Integer

  # @!attribute start_at
  #   Specifies the start of the activation range. Must be greater or equal the start
  #   of the extension range.
  #
  #   @return [Integer]
  required :start_at, Integer

  # @!method initialize(end_at:, start_at:)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::PortingOrders::PhoneNumberExtensionCreateParams::ActivationRange}
  #   for more details.
  #
  #   @param end_at [Integer] Specifies the end of the activation range. It must be no more than the end of th
  #
  #   @param start_at [Integer] Specifies the start of the activation range. Must be greater or equal the start
end

Instance Attribute Details

#end_atInteger

Specifies the end of the activation range. It must be no more than the end of the extension range.

Returns:

  • (Integer)


58
# File 'lib/telnyx/models/porting_orders/phone_number_extension_create_params.rb', line 58

required :end_at, Integer

#start_atInteger

Specifies the start of the activation range. Must be greater or equal the start of the extension range.

Returns:

  • (Integer)


65
# File 'lib/telnyx/models/porting_orders/phone_number_extension_create_params.rb', line 65

required :start_at, Integer