Class: Telnyx::Models::PortingOrders::PortingAssociatedPhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders/porting_associated_phone_number.rb,
sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs

Overview

See Also:

  • Telnyx::Resources::PortingOrders::AssociatedPhoneNumbers#list

Defined Under Namespace

Modules: Action, PhoneNumberType Classes: PhoneNumberRange

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_at: nil, start_at: nil) ⇒ Object

Specifies the phone number range for this associated phone number.

Parameters:

  • end_at (String) (defaults to: nil)

    Specifies the end of the phone number range for this associated phone number.

  • start_at (String) (defaults to: nil)

    Specifies the start of the phone number range for this associated phone number.



# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 66

Instance Attribute Details

#actionSymbol, ...

Specifies the action to take with this phone number during partial porting.



12
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 12

optional :action, enum: -> { Telnyx::PortingOrders::PortingAssociatedPhoneNumber::Action }

#country_codeString?

Specifies the country code for this associated phone number. It is a two-letter ISO 3166-1 alpha-2 country code.

Parameters:

  • (String)

Returns:

  • (String, nil)


19
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 19

optional :country_code, String

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


48
49
50
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 48

def created_at
  @created_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


44
45
46
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 44

def id
  @id
end

#phone_number_rangeTelnyx::Models::PortingOrders::PortingAssociatedPhoneNumber::PhoneNumberRange?

Specifies the phone number range for this associated phone number.



25
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 25

optional :phone_number_range, -> { Telnyx::PortingOrders::PortingAssociatedPhoneNumber::PhoneNumberRange }

#phone_number_typeSymbol, ...

Specifies the phone number type for this associated phone number.



31
32
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 31

optional :phone_number_type,
enum: -> { Telnyx::PortingOrders::PortingAssociatedPhoneNumber::PhoneNumberType }

#porting_order_idString?

Identifies the porting order associated with this phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 38

optional :porting_order_id, String

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


52
53
54
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 52

def record_type
  @record_type
end

#updated_atTime? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (Time, nil)


56
57
58
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 56

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 97

Instance Method Details

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


50
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 50

def created_at=: (Time) -> Time

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


46
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 46

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


54
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 54

def record_type=: (String) -> String

#to_hash{

Returns:

  • ({)


72
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 72

def to_hash: -> {

#updated_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


58
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 58

def updated_at=: (Time) -> Time