Class: Telnyx::Models::PortingOrders::PortingAssociatedPhoneNumber::PhoneNumberRange

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders/porting_associated_phone_number.rb,
sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs

Overview

See Also:

  • Telnyx::Models::PortingOrders::PortingAssociatedPhoneNumber#phone_number_range

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializePhoneNumberRange

Returns a new instance of PhoneNumberRange.

Parameters:

  • end_at: (String)
  • start_at: (String)


106
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 106

def initialize: (?end_at: String, ?start_at: String) -> void

Instance Attribute Details

#end_atString?

Specifies the end of the phone number range for this associated phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


107
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 107

optional :end_at, String

#start_atString?

Specifies the start of the phone number range for this associated phone number.

Parameters:

  • (String)

Returns:

  • (String, nil)


113
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 113

optional :start_at, String

Instance Method Details

#to_hash{ end_at: String, start_at: String }

Returns:

  • ({ end_at: String, start_at: String })


108
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 108

def to_hash: -> { end_at: String, start_at: String }