Class: Telnyx::Models::PortingOrders::PortingPhoneNumberBlock

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders/porting_phone_number_block.rb,
sig/telnyx/models/porting_orders/porting_phone_number_block.rbs

Overview

See Also:

  • Telnyx::Resources::PortingOrders::PhoneNumberBlocks#list

Defined Under Namespace

Modules: PhoneNumberType Classes: ActivationRange, PhoneNumberRange

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_at: nil, start_at: nil) ⇒ Object

Some parameter documentations has been truncated, see PhoneNumberRange for more details.

Specifies the phone number range for this porting phone number block.

Parameters:

  • end_at (String) (defaults to: nil)

    Specifies the end of the phone number range for this porting phone number block.

  • start_at (String) (defaults to: nil)

    Specifies the start of the phone number range for this porting phone number bloc



# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 97

Instance Attribute Details

#activation_rangesArray<Telnyx::Models::PortingOrders::PortingPhoneNumberBlock::ActivationRange>?

Specifies the activation ranges for this porting phone number block. The activation range must be within the phone number range and should not overlap with other activation ranges.



14
15
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 14

optional :activation_ranges,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::PortingOrders::PortingPhoneNumberBlock::ActivationRange] }

#country_codeString?

Specifies the country code for this porting phone number block. It is a two-letter ISO 3166-1 alpha-2 country code.

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 22

optional :country_code, String

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


43
44
45
# File 'sig/telnyx/models/porting_orders/porting_phone_number_block.rbs', line 43

def created_at
  @created_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


39
40
41
# File 'sig/telnyx/models/porting_orders/porting_phone_number_block.rbs', line 39

def id
  @id
end

#phone_number_rangeTelnyx::Models::PortingOrders::PortingPhoneNumberBlock::PhoneNumberRange?

Specifies the phone number range for this porting phone number block.



28
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 28

optional :phone_number_range, -> { Telnyx::PortingOrders::PortingPhoneNumberBlock::PhoneNumberRange }

#phone_number_typeSymbol, ...

Specifies the phone number type for this porting phone number block.



34
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 34

optional :phone_number_type, enum: -> { Telnyx::PortingOrders::PortingPhoneNumberBlock::PhoneNumberType }

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


47
48
49
# File 'sig/telnyx/models/porting_orders/porting_phone_number_block.rbs', line 47

def record_type
  @record_type
end

#updated_atTime? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (Time, nil)


51
52
53
# File 'sig/telnyx/models/porting_orders/porting_phone_number_block.rbs', line 51

def updated_at
  @updated_at
end

Instance Method Details

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


45
# File 'sig/telnyx/models/porting_orders/porting_phone_number_block.rbs', line 45

def created_at=: (Time) -> Time

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


41
# File 'sig/telnyx/models/porting_orders/porting_phone_number_block.rbs', line 41

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


49
# File 'sig/telnyx/models/porting_orders/porting_phone_number_block.rbs', line 49

def record_type=: (String) -> String

#to_hash{

Returns:

  • ({)


66
# File 'sig/telnyx/models/porting_orders/porting_phone_number_block.rbs', line 66

def to_hash: -> {

#updated_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


53
# File 'sig/telnyx/models/porting_orders/porting_phone_number_block.rbs', line 53

def updated_at=: (Time) -> Time