Class: Telnyx::Models::PortingOrders::PortingPhoneNumberExtension
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::PortingPhoneNumberExtension
- Defined in:
- lib/telnyx/models/porting_orders/porting_phone_number_extension.rb,
sig/telnyx/models/porting_orders/porting_phone_number_extension.rbs
Overview
Defined Under Namespace
Classes: ActivationRange, ExtensionRange
Instance Attribute Summary collapse
-
#activation_ranges ⇒ Array<Telnyx::Models::PortingOrders::PortingPhoneNumberExtension::ActivationRange>?
Specifies the activation ranges for this porting phone number extension.
-
#created_at ⇒ Time?
readonly
Returns the value of attribute created_at.
-
#extension_range ⇒ Telnyx::Models::PortingOrders::PortingPhoneNumberExtension::ExtensionRange?
Specifies the extension range for this porting phone number extension.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#porting_phone_number_id ⇒ String?
Identifies the porting phone number associated with this porting phone number extension.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#updated_at ⇒ Time?
readonly
Returns the value of attribute updated_at.
Instance Method Summary collapse
- #created_at ⇒ Time readonly
- #id ⇒ String readonly
-
#initialize(end_at: nil, start_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActivationRange for more details.
- #record_type ⇒ String readonly
- #to_hash ⇒ {
- #updated_at ⇒ Time readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_at: nil, start_at: nil) ⇒ Object
Some parameter documentations has been truncated, see ActivationRange for more details.
|
|
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 89
|
Instance Attribute Details
#activation_ranges ⇒ Array<Telnyx::Models::PortingOrders::PortingPhoneNumberExtension::ActivationRange>?
Specifies the activation ranges for this porting phone number extension. The activation range must be within the extension range and should not overlap with other activation ranges.
14 15 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 14 optional :activation_ranges, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PortingOrders::PortingPhoneNumberExtension::ActivationRange] } |
#created_at ⇒ Time? (readonly)
Returns the value of attribute created_at.
36 37 38 |
# File 'sig/telnyx/models/porting_orders/porting_phone_number_extension.rbs', line 36 def created_at @created_at end |
#extension_range ⇒ Telnyx::Models::PortingOrders::PortingPhoneNumberExtension::ExtensionRange?
Specifies the extension range for this porting phone number extension.
21 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 21 optional :extension_range, -> { Telnyx::PortingOrders::PortingPhoneNumberExtension::ExtensionRange } |
#id ⇒ String? (readonly)
Returns the value of attribute id.
32 33 34 |
# File 'sig/telnyx/models/porting_orders/porting_phone_number_extension.rbs', line 32 def id @id end |
#porting_phone_number_id ⇒ String?
Identifies the porting phone number associated with this porting phone number extension.
28 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 28 optional :porting_phone_number_id, String |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
40 41 42 |
# File 'sig/telnyx/models/porting_orders/porting_phone_number_extension.rbs', line 40 def record_type @record_type end |
#updated_at ⇒ Time? (readonly)
Returns the value of attribute updated_at.
44 45 46 |
# File 'sig/telnyx/models/porting_orders/porting_phone_number_extension.rbs', line 44 def updated_at @updated_at end |
Instance Method Details
#created_at= ⇒ Time (readonly)
38 |
# File 'sig/telnyx/models/porting_orders/porting_phone_number_extension.rbs', line 38
def created_at=: (Time) -> Time
|
#id= ⇒ String (readonly)
34 |
# File 'sig/telnyx/models/porting_orders/porting_phone_number_extension.rbs', line 34
def id=: (String) -> String
|
#record_type= ⇒ String (readonly)
42 |
# File 'sig/telnyx/models/porting_orders/porting_phone_number_extension.rbs', line 42
def record_type=: (String) -> String
|
#to_hash ⇒ {
58 |
# File 'sig/telnyx/models/porting_orders/porting_phone_number_extension.rbs', line 58
def to_hash: -> {
|
#updated_at= ⇒ Time (readonly)
46 |
# File 'sig/telnyx/models/porting_orders/porting_phone_number_extension.rbs', line 46
def updated_at=: (Time) -> Time
|