Class: Telnyx::Models::PortingOrders::PortingPhoneNumberExtension::ExtensionRange

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders/porting_phone_number_extension.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_at: nil, start_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortingOrders::PortingPhoneNumberExtension::ExtensionRange for more details.

Specifies the extension range for this porting phone number extension.

Parameters:

  • end_at (Integer) (defaults to: nil)

    Specifies the end of the extension range for this porting phone number extension

  • start_at (Integer) (defaults to: nil)

    Specifies the start of the extension range for this porting phone number extensi



# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 115

Instance Attribute Details

#end_atInteger?

Specifies the end of the extension range for this porting phone number extension.

Returns:

  • (Integer, nil)


106
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 106

optional :end_at, Integer

#start_atInteger?

Specifies the start of the extension range for this porting phone number extension.

Returns:

  • (Integer, nil)


113
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 113

optional :start_at, Integer