Class: Telnyx::Models::PortingOrders::VerificationCodeVerifyResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::VerificationCodeVerifyResponse::Data
- Defined in:
- lib/telnyx/models/porting_orders/verification_code_verify_response.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
-
#id ⇒ String?
Uniquely identifies this porting verification code.
-
#phone_number ⇒ String?
E164 formatted phone number.
-
#porting_order_id ⇒ String?
Identifies the associated porting order.
-
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
-
#verified ⇒ Boolean?
Indicates whether the verification code has been verified.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, phone_number: nil, porting_order_id: nil, record_type: nil, updated_at: nil, verified: nil) ⇒ Object
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/telnyx/models/porting_orders/verification_code_verify_response.rb', line 17 class Data < Telnyx::Internal::Type::BaseModel # @!attribute id # Uniquely identifies this porting verification code # # @return [String, nil] optional :id, String # @!attribute created_at # ISO 8601 formatted date indicating when the resource was created. # # @return [Time, nil] optional :created_at, Time # @!attribute phone_number # E164 formatted phone number # # @return [String, nil] optional :phone_number, String # @!attribute porting_order_id # Identifies the associated porting order # # @return [String, nil] optional :porting_order_id, String # @!attribute updated_at # ISO 8601 formatted date indicating when the resource was updated. # # @return [Time, nil] optional :updated_at, Time # @!attribute verified # Indicates whether the verification code has been verified # # @return [Boolean, nil] optional :verified, Telnyx::Internal::Type::Boolean response_only do # @!attribute record_type # Identifies the type of the resource. # # @return [String, nil] optional :record_type, String end # @!method initialize(id: nil, created_at: nil, phone_number: nil, porting_order_id: nil, record_type: nil, updated_at: nil, verified: nil) # @param id [String] Uniquely identifies this porting verification code # # @param created_at [Time] ISO 8601 formatted date indicating when the resource was created. # # @param phone_number [String] E164 formatted phone number # # @param porting_order_id [String] Identifies the associated porting order # # @param record_type [String] Identifies the type of the resource. # # @param updated_at [Time] ISO 8601 formatted date indicating when the resource was updated. # # @param verified [Boolean] Indicates whether the verification code has been verified end |
Instance Attribute Details
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
28 |
# File 'lib/telnyx/models/porting_orders/verification_code_verify_response.rb', line 28 optional :created_at, Time |
#id ⇒ String?
Uniquely identifies this porting verification code
22 |
# File 'lib/telnyx/models/porting_orders/verification_code_verify_response.rb', line 22 optional :id, String |
#phone_number ⇒ String?
E164 formatted phone number
34 |
# File 'lib/telnyx/models/porting_orders/verification_code_verify_response.rb', line 34 optional :phone_number, String |
#porting_order_id ⇒ String?
Identifies the associated porting order
40 |
# File 'lib/telnyx/models/porting_orders/verification_code_verify_response.rb', line 40 optional :porting_order_id, String |
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
46 |
# File 'lib/telnyx/models/porting_orders/verification_code_verify_response.rb', line 46 optional :updated_at, Time |