Class: Telnyx::Models::PortingOrdersActivationJob

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders_activation_job.rb,
sig/telnyx/models/porting_orders_activation_job.rbs

Defined Under Namespace

Modules: ActivationType, Status Classes: ActivationWindow

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_at: nil, start_at: nil) ⇒ Object

Parameters:

  • end_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the activation window ends

  • start_at (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the activation window starts



# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 58

Instance Attribute Details

#activate_atTime?

ISO 8601 formatted date indicating when the activation job should be executed. This time should be between some activation window.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


11
# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 11

optional :activate_at, Time

#activation_typeSymbol, ...

Specifies the type of this activation job



17
# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 17

optional :activation_type, enum: -> { Telnyx::PortingOrdersActivationJob::ActivationType }

#activation_windowsArray<Telnyx::Models::PortingOrdersActivationJob::ActivationWindow>?

List of allowed activation windows for this activation job



23
24
# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 23

optional :activation_windows,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::PortingOrdersActivationJob::ActivationWindow] }

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


42
43
44
# File 'sig/telnyx/models/porting_orders_activation_job.rbs', line 42

def created_at
  @created_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


38
39
40
# File 'sig/telnyx/models/porting_orders_activation_job.rbs', line 38

def id
  @id
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


46
47
48
# File 'sig/telnyx/models/porting_orders_activation_job.rbs', line 46

def record_type
  @record_type
end

#statusSymbol, ...

Specifies the status of this activation job



30
# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 30

optional :status, enum: -> { Telnyx::PortingOrdersActivationJob::Status }

#updated_atTime? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (Time, nil)


50
51
52
# File 'sig/telnyx/models/porting_orders_activation_job.rbs', line 50

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 87

Instance Method Details

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


44
# File 'sig/telnyx/models/porting_orders_activation_job.rbs', line 44

def created_at=: (Time) -> Time

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


40
# File 'sig/telnyx/models/porting_orders_activation_job.rbs', line 40

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


48
# File 'sig/telnyx/models/porting_orders_activation_job.rbs', line 48

def record_type=: (String) -> String

#to_hash{

Returns:

  • ({)


65
# File 'sig/telnyx/models/porting_orders_activation_job.rbs', line 65

def to_hash: -> {

#updated_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


52
# File 'sig/telnyx/models/porting_orders_activation_job.rbs', line 52

def updated_at=: (Time) -> Time