Class: Telnyx::Models::PortingPhoneNumberListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_phone_number_list_response.rb

Overview

Defined Under Namespace

Modules: ActivationStatus, PhoneNumberType, PortabilityStatus, PortingOrderStatus, RequirementsStatus

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(activation_status: nil, phone_number: nil, phone_number_type: nil, portability_status: nil, porting_order_id: nil, porting_order_status: nil, record_type: nil, requirements_status: nil, support_key: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortingPhoneNumberListResponse for more details.

Parameters:



# File 'lib/telnyx/models/porting_phone_number_list_response.rb', line 67

Instance Attribute Details

#activation_statusSymbol, ...

Activation status



11
# File 'lib/telnyx/models/porting_phone_number_list_response.rb', line 11

optional :activation_status, enum: -> { Telnyx::Models::PortingPhoneNumberListResponse::ActivationStatus }

#phone_numberString?

E164 formatted phone number

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/porting_phone_number_list_response.rb', line 17

optional :phone_number, String

#phone_number_typeSymbol, ...

The type of the phone number



23
# File 'lib/telnyx/models/porting_phone_number_list_response.rb', line 23

optional :phone_number_type, enum: -> { Telnyx::Models::PortingPhoneNumberListResponse::PhoneNumberType }

#portability_statusSymbol, ...

Specifies whether Telnyx is able to confirm portability this number in the United States & Canada. International phone numbers are provisional by default.



30
31
# File 'lib/telnyx/models/porting_phone_number_list_response.rb', line 30

optional :portability_status,
enum: -> { Telnyx::Models::PortingPhoneNumberListResponse::PortabilityStatus }

#porting_order_idString?

Identifies the associated port request

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/porting_phone_number_list_response.rb', line 37

optional :porting_order_id, String

#porting_order_statusSymbol, ...

The current status of the porting order



43
44
# File 'lib/telnyx/models/porting_phone_number_list_response.rb', line 43

optional :porting_order_status,
enum: -> { Telnyx::Models::PortingPhoneNumberListResponse::PortingOrderStatus }

#requirements_statusSymbol, ...

The current status of the requirements in a INTL porting order



50
51
# File 'lib/telnyx/models/porting_phone_number_list_response.rb', line 50

optional :requirements_status,
enum: -> { Telnyx::Models::PortingPhoneNumberListResponse::RequirementsStatus }

#support_keyString?

A key to reference this porting order when contacting Telnyx customer support

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/porting_phone_number_list_response.rb', line 57

optional :support_key, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/porting_phone_number_list_response.rb', line 109