Class: Telnyx::Models::PortoutDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/portout_details.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, already_ported: nil, authorized_name: nil, carrier_name: nil, city: nil, created_at: nil, current_carrier: nil, end_user_name: nil, foc_date: nil, host_messaging: nil, inserted_at: nil, lsr: nil, phone_numbers: nil, pon: nil, reason: nil, record_type: nil, rejection_code: nil, requested_foc_date: nil, service_address: nil, spid: nil, state: nil, status: nil, support_key: nil, updated_at: nil, user_id: nil, vendor: nil, zip: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortoutDetails for more details.

Parameters:

  • id (String) (defaults to: nil)
  • already_ported (Boolean) (defaults to: nil)

    Is true when the number is already ported

  • authorized_name (String) (defaults to: nil)

    Name of person authorizing the porting order

  • carrier_name (String) (defaults to: nil)

    Carrier the number will be ported out to

  • city (String) (defaults to: nil)

    City or municipality of billing address

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the portout was created

  • current_carrier (String) (defaults to: nil)

    The current carrier

  • end_user_name (String) (defaults to: nil)

    Person name or company name requesting the port

  • foc_date (String) (defaults to: nil)

    ISO 8601 formatted Date/Time of the FOC date

  • host_messaging (Boolean) (defaults to: nil)

    Indicates whether messaging services should be maintained with Telnyx after the

  • inserted_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the portout was created

  • lsr (Array<String>) (defaults to: nil)

    The Local Service Request

  • phone_numbers (Array<String>) (defaults to: nil)

    Phone numbers associated with this portout

  • pon (String) (defaults to: nil)

    Port order number assigned by the carrier the number will be ported out to

  • reason (String, nil) (defaults to: nil)

    The reason why the order is being rejected by the user. If the order is authoriz

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • rejection_code (Integer) (defaults to: nil)

    The rejection code for one of the valid rejections to reject a port out order

  • requested_foc_date (String) (defaults to: nil)

    ISO 8601 formatted Date/Time of the user requested FOC date

  • service_address (String) (defaults to: nil)

    First line of billing address (street address)

  • spid (String) (defaults to: nil)

    New service provider spid

  • state (String) (defaults to: nil)

    State, province, or similar of billing address

  • status (Symbol, Telnyx::Models::PortoutDetails::Status) (defaults to: nil)

    Status of portout request

  • support_key (String) (defaults to: nil)

    A key to reference this port out request when contacting Telnyx customer support

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the portout was last updated

  • user_id (String) (defaults to: nil)

    Identifies the user (or organization) who requested the port out

  • vendor (String) (defaults to: nil)

    Telnyx partner providing network coverage

  • zip (String) (defaults to: nil)

    Postal Code of billing address



# File 'lib/telnyx/models/portout_details.rb', line 172

Instance Attribute Details

#already_portedBoolean?

Is true when the number is already ported

Returns:

  • (Boolean, nil)


16
# File 'lib/telnyx/models/portout_details.rb', line 16

optional :already_ported, Telnyx::Internal::Type::Boolean

#authorized_nameString?

Name of person authorizing the porting order

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/portout_details.rb', line 22

optional :authorized_name, String

#carrier_nameString?

Carrier the number will be ported out to

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/portout_details.rb', line 28

optional :carrier_name, String

#cityString?

City or municipality of billing address

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/portout_details.rb', line 34

optional :city, String

#created_atString?

ISO 8601 formatted date of when the portout was created

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/portout_details.rb', line 40

optional :created_at, String

#current_carrierString?

The current carrier

Returns:

  • (String, nil)


46
# File 'lib/telnyx/models/portout_details.rb', line 46

optional :current_carrier, String

#end_user_nameString?

Person name or company name requesting the port

Returns:

  • (String, nil)


52
# File 'lib/telnyx/models/portout_details.rb', line 52

optional :end_user_name, String

#foc_dateString?

ISO 8601 formatted Date/Time of the FOC date

Returns:

  • (String, nil)


58
# File 'lib/telnyx/models/portout_details.rb', line 58

optional :foc_date, String

#host_messagingBoolean?

Indicates whether messaging services should be maintained with Telnyx after the port out completes

Returns:

  • (Boolean, nil)


65
# File 'lib/telnyx/models/portout_details.rb', line 65

optional :host_messaging, Telnyx::Internal::Type::Boolean

#idString?

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/portout_details.rb', line 10

optional :id, String

#inserted_atString?

ISO 8601 formatted date of when the portout was created

Returns:

  • (String, nil)


71
# File 'lib/telnyx/models/portout_details.rb', line 71

optional :inserted_at, String

#lsrArray<String>?

The Local Service Request

Returns:

  • (Array<String>, nil)


77
# File 'lib/telnyx/models/portout_details.rb', line 77

optional :lsr, Telnyx::Internal::Type::ArrayOf[String]

#phone_numbersArray<String>?

Phone numbers associated with this portout

Returns:

  • (Array<String>, nil)


83
# File 'lib/telnyx/models/portout_details.rb', line 83

optional :phone_numbers, Telnyx::Internal::Type::ArrayOf[String]

#ponString?

Port order number assigned by the carrier the number will be ported out to

Returns:

  • (String, nil)


89
# File 'lib/telnyx/models/portout_details.rb', line 89

optional :pon, String

#reasonString?

The reason why the order is being rejected by the user. If the order is authorized, this field can be left null

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/portout_details.rb', line 96

optional :reason, String, nil?: true

#rejection_codeInteger?

The rejection code for one of the valid rejections to reject a port out order

Returns:

  • (Integer, nil)


102
# File 'lib/telnyx/models/portout_details.rb', line 102

optional :rejection_code, Integer

#requested_foc_dateString?

ISO 8601 formatted Date/Time of the user requested FOC date

Returns:

  • (String, nil)


108
# File 'lib/telnyx/models/portout_details.rb', line 108

optional :requested_foc_date, String

#service_addressString?

First line of billing address (street address)

Returns:

  • (String, nil)


114
# File 'lib/telnyx/models/portout_details.rb', line 114

optional :service_address, String

#spidString?

New service provider spid

Returns:

  • (String, nil)


120
# File 'lib/telnyx/models/portout_details.rb', line 120

optional :spid, String

#stateString?

State, province, or similar of billing address

Returns:

  • (String, nil)


126
# File 'lib/telnyx/models/portout_details.rb', line 126

optional :state, String

#statusSymbol, ...

Status of portout request

Returns:



132
# File 'lib/telnyx/models/portout_details.rb', line 132

optional :status, enum: -> { Telnyx::PortoutDetails::Status }

#support_keyString?

A key to reference this port out request when contacting Telnyx customer support

Returns:

  • (String, nil)


138
# File 'lib/telnyx/models/portout_details.rb', line 138

optional :support_key, String

#updated_atString?

ISO 8601 formatted date of when the portout was last updated

Returns:

  • (String, nil)


144
# File 'lib/telnyx/models/portout_details.rb', line 144

optional :updated_at, String

#user_idString?

Identifies the user (or organization) who requested the port out

Returns:

  • (String, nil)


150
# File 'lib/telnyx/models/portout_details.rb', line 150

optional :user_id, String

#vendorString?

Telnyx partner providing network coverage

Returns:

  • (String, nil)


156
# File 'lib/telnyx/models/portout_details.rb', line 156

optional :vendor, String

#zipString?

Postal Code of billing address

Returns:

  • (String, nil)


162
# File 'lib/telnyx/models/portout_details.rb', line 162

optional :zip, String