Class: Telnyx::Models::PortoutUpdateStatusParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortoutUpdateStatusParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/portout_update_status_params.rb,
sig/telnyx/models/portout_update_status_params.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#host_messaging ⇒ Boolean?
Indicates whether messaging services should be maintained with Telnyx after the port out completes.
- #id ⇒ String
-
#reason ⇒ String
Provide a reason if rejecting the port out request.
- #status ⇒ Symbol, Telnyx::Models::PortoutUpdateStatusParams::Status
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
26 |
# File 'sig/telnyx/models/portout_update_status_params.rbs', line 26
def initialize: (
|
Instance Attribute Details
#host_messaging ⇒ Boolean?
Indicates whether messaging services should be maintained with Telnyx after the port out completes
31 |
# File 'lib/telnyx/models/portout_update_status_params.rb', line 31 optional :host_messaging, Telnyx::Internal::Type::Boolean |
#id ⇒ String
13 |
# File 'lib/telnyx/models/portout_update_status_params.rb', line 13 required :id, String |
#reason ⇒ String
Provide a reason if rejecting the port out request
24 |
# File 'lib/telnyx/models/portout_update_status_params.rb', line 24 required :reason, String |
#status ⇒ Symbol, Telnyx::Models::PortoutUpdateStatusParams::Status
18 |
# File 'lib/telnyx/models/portout_update_status_params.rb', line 18 required :status, enum: -> { Telnyx::PortoutUpdateStatusParams::Status } |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/telnyx/models/portout_update_status_params.rbs', line 34
def to_hash: -> {
|