Module: Telnyx::Models::PortoutUpdateStatusParams::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/portout_update_status_params.rb

Constant Summary collapse

AUTHORIZED =
:authorized
REJECTED_PENDING =
:"rejected-pending"

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/portout_update_status_params.rb', line 53

Instance Method Details

#initialize(id:, status:, reason:, host_messaging: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortoutUpdateStatusParams for more details.

Parameters:

  • id (String)
  • status (Symbol, Telnyx::Models::PortoutUpdateStatusParams::Status)
  • reason (String)

    Provide a reason if rejecting the port out request

  • host_messaging (Boolean) (defaults to: nil)

    Indicates whether messaging services should be maintained with Telnyx after the

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


47
48
49
50
51
52
53
54
55
# File 'lib/telnyx/models/portout_update_status_params.rb', line 47

module Status
  extend Telnyx::Internal::Type::Enum

  AUTHORIZED = :authorized
  REJECTED_PENDING = :"rejected-pending"

  # @!method self.values
  #   @return [Array<Symbol>]
end