Class: Telnyx::Models::Portouts::CommentListResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Portouts::CommentListResponse::Data
- Defined in:
- lib/telnyx/models/portouts/comment_list_response.rb
Instance Attribute Summary collapse
-
#body ⇒ String
Comment body.
-
#created_at ⇒ String
Comment creation timestamp in ISO 8601 format.
- #id ⇒ String
-
#portout_id ⇒ String?
Identifies the associated port request.
-
#user_id ⇒ String
Identifies the user who created the comment.
Instance Method Summary collapse
-
#initialize(id:, body:, created_at:, user_id:, portout_id: nil, record_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, body:, created_at:, user_id:, portout_id: nil, record_type: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Portouts::CommentListResponse::Data for more details.
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/telnyx/models/portouts/comment_list_response.rb', line 23 class Data < Telnyx::Internal::Type::BaseModel # @!attribute id # # @return [String] required :id, String # @!attribute body # Comment body # # @return [String] required :body, String # @!attribute created_at # Comment creation timestamp in ISO 8601 format # # @return [String] required :created_at, String # @!attribute user_id # Identifies the user who created the comment. Will be null if created by Telnyx # Admin # # @return [String] required :user_id, String # @!attribute portout_id # Identifies the associated port request # # @return [String, nil] optional :portout_id, String response_only do # @!attribute record_type # Identifies the type of the resource. # # @return [String, nil] optional :record_type, String end # @!method initialize(id:, body:, created_at:, user_id:, portout_id: nil, record_type: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::Portouts::CommentListResponse::Data} for more details. # # @param id [String] # # @param body [String] Comment body # # @param created_at [String] Comment creation timestamp in ISO 8601 format # # @param user_id [String] Identifies the user who created the comment. Will be null if created by Telnyx A # # @param portout_id [String] Identifies the associated port request # # @param record_type [String] Identifies the type of the resource. end |
Instance Attribute Details
#body ⇒ String
Comment body
33 |
# File 'lib/telnyx/models/portouts/comment_list_response.rb', line 33 required :body, String |
#created_at ⇒ String
Comment creation timestamp in ISO 8601 format
39 |
# File 'lib/telnyx/models/portouts/comment_list_response.rb', line 39 required :created_at, String |
#id ⇒ String
27 |
# File 'lib/telnyx/models/portouts/comment_list_response.rb', line 27 required :id, String |
#portout_id ⇒ String?
Identifies the associated port request
52 |
# File 'lib/telnyx/models/portouts/comment_list_response.rb', line 52 optional :portout_id, String |
#user_id ⇒ String
Identifies the user who created the comment. Will be null if created by Telnyx Admin
46 |
# File 'lib/telnyx/models/portouts/comment_list_response.rb', line 46 required :user_id, String |