Class: Telnyx::Models::Portouts::EventListResponse::WebhookPortoutStatusChanged::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Portouts::EventListResponse::WebhookPortoutStatusChanged::Payload
- Defined in:
- lib/telnyx/models/portouts/event_list_response.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#attempted_pin ⇒ String?
The PIN that was attempted to be used to authorize the port out.
-
#carrier_name ⇒ String?
Carrier the number will be ported out to.
-
#id ⇒ String?
Identifies the port out that was moved.
-
#phone_numbers ⇒ Array<String>?
Phone numbers associated with this port-out order.
-
#rejection_reason ⇒ String?
The reason why the order is being rejected by the user.
-
#spid ⇒ String?
The new carrier SPID.
-
#status ⇒ Symbol, ...
The new status of the port out.
-
#subscriber_name ⇒ String?
The name of the port-out’s end user.
-
#user_id ⇒ String?
Identifies the user that the port-out order belongs to.
Instance Method Summary collapse
-
#initialize(id: nil, attempted_pin: nil, carrier_name: nil, phone_numbers: nil, rejection_reason: nil, spid: nil, status: nil, subscriber_name: nil, user_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, attempted_pin: nil, carrier_name: nil, phone_numbers: nil, rejection_reason: nil, spid: nil, status: nil, subscriber_name: nil, user_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Portouts::EventListResponse::WebhookPortoutStatusChanged::Payload for more details.
The webhook payload for the portout.status_changed event
|
|
# File 'lib/telnyx/models/portouts/event_list_response.rb', line 184
|
Instance Attribute Details
#attempted_pin ⇒ String?
The PIN that was attempted to be used to authorize the port out.
138 |
# File 'lib/telnyx/models/portouts/event_list_response.rb', line 138 optional :attempted_pin, String |
#carrier_name ⇒ String?
Carrier the number will be ported out to
144 |
# File 'lib/telnyx/models/portouts/event_list_response.rb', line 144 optional :carrier_name, String |
#id ⇒ String?
Identifies the port out that was moved.
132 |
# File 'lib/telnyx/models/portouts/event_list_response.rb', line 132 optional :id, String |
#phone_numbers ⇒ Array<String>?
Phone numbers associated with this port-out order
150 |
# File 'lib/telnyx/models/portouts/event_list_response.rb', line 150 optional :phone_numbers, Telnyx::Internal::Type::ArrayOf[String] |
#rejection_reason ⇒ String?
The reason why the order is being rejected by the user. If the order is authorized, this field can be left null
157 |
# File 'lib/telnyx/models/portouts/event_list_response.rb', line 157 optional :rejection_reason, String, nil?: true |
#spid ⇒ String?
The new carrier SPID.
163 |
# File 'lib/telnyx/models/portouts/event_list_response.rb', line 163 optional :spid, String |
#status ⇒ Symbol, ...
The new status of the port out.
169 170 |
# File 'lib/telnyx/models/portouts/event_list_response.rb', line 169 optional :status, enum: -> { Telnyx::Models::Portouts::EventListResponse::WebhookPortoutStatusChanged::Payload::Status } |
#subscriber_name ⇒ String?
The name of the port-out’s end user.
176 |
# File 'lib/telnyx/models/portouts/event_list_response.rb', line 176 optional :subscriber_name, String |
#user_id ⇒ String?
Identifies the user that the port-out order belongs to.
182 |
# File 'lib/telnyx/models/portouts/event_list_response.rb', line 182 optional :user_id, String |