Class: Telnyx::Models::Portouts::EventRetrieveResponse::Data::WebhookPortoutStatusChanged::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Portouts::EventRetrieveResponse::Data::WebhookPortoutStatusChanged::Payload
- Defined in:
- lib/telnyx/models/portouts/event_retrieve_response.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#attempted_pin ⇒ String?
The PIN that was attempted to be used to authorize the port out.
-
#carrier_name ⇒ String?
Carrier the number will be ported out to.
-
#id ⇒ String?
Identifies the port out that was moved.
-
#phone_numbers ⇒ Array<String>?
Phone numbers associated with this port-out order.
-
#rejection_reason ⇒ String?
The reason why the order is being rejected by the user.
-
#spid ⇒ String?
The new carrier SPID.
-
#status ⇒ Symbol, ...
The new status of the port out.
-
#subscriber_name ⇒ String?
The name of the port-out’s end user.
-
#user_id ⇒ String?
Identifies the user that the port-out order belongs to.
Instance Method Summary collapse
-
#initialize(id: nil, attempted_pin: nil, carrier_name: nil, phone_numbers: nil, rejection_reason: nil, spid: nil, status: nil, subscriber_name: nil, user_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, attempted_pin: nil, carrier_name: nil, phone_numbers: nil, rejection_reason: nil, spid: nil, status: nil, subscriber_name: nil, user_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Portouts::EventRetrieveResponse::Data::WebhookPortoutStatusChanged::Payload for more details.
The webhook payload for the portout.status_changed event
|
|
# File 'lib/telnyx/models/portouts/event_retrieve_response.rb', line 194
|
Instance Attribute Details
#attempted_pin ⇒ String?
The PIN that was attempted to be used to authorize the port out.
148 |
# File 'lib/telnyx/models/portouts/event_retrieve_response.rb', line 148 optional :attempted_pin, String |
#carrier_name ⇒ String?
Carrier the number will be ported out to
154 |
# File 'lib/telnyx/models/portouts/event_retrieve_response.rb', line 154 optional :carrier_name, String |
#id ⇒ String?
Identifies the port out that was moved.
142 |
# File 'lib/telnyx/models/portouts/event_retrieve_response.rb', line 142 optional :id, String |
#phone_numbers ⇒ Array<String>?
Phone numbers associated with this port-out order
160 |
# File 'lib/telnyx/models/portouts/event_retrieve_response.rb', line 160 optional :phone_numbers, Telnyx::Internal::Type::ArrayOf[String] |
#rejection_reason ⇒ String?
The reason why the order is being rejected by the user. If the order is authorized, this field can be left null
167 |
# File 'lib/telnyx/models/portouts/event_retrieve_response.rb', line 167 optional :rejection_reason, String, nil?: true |
#spid ⇒ String?
The new carrier SPID.
173 |
# File 'lib/telnyx/models/portouts/event_retrieve_response.rb', line 173 optional :spid, String |
#status ⇒ Symbol, ...
The new status of the port out.
179 180 |
# File 'lib/telnyx/models/portouts/event_retrieve_response.rb', line 179 optional :status, enum: -> { Telnyx::Models::Portouts::EventRetrieveResponse::Data::WebhookPortoutStatusChanged::Payload::Status } |
#subscriber_name ⇒ String?
The name of the port-out’s end user.
186 |
# File 'lib/telnyx/models/portouts/event_retrieve_response.rb', line 186 optional :subscriber_name, String |
#user_id ⇒ String?
Identifies the user that the port-out order belongs to.
192 |
# File 'lib/telnyx/models/portouts/event_retrieve_response.rb', line 192 optional :user_id, String |