Class: Telnyx::Models::Portouts::WebhookPortoutNewComment::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Portouts::WebhookPortoutNewComment::Payload
- Defined in:
- lib/telnyx/models/portouts/webhook_portout_new_comment.rb,
sig/telnyx/models/portouts/webhook_portout_new_comment.rbs
Overview
Instance Attribute Summary collapse
-
#comment ⇒ String?
The body of the comment.
-
#id ⇒ String?
Identifies the comment that was added to the port-out order.
-
#portout_id ⇒ String?
Identifies the port-out order that the comment was added to.
-
#user_id ⇒ String?
Identifies the user that added the comment.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
132 |
# File 'sig/telnyx/models/portouts/webhook_portout_new_comment.rbs', line 132
def initialize: (
|
Instance Attribute Details
#comment ⇒ String?
The body of the comment.
119 |
# File 'lib/telnyx/models/portouts/webhook_portout_new_comment.rb', line 119 optional :comment, String |
#id ⇒ String?
Identifies the comment that was added to the port-out order.
113 |
# File 'lib/telnyx/models/portouts/webhook_portout_new_comment.rb', line 113 optional :id, String |
#portout_id ⇒ String?
Identifies the port-out order that the comment was added to.
125 |
# File 'lib/telnyx/models/portouts/webhook_portout_new_comment.rb', line 125 optional :portout_id, String |
#user_id ⇒ String?
Identifies the user that added the comment.
131 |
# File 'lib/telnyx/models/portouts/webhook_portout_new_comment.rb', line 131 optional :user_id, String |
Instance Method Details
#to_hash ⇒ {
139 |
# File 'sig/telnyx/models/portouts/webhook_portout_new_comment.rbs', line 139
def to_hash: -> {
|