Class: Telnyx::Models::PrivateWirelessGateway

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/private_wireless_gateway.rb,
sig/telnyx/models/private_wireless_gateway.rbs

Overview

See Also:

  • Telnyx::Resources::PrivateWirelessGateways#list

Constant Summary collapse

Telnyx =

Returns:

  • (:PrivateWirelessGatewayStatus)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, assigned_resources: nil, created_at: nil, ip_range: nil, name: nil, network_id: nil, record_type: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PrivateWirelessGateway for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • assigned_resources (Array<Telnyx::Models::PwgAssignedResourcesSummary>) (defaults to: nil)

    A list of the resources that have been assigned to the Private Wireless Gateway.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • ip_range (String) (defaults to: nil)

    IP block used to assign IPs to the SIM cards in the Private Wireless Gateway.

  • name (String) (defaults to: nil)

    The private wireless gateway name.

  • network_id (String) (defaults to: nil)

    The identification of the related network resource.

  • record_type (String) (defaults to: nil)
  • region_code (String) (defaults to: nil)

    The name of the region where the Private Wireless Gateway is deployed.

  • status (Telnyx::Models::PrivateWirelessGatewayStatus) (defaults to: nil)

    The current status or failure details of the Private Wireless Gateway.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/private_wireless_gateway.rb', line 68

Instance Attribute Details

#assigned_resourcesArray<Telnyx::Models::PwgAssignedResourcesSummary>?

A list of the resources that have been assigned to the Private Wireless Gateway.



11
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 11

optional :assigned_resources, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PwgAssignedResourcesSummary] }

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


46
47
48
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 46

def created_at
  @created_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


42
43
44
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 42

def id
  @id
end

#ip_rangeString? (readonly)

Returns the value of attribute ip_range.

Returns:

  • (String, nil)


50
51
52
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 50

def ip_range
  @ip_range
end

#nameString?

The private wireless gateway name.

Parameters:

  • (String)

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 17

optional :name, String

#network_idString?

The identification of the related network resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 23

optional :network_id, String

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


54
55
56
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 54

def record_type
  @record_type
end

#region_codeString?

The name of the region where the Private Wireless Gateway is deployed.

Parameters:

  • (String)

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 29

optional :region_code, String

#statusTelnyx::Models::PrivateWirelessGatewayStatus?

The current status or failure details of the Private Wireless Gateway.



35
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 35

optional :status, -> { Telnyx::PrivateWirelessGatewayStatus }

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


58
59
60
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 58

def updated_at
  @updated_at
end

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


48
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 48

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


44
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 44

def id=: (String) -> String

#ip_range=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


52
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 52

def ip_range=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


56
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 56

def record_type=: (String) -> String

#to_hash{

Returns:

  • ({)


75
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 75

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


60
# File 'sig/telnyx/models/private_wireless_gateway.rbs', line 60

def updated_at=: (String) -> String