Module: Telnyx::Models::PrivateWirelessGatewayStatus::Value
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/private_wireless_gateway_status.rb,
sig/telnyx/models/private_wireless_gateway_status.rbs
Overview
The current status or failure details of the Private Wireless Gateway.
provisioning- the Private Wireless Gateway is being provisioned.provisioned- the Private Wireless Gateway was provisioned and able to receive connections.failed- the provisioning had failed for a reason and it requires an intervention.decommissioning- the Private Wireless Gateway is being removed from the network.
Constant Summary collapse
- PROVISIONING =
:provisioning- PROVISIONED =
:provisioned- FAILED =
:failed- DECOMMISSIONING =
:decommissioning
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/private_wireless_gateway_status.rb', line 65
|
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::PrivateWirelessGatewayStatus::value]
43 |
# File 'sig/telnyx/models/private_wireless_gateway_status.rbs', line 43
def self?.values: -> ::Array[Telnyx::Models::PrivateWirelessGatewayStatus::value]
|