Class: Telnyx::Models::PublicInternetGateway

Inherits:
Record show all
Defined in:
lib/telnyx/models/public_internet_gateway.rb,
sig/telnyx/models/public_internet_gateway.rbs

Instance Attribute Summary collapse

Attributes inherited from Record

#created_at, #id, #record_type, #updated_at

Instance Method Summary collapse

Methods inherited from Record

#created_at=, #id=, #record_type=, #updated_at=

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil, network_id: nil, region_code: nil) ⇒ Object

Parameters:

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • region_code (String) (defaults to: nil)

    The region interface is deployed to.



# File 'lib/telnyx/models/public_internet_gateway.rb', line 24

Instance Attribute Details

#nameString?

A user specified name for the interface.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/public_internet_gateway.rb', line 10

optional :name, String

#network_idString?

The id of the network associated with the interface.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/public_internet_gateway.rb', line 16

optional :network_id, String

#region_codeString?

The region interface is deployed to.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/public_internet_gateway.rb', line 22

optional :region_code, String

Instance Method Details

#to_hash{

Returns:

  • ({)


31
# File 'sig/telnyx/models/public_internet_gateway.rbs', line 31

def to_hash: -> {