Class: Telnyx::Models::PublicInternetGatewayCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/public_internet_gateway_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil, network_id: nil, region_code: nil, request_options: {}) ⇒ Object

Parameters:

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • region_code (String) (defaults to: nil)

    The region interface is deployed to.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/public_internet_gateway_create_params.rb', line 28

Instance Attribute Details

#nameString?

A user specified name for the interface.

Returns:

  • (String, nil)


14
# File 'lib/telnyx/models/public_internet_gateway_create_params.rb', line 14

optional :name, String

#network_idString?

The id of the network associated with the interface.

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/public_internet_gateway_create_params.rb', line 20

optional :network_id, String

#region_codeString?

The region interface is deployed to.

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/public_internet_gateway_create_params.rb', line 26

optional :region_code, String