Class: Telnyx::Models::PublicInternetGatewayRead

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/public_internet_gateway_read.rb,
sig/telnyx/models/public_internet_gateway_read.rbs

Overview

See Also:

  • Telnyx::Resources::PublicInternetGateways#list

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, name: nil, network_id: nil, public_ip: nil, record_type: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • public_ip (String) (defaults to: nil)

    The publically accessible ip for this interface.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • region_code (String) (defaults to: nil)

    The region interface is deployed to.

  • status (Symbol, Telnyx::Models::InterfaceStatus) (defaults to: nil)

    The current status of the interface deployment.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 63

Instance Attribute Details

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


33
34
35
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 33

def created_at
  @created_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


29
30
31
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 29

def id
  @id
end

#nameString?

A user specified name for the interface.

Parameters:

  • (String)

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 11

optional :name, String

#network_idString?

The id of the network associated with the interface.

Parameters:

  • (String)

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 17

optional :network_id, String

#public_ipString? (readonly)

Returns the value of attribute public_ip.

Returns:

  • (String, nil)


37
38
39
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 37

def public_ip
  @public_ip
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


41
42
43
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 41

def record_type
  @record_type
end

#region_codeString?

The region interface is deployed to.

Parameters:

  • (String)

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 23

optional :region_code, String

#statusTelnyx::Models::interface_status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::interface_status, nil)


45
46
47
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 45

def status
  @status
end

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


51
52
53
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 51

def updated_at
  @updated_at
end

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


35
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 35

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


31
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 31

def id=: (String) -> String

#public_ip=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


39
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 39

def public_ip=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


43
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 43

def record_type=: (String) -> String

#status=Object (readonly)



47
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 47

def status=: (

#to_hash{

Returns:

  • ({)


67
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 67

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


53
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 53

def updated_at=: (String) -> String