Class: Telnyx::Models::PushCredential

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/push_credential.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, alias_:, certificate:, created_at:, private_key:, project_account_json_file:, record_type:, type:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PushCredential for more details.

Parameters:

  • id (String)

    Unique identifier of a push credential

  • alias_ (String)

    Alias to uniquely identify a credential

  • certificate (String)

    Apple certificate for sending push notifications. For iOS only

  • created_at (Time)

    ISO 8601 timestamp when the room was created

  • private_key (String)

    Apple private key for a given certificate for sending push notifications. For iO

  • project_account_json_file (Hash{Symbol=>Object})

    Google server key for sending push notifications. For Android only

  • record_type (String)
  • type (String)

    Type of mobile push credential. Either ios or android

  • updated_at (Time)

    ISO 8601 timestamp when the room was updated.



# File 'lib/telnyx/models/push_credential.rb', line 63

Instance Attribute Details

#alias_String

Alias to uniquely identify a credential

Returns:

  • (String)


17
# File 'lib/telnyx/models/push_credential.rb', line 17

required :alias_, String, api_name: :alias

#certificateString

Apple certificate for sending push notifications. For iOS only

Returns:

  • (String)


23
# File 'lib/telnyx/models/push_credential.rb', line 23

required :certificate, String

#created_atTime

ISO 8601 timestamp when the room was created

Returns:

  • (Time)


29
# File 'lib/telnyx/models/push_credential.rb', line 29

required :created_at, Time

#idString

Unique identifier of a push credential

Returns:

  • (String)


11
# File 'lib/telnyx/models/push_credential.rb', line 11

required :id, String

#private_keyString

Apple private key for a given certificate for sending push notifications. For iOS only

Returns:

  • (String)


36
# File 'lib/telnyx/models/push_credential.rb', line 36

required :private_key, String

#project_account_json_fileHash{Symbol=>Object}

Google server key for sending push notifications. For Android only

Returns:

  • (Hash{Symbol=>Object})


42
# File 'lib/telnyx/models/push_credential.rb', line 42

required :project_account_json_file, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#typeString

Type of mobile push credential. Either ios or android

Returns:

  • (String)


48
# File 'lib/telnyx/models/push_credential.rb', line 48

required :type, String

#updated_atTime

ISO 8601 timestamp when the room was updated.

Returns:

  • (Time)


54
# File 'lib/telnyx/models/push_credential.rb', line 54

required :updated_at, Time