Class: Telnyx::Models::PwgAssignedResourcesSummary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/pwg_assigned_resources_summary.rb,
sig/telnyx/models/pwg_assigned_resources_summary.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(count: nil, record_type: nil) ⇒ PwgAssignedResourcesSummary

The summary of the resource that have been assigned to the Private Wireless Gateway.

Parameters:

  • count (Integer) (defaults to: nil)

    The current count of a resource type assigned to the Private Wireless Gateway.

  • record_type (String) (defaults to: nil)

    The type of the resource assigned to the Private Wireless Gateway.

  • count: (Integer) (defaults to: nil)
  • record_type: (String) (defaults to: nil)


# File 'lib/telnyx/models/pwg_assigned_resources_summary.rb', line 20

Instance Attribute Details

#countInteger? (readonly)

Returns the value of attribute count.

Returns:

  • (Integer, nil)


7
8
9
# File 'sig/telnyx/models/pwg_assigned_resources_summary.rbs', line 7

def count
  @count
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


11
12
13
# File 'sig/telnyx/models/pwg_assigned_resources_summary.rbs', line 11

def record_type
  @record_type
end

Instance Method Details

#count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


9
# File 'sig/telnyx/models/pwg_assigned_resources_summary.rbs', line 9

def count=: (Integer) -> Integer

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


13
# File 'sig/telnyx/models/pwg_assigned_resources_summary.rbs', line 13

def record_type=: (String) -> String

#to_hash{ count: Integer, record_type: String }

Returns:

  • ({ count: Integer, record_type: String })


17
# File 'sig/telnyx/models/pwg_assigned_resources_summary.rbs', line 17

def to_hash: -> { count: Integer, record_type: String }