Class: Telnyx::Models::Queues::CallListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/queues/call_list_response.rb

Overview

Defined Under Namespace

Modules: RecordType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, call_leg_id:, call_session_id:, connection_id:, enqueued_at:, from:, queue_id:, queue_position:, record_type:, to:, wait_time_secs:, is_alive: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Queues::CallListResponse for more details.

Parameters:

  • call_control_id (String)

    Unique identifier and token for controlling the call.

  • call_leg_id (String)

    ID that is unique to the call and can be used to correlate webhook events

  • call_session_id (String)

    ID that is unique to the call session and can be used to correlate webhook event

  • connection_id (String)

    Call Control App ID (formerly Telnyx connection ID) used in the call.

  • enqueued_at (String)

    ISO 8601 formatted date of when the call was put in the queue

  • from (String)

    Number or SIP URI placing the call.

  • queue_id (String)

    Unique identifier of the queue the call is in.

  • queue_position (Integer)

    Current position of the call in the queue

  • record_type (Symbol, Telnyx::Models::Queues::CallListResponse::RecordType)
  • to (String)

    Destination number or SIP URI of the call.

  • wait_time_secs (Integer)

    The time the call has been waiting in the queue, given in seconds

  • is_alive (Boolean) (defaults to: nil)

    Indicates whether the call is still active in the queue.



# File 'lib/telnyx/models/queues/call_list_response.rb', line 81

Instance Attribute Details

#call_control_idString

Unique identifier and token for controlling the call.

Returns:

  • (String)


12
# File 'lib/telnyx/models/queues/call_list_response.rb', line 12

required :call_control_id, String

#call_leg_idString

ID that is unique to the call and can be used to correlate webhook events

Returns:

  • (String)


18
# File 'lib/telnyx/models/queues/call_list_response.rb', line 18

required :call_leg_id, String

#call_session_idString

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call

Returns:

  • (String)


26
# File 'lib/telnyx/models/queues/call_list_response.rb', line 26

required :call_session_id, String

#connection_idString

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String)


32
# File 'lib/telnyx/models/queues/call_list_response.rb', line 32

required :connection_id, String

#enqueued_atString

ISO 8601 formatted date of when the call was put in the queue

Returns:

  • (String)


38
# File 'lib/telnyx/models/queues/call_list_response.rb', line 38

required :enqueued_at, String

#fromString

Number or SIP URI placing the call.

Returns:

  • (String)


44
# File 'lib/telnyx/models/queues/call_list_response.rb', line 44

required :from, String

#is_aliveBoolean?

Indicates whether the call is still active in the queue.

Returns:

  • (Boolean, nil)


79
# File 'lib/telnyx/models/queues/call_list_response.rb', line 79

optional :is_alive, Telnyx::Internal::Type::Boolean

#queue_idString

Unique identifier of the queue the call is in.

Returns:

  • (String)


50
# File 'lib/telnyx/models/queues/call_list_response.rb', line 50

required :queue_id, String

#queue_positionInteger

Current position of the call in the queue

Returns:

  • (Integer)


56
# File 'lib/telnyx/models/queues/call_list_response.rb', line 56

required :queue_position, Integer

#record_typeSymbol, Telnyx::Models::Queues::CallListResponse::RecordType



61
# File 'lib/telnyx/models/queues/call_list_response.rb', line 61

required :record_type, enum: -> { Telnyx::Models::Queues::CallListResponse::RecordType }

#toString

Destination number or SIP URI of the call.

Returns:

  • (String)


67
# File 'lib/telnyx/models/queues/call_list_response.rb', line 67

required :to, String

#wait_time_secsInteger

The time the call has been waiting in the queue, given in seconds

Returns:

  • (Integer)


73
# File 'lib/telnyx/models/queues/call_list_response.rb', line 73

required :wait_time_secs, Integer