Class: Telnyx::Models::RcsAgentMessage::ContentMessage::RichCard::CarouselCard
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RcsAgentMessage::ContentMessage::RichCard::CarouselCard
- Defined in:
- lib/telnyx/models/rcs_agent_message.rb
Overview
Defined Under Namespace
Modules: CardWidth
Instance Attribute Summary collapse
-
#card_contents ⇒ Array<Telnyx::Models::RcsCardContent>
The list of contents for each card in the carousel.
-
#card_width ⇒ Symbol, Telnyx::Models::RcsAgentMessage::ContentMessage::RichCard::CarouselCard::CardWidth
The width of the cards in the carousel.
Instance Method Summary collapse
-
#initialize(card_contents:, card_width:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CarouselCard for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(card_contents:, card_width:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::RcsAgentMessage::ContentMessage::RichCard::CarouselCard for more details.
Carousel of cards.
|
|
# File 'lib/telnyx/models/rcs_agent_message.rb', line 106
|
Instance Attribute Details
#card_contents ⇒ Array<Telnyx::Models::RcsCardContent>
The list of contents for each card in the carousel. A carousel can have a minimum of 2 cards and a maximum 10 cards.
97 |
# File 'lib/telnyx/models/rcs_agent_message.rb', line 97 required :card_contents, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::RcsCardContent] } |
#card_width ⇒ Symbol, Telnyx::Models::RcsAgentMessage::ContentMessage::RichCard::CarouselCard::CardWidth
The width of the cards in the carousel.
103 104 |
# File 'lib/telnyx/models/rcs_agent_message.rb', line 103 required :card_width, enum: -> { Telnyx::RcsAgentMessage::ContentMessage::RichCard::CarouselCard::CardWidth } |