Class: Telnyx::Models::RcsSuggestion::Action

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/rcs_suggestion.rb

Overview

See Also:

Defined Under Namespace

Classes: CreateCalendarEventAction, DialAction, OpenURLAction, ViewLocationAction

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(phone_number:) ⇒ Object

Opens the user’s default dialer app with the agent-specified phone number filled in.

Parameters:

  • phone_number (String)

    Phone number in +E.164 format



# File 'lib/telnyx/models/rcs_suggestion.rb', line 77

Instance Attribute Details

#create_calendar_event_actionTelnyx::Models::RcsSuggestion::Action::CreateCalendarEventAction?

Opens the user’s default calendar app and starts the new calendar event flow with the agent-specified event data pre-filled.



29
# File 'lib/telnyx/models/rcs_suggestion.rb', line 29

optional :create_calendar_event_action, -> { Telnyx::RcsSuggestion::Action::CreateCalendarEventAction }

#dial_actionTelnyx::Models::RcsSuggestion::Action::DialAction?

Opens the user’s default dialer app with the agent-specified phone number filled in.



36
# File 'lib/telnyx/models/rcs_suggestion.rb', line 36

optional :dial_action, -> { Telnyx::RcsSuggestion::Action::DialAction }

#fallback_urlString?

Fallback URL to use if a client doesn’t support a suggested action. Fallback URLs open in new browser windows. Maximum 2048 characters.

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/rcs_suggestion.rb', line 43

optional :fallback_url, String

#open_url_actionTelnyx::Models::RcsSuggestion::Action::OpenURLAction?

Opens the user’s default web browser app to the specified URL.



49
# File 'lib/telnyx/models/rcs_suggestion.rb', line 49

optional :open_url_action, -> { Telnyx::RcsSuggestion::Action::OpenURLAction }

#postback_dataString?

Payload (base64 encoded) that will be sent to the agent in the user event that results when the user taps the suggested action. Maximum 2048 characters.

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/rcs_suggestion.rb', line 56

optional :postback_data, String

#share_location_actionHash{Symbol=>Object}?

Opens the RCS app’s location chooser so the user can pick a location to send back to the agent.

Returns:

  • (Hash{Symbol=>Object}, nil)


63
# File 'lib/telnyx/models/rcs_suggestion.rb', line 63

optional :share_location_action, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#textString?

Text that is shown in the suggested action. Maximum 25 characters.

Returns:

  • (String, nil)


69
# File 'lib/telnyx/models/rcs_suggestion.rb', line 69

optional :text, String

#view_location_actionTelnyx::Models::RcsSuggestion::Action::ViewLocationAction?

Opens the user’s default map app and selects the agent-specified location.



75
# File 'lib/telnyx/models/rcs_suggestion.rb', line 75

optional :view_location_action, -> { Telnyx::RcsSuggestion::Action::ViewLocationAction }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/rcs_suggestion.rb', line 209