Class: Telnyx::Models::RcsSuggestion::Reply
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RcsSuggestion::Reply
- Defined in:
- lib/telnyx/models/rcs_suggestion.rb
Overview
Instance Attribute Summary collapse
-
#postback_data ⇒ String?
Payload (base64 encoded) that will be sent to the agent in the user event that results when the user taps the suggested action.
-
#text ⇒ String?
Text that is shown in the suggested reply (maximum 25 characters).
Instance Method Summary collapse
-
#initialize(postback_data: nil, text: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Reply for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(postback_data: nil, text: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::RcsSuggestion::Reply for more details.
|
|
# File 'lib/telnyx/models/rcs_suggestion.rb', line 279
|
Instance Attribute Details
#postback_data ⇒ String?
Payload (base64 encoded) that will be sent to the agent in the user event that results when the user taps the suggested action. Maximum 2048 characters.
271 |
# File 'lib/telnyx/models/rcs_suggestion.rb', line 271 optional :postback_data, String |
#text ⇒ String?
Text that is shown in the suggested reply (maximum 25 characters)
277 |
# File 'lib/telnyx/models/rcs_suggestion.rb', line 277 optional :text, String |