Class: Telnyx::Models::RecordingResponseData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/recording_response_data.rb

Overview

Defined Under Namespace

Modules: Channels, RecordType, Source, Status Classes: DownloadURLs

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mp3: nil, wav: nil) ⇒ Object

Links to download the recording files.

Parameters:

  • mp3 (String) (defaults to: nil)

    Link to download the recording in mp3 format.

  • wav (String) (defaults to: nil)

    Link to download the recording in wav format.



# File 'lib/telnyx/models/recording_response_data.rb', line 127

Instance Attribute Details

#call_control_idString?

Unique identifier and token for controlling the call.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/recording_response_data.rb', line 17

optional :call_control_id, String

#call_leg_idString?

ID unique to the call leg (used to correlate webhook events).

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/recording_response_data.rb', line 23

optional :call_leg_id, String

#call_session_idString?

ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/recording_response_data.rb', line 31

optional :call_session_id, String

#channelsSymbol, ...

When ‘dual`, the final audio file has the first leg on channel A, and the rest on channel B.



38
# File 'lib/telnyx/models/recording_response_data.rb', line 38

optional :channels, enum: -> { Telnyx::RecordingResponseData::Channels }

#conference_idString?

Uniquely identifies the conference.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/recording_response_data.rb', line 44

optional :conference_id, String

#connection_idString?

Identifies the Telnyx application (Call Control, TeXML) or SIP connection resource associated with this recording.

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/recording_response_data.rb', line 51

optional :connection_id, String

#created_atString?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/recording_response_data.rb', line 57

optional :created_at, String

#download_urlsTelnyx::Models::RecordingResponseData::DownloadURLs?

Links to download the recording files.



63
# File 'lib/telnyx/models/recording_response_data.rb', line 63

optional :download_urls, -> { Telnyx::RecordingResponseData::DownloadURLs }

#duration_millisInteger?

The duration of the recording in milliseconds.

Returns:

  • (Integer, nil)


69
# File 'lib/telnyx/models/recording_response_data.rb', line 69

optional :duration_millis, Integer

#fromString?

The ‘from` (caller) number for the call that generated this recording.

Returns:

  • (String, nil)


75
# File 'lib/telnyx/models/recording_response_data.rb', line 75

optional :from, String

#idString?

Uniquely identifies the recording.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/recording_response_data.rb', line 11

optional :id, String

#initiated_byString?

Indicates what triggered the recording. Possible values include ‘DialVerb`, `Conference`, `OutboundAPI`, `Trunking`, `RecordVerb`, `StartCallRecordingAPI`, `StartConferenceRecordingAPI`.

Returns:

  • (String, nil)


83
# File 'lib/telnyx/models/recording_response_data.rb', line 83

optional :initiated_by, String

#record_typeSymbol, ...



88
# File 'lib/telnyx/models/recording_response_data.rb', line 88

optional :record_type, enum: -> { Telnyx::RecordingResponseData::RecordType }

#recording_ended_atString?

ISO 8601 formatted date of when the recording ended.

Returns:

  • (String, nil)


94
# File 'lib/telnyx/models/recording_response_data.rb', line 94

optional :recording_ended_at, String

#recording_started_atString?

ISO 8601 formatted date of when the recording started.

Returns:

  • (String, nil)


100
# File 'lib/telnyx/models/recording_response_data.rb', line 100

optional :recording_started_at, String

#sourceSymbol, ...

The kind of event that led to this recording being created.



106
# File 'lib/telnyx/models/recording_response_data.rb', line 106

optional :source, enum: -> { Telnyx::RecordingResponseData::Source }

#statusSymbol, ...

The status of the recording. Only ‘completed` recordings are currently supported.



113
# File 'lib/telnyx/models/recording_response_data.rb', line 113

optional :status, enum: -> { Telnyx::RecordingResponseData::Status }

#toString?

The ‘to` (callee) number for the call that generated this recording.

Returns:

  • (String, nil)


119
# File 'lib/telnyx/models/recording_response_data.rb', line 119

optional :to, String

#updated_atString?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (String, nil)


125
# File 'lib/telnyx/models/recording_response_data.rb', line 125

optional :updated_at, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/recording_response_data.rb', line 179