Module: Telnyx::Models::RecordingResponseData::Channels
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/recording_response_data.rb
Overview
When ‘dual`, the final audio file has the first leg on channel A, and the rest on channel B.
Constant Summary collapse
- SINGLE =
:single- DUAL =
:dual
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info