Class: Telnyx::Models::RegulatoryRequirementRetrieveParams::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RegulatoryRequirementRetrieveParams::Filter
- Defined in:
- lib/telnyx/models/regulatory_requirement_retrieve_params.rb
Defined Under Namespace
Modules: Action, PhoneNumberType
Instance Attribute Summary collapse
-
#action ⇒ Symbol, ...
Action to check requirements for.
-
#country_code ⇒ String?
Country code(iso2) to check requirements for.
-
#phone_number ⇒ String?
Phone number to check requirements for.
-
#phone_number_type ⇒ Symbol, ...
Phone number type to check requirements for.
-
#requirement_group_id ⇒ String?
ID of requirement group to check requirements for.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(action: nil, country_code: nil, phone_number: nil, phone_number_type: nil, requirement_group_id: nil) ⇒ Object
constructor
Consolidated filter parameter (deepObject style).
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action: nil, country_code: nil, phone_number: nil, phone_number_type: nil, requirement_group_id: nil) ⇒ Object
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/telnyx/models/regulatory_requirement_retrieve_params.rb', line 26 class Filter < Telnyx::Internal::Type::BaseModel # @!attribute action # Action to check requirements for # # @return [Symbol, Telnyx::Models::RegulatoryRequirementRetrieveParams::Filter::Action, nil] optional :action, enum: -> { Telnyx::RegulatoryRequirementRetrieveParams::Filter::Action } # @!attribute country_code # Country code(iso2) to check requirements for # # @return [String, nil] optional :country_code, String # @!attribute phone_number # Phone number to check requirements for # # @return [String, nil] optional :phone_number, String # @!attribute phone_number_type # Phone number type to check requirements for # # @return [Symbol, Telnyx::Models::RegulatoryRequirementRetrieveParams::Filter::PhoneNumberType, nil] optional :phone_number_type, enum: -> { Telnyx::RegulatoryRequirementRetrieveParams::Filter::PhoneNumberType } # @!attribute requirement_group_id # ID of requirement group to check requirements for # # @return [String, nil] optional :requirement_group_id, String # @!method initialize(action: nil, country_code: nil, phone_number: nil, phone_number_type: nil, requirement_group_id: nil) # Consolidated filter parameter (deepObject style). Originally: # filter[phone_number], filter[requirement_group_id], filter[country_code], # filter[phone_number_type], filter[action] # # @param action [Symbol, Telnyx::Models::RegulatoryRequirementRetrieveParams::Filter::Action] Action to check requirements for # # @param country_code [String] Country code(iso2) to check requirements for # # @param phone_number [String] Phone number to check requirements for # # @param phone_number_type [Symbol, Telnyx::Models::RegulatoryRequirementRetrieveParams::Filter::PhoneNumberType] Phone number type to check requirements for # # @param requirement_group_id [String] ID of requirement group to check requirements for # Action to check requirements for # # @see Telnyx::Models::RegulatoryRequirementRetrieveParams::Filter#action module Action extend Telnyx::Internal::Type::Enum ORDERING = :ordering PORTING = :porting ACTION = :action # @!method self.values # @return [Array<Symbol>] end # Phone number type to check requirements for # # @see Telnyx::Models::RegulatoryRequirementRetrieveParams::Filter#phone_number_type module PhoneNumberType extend Telnyx::Internal::Type::Enum LOCAL = :local TOLL_FREE = :toll_free MOBILE = :mobile NATIONAL = :national SHARED_COST = :shared_cost # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#action ⇒ Symbol, ...
Action to check requirements for
31 |
# File 'lib/telnyx/models/regulatory_requirement_retrieve_params.rb', line 31 optional :action, enum: -> { Telnyx::RegulatoryRequirementRetrieveParams::Filter::Action } |
#country_code ⇒ String?
Country code(iso2) to check requirements for
37 |
# File 'lib/telnyx/models/regulatory_requirement_retrieve_params.rb', line 37 optional :country_code, String |
#phone_number ⇒ String?
Phone number to check requirements for
43 |
# File 'lib/telnyx/models/regulatory_requirement_retrieve_params.rb', line 43 optional :phone_number, String |
#phone_number_type ⇒ Symbol, ...
Phone number type to check requirements for
49 50 |
# File 'lib/telnyx/models/regulatory_requirement_retrieve_params.rb', line 49 optional :phone_number_type, enum: -> { Telnyx::RegulatoryRequirementRetrieveParams::Filter::PhoneNumberType } |
#requirement_group_id ⇒ String?
ID of requirement group to check requirements for
56 |
# File 'lib/telnyx/models/regulatory_requirement_retrieve_params.rb', line 56 optional :requirement_group_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/regulatory_requirement_retrieve_params.rb', line 83
|