Class: Telnyx::Models::ReplacedLinkClickWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/replaced_link_click_webhook_event.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(message_id: nil, record_type: nil, time_clicked: nil, to: nil, url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ReplacedLinkClickWebhookEvent::Data for more details.

Parameters:

  • message_id (String) (defaults to: nil)

    The message ID associated with the clicked link.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • time_clicked (Time) (defaults to: nil)

    ISO 8601 formatted date indicating when the message request was received.

  • to (String) (defaults to: nil)

    Sending address (+E.164 formatted phone number, alphanumeric sender ID, or short

  • url (String) (defaults to: nil)

    The original link that was sent in the message.



# File 'lib/telnyx/models/replaced_link_click_webhook_event.rb', line 47

Instance Attribute Details

#message_idString?

The message ID associated with the clicked link.

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/replaced_link_click_webhook_event.rb', line 20

optional :message_id, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/replaced_link_click_webhook_event.rb', line 26

optional :record_type, String

#time_clickedTime?

ISO 8601 formatted date indicating when the message request was received.

Returns:

  • (Time, nil)


32
# File 'lib/telnyx/models/replaced_link_click_webhook_event.rb', line 32

optional :time_clicked, Time

#toString?

Sending address (+E.164 formatted phone number, alphanumeric sender ID, or short code).

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/replaced_link_click_webhook_event.rb', line 39

optional :to, String

#urlString?

The original link that was sent in the message.

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/replaced_link_click_webhook_event.rb', line 45

optional :url, String