Class: Telnyx::Models::ReportListMdrsResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/report_list_mdrs_response.rb

Defined Under Namespace

Modules: Currency, MessageType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, cld: nil, cli: nil, cost: nil, created_at: nil, currency: nil, direction: nil, message_type: nil, parts: nil, profile_name: nil, rate: nil, record_type: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ReportListMdrsResponse::Data for more details.

Parameters:

  • id (String) (defaults to: nil)

    Id of message detail record

  • cld (String) (defaults to: nil)

    The destination number for a call, or the callee

  • cli (String) (defaults to: nil)

    The number associated with the person initiating the call, or the caller

  • cost (String) (defaults to: nil)

    Final cost. Cost is calculated as rate * parts

  • created_at (Time) (defaults to: nil)

    Message sent time

  • currency (Symbol, Telnyx::Models::ReportListMdrsResponse::Data::Currency) (defaults to: nil)

    Currency of the rate and cost

  • direction (String) (defaults to: nil)

    Direction of message - inbound or outbound.

  • message_type (Symbol, Telnyx::Models::ReportListMdrsResponse::Data::MessageType) (defaults to: nil)

    Type of message

  • parts (Float) (defaults to: nil)

    Number of parts this message has. Max number of character is 160. If message con

  • profile_name (String) (defaults to: nil)

    Configured profile name. New profiles can be created and configured on Telnyx po

  • rate (String) (defaults to: nil)

    Rate applied to the message

  • record_type (String) (defaults to: nil)
  • status (Symbol, Telnyx::Models::ReportListMdrsResponse::Data::Status) (defaults to: nil)

    Message status



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 21

class Data < Telnyx::Internal::Type::BaseModel
  # @!attribute id
  #   Id of message detail record
  #
  #   @return [String, nil]
  optional :id, String

  # @!attribute cld
  #   The destination number for a call, or the callee
  #
  #   @return [String, nil]
  optional :cld, String

  # @!attribute cli
  #   The number associated with the person initiating the call, or the caller
  #
  #   @return [String, nil]
  optional :cli, String

  # @!attribute cost
  #   Final cost. Cost is calculated as rate \* parts
  #
  #   @return [String, nil]
  optional :cost, String

  # @!attribute created_at
  #   Message sent time
  #
  #   @return [Time, nil]
  optional :created_at, Time

  # @!attribute currency
  #   Currency of the rate and cost
  #
  #   @return [Symbol, Telnyx::Models::ReportListMdrsResponse::Data::Currency, nil]
  optional :currency, enum: -> { Telnyx::Models::ReportListMdrsResponse::Data::Currency }

  # @!attribute direction
  #   Direction of message - inbound or outbound.
  #
  #   @return [String, nil]
  optional :direction, String

  # @!attribute message_type
  #   Type of message
  #
  #   @return [Symbol, Telnyx::Models::ReportListMdrsResponse::Data::MessageType, nil]
  optional :message_type, enum: -> { Telnyx::Models::ReportListMdrsResponse::Data::MessageType }

  # @!attribute parts
  #   Number of parts this message has. Max number of character is 160. If message
  #   contains more characters then that it will be broken down in multiple parts
  #
  #   @return [Float, nil]
  optional :parts, Float

  # @!attribute profile_name
  #   Configured profile name. New profiles can be created and configured on Telnyx
  #   portal
  #
  #   @return [String, nil]
  optional :profile_name, String

  # @!attribute rate
  #   Rate applied to the message
  #
  #   @return [String, nil]
  optional :rate, String

  # @!attribute record_type
  #
  #   @return [String, nil]
  optional :record_type, String

  # @!attribute status
  #   Message status
  #
  #   @return [Symbol, Telnyx::Models::ReportListMdrsResponse::Data::Status, nil]
  optional :status, enum: -> { Telnyx::Models::ReportListMdrsResponse::Data::Status }

  # @!method initialize(id: nil, cld: nil, cli: nil, cost: nil, created_at: nil, currency: nil, direction: nil, message_type: nil, parts: nil, profile_name: nil, rate: nil, record_type: nil, status: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::ReportListMdrsResponse::Data} for more details.
  #
  #   @param id [String] Id of message detail record
  #
  #   @param cld [String] The destination number for a call, or the callee
  #
  #   @param cli [String] The number associated with the person initiating the call, or the caller
  #
  #   @param cost [String] Final cost. Cost is calculated as rate \* parts
  #
  #   @param created_at [Time] Message sent time
  #
  #   @param currency [Symbol, Telnyx::Models::ReportListMdrsResponse::Data::Currency] Currency of the rate and cost
  #
  #   @param direction [String] Direction of message - inbound or outbound.
  #
  #   @param message_type [Symbol, Telnyx::Models::ReportListMdrsResponse::Data::MessageType] Type of message
  #
  #   @param parts [Float] Number of parts this message has. Max number of character is 160. If message con
  #
  #   @param profile_name [String] Configured profile name. New profiles can be created and configured on Telnyx po
  #
  #   @param rate [String] Rate applied to the message
  #
  #   @param record_type [String]
  #
  #   @param status [Symbol, Telnyx::Models::ReportListMdrsResponse::Data::Status] Message status

  # Currency of the rate and cost
  #
  # @see Telnyx::Models::ReportListMdrsResponse::Data#currency
  module Currency
    extend Telnyx::Internal::Type::Enum

    AUD = :AUD
    CAD = :CAD
    EUR = :EUR
    GBP = :GBP
    USD = :USD

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # Type of message
  #
  # @see Telnyx::Models::ReportListMdrsResponse::Data#message_type
  module MessageType
    extend Telnyx::Internal::Type::Enum

    SMS = :SMS
    MMS = :MMS

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # Message status
  #
  # @see Telnyx::Models::ReportListMdrsResponse::Data#status
  module Status
    extend Telnyx::Internal::Type::Enum

    GW_TIMEOUT = :GW_TIMEOUT
    DELIVERED = :DELIVERED
    DLR_UNCONFIRMED = :DLR_UNCONFIRMED
    DLR_TIMEOUT = :DLR_TIMEOUT
    RECEIVED = :RECEIVED
    GW_REJECT = :GW_REJECT
    FAILED = :FAILED

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#cldString?

The destination number for a call, or the callee

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 32

optional :cld, String

#cliString?

The number associated with the person initiating the call, or the caller

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 38

optional :cli, String

#costString?

Final cost. Cost is calculated as rate * parts

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 44

optional :cost, String

#created_atTime?

Message sent time

Returns:

  • (Time, nil)


50
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 50

optional :created_at, Time

#currencySymbol, ...

Currency of the rate and cost



56
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 56

optional :currency, enum: -> { Telnyx::Models::ReportListMdrsResponse::Data::Currency }

#directionString?

Direction of message - inbound or outbound.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 62

optional :direction, String

#idString?

Id of message detail record

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 26

optional :id, String

#message_typeSymbol, ...

Type of message



68
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 68

optional :message_type, enum: -> { Telnyx::Models::ReportListMdrsResponse::Data::MessageType }

#partsFloat?

Number of parts this message has. Max number of character is 160. If message contains more characters then that it will be broken down in multiple parts

Returns:

  • (Float, nil)


75
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 75

optional :parts, Float

#profile_nameString?

Configured profile name. New profiles can be created and configured on Telnyx portal

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 82

optional :profile_name, String

#rateString?

Rate applied to the message

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 88

optional :rate, String

#record_typeString?

Returns:

  • (String, nil)


93
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 93

optional :record_type, String

#statusSymbol, ...

Message status



99
# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 99

optional :status, enum: -> { Telnyx::Models::ReportListMdrsResponse::Data::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/report_list_mdrs_response.rb', line 143