Class: Telnyx::Models::Reputation::NumberRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Reputation::NumberRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/reputation/number_retrieve_response.rb
Overview
Instance Attribute Summary collapse
- #enterprise_id ⇒ String?
-
#phone_number ⇒ String?
E.164 with leading ‘+`.
-
#reputation_data ⇒ Telnyx::Models::ReputationData?
‘null` until the first refresh has been collected for this number.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, enterprise_id: nil, phone_number: nil, reputation_data: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/reputation/number_retrieve_response.rb', line 52
|
Instance Attribute Details
#enterprise_id ⇒ String?
21 |
# File 'lib/telnyx/models/reputation/number_retrieve_response.rb', line 21 optional :enterprise_id, String |
#phone_number ⇒ String?
E.164 with leading ‘+`.
27 |
# File 'lib/telnyx/models/reputation/number_retrieve_response.rb', line 27 optional :phone_number, String |
#reputation_data ⇒ Telnyx::Models::ReputationData?
‘null` until the first refresh has been collected for this number.
33 |
# File 'lib/telnyx/models/reputation/number_retrieve_response.rb', line 33 optional :reputation_data, -> { Telnyx::ReputationData }, nil?: true |