Class: Telnyx::Models::ReservedPhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/reserved_phone_number.rb,
sig/telnyx/models/reserved_phone_number.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, errors: nil, expired_at: nil, phone_number: nil, record_type: nil, status: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ReservedPhoneNumber for more details.

Parameters:

  • id (String) (defaults to: nil)
  • created_at (Time) (defaults to: nil)

    An ISO 8901 datetime string denoting when the individual number reservation was

  • errors (String) (defaults to: nil)

    Errors the reservation could happen upon

  • expired_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the individual number reservation is going

  • phone_number (String) (defaults to: nil)
  • record_type (String) (defaults to: nil)
  • status (Symbol, Telnyx::Models::ReservedPhoneNumber::Status) (defaults to: nil)

    The status of the phone number's reservation.

  • updated_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the the individual number reservation was u



# File 'lib/telnyx/models/reserved_phone_number.rb', line 56

Instance Attribute Details

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


24
25
26
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 24

def created_at
  @created_at
end

#errorsString? (readonly)

Returns the value of attribute errors.

Returns:

  • (String, nil)


28
29
30
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 28

def errors
  @errors
end

#expired_atTime? (readonly)

Returns the value of attribute expired_at.

Returns:

  • (Time, nil)


32
33
34
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 32

def expired_at
  @expired_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


20
21
22
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 20

def id
  @id
end

#phone_numberString?

Parameters:

  • (String)

Returns:

  • (String, nil)


9
# File 'lib/telnyx/models/reserved_phone_number.rb', line 9

optional :phone_number, String

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


36
37
38
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 36

def record_type
  @record_type
end

#statusTelnyx::Models::ReservedPhoneNumber::status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::ReservedPhoneNumber::status, nil)


40
41
42
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 40

def status
  @status
end

#updated_atTime? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (Time, nil)


46
47
48
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 46

def updated_at
  @updated_at
end

Instance Method Details

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


26
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 26

def created_at=: (Time) -> Time

#errors=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


30
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 30

def errors=: (String) -> String

#expired_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


34
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 34

def expired_at=: (Time) -> Time

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


22
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 22

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


38
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 38

def record_type=: (String) -> String

#status=Object (readonly)



42
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 42

def status=: (

#to_hash{

Returns:

  • ({)


61
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 61

def to_hash: -> {

#updated_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


48
# File 'sig/telnyx/models/reserved_phone_number.rbs', line 48

def updated_at=: (Time) -> Time