Class: Telnyx::Models::Room

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/room.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, active_session_id: nil, created_at: nil, enable_recording: nil, max_participants: nil, record_type: nil, sessions: nil, unique_name: nil, updated_at: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Room for more details.

Parameters:

  • id (String) (defaults to: nil)

    A unique identifier for the room.

  • active_session_id (String) (defaults to: nil)

    The identifier of the active room session if any.

  • created_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the room was created.

  • enable_recording (Boolean) (defaults to: nil)

    Enable or disable recording for that room.

  • max_participants (Integer) (defaults to: nil)

    Maximum participants allowed in the room.

  • record_type (String) (defaults to: nil)
  • sessions (Array<Telnyx::Models::RoomSession>) (defaults to: nil)
  • unique_name (String) (defaults to: nil)

    The unique (within the Telnyx account scope) name of the room.

  • updated_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the room was updated.

  • webhook_event_failover_url (String) (defaults to: nil)

    The failover URL where webhooks related to this room will be sent if sending to

  • webhook_event_url (String) (defaults to: nil)

    The URL where webhooks related to this room will be sent. Must include a scheme,

  • webhook_timeout_secs (Integer) (defaults to: nil)

    Specifies how many seconds to wait before timing out a webhook.



# File 'lib/telnyx/models/room.rb', line 81

Instance Attribute Details

#active_session_idString?

The identifier of the active room session if any.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/room.rb', line 17

optional :active_session_id, String

#created_atTime?

ISO 8601 timestamp when the room was created.

Returns:

  • (Time, nil)


23
# File 'lib/telnyx/models/room.rb', line 23

optional :created_at, Time

#enable_recordingBoolean?

Enable or disable recording for that room.

Returns:

  • (Boolean, nil)


29
# File 'lib/telnyx/models/room.rb', line 29

optional :enable_recording, Telnyx::Internal::Type::Boolean

#idString?

A unique identifier for the room.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/room.rb', line 11

optional :id, String

#max_participantsInteger?

Maximum participants allowed in the room.

Returns:

  • (Integer, nil)


35
# File 'lib/telnyx/models/room.rb', line 35

optional :max_participants, Integer

#sessionsArray<Telnyx::Models::RoomSession>?

Returns:



40
# File 'lib/telnyx/models/room.rb', line 40

optional :sessions, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::RoomSession] }

#unique_nameString?

The unique (within the Telnyx account scope) name of the room.

Returns:

  • (String, nil)


46
# File 'lib/telnyx/models/room.rb', line 46

optional :unique_name, String

#updated_atTime?

ISO 8601 timestamp when the room was updated.

Returns:

  • (Time, nil)


52
# File 'lib/telnyx/models/room.rb', line 52

optional :updated_at, Time

#webhook_event_failover_urlString?

The failover URL where webhooks related to this room will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/room.rb', line 59

optional :webhook_event_failover_url, String

#webhook_event_urlString?

The URL where webhooks related to this room will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


66
# File 'lib/telnyx/models/room.rb', line 66

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


72
# File 'lib/telnyx/models/room.rb', line 72

optional :webhook_timeout_secs, Integer