Class: Telnyx::Models::RoomCompositionCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/room_composition_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(format_: nil, resolution: nil, session_id: nil, video_layout: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::RoomCompositionCreateParams for more details.

Parameters:

  • format_ (String) (defaults to: nil)

    The desired format of the room composition.

  • resolution (String) (defaults to: nil)

    The desired resolution (width/height in pixels) of the resulting video of the ro

  • session_id (String) (defaults to: nil)

    id of the room session associated with the room composition.

  • video_layout (Hash{Symbol=>Telnyx::Models::VideoRegion}) (defaults to: nil)

    Describes the video layout of the room composition in terms of regions.

  • webhook_event_failover_url (String) (defaults to: nil)

    The failover URL where webhooks related to this room composition will be sent if

  • webhook_event_url (String) (defaults to: nil)

    The URL where webhooks related to this room composition will be sent. Must inclu

  • webhook_timeout_secs (Integer) (defaults to: nil)

    Specifies how many seconds to wait before timing out a webhook.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/room_composition_create_params.rb', line 56

Instance Attribute Details

#format_String?

The desired format of the room composition.

Returns:

  • (String, nil)


14
# File 'lib/telnyx/models/room_composition_create_params.rb', line 14

optional :format_, String, api_name: :format

#resolutionString?

The desired resolution (width/height in pixels) of the resulting video of the room composition. Both width and height are required to be between 16 and 1280; and width _ height should not exceed 1280 _ 720

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/room_composition_create_params.rb', line 22

optional :resolution, String

#session_idString?

id of the room session associated with the room composition.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/room_composition_create_params.rb', line 28

optional :session_id, String

#video_layoutHash{Symbol=>Telnyx::Models::VideoRegion}?

Describes the video layout of the room composition in terms of regions.

Returns:



34
# File 'lib/telnyx/models/room_composition_create_params.rb', line 34

optional :video_layout, -> { Telnyx::Internal::Type::HashOf[Telnyx::VideoRegion] }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this room composition will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/room_composition_create_params.rb', line 41

optional :webhook_event_failover_url, String

#webhook_event_urlString?

The URL where webhooks related to this room composition will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/room_composition_create_params.rb', line 48

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


54
# File 'lib/telnyx/models/room_composition_create_params.rb', line 54

optional :webhook_timeout_secs, Integer