Class: Telnyx::Models::RoomCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/room_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enable_recording: nil, max_participants: nil, unique_name: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::RoomCreateParams for more details.

Parameters:

  • enable_recording (Boolean) (defaults to: nil)

    Enable or disable recording for that room.

  • max_participants (Integer) (defaults to: nil)

    The maximum amount of participants allowed in a room. If new participants try to

  • unique_name (String) (defaults to: nil)

    The unique (within the Telnyx account scope) name of the room.

  • webhook_event_failover_url (String) (defaults to: nil)

    The failover URL where webhooks related to this room will be sent if sending to

  • webhook_event_url (String) (defaults to: nil)

    The URL where webhooks related to this room will be sent. Must include a scheme,

  • webhook_timeout_secs (Integer) (defaults to: nil)

    Specifies how many seconds to wait before timing out a webhook.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/room_create_params.rb', line 49

Instance Attribute Details

#enable_recordingBoolean?

Enable or disable recording for that room.

Returns:

  • (Boolean, nil)


14
# File 'lib/telnyx/models/room_create_params.rb', line 14

optional :enable_recording, Telnyx::Internal::Type::Boolean

#max_participantsInteger?

The maximum amount of participants allowed in a room. If new participants try to join after that limit is reached, their request will be rejected.

Returns:

  • (Integer, nil)


21
# File 'lib/telnyx/models/room_create_params.rb', line 21

optional :max_participants, Integer

#unique_nameString?

The unique (within the Telnyx account scope) name of the room.

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/room_create_params.rb', line 27

optional :unique_name, String

#webhook_event_failover_urlString?

The failover URL where webhooks related to this room will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/room_create_params.rb', line 34

optional :webhook_event_failover_url, String

#webhook_event_urlString?

The URL where webhooks related to this room will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/room_create_params.rb', line 41

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


47
# File 'lib/telnyx/models/room_create_params.rb', line 47

optional :webhook_timeout_secs, Integer