Class: Telnyx::Models::RoomListParams::Filter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/room_list_params.rb,
sig/telnyx/models/room_list_params.rbs

Defined Under Namespace

Classes: DateCreatedAt, DateUpdatedAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(eq: nil, gte: nil, lte: nil) ⇒ Object

Parameters:

  • eq (Date) (defaults to: nil)

    ISO 8601 date for filtering rooms created on that date.

  • gte (Date) (defaults to: nil)

    ISO 8601 date for filtering rooms created on or after that date.

  • lte (Date) (defaults to: nil)

    ISO 8601 date for filtering rooms created on or before that date.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/telnyx/models/room_list_params.rb', line 49

class Filter < Telnyx::Internal::Type::BaseModel
  # @!attribute date_created_at
  #
  #   @return [Telnyx::Models::RoomListParams::Filter::DateCreatedAt, nil]
  optional :date_created_at, -> { Telnyx::RoomListParams::Filter::DateCreatedAt }

  # @!attribute date_updated_at
  #
  #   @return [Telnyx::Models::RoomListParams::Filter::DateUpdatedAt, nil]
  optional :date_updated_at, -> { Telnyx::RoomListParams::Filter::DateUpdatedAt }

  # @!attribute unique_name
  #   Unique_name for filtering rooms.
  #
  #   @return [String, nil]
  optional :unique_name, String

  # @!method initialize(date_created_at: nil, date_updated_at: nil, unique_name: nil)
  #   Consolidated filter parameter (deepObject style). Originally:
  #   filter[date_created_at][eq], filter[date_created_at][gte],
  #   filter[date_created_at][lte], filter[date_updated_at][eq],
  #   filter[date_updated_at][gte], filter[date_updated_at][lte], filter[unique_name]
  #
  #   @param date_created_at [Telnyx::Models::RoomListParams::Filter::DateCreatedAt]
  #
  #   @param date_updated_at [Telnyx::Models::RoomListParams::Filter::DateUpdatedAt]
  #
  #   @param unique_name [String] Unique_name for filtering rooms.

  # @see Telnyx::Models::RoomListParams::Filter#date_created_at
  class DateCreatedAt < Telnyx::Internal::Type::BaseModel
    # @!attribute eq
    #   ISO 8601 date for filtering rooms created on that date.
    #
    #   @return [Date, nil]
    optional :eq, Date

    # @!attribute gte
    #   ISO 8601 date for filtering rooms created on or after that date.
    #
    #   @return [Date, nil]
    optional :gte, Date

    # @!attribute lte
    #   ISO 8601 date for filtering rooms created on or before that date.
    #
    #   @return [Date, nil]
    optional :lte, Date

    # @!method initialize(eq: nil, gte: nil, lte: nil)
    #   @param eq [Date] ISO 8601 date for filtering rooms created on that date.
    #
    #   @param gte [Date] ISO 8601 date for filtering rooms created on or after that date.
    #
    #   @param lte [Date] ISO 8601 date for filtering rooms created on or before that date.
  end

  # @see Telnyx::Models::RoomListParams::Filter#date_updated_at
  class DateUpdatedAt < Telnyx::Internal::Type::BaseModel
    # @!attribute eq
    #   ISO 8601 date for filtering rooms updated on that date.
    #
    #   @return [Date, nil]
    optional :eq, Date

    # @!attribute gte
    #   ISO 8601 date for filtering rooms updated on or after that date.
    #
    #   @return [Date, nil]
    optional :gte, Date

    # @!attribute lte
    #   ISO 8601 date for filtering rooms updated on or before that date.
    #
    #   @return [Date, nil]
    optional :lte, Date

    # @!method initialize(eq: nil, gte: nil, lte: nil)
    #   @param eq [Date] ISO 8601 date for filtering rooms updated on that date.
    #
    #   @param gte [Date] ISO 8601 date for filtering rooms updated on or after that date.
    #
    #   @param lte [Date] ISO 8601 date for filtering rooms updated on or before that date.
  end
end

Instance Attribute Details

#date_created_atTelnyx::Models::RoomListParams::Filter::DateCreatedAt?



53
# File 'lib/telnyx/models/room_list_params.rb', line 53

optional :date_created_at, -> { Telnyx::RoomListParams::Filter::DateCreatedAt }

#date_updated_atTelnyx::Models::RoomListParams::Filter::DateUpdatedAt?



58
# File 'lib/telnyx/models/room_list_params.rb', line 58

optional :date_updated_at, -> { Telnyx::RoomListParams::Filter::DateUpdatedAt }

#unique_nameString?

Unique_name for filtering rooms.

Parameters:

  • (String)

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/room_list_params.rb', line 64

optional :unique_name, String

Instance Method Details

#to_hash{

Returns:

  • ({)


80
# File 'sig/telnyx/models/room_list_params.rbs', line 80

def to_hash: -> {