Class: Telnyx::Models::RoomParticipant

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/room_participant.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, context: nil, joined_at: nil, left_at: nil, record_type: nil, session_id: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    A unique identifier for the room participant.

  • context (String) (defaults to: nil)

    Context provided to the given participant through the client SDK

  • joined_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the participant joined the session.

  • left_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the participant left the session.

  • record_type (String) (defaults to: nil)
  • session_id (String) (defaults to: nil)

    Identify the room session that participant is part of.

  • updated_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the participant was updated.



# File 'lib/telnyx/models/room_participant.rb', line 49

Instance Attribute Details

#contextString?

Context provided to the given participant through the client SDK

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/room_participant.rb', line 16

optional :context, String

#idString?

A unique identifier for the room participant.

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/room_participant.rb', line 10

optional :id, String

#joined_atTime?

ISO 8601 timestamp when the participant joined the session.

Returns:

  • (Time, nil)


22
# File 'lib/telnyx/models/room_participant.rb', line 22

optional :joined_at, Time

#left_atTime?

ISO 8601 timestamp when the participant left the session.

Returns:

  • (Time, nil)


28
# File 'lib/telnyx/models/room_participant.rb', line 28

optional :left_at, Time

#session_idString?

Identify the room session that participant is part of.

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/room_participant.rb', line 34

optional :session_id, String

#updated_atTime?

ISO 8601 timestamp when the participant was updated.

Returns:

  • (Time, nil)


40
# File 'lib/telnyx/models/room_participant.rb', line 40

optional :updated_at, Time