Class: Telnyx::Models::RoomRecordingListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RoomRecordingListResponse
- Defined in:
- lib/telnyx/models/room_recording_list_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#codec ⇒ String?
Shows the codec used for the room recording.
-
#completed_at ⇒ Time?
ISO 8601 timestamp when the room recording has completed.
-
#created_at ⇒ Time?
ISO 8601 timestamp when the room recording was created.
-
#download_url ⇒ String?
Url to download the recording.
-
#duration_secs ⇒ Integer?
Shows the room recording duration in seconds.
-
#ended_at ⇒ Time?
ISO 8601 timestamp when the room recording has ended.
-
#id ⇒ String?
A unique identifier for the room recording.
-
#participant_id ⇒ String?
Identify the room participant associated with the room recording.
-
#room_id ⇒ String?
Identify the room associated with the room recording.
-
#session_id ⇒ String?
Identify the room session associated with the room recording.
-
#size_mb ⇒ Float?
Shows the room recording size in MB.
-
#started_at ⇒ Time?
ISO 8601 timestamp when the room recording has stated.
-
#status ⇒ Symbol, ...
Shows the room recording status.
-
#type ⇒ Symbol, ...
Shows the room recording type.
-
#updated_at ⇒ Time?
ISO 8601 timestamp when the room recording was updated.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, codec: nil, completed_at: nil, created_at: nil, download_url: nil, duration_secs: nil, ended_at: nil, participant_id: nil, record_type: nil, room_id: nil, session_id: nil, size_mb: nil, started_at: nil, status: nil, type: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/room_recording_list_response.rb', line 104
|
Instance Attribute Details
#codec ⇒ String?
Shows the codec used for the room recording.
17 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 17 optional :codec, String |
#completed_at ⇒ Time?
ISO 8601 timestamp when the room recording has completed.
23 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 23 optional :completed_at, Time |
#created_at ⇒ Time?
ISO 8601 timestamp when the room recording was created.
29 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 29 optional :created_at, Time |
#download_url ⇒ String?
Url to download the recording.
35 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 35 optional :download_url, String |
#duration_secs ⇒ Integer?
Shows the room recording duration in seconds.
41 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 41 optional :duration_secs, Integer |
#ended_at ⇒ Time?
ISO 8601 timestamp when the room recording has ended.
47 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 47 optional :ended_at, Time |
#id ⇒ String?
A unique identifier for the room recording.
11 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 11 optional :id, String |
#participant_id ⇒ String?
Identify the room participant associated with the room recording.
53 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 53 optional :participant_id, String |
#room_id ⇒ String?
Identify the room associated with the room recording.
59 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 59 optional :room_id, String |
#session_id ⇒ String?
Identify the room session associated with the room recording.
65 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 65 optional :session_id, String |
#size_mb ⇒ Float?
Shows the room recording size in MB.
71 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 71 optional :size_mb, Float |
#started_at ⇒ Time?
ISO 8601 timestamp when the room recording has stated.
77 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 77 optional :started_at, Time |
#status ⇒ Symbol, ...
Shows the room recording status.
83 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 83 optional :status, enum: -> { Telnyx::Models::RoomRecordingListResponse::Status } |
#type ⇒ Symbol, ...
Shows the room recording type.
89 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 89 optional :type, enum: -> { Telnyx::Models::RoomRecordingListResponse::Type } |
#updated_at ⇒ Time?
ISO 8601 timestamp when the room recording was updated.
95 |
# File 'lib/telnyx/models/room_recording_list_response.rb', line 95 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/room_recording_list_response.rb', line 146
|