Class: Telnyx::Models::RoomRecordingRetrieveResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/room_recording_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, codec: nil, completed_at: nil, created_at: nil, download_url: nil, duration_secs: nil, ended_at: nil, participant_id: nil, record_type: nil, room_id: nil, session_id: nil, size_mb: nil, started_at: nil, status: nil, type: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    A unique identifier for the room recording.

  • codec (String) (defaults to: nil)

    Shows the codec used for the room recording.

  • completed_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the room recording has completed.

  • created_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the room recording was created.

  • download_url (String) (defaults to: nil)

    Url to download the recording.

  • duration_secs (Integer) (defaults to: nil)

    Shows the room recording duration in seconds.

  • ended_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the room recording has ended.

  • participant_id (String) (defaults to: nil)

    Identify the room participant associated with the room recording.

  • record_type (String) (defaults to: nil)
  • room_id (String) (defaults to: nil)

    Identify the room associated with the room recording.

  • session_id (String) (defaults to: nil)

    Identify the room session associated with the room recording.

  • size_mb (Float) (defaults to: nil)

    Shows the room recording size in MB.

  • started_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the room recording has stated.

  • status (Symbol, Telnyx::Models::RoomRecordingRetrieveResponse::Data::Status) (defaults to: nil)

    Shows the room recording status.

  • type (Symbol, Telnyx::Models::RoomRecordingRetrieveResponse::Data::Type) (defaults to: nil)

    Shows the room recording type.

  • updated_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the room recording was updated.



# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 114

Instance Attribute Details

#codecString?

Shows the codec used for the room recording.

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 27

optional :codec, String

#completed_atTime?

ISO 8601 timestamp when the room recording has completed.

Returns:

  • (Time, nil)


33
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 33

optional :completed_at, Time

#created_atTime?

ISO 8601 timestamp when the room recording was created.

Returns:

  • (Time, nil)


39
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 39

optional :created_at, Time

#download_urlString?

Url to download the recording.

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 45

optional :download_url, String

#duration_secsInteger?

Shows the room recording duration in seconds.

Returns:

  • (Integer, nil)


51
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 51

optional :duration_secs, Integer

#ended_atTime?

ISO 8601 timestamp when the room recording has ended.

Returns:

  • (Time, nil)


57
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 57

optional :ended_at, Time

#idString?

A unique identifier for the room recording.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 21

optional :id, String

#participant_idString?

Identify the room participant associated with the room recording.

Returns:

  • (String, nil)


63
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 63

optional :participant_id, String

#room_idString?

Identify the room associated with the room recording.

Returns:

  • (String, nil)


69
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 69

optional :room_id, String

#session_idString?

Identify the room session associated with the room recording.

Returns:

  • (String, nil)


75
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 75

optional :session_id, String

#size_mbFloat?

Shows the room recording size in MB.

Returns:

  • (Float, nil)


81
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 81

optional :size_mb, Float

#started_atTime?

ISO 8601 timestamp when the room recording has stated.

Returns:

  • (Time, nil)


87
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 87

optional :started_at, Time

#statusSymbol, ...

Shows the room recording status.



93
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 93

optional :status, enum: -> { Telnyx::Models::RoomRecordingRetrieveResponse::Data::Status }

#typeSymbol, ...

Shows the room recording type.



99
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 99

optional :type, enum: -> { Telnyx::Models::RoomRecordingRetrieveResponse::Data::Type }

#updated_atTime?

ISO 8601 timestamp when the room recording was updated.

Returns:

  • (Time, nil)


105
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 105

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 156