Class: Telnyx::Models::RoomSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RoomSession
- Defined in:
- lib/telnyx/models/room_session.rb,
sig/telnyx/models/room_session.rbs
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Shows if the room session is active or not.
-
#created_at ⇒ Time?
ISO 8601 timestamp when the room session was created.
-
#ended_at ⇒ Time?
ISO 8601 timestamp when the room session has ended.
-
#id ⇒ String?
A unique identifier for the room session.
- #participants ⇒ Array<Telnyx::Models::RoomParticipant>?
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#room_id ⇒ String?
Identify the room hosting that room session.
-
#updated_at ⇒ Time?
ISO 8601 timestamp when the room session was updated.
Instance Method Summary collapse
- #initialize(id: nil, active: nil, created_at: nil, ended_at: nil, participants: nil, record_type: nil, room_id: nil, updated_at: nil) ⇒ Object constructor
- #record_type ⇒ String readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, active: nil, created_at: nil, ended_at: nil, participants: nil, record_type: nil, room_id: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/room_session.rb', line 54
|
Instance Attribute Details
#active ⇒ Boolean?
Shows if the room session is active or not.
16 |
# File 'lib/telnyx/models/room_session.rb', line 16 optional :active, Telnyx::Internal::Type::Boolean |
#created_at ⇒ Time?
ISO 8601 timestamp when the room session was created.
22 |
# File 'lib/telnyx/models/room_session.rb', line 22 optional :created_at, Time |
#ended_at ⇒ Time?
ISO 8601 timestamp when the room session has ended.
28 |
# File 'lib/telnyx/models/room_session.rb', line 28 optional :ended_at, Time |
#id ⇒ String?
A unique identifier for the room session.
10 |
# File 'lib/telnyx/models/room_session.rb', line 10 optional :id, String |
#participants ⇒ Array<Telnyx::Models::RoomParticipant>?
33 |
# File 'lib/telnyx/models/room_session.rb', line 33 optional :participants, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::RoomParticipant] } |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
46 47 48 |
# File 'sig/telnyx/models/room_session.rbs', line 46 def record_type @record_type end |
#room_id ⇒ String?
Identify the room hosting that room session.
39 |
# File 'lib/telnyx/models/room_session.rb', line 39 optional :room_id, String |
#updated_at ⇒ Time?
ISO 8601 timestamp when the room session was updated.
45 |
# File 'lib/telnyx/models/room_session.rb', line 45 optional :updated_at, Time |
Instance Method Details
#record_type= ⇒ String (readonly)
48 |
# File 'sig/telnyx/models/room_session.rbs', line 48
def record_type=: (String) -> String
|
#to_hash ⇒ {
61 |
# File 'sig/telnyx/models/room_session.rbs', line 61
def to_hash: -> {
|