Class: Telnyx::Models::Rooms::ActionGenerateJoinClientTokenParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/rooms/action_generate_join_client_token_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(room_id:, refresh_token_ttl_secs: nil, token_ttl_secs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Rooms::ActionGenerateJoinClientTokenParams for more details.

Parameters:

  • room_id (String)
  • refresh_token_ttl_secs (Integer) (defaults to: nil)

    The time to live in seconds of the Refresh Token, after that time the Refresh To

  • token_ttl_secs (Integer) (defaults to: nil)

    The time to live in seconds of the Client Token, after that time the Client Toke

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/rooms/action_generate_join_client_token_params.rb', line 30

Instance Attribute Details

#refresh_token_ttl_secsInteger?

The time to live in seconds of the Refresh Token, after that time the Refresh Token is invalid and can’t be used to refresh Client Token.

Returns:

  • (Integer, nil)


21
# File 'lib/telnyx/models/rooms/action_generate_join_client_token_params.rb', line 21

optional :refresh_token_ttl_secs, Integer

#room_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/rooms/action_generate_join_client_token_params.rb', line 14

required :room_id, String

#token_ttl_secsInteger?

The time to live in seconds of the Client Token, after that time the Client Token is invalid and can’t be used to join a Room.

Returns:

  • (Integer, nil)


28
# File 'lib/telnyx/models/rooms/action_generate_join_client_token_params.rb', line 28

optional :token_ttl_secs, Integer