Class: Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/rooms/session_retrieve_participants_params.rb

Defined Under Namespace

Classes: DateJoinedAt, DateLeftAt, DateUpdatedAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(eq: nil, gte: nil, lte: nil) ⇒ Object

Parameters:

  • eq (Date) (defaults to: nil)

    ISO 8601 date for filtering room participants that left on that date.

  • gte (Date) (defaults to: nil)

    ISO 8601 date for filtering room participants that left on or after that date.

  • lte (Date) (defaults to: nil)

    ISO 8601 date for filtering room participants that left on or before that date.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 51

class Filter < Telnyx::Internal::Type::BaseModel
  # @!attribute context
  #   Filter room participants based on the context.
  #
  #   @return [String, nil]
  optional :context, String

  # @!attribute date_joined_at
  #
  #   @return [Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateJoinedAt, nil]
  optional :date_joined_at, -> { Telnyx::Rooms::SessionRetrieveParticipantsParams::Filter::DateJoinedAt }

  # @!attribute date_left_at
  #
  #   @return [Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateLeftAt, nil]
  optional :date_left_at, -> { Telnyx::Rooms::SessionRetrieveParticipantsParams::Filter::DateLeftAt }

  # @!attribute date_updated_at
  #
  #   @return [Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateUpdatedAt, nil]
  optional :date_updated_at, -> { Telnyx::Rooms::SessionRetrieveParticipantsParams::Filter::DateUpdatedAt }

  # @!method initialize(context: nil, date_joined_at: nil, date_left_at: nil, date_updated_at: nil)
  #   Consolidated filter parameter (deepObject style). Originally:
  #   filter[date_joined_at][eq], filter[date_joined_at][gte],
  #   filter[date_joined_at][lte], filter[date_updated_at][eq],
  #   filter[date_updated_at][gte], filter[date_updated_at][lte],
  #   filter[date_left_at][eq], filter[date_left_at][gte], filter[date_left_at][lte],
  #   filter[context]
  #
  #   @param context [String] Filter room participants based on the context.
  #
  #   @param date_joined_at [Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateJoinedAt]
  #
  #   @param date_left_at [Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateLeftAt]
  #
  #   @param date_updated_at [Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateUpdatedAt]

  # @see Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter#date_joined_at
  class DateJoinedAt < Telnyx::Internal::Type::BaseModel
    # @!attribute eq
    #   ISO 8601 date for filtering room participants that joined on that date.
    #
    #   @return [Date, nil]
    optional :eq, Date

    # @!attribute gte
    #   ISO 8601 date for filtering room participants that joined on or after that date.
    #
    #   @return [Date, nil]
    optional :gte, Date

    # @!attribute lte
    #   ISO 8601 date for filtering room participants that joined on or before that
    #   date.
    #
    #   @return [Date, nil]
    optional :lte, Date

    # @!method initialize(eq: nil, gte: nil, lte: nil)
    #   Some parameter documentations has been truncated, see
    #   {Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateJoinedAt}
    #   for more details.
    #
    #   @param eq [Date] ISO 8601 date for filtering room participants that joined on that date.
    #
    #   @param gte [Date] ISO 8601 date for filtering room participants that joined on or after that date.
    #
    #   @param lte [Date] ISO 8601 date for filtering room participants that joined on or before that date
  end

  # @see Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter#date_left_at
  class DateLeftAt < Telnyx::Internal::Type::BaseModel
    # @!attribute eq
    #   ISO 8601 date for filtering room participants that left on that date.
    #
    #   @return [Date, nil]
    optional :eq, Date

    # @!attribute gte
    #   ISO 8601 date for filtering room participants that left on or after that date.
    #
    #   @return [Date, nil]
    optional :gte, Date

    # @!attribute lte
    #   ISO 8601 date for filtering room participants that left on or before that date.
    #
    #   @return [Date, nil]
    optional :lte, Date

    # @!method initialize(eq: nil, gte: nil, lte: nil)
    #   @param eq [Date] ISO 8601 date for filtering room participants that left on that date.
    #
    #   @param gte [Date] ISO 8601 date for filtering room participants that left on or after that date.
    #
    #   @param lte [Date] ISO 8601 date for filtering room participants that left on or before that date.
  end

  # @see Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter#date_updated_at
  class DateUpdatedAt < Telnyx::Internal::Type::BaseModel
    # @!attribute eq
    #   ISO 8601 date for filtering room participants updated on that date.
    #
    #   @return [Date, nil]
    optional :eq, Date

    # @!attribute gte
    #   ISO 8601 date for filtering room participants updated on or after that date.
    #
    #   @return [Date, nil]
    optional :gte, Date

    # @!attribute lte
    #   ISO 8601 date for filtering room participants updated on or before that date.
    #
    #   @return [Date, nil]
    optional :lte, Date

    # @!method initialize(eq: nil, gte: nil, lte: nil)
    #   @param eq [Date] ISO 8601 date for filtering room participants updated on that date.
    #
    #   @param gte [Date] ISO 8601 date for filtering room participants updated on or after that date.
    #
    #   @param lte [Date] ISO 8601 date for filtering room participants updated on or before that date.
  end
end

Instance Attribute Details

#contextString?

Filter room participants based on the context.

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 56

optional :context, String

#date_joined_atTelnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateJoinedAt?



61
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 61

optional :date_joined_at, -> { Telnyx::Rooms::SessionRetrieveParticipantsParams::Filter::DateJoinedAt }

#date_left_atTelnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateLeftAt?



66
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 66

optional :date_left_at, -> { Telnyx::Rooms::SessionRetrieveParticipantsParams::Filter::DateLeftAt }

#date_updated_atTelnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateUpdatedAt?



71
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 71

optional :date_updated_at, -> { Telnyx::Rooms::SessionRetrieveParticipantsParams::Filter::DateUpdatedAt }