Class: Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateLeftAt

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/rooms/session_retrieve_participants_params.rb,
sig/telnyx/models/rooms/session_retrieve_participants_params.rbs

Overview

See Also:

  • Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter#date_left_at

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeDateLeftAt

Returns a new instance of DateLeftAt.

Parameters:

  • eq: (Date)
  • gte: (Date)
  • lte: (Date)


129
# File 'sig/telnyx/models/rooms/session_retrieve_participants_params.rbs', line 129

def initialize: (?eq: Date, ?gte: Date, ?lte: Date) -> void

Instance Attribute Details

#eqDate?

ISO 8601 date for filtering room participants that left on that date.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


128
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 128

optional :eq, Date

#gteDate?

ISO 8601 date for filtering room participants that left on or after that date.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


134
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 134

optional :gte, Date

#lteDate?

ISO 8601 date for filtering room participants that left on or before that date.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


140
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 140

optional :lte, Date

Instance Method Details

#to_hash{ eq: Date, gte: Date, lte: Date }

Returns:

  • ({ eq: Date, gte: Date, lte: Date })


131
# File 'sig/telnyx/models/rooms/session_retrieve_participants_params.rbs', line 131

def to_hash: -> { eq: Date, gte: Date, lte: Date }