Class: Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateUpdatedAt

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/rooms/session_retrieve_participants_params.rb,
sig/telnyx/models/rooms/session_retrieve_participants_params.rbs

Overview

See Also:

  • Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter#date_updated_at

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(eq: nil, gte: nil, lte: nil) ⇒ DateUpdatedAt

Returns a new instance of DateUpdatedAt.

Parameters:

  • eq (Date) (defaults to: nil)

    ISO 8601 date for filtering room participants updated on that date.

  • gte (Date) (defaults to: nil)

    ISO 8601 date for filtering room participants updated on or after that date.

  • lte (Date) (defaults to: nil)

    ISO 8601 date for filtering room participants updated on or before that date.

  • eq: (Date) (defaults to: nil)
  • gte: (Date) (defaults to: nil)
  • lte: (Date) (defaults to: nil)


# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 170

Instance Attribute Details

#eqDate?

ISO 8601 date for filtering room participants updated on that date.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


156
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 156

optional :eq, Date

#gteDate?

ISO 8601 date for filtering room participants updated on or after that date.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


162
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 162

optional :gte, Date

#lteDate?

ISO 8601 date for filtering room participants updated on or before that date.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


168
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 168

optional :lte, Date

Instance Method Details

#to_hash{ eq: Date, gte: Date, lte: Date }

Returns:

  • ({ eq: Date, gte: Date, lte: Date })


151
# File 'sig/telnyx/models/rooms/session_retrieve_participants_params.rbs', line 151

def to_hash: -> { eq: Date, gte: Date, lte: Date }