Class: Telnyx::Models::Rooms::Sessions::ActionsParticipantsRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Rooms::Sessions::ActionsParticipantsRequest
- Defined in:
- lib/telnyx/models/rooms/sessions/actions_participants_request.rb
Direct Known Subclasses
Defined Under Namespace
Modules: Participants
Instance Attribute Summary collapse
-
#exclude ⇒ Array<String>?
List of participant id to exclude from the action.
-
#participants ⇒ Symbol, ...
Either a list of participant id to perform the action on, or the keyword “all” to perform the action on all participant.
Instance Method Summary collapse
-
#initialize(exclude: nil, participants: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionsParticipantsRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(exclude: nil, participants: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Rooms::Sessions::ActionsParticipantsRequest for more details.
|
|
# File 'lib/telnyx/models/rooms/sessions/actions_participants_request.rb', line 21
|
Instance Attribute Details
#exclude ⇒ Array<String>?
List of participant id to exclude from the action.
12 |
# File 'lib/telnyx/models/rooms/sessions/actions_participants_request.rb', line 12 optional :exclude, Telnyx::Internal::Type::ArrayOf[String] |
#participants ⇒ Symbol, ...
Either a list of participant id to perform the action on, or the keyword “all” to perform the action on all participant.
19 |
# File 'lib/telnyx/models/rooms/sessions/actions_participants_request.rb', line 19 optional :participants, union: -> { Telnyx::Rooms::Sessions::ActionsParticipantsRequest::Participants } |