Class: Telnyx::Models::S3GenericConfigurationData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::S3GenericConfigurationData
- Defined in:
- lib/telnyx/models/s3_generic_configuration_data.rb,
sig/telnyx/models/s3_generic_configuration_data.rbs
Defined Under Namespace
Modules: Backend
Instance Attribute Summary collapse
-
#aws_access_key_id ⇒ String
AWS credentials access key id.
-
#aws_secret_access_key ⇒ String
AWS secret access key.
-
#backend ⇒ Symbol, Telnyx::Models::S3GenericConfigurationData::Backend
Storage backend type.
-
#bucket ⇒ String
Name of the bucket to be used to store recording files.
-
#endpoint ⇒ String
URL of an S3-compatible storage endpoint, used to direct uploads and presigned download URLs to a non-AWS store (for example MinIO, Cloudflare R2, Wasabi, Backblaze B2, or Supabase).
-
#region ⇒ String
Region where the bucket is located.
Instance Method Summary collapse
-
#initialize(aws_access_key_id:, aws_secret_access_key:, backend:, bucket:, endpoint:, region:) ⇒ Object
constructor
Some parameter documentations has been truncated, see S3GenericConfigurationData for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(aws_access_key_id:, aws_secret_access_key:, backend:, bucket:, endpoint:, region:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::S3GenericConfigurationData for more details.
|
|
# File 'lib/telnyx/models/s3_generic_configuration_data.rb', line 46
|
Instance Attribute Details
#aws_access_key_id ⇒ String
AWS credentials access key id.
10 |
# File 'lib/telnyx/models/s3_generic_configuration_data.rb', line 10 required :aws_access_key_id, String |
#aws_secret_access_key ⇒ String
AWS secret access key.
16 |
# File 'lib/telnyx/models/s3_generic_configuration_data.rb', line 16 required :aws_secret_access_key, String |
#backend ⇒ Symbol, Telnyx::Models::S3GenericConfigurationData::Backend
Storage backend type
22 |
# File 'lib/telnyx/models/s3_generic_configuration_data.rb', line 22 required :backend, enum: -> { Telnyx::S3GenericConfigurationData::Backend } |
#bucket ⇒ String
Name of the bucket to be used to store recording files.
28 |
# File 'lib/telnyx/models/s3_generic_configuration_data.rb', line 28 required :bucket, String |
#endpoint ⇒ String
URL of an S3-compatible storage endpoint, used to direct uploads and presigned download URLs to a non-AWS store (for example MinIO, Cloudflare R2, Wasabi, Backblaze B2, or Supabase). A bare host (https://s3.example.com) or a path-prefixed URL (https://xyz.supabase.co/storage/v1/s3) is accepted, and must use the http or https scheme.
38 |
# File 'lib/telnyx/models/s3_generic_configuration_data.rb', line 38 required :endpoint, String |
#region ⇒ String
Region where the bucket is located.
44 |
# File 'lib/telnyx/models/s3_generic_configuration_data.rb', line 44 required :region, String |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/telnyx/models/s3_generic_configuration_data.rbs', line 35
def to_hash: -> {
|