Class: Telnyx::Models::SessionAnalysisRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/session_analysis_retrieve_params.rb

Overview

Defined Under Namespace

Modules: Expand

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(record_type:, event_id:, date_time: nil, expand: nil, include_children: nil, max_depth: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SessionAnalysisRetrieveParams for more details.

Parameters:

  • record_type (String)
  • event_id (String)
  • date_time (Time) (defaults to: nil)

    ISO 8601 timestamp or date to narrow index selection for faster lookups. Accepts

  • expand (Symbol, Telnyx::Models::SessionAnalysisRetrieveParams::Expand) (defaults to: nil)

    Controls what data to expand on each event node.

  • include_children (Boolean) (defaults to: nil)

    Whether to include child events in the response.

  • max_depth (Integer) (defaults to: nil)

    Maximum traversal depth for the event tree.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/session_analysis_retrieve_params.rb', line 46

Instance Attribute Details

#date_timeTime?

ISO 8601 timestamp or date to narrow index selection for faster lookups. Accepts full datetime (e.g., 2026-03-17T10:00:00Z) or date-only format (e.g., 2026-03-17).

Returns:

  • (Time, nil)


26
# File 'lib/telnyx/models/session_analysis_retrieve_params.rb', line 26

optional :date_time, Time

#event_idString

Returns:

  • (String)


18
# File 'lib/telnyx/models/session_analysis_retrieve_params.rb', line 18

required :event_id, String

#expandSymbol, ...

Controls what data to expand on each event node.



32
# File 'lib/telnyx/models/session_analysis_retrieve_params.rb', line 32

optional :expand, enum: -> { Telnyx::SessionAnalysisRetrieveParams::Expand }

#include_childrenBoolean?

Whether to include child events in the response.

Returns:

  • (Boolean, nil)


38
# File 'lib/telnyx/models/session_analysis_retrieve_params.rb', line 38

optional :include_children, Telnyx::Internal::Type::Boolean

#max_depthInteger?

Maximum traversal depth for the event tree.

Returns:

  • (Integer, nil)


44
# File 'lib/telnyx/models/session_analysis_retrieve_params.rb', line 44

optional :max_depth, Integer

#record_typeString

Returns:

  • (String)


13
# File 'lib/telnyx/models/session_analysis_retrieve_params.rb', line 13

required :record_type, String