Class: Telnyx::Models::SessionStatusChangedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/session_status_changed_webhook_event.rb,
sig/telnyx/models/session_status_changed_webhook_event.rbs

Defined Under Namespace

Modules: Event Classes: Data

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(recording:, session_id:, status:, status_detail:) ⇒ Object

Some parameter documentations has been truncated, see Data for more details.

Status transition details.

Parameters:

  • recording (Boolean)

    Whether the session is recording at this lifecycle edge.

  • session_id (String)

    The meeting session this event belongs to.

  • status (String)

    The new session status.

  • status_detail (String, nil)

    Additional detail about the status (for example timeout_exceeded_everyone_left



# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 36

Instance Attribute Details

#dataTelnyx::Models::SessionStatusChangedWebhookEvent::Data

Status transition details.

Parameters:

  • value (Telnyx::SessionStatusChangedWebhookEvent::Data)

Returns:



16
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 16

required :data, -> { Telnyx::SessionStatusChangedWebhookEvent::Data }

#eventSymbol, Telnyx::Models::SessionStatusChangedWebhookEvent::Event

Event type.

Parameters:

  • value (Telnyx::Models::SessionStatusChangedWebhookEvent::event)

Returns:



22
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 22

required :event, enum: -> { Telnyx::SessionStatusChangedWebhookEvent::Event }

#idString

Unique event id; deduplicate deliveries on it.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 10

required :id, String

#occurred_atTime

When the event occurred.

Parameters:

  • value (Time)

Returns:

  • (Time)


28
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 28

required :occurred_at, Time

#versionString

Envelope version.

Parameters:

  • value (String)

Returns:

  • (String)


34
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 34

required :version, String

Instance Method Details

#to_hash{

Returns:

  • ({)


31
# File 'sig/telnyx/models/session_status_changed_webhook_event.rbs', line 31

def to_hash: -> {