Class: Telnyx::Models::SessionStatusChangedWebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SessionStatusChangedWebhookEvent::Data
- Defined in:
- lib/telnyx/models/session_status_changed_webhook_event.rb,
sig/telnyx/models/session_status_changed_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#recording ⇒ Boolean
Whether the session is recording at this lifecycle edge.
-
#session_id ⇒ String
The meeting session this event belongs to.
-
#status ⇒ String
The new session status.
-
#status_detail ⇒ String?
Additional detail about the status (for example
timeout_exceeded_everyone_leftorcancelled), or null.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
56 |
# File 'sig/telnyx/models/session_status_changed_webhook_event.rbs', line 56
def initialize: (
|
Instance Attribute Details
#recording ⇒ Boolean
Whether the session is recording at this lifecycle edge.
53 |
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 53 required :recording, Telnyx::Internal::Type::Boolean |
#session_id ⇒ String
The meeting session this event belongs to.
59 |
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 59 required :session_id, String |
#status ⇒ String
The new session status.
65 |
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 65 required :status, String |
#status_detail ⇒ String?
Additional detail about the status (for example timeout_exceeded_everyone_left
or cancelled), or null.
72 |
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 72 required :status_detail, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
63 |
# File 'sig/telnyx/models/session_status_changed_webhook_event.rbs', line 63
def to_hash: -> {
|