Class: Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse::Data::BlackBoxTest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/seti_retrieve_black_box_test_results_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, record_type: nil, result: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    The name of the black box test.

  • record_type (String) (defaults to: nil)
  • result (Float) (defaults to: nil)

    The average result of the black box test over the last hour.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/telnyx/models/seti_retrieve_black_box_test_results_response.rb', line 41

class BlackBoxTest < Telnyx::Internal::Type::BaseModel
  # @!attribute id
  #   The name of the black box test.
  #
  #   @return [String, nil]
  optional :id, String

  # @!attribute record_type
  #
  #   @return [String, nil]
  optional :record_type, String

  # @!attribute result
  #   The average result of the black box test over the last hour.
  #
  #   @return [Float, nil]
  optional :result, Float

  # @!method initialize(id: nil, record_type: nil, result: nil)
  #   @param id [String] The name of the black box test.
  #
  #   @param record_type [String]
  #
  #   @param result [Float] The average result of the black box test over the last hour.
end

Instance Attribute Details

#idString?

The name of the black box test.

Returns:

  • (String, nil)


46
# File 'lib/telnyx/models/seti_retrieve_black_box_test_results_response.rb', line 46

optional :id, String

#record_typeString?

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/seti_retrieve_black_box_test_results_response.rb', line 51

optional :record_type, String

#resultFloat?

The average result of the black box test over the last hour.

Returns:

  • (Float, nil)


57
# File 'lib/telnyx/models/seti_retrieve_black_box_test_results_response.rb', line 57

optional :result, Float