Class: Telnyx::Models::SimCardGroupCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimCardGroupCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/sim_card_group_create_params.rb
Overview
Defined Under Namespace
Classes: DataLimit
Instance Attribute Summary collapse
-
#data_limit ⇒ Telnyx::Models::SimCardGroupCreateParams::DataLimit?
Upper limit on the amount of data the SIM cards, within the group, can use.
-
#name ⇒ String
A user friendly name for the SIM card group.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#data_limit ⇒ Telnyx::Models::SimCardGroupCreateParams::DataLimit?
Upper limit on the amount of data the SIM cards, within the group, can use.
20 |
# File 'lib/telnyx/models/sim_card_group_create_params.rb', line 20 optional :data_limit, -> { Telnyx::SimCardGroupCreateParams::DataLimit } |
#name ⇒ String
A user friendly name for the SIM card group.
14 |
# File 'lib/telnyx/models/sim_card_group_create_params.rb', line 14 required :name, String |