Class: Telnyx::Models::SimCardGroupCreateParams::DataLimit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimCardGroupCreateParams::DataLimit
- Defined in:
- lib/telnyx/models/sim_card_group_create_params.rb,
sig/telnyx/models/sim_card_group_create_params.rbs
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(amount: nil, unit: nil) ⇒ DataLimit
constructor
Upper limit on the amount of data the SIM cards, within the group, can use.
- #to_hash ⇒ { amount: String, unit: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount: nil, unit: nil) ⇒ DataLimit
Upper limit on the amount of data the SIM cards, within the group, can use.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/telnyx/models/sim_card_group_create_params.rb', line 29 class DataLimit < Telnyx::Internal::Type::BaseModel # @!attribute amount # # @return [String, nil] optional :amount, String # @!attribute unit # # @return [String, nil] optional :unit, String # @!method initialize(amount: nil, unit: nil) # Upper limit on the amount of data the SIM cards, within the group, can use. # # @param amount [String] # @param unit [String] end |
Instance Attribute Details
#amount ⇒ String?
33 |
# File 'lib/telnyx/models/sim_card_group_create_params.rb', line 33 optional :amount, String |
#unit ⇒ String?
38 |
# File 'lib/telnyx/models/sim_card_group_create_params.rb', line 38 optional :unit, String |
Instance Method Details
#to_hash ⇒ { amount: String, unit: String }
44 |
# File 'sig/telnyx/models/sim_card_group_create_params.rbs', line 44
def to_hash: -> { amount: String, unit: String }
|