Class: Telnyx::Models::SimCardGroupListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sim_card_group_list_response.rb,
sig/telnyx/models/sim_card_group_list_response.rbs

Overview

See Also:

  • Telnyx::Resources::SimCardGroups#list

Defined Under Namespace

Classes: DataLimit

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, consumed_data: nil, created_at: nil, data_limit: nil, default: nil, name: nil, private_wireless_gateway_id: nil, record_type: nil, sim_card_count: nil, updated_at: nil, wireless_blocklist_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SimCardGroupListResponse for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • consumed_data (Telnyx::Models::ConsumedData) (defaults to: nil)

    Represents the amount of data consumed.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • data_limit (Telnyx::Models::SimCardGroupListResponse::DataLimit) (defaults to: nil)

    Upper limit on the amount of data the SIM cards, within the group, can use.

  • default (Boolean) (defaults to: nil)

    Indicates whether the SIM card group is the users default group.
    The default

  • name (String) (defaults to: nil)

    A user friendly name for the SIM card group.

  • private_wireless_gateway_id (String) (defaults to: nil)

    The identification of the related Private Wireless Gateway resource.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • sim_card_count (Integer) (defaults to: nil)

    The number of SIM cards associated with the group.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.

  • wireless_blocklist_id (String) (defaults to: nil)

    The identification of the related Wireless Blocklist resource.



# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 76

Instance Attribute Details

#consumed_dataTelnyx::Models::ConsumedData?

Represents the amount of data consumed.

Parameters:

Returns:



11
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 11

optional :consumed_data, -> { Telnyx::ConsumedData }

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


49
50
51
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 49

def created_at
  @created_at
end

#data_limitTelnyx::Models::SimCardGroupListResponse::DataLimit?

Upper limit on the amount of data the SIM cards, within the group, can use.



17
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 17

optional :data_limit, -> { Telnyx::Models::SimCardGroupListResponse::DataLimit }

#defaultBoolean? (readonly)

Returns the value of attribute default.

Returns:

  • (Boolean, nil)


53
54
55
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 53

def default
  @default
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


45
46
47
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 45

def id
  @id
end

#nameString?

A user friendly name for the SIM card group.

Parameters:

  • (String)

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 23

optional :name, String

#private_wireless_gateway_idString?

The identification of the related Private Wireless Gateway resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 29

optional :private_wireless_gateway_id, String

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


57
58
59
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 57

def record_type
  @record_type
end

#sim_card_countInteger?

The number of SIM cards associated with the group.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


35
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 35

optional :sim_card_count, Integer

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


61
62
63
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 61

def updated_at
  @updated_at
end

#wireless_blocklist_idString?

The identification of the related Wireless Blocklist resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 41

optional :wireless_blocklist_id, String

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


51
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 51

def created_at=: (String) -> String

#default=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


55
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 55

def default=: (bool) -> bool

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


47
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 47

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


59
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 59

def record_type=: (String) -> String

#to_hash{

Returns:

  • ({)


79
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 79

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


63
# File 'sig/telnyx/models/sim_card_group_list_response.rbs', line 63

def updated_at=: (String) -> String