Class: Telnyx::Models::SimCardGroupUpdateParams::DataLimit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sim_card_group_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount: nil, unit: nil) ⇒ Object

Upper limit on the amount of data the SIM cards, within the group, can use.

Parameters:

  • amount (String) (defaults to: nil)
  • unit (String) (defaults to: nil)


36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/telnyx/models/sim_card_group_update_params.rb', line 36

class DataLimit < Telnyx::Internal::Type::BaseModel
  # @!attribute amount
  #
  #   @return [String, nil]
  optional :amount, String

  # @!attribute unit
  #
  #   @return [String, nil]
  optional :unit, String

  # @!method initialize(amount: nil, unit: nil)
  #   Upper limit on the amount of data the SIM cards, within the group, can use.
  #
  #   @param amount [String]
  #   @param unit [String]
end

Instance Attribute Details

#amountString?

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/sim_card_group_update_params.rb', line 40

optional :amount, String

#unitString?

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/sim_card_group_update_params.rb', line 45

optional :unit, String