Class: Telnyx::Models::SimCardListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/sim_card_list_params.rb

Overview

Defined Under Namespace

Modules: Sort Classes: Filter

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#filterTelnyx::Models::SimCardListParams::Filter?

Consolidated filter parameter for SIM cards (deepObject style). Originally: filter, filter, filter, filter



15
# File 'lib/telnyx/models/sim_card_list_params.rb', line 15

optional :filter, -> { Telnyx::SimCardListParams::Filter }

#filter_sim_card_group_idString?

A valid SIM card group ID.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/sim_card_list_params.rb', line 21

optional :filter_sim_card_group_id, String

#include_sim_card_groupBoolean?

It includes the associated SIM card group object in the response when present.

Returns:

  • (Boolean, nil)


27
# File 'lib/telnyx/models/sim_card_list_params.rb', line 27

optional :include_sim_card_group, Telnyx::Internal::Type::Boolean

#page_numberInteger?

Returns:

  • (Integer, nil)


32
# File 'lib/telnyx/models/sim_card_list_params.rb', line 32

optional :page_number, Integer

#page_sizeInteger?

Returns:

  • (Integer, nil)


37
# File 'lib/telnyx/models/sim_card_list_params.rb', line 37

optional :page_size, Integer

#sortSymbol, ...

Sorts SIM cards by the given field. Defaults to ascending order unless field is prefixed with a minus sign.

Returns:



44
# File 'lib/telnyx/models/sim_card_list_params.rb', line 44

optional :sort, enum: -> { Telnyx::SimCardListParams::Sort }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/sim_card_list_params.rb', line 121