Class: Telnyx::Models::SimCardListWirelessConnectivityLogsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimCardListWirelessConnectivityLogsResponse
- Defined in:
- lib/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rb,
sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs
Overview
Defined Under Namespace
Modules: LogType
Instance Attribute Summary collapse
-
#apn ⇒ String?
readonly
Returns the value of attribute apn.
-
#cell_id ⇒ String?
readonly
Returns the value of attribute cell_id.
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#id ⇒ Integer?
readonly
Returns the value of attribute id.
-
#imei ⇒ String?
readonly
Returns the value of attribute imei.
-
#imsi ⇒ String?
readonly
Returns the value of attribute imsi.
-
#ipv4 ⇒ String?
readonly
Returns the value of attribute ipv4.
-
#ipv6 ⇒ String?
readonly
Returns the value of attribute ipv6.
-
#last_seen ⇒ String?
readonly
Returns the value of attribute last_seen.
-
#log_type ⇒ Telnyx::Models::SimCardListWirelessConnectivityLogsResponse::log_type?
readonly
Returns the value of attribute log_type.
-
#mobile_country_code ⇒ String?
readonly
Returns the value of attribute mobile_country_code.
-
#mobile_network_code ⇒ String?
readonly
Returns the value of attribute mobile_network_code.
-
#radio_access_technology ⇒ String?
readonly
Returns the value of attribute radio_access_technology.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#sim_card_id ⇒ String?
The identification UUID of the related SIM card resource.
-
#start_time ⇒ String?
readonly
Returns the value of attribute start_time.
-
#state ⇒ String?
readonly
Returns the value of attribute state.
-
#stop_time ⇒ String?
readonly
Returns the value of attribute stop_time.
Instance Method Summary collapse
- #apn ⇒ String readonly
- #cell_id ⇒ String readonly
- #created_at ⇒ String readonly
- #id ⇒ Integer readonly
- #imei ⇒ String readonly
- #imsi ⇒ String readonly
-
#initialize(id: nil, apn: nil, cell_id: nil, created_at: nil, imei: nil, imsi: nil, ipv4: nil, ipv6: nil, last_seen: nil, log_type: nil, mobile_country_code: nil, mobile_network_code: nil, radio_access_technology: nil, record_type: nil, sim_card_id: nil, start_time: nil, state: nil, stop_time: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SimCardListWirelessConnectivityLogsResponse for more details.
- #ipv4 ⇒ String readonly
- #ipv6 ⇒ String readonly
- #last_seen ⇒ String readonly
- #log_type ⇒ Object readonly
- #mobile_country_code ⇒ String readonly
- #mobile_network_code ⇒ String readonly
- #radio_access_technology ⇒ String readonly
- #record_type ⇒ String readonly
- #start_time ⇒ String readonly
- #state ⇒ String readonly
- #stop_time ⇒ String readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, apn: nil, cell_id: nil, created_at: nil, imei: nil, imsi: nil, ipv4: nil, ipv6: nil, last_seen: nil, log_type: nil, mobile_country_code: nil, mobile_network_code: nil, radio_access_technology: nil, record_type: nil, sim_card_id: nil, start_time: nil, state: nil, stop_time: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::SimCardListWirelessConnectivityLogsResponse for more details.
This object represents a wireless connectivity session log that happened through a SIM card. It aids in finding out potential problems when the SIM is not able to attach properly.
|
|
# File 'lib/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rb', line 134
|
Instance Attribute Details
#apn ⇒ String? (readonly)
Returns the value of attribute apn.
34 35 36 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 34 def apn @apn end |
#cell_id ⇒ String? (readonly)
Returns the value of attribute cell_id.
38 39 40 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 38 def cell_id @cell_id end |
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
42 43 44 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 42 def created_at @created_at end |
#id ⇒ Integer? (readonly)
Returns the value of attribute id.
30 31 32 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 30 def id @id end |
#imei ⇒ String? (readonly)
Returns the value of attribute imei.
46 47 48 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 46 def imei @imei end |
#imsi ⇒ String? (readonly)
Returns the value of attribute imsi.
50 51 52 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 50 def imsi @imsi end |
#ipv4 ⇒ String? (readonly)
Returns the value of attribute ipv4.
54 55 56 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 54 def ipv4 @ipv4 end |
#ipv6 ⇒ String? (readonly)
Returns the value of attribute ipv6.
58 59 60 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 58 def ipv6 @ipv6 end |
#last_seen ⇒ String? (readonly)
Returns the value of attribute last_seen.
62 63 64 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 62 def last_seen @last_seen end |
#log_type ⇒ Telnyx::Models::SimCardListWirelessConnectivityLogsResponse::log_type? (readonly)
Returns the value of attribute log_type.
66 67 68 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 66 def log_type @log_type end |
#mobile_country_code ⇒ String? (readonly)
Returns the value of attribute mobile_country_code.
72 73 74 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 72 def mobile_country_code @mobile_country_code end |
#mobile_network_code ⇒ String? (readonly)
Returns the value of attribute mobile_network_code.
76 77 78 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 76 def mobile_network_code @mobile_network_code end |
#radio_access_technology ⇒ String? (readonly)
Returns the value of attribute radio_access_technology.
80 81 82 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 80 def radio_access_technology @radio_access_technology end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
84 85 86 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 84 def record_type @record_type end |
#sim_card_id ⇒ String?
The identification UUID of the related SIM card resource.
11 |
# File 'lib/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rb', line 11 optional :sim_card_id, String |
#start_time ⇒ String? (readonly)
Returns the value of attribute start_time.
88 89 90 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 88 def start_time @start_time end |
#state ⇒ String? (readonly)
Returns the value of attribute state.
92 93 94 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 92 def state @state end |
#stop_time ⇒ String? (readonly)
Returns the value of attribute stop_time.
96 97 98 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 96 def stop_time @stop_time end |
Instance Method Details
#apn= ⇒ String (readonly)
36 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 36
def apn=: (String) -> String
|
#cell_id= ⇒ String (readonly)
40 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 40
def cell_id=: (String) -> String
|
#created_at= ⇒ String (readonly)
44 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 44
def created_at=: (String) -> String
|
#id= ⇒ Integer (readonly)
32 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 32
def id=: (Integer) -> Integer
|
#imei= ⇒ String (readonly)
48 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 48
def imei=: (String) -> String
|
#imsi= ⇒ String (readonly)
52 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 52
def imsi=: (String) -> String
|
#ipv4= ⇒ String (readonly)
56 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 56
def ipv4=: (String) -> String
|
#ipv6= ⇒ String (readonly)
60 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 60
def ipv6=: (String) -> String
|
#last_seen= ⇒ String (readonly)
64 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 64
def last_seen=: (String) -> String
|
#log_type= ⇒ Object (readonly)
68 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 68
def log_type=: (
|
#mobile_country_code= ⇒ String (readonly)
74 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 74
def mobile_country_code=: (String) -> String
|
#mobile_network_code= ⇒ String (readonly)
78 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 78
def mobile_network_code=: (String) -> String
|
#radio_access_technology= ⇒ String (readonly)
82 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 82
def radio_access_technology=: (String) -> String
|
#record_type= ⇒ String (readonly)
86 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 86
def record_type=: (String) -> String
|
#start_time= ⇒ String (readonly)
90 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 90
def start_time=: (String) -> String
|
#state= ⇒ String (readonly)
94 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 94
def state=: (String) -> String
|
#stop_time= ⇒ String (readonly)
98 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 98
def stop_time=: (String) -> String
|
#to_hash ⇒ {
121 |
# File 'sig/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rbs', line 121
def to_hash: -> {
|