Class: Telnyx::Models::SimCardOrder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sim_card_order.rb,
sig/telnyx/models/sim_card_order.rbs

Overview

See Also:

  • Telnyx::Resources::SimCardOrders#list

Defined Under Namespace

Modules: Status Classes: Cost, OrderAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, administrative_area: nil, business_name: nil, country_code: nil, extended_address: nil, first_name: nil, last_name: nil, locality: nil, postal_code: nil, street_address: nil) ⇒ Object

An object representing the address information from when the order was submitted.

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the address for the order.

  • administrative_area (String) (defaults to: nil)

    State or province where the address is located.

  • business_name (String) (defaults to: nil)

    The name of the business where the address is located.

  • country_code (String) (defaults to: nil)

    The mobile operator two-character (ISO 3166-1 alpha-2) origin country code.

  • extended_address (String) (defaults to: nil)

    Supplemental field for address information.

  • first_name (String) (defaults to: nil)

    The first name of the shipping recipient.

  • last_name (String) (defaults to: nil)

    The last name of the shipping recipient.

  • locality (String) (defaults to: nil)

    The name of the city where the address is located.

  • postal_code (String) (defaults to: nil)

    Postal code for the address.

  • street_address (String) (defaults to: nil)

    The name of the street where the address is located.



# File 'lib/telnyx/models/sim_card_order.rb', line 71

Instance Attribute Details

#costTelnyx::Models::SimCardOrder::Cost?

An object representing the total cost of the order.

Parameters:

  • (Telnyx::SimCardOrder::Cost)

Returns:



11
# File 'lib/telnyx/models/sim_card_order.rb', line 11

optional :cost, -> { Telnyx::SimCardOrder::Cost }

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


39
40
41
# File 'sig/telnyx/models/sim_card_order.rbs', line 39

def created_at
  @created_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


35
36
37
# File 'sig/telnyx/models/sim_card_order.rbs', line 35

def id
  @id
end

#order_addressTelnyx::SimCardOrder::OrderAddress? (readonly)

Returns the value of attribute order_address.

Returns:

  • (Telnyx::SimCardOrder::OrderAddress, nil)


43
44
45
# File 'sig/telnyx/models/sim_card_order.rbs', line 43

def order_address
  @order_address
end

#quantityInteger?

The amount of SIM cards requested in the SIM card order.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


17
# File 'lib/telnyx/models/sim_card_order.rb', line 17

optional :quantity, Integer

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


49
50
51
# File 'sig/telnyx/models/sim_card_order.rbs', line 49

def record_type
  @record_type
end

#statusSymbol, ...

The current status of the SIM Card order.

  • pending - the order is waiting to be processed.
  • processing - the order is currently being processed.
  • ready_to_ship - the order is ready to be shipped to the specified address.
  • shipped - the order was shipped and is on its way to be delivered to the specified address.
  • delivered - the order was delivered to the specified address.
  • canceled - the order was canceled.

Returns:



30
# File 'lib/telnyx/models/sim_card_order.rb', line 30

optional :status, enum: -> { Telnyx::SimCardOrder::Status }

#tracking_urlString?

The URL used to get tracking information about the order.

Parameters:

  • (String)

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/sim_card_order.rb', line 36

optional :tracking_url, String

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


53
54
55
# File 'sig/telnyx/models/sim_card_order.rbs', line 53

def updated_at
  @updated_at
end

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


41
# File 'sig/telnyx/models/sim_card_order.rbs', line 41

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


37
# File 'sig/telnyx/models/sim_card_order.rbs', line 37

def id=: (String) -> String

#order_address=Object (readonly)



45
# File 'sig/telnyx/models/sim_card_order.rbs', line 45

def order_address=: (

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


51
# File 'sig/telnyx/models/sim_card_order.rbs', line 51

def record_type=: (String) -> String

#to_hash{

Returns:

  • ({)


69
# File 'sig/telnyx/models/sim_card_order.rbs', line 69

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


55
# File 'sig/telnyx/models/sim_card_order.rbs', line 55

def updated_at=: (String) -> String