Class: Telnyx::Models::SimCardOrder::OrderAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sim_card_order.rb

Overview

See Also:

  • #order_address

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#administrative_areaString?

State or province where the address is located.

Returns:

  • (String, nil)


127
# File 'lib/telnyx/models/sim_card_order.rb', line 127

optional :administrative_area, String

#business_nameString?

The name of the business where the address is located.

Returns:

  • (String, nil)


133
# File 'lib/telnyx/models/sim_card_order.rb', line 133

optional :business_name, String

#country_codeString?

The mobile operator two-character (ISO 3166-1 alpha-2) origin country code.

Returns:

  • (String, nil)


139
# File 'lib/telnyx/models/sim_card_order.rb', line 139

optional :country_code, String

#extended_addressString?

Supplemental field for address information.

Returns:

  • (String, nil)


145
# File 'lib/telnyx/models/sim_card_order.rb', line 145

optional :extended_address, String

#first_nameString?

The first name of the shipping recipient.

Returns:

  • (String, nil)


151
# File 'lib/telnyx/models/sim_card_order.rb', line 151

optional :first_name, String

#idString?

Uniquely identifies the address for the order.

Returns:

  • (String, nil)


121
# File 'lib/telnyx/models/sim_card_order.rb', line 121

optional :id, String

#last_nameString?

The last name of the shipping recipient.

Returns:

  • (String, nil)


157
# File 'lib/telnyx/models/sim_card_order.rb', line 157

optional :last_name, String

#localityString?

The name of the city where the address is located.

Returns:

  • (String, nil)


163
# File 'lib/telnyx/models/sim_card_order.rb', line 163

optional :locality, String

#postal_codeString?

Postal code for the address.

Returns:

  • (String, nil)


169
# File 'lib/telnyx/models/sim_card_order.rb', line 169

optional :postal_code, String

#street_addressString?

The name of the street where the address is located.

Returns:

  • (String, nil)


175
# File 'lib/telnyx/models/sim_card_order.rb', line 175

optional :street_address, String