Module: Telnyx::Models::SimCardOrder::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/sim_card_order.rb,
sig/telnyx/models/sim_card_order.rbs
Overview
The current status of the SIM Card order.
pending- the order is waiting to be processed.processing- the order is currently being processed.ready_to_ship- the order is ready to be shipped to the specified address.shipped- the order was shipped and is on its way to be delivered to the specified address.delivered- the order was delivered to the specified address.canceled- the order was canceled.
Constant Summary collapse
- PENDING =
:pending- PROCESSING =
:processing- READY_TO_SHIP =
:ready_to_ship- SHIPPED =
:shipped- DELIVERED =
:delivered- CANCELED =
:canceled
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/sim_card_order.rb', line 222
|
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::SimCardOrder::status]
197 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 197
def self?.values: -> ::Array[Telnyx::Models::SimCardOrder::status]
|