Class: Telnyx::Models::SimCardRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/sim_card_retrieve_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, include_pin_puk_codes: nil, include_sim_card_group: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SimCardRetrieveParams for more details.

Parameters:

  • id (String)
  • include_pin_puk_codes (Boolean) (defaults to: nil)

    When set to true, includes the PIN and PUK codes in the response. These codes ar

  • include_sim_card_group (Boolean) (defaults to: nil)

    It includes the associated SIM card group object in the response when present.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/sim_card_retrieve_params.rb', line 29

Instance Attribute Details

#idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/sim_card_retrieve_params.rb', line 13

required :id, String

#include_pin_puk_codesBoolean?

When set to true, includes the PIN and PUK codes in the response. These codes are used for SIM card security and unlocking purposes. Available for both physical SIM cards and eSIMs.

Returns:

  • (Boolean, nil)


21
# File 'lib/telnyx/models/sim_card_retrieve_params.rb', line 21

optional :include_pin_puk_codes, Telnyx::Internal::Type::Boolean

#include_sim_card_groupBoolean?

It includes the associated SIM card group object in the response when present.

Returns:

  • (Boolean, nil)


27
# File 'lib/telnyx/models/sim_card_retrieve_params.rb', line 27

optional :include_sim_card_group, Telnyx::Internal::Type::Boolean