Module: Telnyx::Models::SimCardStatus::Value

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/sim_card_status.rb,
sig/telnyx/models/sim_card_status.rbs

Overview

The current status of the SIM card. It will be one of the following:

  • registering - the card is being registered
  • enabling - the card is being enabled
  • enabled - the card is enabled and ready for use
  • disabling - the card is being disabled
  • disabled - the card has been disabled and cannot be used
  • data_limit_exceeded - the card has exceeded its data consumption limit
  • setting_standby - the process to set the card in stand by is in progress
  • standby - the card is in stand by
Transitioning between the enabled and disabled states may take a period of time.

See Also:

  • Telnyx::Models::SimCardStatus#value

Constant Summary collapse

REGISTERING =

Returns:

  • (:registering)
:registering
ENABLING =

Returns:

  • (:enabling)
:enabling
ENABLED =

Returns:

  • (:enabled)
:enabled
DISABLING =

Returns:

  • (:disabling)
:disabling
DISABLED =

Returns:

  • (:disabled)
:disabled
DATA_LIMIT_EXCEEDED =

Returns:

  • (:data_limit_exceeded)
:data_limit_exceeded
SETTING_STANDBY =

Returns:

  • (:setting_standby)
:setting_standby
STANDBY =

Returns:

  • (:standby)
:standby

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/sim_card_status.rb', line 67

Instance Method Details

#self?.values::Array[Telnyx::Models::SimCardStatus::value]

Returns:

  • (::Array[Telnyx::Models::SimCardStatus::value])


49
# File 'sig/telnyx/models/sim_card_status.rbs', line 49

def self?.values: -> ::Array[Telnyx::Models::SimCardStatus::value]