Class: Telnyx::Models::SimpleSimCard
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimpleSimCard
- Defined in:
- lib/telnyx/models/simple_sim_card.rb,
sig/telnyx/models/simple_sim_card.rbs
Defined Under Namespace
Modules: EsimInstallationStatus, Type Classes: CurrentBillingPeriodConsumedData, DataLimit
Instance Attribute Summary collapse
-
#actions_in_progress ⇒ Boolean?
readonly
Returns the value of attribute actions_in_progress.
-
#authorized_imeis ⇒ Array<String>?
List of IMEIs authorized to use a given SIM card.
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#current_billing_period_consumed_data ⇒ Telnyx::SimpleSimCard::CurrentBillingPeriodConsumedData?
readonly
Returns the value of attribute current_billing_period_consumed_data.
-
#data_limit ⇒ Telnyx::SimpleSimCard::DataLimit?
readonly
Returns the value of attribute data_limit.
-
#eid ⇒ String?
Returns the value of attribute eid.
-
#esim_installation_status ⇒ Telnyx::Models::SimpleSimCard::esim_installation_status?
Returns the value of attribute esim_installation_status.
-
#iccid ⇒ String?
readonly
Returns the value of attribute iccid.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#imsi ⇒ String?
readonly
Returns the value of attribute imsi.
-
#msisdn ⇒ String?
readonly
Returns the value of attribute msisdn.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#resources_with_in_progress_actions ⇒ ::Array[::Hash[Symbol, top]]?
readonly
Returns the value of attribute resources_with_in_progress_actions.
-
#sim_card_group_id ⇒ String?
The group SIMCardGroup identification.
- #status ⇒ Telnyx::Models::SimCardStatus?
-
#tags ⇒ Array<String>?
Searchable tags associated with the SIM card.
-
#type ⇒ Telnyx::Models::SimpleSimCard::type_?
readonly
Returns the value of attribute type.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
-
#version ⇒ String?
readonly
Returns the value of attribute version.
-
#voice_enabled ⇒ Boolean?
readonly
Returns the value of attribute voice_enabled.
Class Method Summary collapse
Instance Method Summary collapse
- #actions_in_progress ⇒ Boolean readonly
- #created_at ⇒ String readonly
- #current_billing_period_consumed_data ⇒ Object readonly
- #data_limit ⇒ Object readonly
- #iccid ⇒ String readonly
- #id ⇒ String readonly
- #imsi ⇒ String readonly
-
#initialize(amount: nil, unit: nil) ⇒ Object
constructor
The SIM card consumption so far in the current billing cycle.
- #msisdn ⇒ String readonly
- #record_type ⇒ String readonly
- #resources_with_in_progress_actions ⇒ Object readonly
- #to_hash ⇒ {
- #type ⇒ Object readonly
- #updated_at ⇒ String readonly
- #version ⇒ String readonly
- #voice_enabled ⇒ Boolean readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount: nil, unit: nil) ⇒ Object
The SIM card consumption so far in the current billing cycle.
|
|
# File 'lib/telnyx/models/simple_sim_card.rb', line 145
|
Instance Attribute Details
#actions_in_progress ⇒ Boolean? (readonly)
Returns the value of attribute actions_in_progress.
46 47 48 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 46 def actions_in_progress @actions_in_progress end |
#authorized_imeis ⇒ Array<String>?
List of IMEIs authorized to use a given SIM card.
10 |
# File 'lib/telnyx/models/simple_sim_card.rb', line 10 optional :authorized_imeis, Telnyx::Internal::Type::ArrayOf[String], nil?: true |
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
50 51 52 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 50 def created_at @created_at end |
#current_billing_period_consumed_data ⇒ Telnyx::SimpleSimCard::CurrentBillingPeriodConsumedData? (readonly)
Returns the value of attribute current_billing_period_consumed_data.
54 55 56 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 54 def current_billing_period_consumed_data @current_billing_period_consumed_data end |
#data_limit ⇒ Telnyx::SimpleSimCard::DataLimit? (readonly)
Returns the value of attribute data_limit.
60 61 62 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 60 def data_limit @data_limit end |
#eid ⇒ String?
Returns the value of attribute eid.
66 67 68 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 66 def eid @eid end |
#esim_installation_status ⇒ Telnyx::Models::SimpleSimCard::esim_installation_status?
Returns the value of attribute esim_installation_status.
68 69 70 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 68 def esim_installation_status @esim_installation_status end |
#iccid ⇒ String? (readonly)
Returns the value of attribute iccid.
70 71 72 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 70 def iccid @iccid end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
42 43 44 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 42 def id @id end |
#imsi ⇒ String? (readonly)
Returns the value of attribute imsi.
74 75 76 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 74 def imsi @imsi end |
#msisdn ⇒ String? (readonly)
Returns the value of attribute msisdn.
78 79 80 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 78 def msisdn @msisdn end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
82 83 84 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 82 def record_type @record_type end |
#resources_with_in_progress_actions ⇒ ::Array[::Hash[Symbol, top]]? (readonly)
Returns the value of attribute resources_with_in_progress_actions.
86 87 88 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 86 def resources_with_in_progress_actions @resources_with_in_progress_actions end |
#sim_card_group_id ⇒ String?
The group SIMCardGroup identification. This attribute can be null
when it's present in an associated resource.
17 |
# File 'lib/telnyx/models/simple_sim_card.rb', line 17 optional :sim_card_group_id, String |
#status ⇒ Telnyx::Models::SimCardStatus?
22 |
# File 'lib/telnyx/models/simple_sim_card.rb', line 22 optional :status, -> { Telnyx::SimCardStatus } |
#tags ⇒ Array<String>?
Searchable tags associated with the SIM card
28 |
# File 'lib/telnyx/models/simple_sim_card.rb', line 28 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#type ⇒ Telnyx::Models::SimpleSimCard::type_? (readonly)
Returns the value of attribute type.
92 93 94 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 92 def type @type end |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
98 99 100 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 98 def updated_at @updated_at end |
#version ⇒ String? (readonly)
Returns the value of attribute version.
102 103 104 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 102 def version @version end |
#voice_enabled ⇒ Boolean? (readonly)
Returns the value of attribute voice_enabled.
106 107 108 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 106 def voice_enabled @voice_enabled end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/simple_sim_card.rb', line 233
|
Instance Method Details
#actions_in_progress= ⇒ Boolean (readonly)
48 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 48
def actions_in_progress=: (bool) -> bool
|
#created_at= ⇒ String (readonly)
52 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 52
def created_at=: (String) -> String
|
#current_billing_period_consumed_data= ⇒ Object (readonly)
56 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 56
def current_billing_period_consumed_data=: (
|
#data_limit= ⇒ Object (readonly)
62 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 62
def data_limit=: (
|
#iccid= ⇒ String (readonly)
72 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 72
def iccid=: (String) -> String
|
#id= ⇒ String (readonly)
44 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 44
def id=: (String) -> String
|
#imsi= ⇒ String (readonly)
76 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 76
def imsi=: (String) -> String
|
#msisdn= ⇒ String (readonly)
80 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 80
def msisdn=: (String) -> String
|
#record_type= ⇒ String (readonly)
84 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 84
def record_type=: (String) -> String
|
#resources_with_in_progress_actions= ⇒ Object (readonly)
88 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 88
def resources_with_in_progress_actions=: (
|
#to_hash ⇒ {
133 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 133
def to_hash: -> {
|
#type= ⇒ Object (readonly)
94 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 94
def type=: (
|
#updated_at= ⇒ String (readonly)
100 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 100
def updated_at=: (String) -> String
|
#version= ⇒ String (readonly)
104 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 104
def version=: (String) -> String
|
#voice_enabled= ⇒ Boolean (readonly)
108 |
# File 'sig/telnyx/models/simple_sim_card.rbs', line 108
def voice_enabled=: (bool) -> bool
|