Class: Telnyx::Models::SipRegistrationStatusRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/sip_registration_status_retrieve_params.rb

Overview

Defined Under Namespace

Modules: CredentialType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credential_type:, connection_id: nil, username: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SipRegistrationStatusRetrieveParams for more details.

Parameters:

  • credential_type (Symbol, Telnyx::Models::SipRegistrationStatusRetrieveParams::CredentialType)

    The kind of credential to look up. ‘uac_external_credential` is keyed by `connec

  • connection_id (String) (defaults to: nil)

    Identifier of the UAC connection to look up. Required when ‘credential_type` is

  • username (String) (defaults to: nil)

    SIP username of the telephony credential to look up. Required when ‘credential_t

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/sip_registration_status_retrieve_params.rb', line 31

Instance Attribute Details

#connection_idString?

Identifier of the UAC connection to look up. Required when ‘credential_type` is `uac_external_credential`.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/sip_registration_status_retrieve_params.rb', line 22

optional :connection_id, String

#credential_typeSymbol, Telnyx::Models::SipRegistrationStatusRetrieveParams::CredentialType

The kind of credential to look up. ‘uac_external_credential` is keyed by `connection_id`; `telephony_credential` is keyed by `username`.



15
# File 'lib/telnyx/models/sip_registration_status_retrieve_params.rb', line 15

required :credential_type, enum: -> { Telnyx::SipRegistrationStatusRetrieveParams::CredentialType }

#usernameString?

SIP username of the telephony credential to look up. Required when ‘credential_type` is `telephony_credential`.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/sip_registration_status_retrieve_params.rb', line 29

optional :username, String