Class: Telnyx::Models::SipRegistrationStatusRetrieveResponse::SipRegistrationDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sip_registration_status_retrieve_response.rb,
sig/telnyx/models/sip_registration_status_retrieve_response.rbs

Overview

See Also:

  • Telnyx::Models::SipRegistrationStatusRetrieveResponse#sip_registration_details

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



144
# File 'sig/telnyx/models/sip_registration_status_retrieve_response.rbs', line 144

def initialize: (

Instance Attribute Details

#auth_retriesInteger?

Number of authentication retries on the last attempt (uac_external_credential).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


102
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 102

optional :auth_retries, Integer

#expiresInteger?

Unix timestamp when the current registration expires.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


108
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 108

optional :expires, Integer

#failuresInteger?

Count of consecutive registration failures (uac_external_credential).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


114
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 114

optional :failures, Integer

#last_modifiedString?

Timestamp when the registration was last modified (telephony_credential and sip_credential_connection).

Parameters:

  • (String)

Returns:

  • (String, nil)


121
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 121

optional :last_modified, String

#next_action_atInteger?

Unix timestamp of the next scheduled registration action (uac_external_credential).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


128
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 128

optional :next_action_at, Integer

#sip_uri_user_hostString?

SIP URI user@host of the registered contact (uac_external_credential).

Parameters:

  • (String)

Returns:

  • (String, nil)


134
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 134

optional :sip_uri_user_host, String

#transportString?

Transport used for the registration, e.g. UDP/TCP/TLS (telephony_credential and sip_credential_connection).

Parameters:

  • (String)

Returns:

  • (String, nil)


141
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 141

optional :transport, String

#ua_ipString?

IP address of the registered user agent (telephony_credential and sip_credential_connection).

Parameters:

  • (String)

Returns:

  • (String, nil)


148
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 148

optional :ua_ip, String

#ua_portInteger?

Port of the registered user agent (telephony_credential and sip_credential_connection).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


155
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 155

optional :ua_port, Integer

#uptimeInteger?

Registration uptime reported by the registrar (uac_external_credential).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


161
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 161

optional :uptime, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


157
# File 'sig/telnyx/models/sip_registration_status_retrieve_response.rbs', line 157

def to_hash: -> {