Class: Telnyx::Models::SiprecConnectorUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/siprec_connector_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(connector_name:, host:, name:, port:, app_subdomain: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SiprecConnectorUpdateParams for more details.

Parameters:

  • connector_name (String)
  • host (String)

    Hostname/IPv4 address of the SIPREC SRS.

  • name (String)

    Name for the SIPREC connector resource.

  • port (Integer)

    Port for the SIPREC SRS.

  • app_subdomain (String) (defaults to: nil)

    Subdomain to route the call when using Telnyx SRS (optional for non-Telnyx SRS).

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 39

Instance Attribute Details

#app_subdomainString?

Subdomain to route the call when using Telnyx SRS (optional for non-Telnyx SRS).

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 37

optional :app_subdomain, String

#connector_nameString

Returns:

  • (String)


13
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 13

required :connector_name, String

#hostString

Hostname/IPv4 address of the SIPREC SRS.

Returns:

  • (String)


19
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 19

required :host, String

#nameString

Name for the SIPREC connector resource.

Returns:

  • (String)


25
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 25

required :name, String

#portInteger

Port for the SIPREC SRS.

Returns:

  • (Integer)


31
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 31

required :port, Integer