Class: Telnyx::Models::SoundModifications

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sound_modifications.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(octaves: nil, pitch: nil, semitone: nil, track: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SoundModifications for more details.

Use this field to modify sound effects, for example adjust the pitch.

Parameters:

  • octaves (Float) (defaults to: nil)

    Adjust the pitch in octaves, values should be between -1 and 1, default 0

  • pitch (Float) (defaults to: nil)

    Set the pitch directly, value should be > 0, default 1 (lower = lower tone)

  • semitone (Float) (defaults to: nil)

    Adjust the pitch in semitones, values should be between -14 and 14, default 0

  • track (String) (defaults to: nil)

    The track to which the sound modifications will be applied. Accepted values are



# File 'lib/telnyx/models/sound_modifications.rb', line 31

Instance Attribute Details

#octavesFloat?

Adjust the pitch in octaves, values should be between -1 and 1, default 0

Returns:

  • (Float, nil)


10
# File 'lib/telnyx/models/sound_modifications.rb', line 10

optional :octaves, Float

#pitchFloat?

Set the pitch directly, value should be > 0, default 1 (lower = lower tone)

Returns:

  • (Float, nil)


16
# File 'lib/telnyx/models/sound_modifications.rb', line 16

optional :pitch, Float

#semitoneFloat?

Adjust the pitch in semitones, values should be between -14 and 14, default 0

Returns:

  • (Float, nil)


22
# File 'lib/telnyx/models/sound_modifications.rb', line 22

optional :semitone, Float

#trackString?

The track to which the sound modifications will be applied. Accepted values are ‘inbound` or `outbound`

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/sound_modifications.rb', line 29

optional :track, String