Class: Telnyx::Models::SpeechToTextListProvidersParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SpeechToTextListProvidersParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/speech_to_text_list_providers_params.rb,
sig/telnyx/models/speech_to_text_list_providers_params.rbs
Overview
Defined Under Namespace
Modules: Provider
Instance Attribute Summary collapse
-
#provider ⇒ Symbol, ...
Filter to entries for a specific STT provider.
-
#service_type ⇒ Symbol, ...
Filter to entries that support the given service type.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(provider: nil, service_type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SpeechToTextListProvidersParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(provider: nil, service_type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::SpeechToTextListProvidersParams for more details.
|
|
# File 'lib/telnyx/models/speech_to_text_list_providers_params.rb', line 31
|
Instance Attribute Details
#provider ⇒ Symbol, ...
Filter to entries for a specific STT provider. The enum mirrors the providers
advertised across the speech-to-text spec (including google and telnyx,
which are accepted as WebSocket transcription engines). A provider that has no
models currently registered for any service type will return an empty data
array rather than an error.
18 |
# File 'lib/telnyx/models/speech_to_text_list_providers_params.rb', line 18 optional :provider, enum: -> { Telnyx::SpeechToTextListProvidersParams::Provider } |
#service_type ⇒ Symbol, ...
Filter to entries that support the given service type. For backward
compatibility with the values that briefly shipped before the product-aligned
rename, the legacy aliases file_transcription, in_call_transcription, and
ai_assistant_transcription are silently accepted and normalized to
file_based, in_call, and ai_assistant respectively. The response always
emits the canonical (post-rename) values.
29 |
# File 'lib/telnyx/models/speech_to_text_list_providers_params.rb', line 29 optional :service_type, enum: -> { Telnyx::SttServiceType } |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/telnyx/models/speech_to_text_list_providers_params.rbs', line 32
def to_hash: -> {
|