Class: Telnyx::Models::SpeechToTextRetrieveTranscriptionParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb

Overview

Defined Under Namespace

Modules: InputFormat, Model, TranscriptionEngine

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input_format:, transcription_engine:, endpointing: nil, interim_results: nil, keyterm: nil, keywords: nil, language: nil, model: nil, redact: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SpeechToTextRetrieveTranscriptionParams for more details.

Parameters:

  • input_format (Symbol, Telnyx::Models::SpeechToTextRetrieveTranscriptionParams::InputFormat)

    The format of input audio stream.

  • transcription_engine (Symbol, Telnyx::Models::SpeechToTextRetrieveTranscriptionParams::TranscriptionEngine)

    The transcription engine to use for processing the audio stream.

  • endpointing (Integer) (defaults to: nil)

    Silence duration (in milliseconds) that triggers end-of-speech detection. When s

  • interim_results (Boolean) (defaults to: nil)

    Whether to receive interim transcription results.

  • keyterm (String) (defaults to: nil)

    A key term to boost in the transcription. The engine will be more likely to reco

  • keywords (String) (defaults to: nil)

    Comma-separated list of keywords to boost in the transcription. The engine will

  • language (String) (defaults to: nil)

    The language spoken in the audio stream.

  • model (Symbol, Telnyx::Models::SpeechToTextRetrieveTranscriptionParams::Model) (defaults to: nil)

    The specific model to use within the selected transcription engine.

  • redact (String) (defaults to: nil)

    Enable redaction of sensitive information (e.g., PCI data, SSN) from transcripti

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 72

Instance Attribute Details

#endpointingInteger?

Silence duration (in milliseconds) that triggers end-of-speech detection. When set, the engine uses this value to determine when a speaker has stopped talking. Supported by ‘xAI`, `Deepgram`, `Google`, `Speechmatics`, and `Soniox`. `Soniox` accepts values between 500 and 3000. Other engines may not support this parameter.

Returns:

  • (Integer, nil)


31
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 31

optional :endpointing, Integer

#input_formatSymbol, Telnyx::Models::SpeechToTextRetrieveTranscriptionParams::InputFormat

The format of input audio stream.



14
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 14

required :input_format, enum: -> { Telnyx::SpeechToTextRetrieveTranscriptionParams::InputFormat }

#interim_resultsBoolean?

Whether to receive interim transcription results.

Returns:

  • (Boolean, nil)


37
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 37

optional :interim_results, Telnyx::Internal::Type::Boolean

#keytermString?

A key term to boost in the transcription. The engine will be more likely to recognize this term. Can be specified multiple times for multiple terms.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 44

optional :keyterm, String

#keywordsString?

Comma-separated list of keywords to boost in the transcription. The engine will prioritize recognition of these words.

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 51

optional :keywords, String

#languageString?

The language spoken in the audio stream.

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 57

optional :language, String

#modelSymbol, ...

The specific model to use within the selected transcription engine.



63
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 63

optional :model, enum: -> { Telnyx::SpeechToTextRetrieveTranscriptionParams::Model }

#redactString?

Enable redaction of sensitive information (e.g., PCI data, SSN) from transcription results. Supported values depend on the transcription engine.

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 70

optional :redact, String

#transcription_engineSymbol, Telnyx::Models::SpeechToTextRetrieveTranscriptionParams::TranscriptionEngine

The transcription engine to use for processing the audio stream.



20
21
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 20

required :transcription_engine,
enum: -> { Telnyx::SpeechToTextRetrieveTranscriptionParams::TranscriptionEngine }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 103