Class: Telnyx::Models::SpeechToTextTranscribeParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/speech_to_text_transcribe_params.rb

Overview

Defined Under Namespace

Modules: InputFormat, Model, TranscriptionEngine

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input_format:, transcription_engine:, interim_results: nil, language: nil, model: nil, request_options: {}) ⇒ Object

Parameters:



# File 'lib/telnyx/models/speech_to_text_transcribe_params.rb', line 40

Instance Attribute Details

#input_formatSymbol, Telnyx::Models::SpeechToTextTranscribeParams::InputFormat

The format of input audio stream.



14
# File 'lib/telnyx/models/speech_to_text_transcribe_params.rb', line 14

required :input_format, enum: -> { Telnyx::SpeechToTextTranscribeParams::InputFormat }

#interim_resultsBoolean?

Whether to receive interim transcription results.

Returns:

  • (Boolean, nil)


26
# File 'lib/telnyx/models/speech_to_text_transcribe_params.rb', line 26

optional :interim_results, Telnyx::Internal::Type::Boolean

#languageString?

The language spoken in the audio stream.

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/speech_to_text_transcribe_params.rb', line 32

optional :language, String

#modelSymbol, ...

The specific model to use within the selected transcription engine.



38
# File 'lib/telnyx/models/speech_to_text_transcribe_params.rb', line 38

optional :model, enum: -> { Telnyx::SpeechToTextTranscribeParams::Model }

#transcription_engineSymbol, Telnyx::Models::SpeechToTextTranscribeParams::TranscriptionEngine

The transcription engine to use for processing the audio stream.



20
# File 'lib/telnyx/models/speech_to_text_transcribe_params.rb', line 20

required :transcription_engine, enum: -> { Telnyx::SpeechToTextTranscribeParams::TranscriptionEngine }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/speech_to_text_transcribe_params.rb', line 60