Class: Telnyx::Models::Storage::Buckets::BucketsSslCertificate::IssuedTo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/storage/buckets/ssl_certificate.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(common_name: nil, organization: nil, organization_unit: nil) ⇒ Object

Parameters:

  • common_name (String) (defaults to: nil)

    The common name of the entity the certificate was issued to

  • organization (String) (defaults to: nil)

    The organization the certificate was issued to

  • organization_unit (String) (defaults to: nil)

    The organizational unit the certificate was issued to



# File 'lib/telnyx/models/storage/buckets/ssl_certificate.rb', line 103

Instance Attribute Details

#common_nameString?

The common name of the entity the certificate was issued to

Returns:

  • (String, nil)


89
# File 'lib/telnyx/models/storage/buckets/ssl_certificate.rb', line 89

optional :common_name, String

#organizationString?

The organization the certificate was issued to

Returns:

  • (String, nil)


95
# File 'lib/telnyx/models/storage/buckets/ssl_certificate.rb', line 95

optional :organization, String

#organization_unitString?

The organizational unit the certificate was issued to

Returns:

  • (String, nil)


101
# File 'lib/telnyx/models/storage/buckets/ssl_certificate.rb', line 101

optional :organization_unit, String