Class: Telnyx::Models::Storage::CloudfListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Storage::CloudfListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/storage/cloudf_list_params.rb,
sig/telnyx/models/storage/cloudf_list_params.rbs
Overview
Defined Under Namespace
Modules: FilterStatus, Sort
Instance Attribute Summary collapse
-
#filter_name ⇒ String?
Return only the filesystem whose name matches exactly.
-
#filter_region ⇒ String?
Return only filesystems in this region.
-
#filter_status ⇒ Symbol, ...
Return only filesystems with this status.
-
#page_after ⇒ String?
Opaque cursor from a previous response's
meta.cursors.after; returns the page after it. -
#page_before ⇒ String?
Opaque cursor from a previous response's
meta.cursors.before; returns the page before it. -
#page_limit ⇒ Integer?
The number of filesystems to return per page.
-
#sort ⇒ Symbol, ...
Sort order for the results: a field name for ascending, or the field name prefixed with
-for descending.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(filter_name: nil, filter_region: nil, filter_status: nil, page_after: nil, page_before: nil, page_limit: nil, sort: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CloudfListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filter_name: nil, filter_region: nil, filter_status: nil, page_after: nil, page_before: nil, page_limit: nil, sort: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Storage::CloudfListParams for more details.
|
|
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 57
|
Instance Attribute Details
#filter_name ⇒ String?
Return only the filesystem whose name matches exactly.
15 |
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 15 optional :filter_name, String |
#filter_region ⇒ String?
Return only filesystems in this region.
21 |
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 21 optional :filter_region, String |
#filter_status ⇒ Symbol, ...
Return only filesystems with this status. Unrecognized values are ignored.
27 |
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 27 optional :filter_status, enum: -> { Telnyx::Storage::CloudfListParams::FilterStatus } |
#page_after ⇒ String?
Opaque cursor from a previous response's meta.cursors.after; returns the page
after it. Mutually exclusive with page[before].
34 |
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 34 optional :page_after, String |
#page_before ⇒ String?
Opaque cursor from a previous response's meta.cursors.before; returns the page
before it. Mutually exclusive with page[after].
41 |
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 41 optional :page_before, String |
#page_limit ⇒ Integer?
The number of filesystems to return per page. Values above 250 are treated as 250.
48 |
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 48 optional :page_limit, Integer |
#sort ⇒ Symbol, ...
Sort order for the results: a field name for ascending, or the field name
prefixed with - for descending.
55 |
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 55 optional :sort, enum: -> { Telnyx::Storage::CloudfListParams::Sort } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 87
|
Instance Method Details
#to_hash ⇒ {
63 |
# File 'sig/telnyx/models/storage/cloudf_list_params.rbs', line 63
def to_hash: -> {
|