Class: Telnyx::Models::Storage::Kvs::KeyListResponse::Meta

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/storage/kvs/key_list_response.rb,
sig/telnyx/models/storage/kvs/key_list_response.rbs

Overview

See Also:

  • Telnyx::Models::Storage::Kvs::KeyListResponse#meta

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cursor: nil, has_more: nil) ⇒ Meta

Some parameter documentations has been truncated, see Telnyx::Models::Storage::Kvs::KeyListResponse::Meta for more details.

Parameters:

  • cursor (String) (defaults to: nil)

    Opaque cursor for the next page; pass it back as the cursor query parameter. O

  • has_more (Boolean) (defaults to: nil)

    Whether more results are available on a following page.

  • cursor: (String) (defaults to: nil)
  • has_more: (Boolean) (defaults to: nil)


# File 'lib/telnyx/models/storage/kvs/key_list_response.rb', line 70

Instance Attribute Details

#cursorString?

Opaque cursor for the next page; pass it back as the cursor query parameter. Omitted when there are no further results.

Parameters:

  • (String)

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/storage/kvs/key_list_response.rb', line 62

optional :cursor, String

#has_moreBoolean?

Whether more results are available on a following page.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


68
# File 'lib/telnyx/models/storage/kvs/key_list_response.rb', line 68

optional :has_more, Telnyx::Internal::Type::Boolean

Instance Method Details

#to_hash{ cursor: String, has_more: bool }

Returns:

  • ({ cursor: String, has_more: bool })


82
# File 'sig/telnyx/models/storage/kvs/key_list_response.rbs', line 82

def to_hash: -> { cursor: String, has_more: bool }