Class: Telnyx::Models::Storage::Kvs::KeyUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/storage/kvs/key_update_params.rb,
sig/telnyx/models/storage/kvs/key_update_params.rbs

Overview

See Also:

  • Telnyx::Resources::Storage::Kvs::Keys#update

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, key:, body:, ttl_secs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Storage::Kvs::KeyUpdateParams for more details.

Parameters:

  • id (String)
  • key (String)
  • body (Pathname, StringIO, IO, String, Telnyx::FilePart)

    Raw value bytes, stored verbatim.

  • ttl_secs (Integer) (defaults to: nil)

    Time-to-live in seconds. When set, the key expires and is deleted after this dur

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/storage/kvs/key_update_params.rb', line 36

Instance Attribute Details

#bodyPathname, ...

Raw value bytes, stored verbatim.

Parameters:

  • value (Telnyx::Internal::file_input)

Returns:



26
# File 'lib/telnyx/models/storage/kvs/key_update_params.rb', line 26

required :body, Telnyx::Internal::Type::FileInput

#idString

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/telnyx/models/storage/kvs/key_update_params.rb', line 15

required :id, String

#keyString

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/telnyx/models/storage/kvs/key_update_params.rb', line 20

required :key, String

#ttl_secsInteger?

Time-to-live in seconds. When set, the key expires and is deleted after this duration. Requires a namespace provisioned with TTL support; namespaces without it return a 409.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


34
# File 'lib/telnyx/models/storage/kvs/key_update_params.rb', line 34

optional :ttl_secs, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


36
# File 'sig/telnyx/models/storage/kvs/key_update_params.rbs', line 36

def to_hash: -> {