Class: Telnyx::Models::Storage::MigrationParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/storage/migration_params.rb,
sig/telnyx/models/storage/migration_params.rbs

Direct Known Subclasses

MigrationCreateParams

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(source_id:, target_bucket_name:, target_region:, id: nil, bytes_migrated: nil, bytes_to_migrate: nil, created_at: nil, eta: nil, last_copy: nil, refresh: nil, speed: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Storage::MigrationParams for more details.

Parameters:

  • source_id (String)

    ID of the Migration Source from which to migrate data.

  • target_bucket_name (String)

    Bucket name to migrate the data into. Will default to the same name as the `sour

  • target_region (String)

    Telnyx Cloud Storage region to migrate the data to.

  • id (String) (defaults to: nil)

    Unique identifier for the data migration.

  • bytes_migrated (Integer) (defaults to: nil)

    Total amount of data that has been succesfully migrated.

  • bytes_to_migrate (Integer) (defaults to: nil)

    Total amount of data found in source bucket to migrate.

  • created_at (Time) (defaults to: nil)

    Time when data migration was created

  • eta (Time) (defaults to: nil)

    Estimated time the migration will complete.

  • last_copy (Time) (defaults to: nil)

    Time when data migration was last copied from the source.

  • refresh (Boolean) (defaults to: nil)

    If true, will continue to poll the source bucket to ensure new data is continual

  • speed (Integer) (defaults to: nil)

    Current speed of the migration.

  • status (Symbol, Telnyx::Models::Storage::MigrationParams::Status) (defaults to: nil)

    Status of the migration.



# File 'lib/telnyx/models/storage/migration_params.rb', line 83

Instance Attribute Details

#bytes_migratedInteger? (readonly)

Returns the value of attribute bytes_migrated.

Returns:

  • (Integer, nil)


35
36
37
# File 'sig/telnyx/models/storage/migration_params.rbs', line 35

def bytes_migrated
  @bytes_migrated
end

#bytes_to_migrateInteger? (readonly)

Returns the value of attribute bytes_to_migrate.

Returns:

  • (Integer, nil)


39
40
41
# File 'sig/telnyx/models/storage/migration_params.rbs', line 39

def bytes_to_migrate
  @bytes_to_migrate
end

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


43
44
45
# File 'sig/telnyx/models/storage/migration_params.rbs', line 43

def created_at
  @created_at
end

#etaTime? (readonly)

Returns the value of attribute eta.

Returns:

  • (Time, nil)


47
48
49
# File 'sig/telnyx/models/storage/migration_params.rbs', line 47

def eta
  @eta
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


31
32
33
# File 'sig/telnyx/models/storage/migration_params.rbs', line 31

def id
  @id
end

#last_copyTime? (readonly)

Returns the value of attribute last_copy.

Returns:

  • (Time, nil)


51
52
53
# File 'sig/telnyx/models/storage/migration_params.rbs', line 51

def last_copy
  @last_copy
end

#refreshBoolean?

If true, will continue to poll the source bucket to ensure new data is continually migrated over.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


31
# File 'lib/telnyx/models/storage/migration_params.rb', line 31

optional :refresh, Telnyx::Internal::Type::Boolean

#source_idString

ID of the Migration Source from which to migrate data.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/telnyx/models/storage/migration_params.rb', line 11

required :source_id, String

#speedInteger? (readonly)

Returns the value of attribute speed.

Returns:

  • (Integer, nil)


55
56
57
# File 'sig/telnyx/models/storage/migration_params.rbs', line 55

def speed
  @speed
end

#statusTelnyx::Models::Storage::MigrationParams::status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::Storage::MigrationParams::status, nil)


59
60
61
# File 'sig/telnyx/models/storage/migration_params.rbs', line 59

def status
  @status
end

#target_bucket_nameString

Bucket name to migrate the data into. Will default to the same name as the source_bucket_name.

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/telnyx/models/storage/migration_params.rb', line 18

required :target_bucket_name, String

#target_regionString

Telnyx Cloud Storage region to migrate the data to.

Parameters:

  • value (String)

Returns:

  • (String)


24
# File 'lib/telnyx/models/storage/migration_params.rb', line 24

required :target_region, String

Instance Method Details

#bytes_migrated=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


37
# File 'sig/telnyx/models/storage/migration_params.rbs', line 37

def bytes_migrated=: (Integer) -> Integer

#bytes_to_migrate=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


41
# File 'sig/telnyx/models/storage/migration_params.rbs', line 41

def bytes_to_migrate=: (Integer) -> Integer

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


45
# File 'sig/telnyx/models/storage/migration_params.rbs', line 45

def created_at=: (Time) -> Time

#eta=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


49
# File 'sig/telnyx/models/storage/migration_params.rbs', line 49

def eta=: (Time) -> Time

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


33
# File 'sig/telnyx/models/storage/migration_params.rbs', line 33

def id=: (String) -> String

#last_copy=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


53
# File 'sig/telnyx/models/storage/migration_params.rbs', line 53

def last_copy=: (Time) -> Time

#speed=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


57
# File 'sig/telnyx/models/storage/migration_params.rbs', line 57

def speed=: (Integer) -> Integer

#status=Object (readonly)



61
# File 'sig/telnyx/models/storage/migration_params.rbs', line 61

def status=: (

#to_hash{

Returns:

  • ({)


80
# File 'sig/telnyx/models/storage/migration_params.rbs', line 80

def to_hash: -> {