Class: Telnyx::Models::Storage::Sqldbs::ActionQueryResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/storage/sqldbs/action_query_response.rb,
sig/telnyx/models/storage/sqldbs/action_query_response.rbs

Overview

See Also:

  • Telnyx::Models::Storage::Sqldbs::ActionQueryResponse#data

Defined Under Namespace

Classes: Meta

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(count: nil, duration: nil, meta: nil, results: nil, success: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Storage::Sqldbs::ActionQueryResponse::Data for more details.

Parameters:

  • count (Integer) (defaults to: nil)

    Number of rows returned.

  • duration (Float) (defaults to: nil)

    Wall-clock duration of the request, in milliseconds.

  • meta (Telnyx::Models::Storage::Sqldbs::ActionQueryResponse::Data::Meta) (defaults to: nil)
  • results (Array<Hash{Symbol=>Object}>) (defaults to: nil)

    The result rows, each a map of column name to value. Empty for statements that r

  • success (Boolean) (defaults to: nil)


# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 49

Instance Attribute Details

#countInteger?

Number of rows returned.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


23
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 23

optional :count, Integer

#durationFloat?

Wall-clock duration of the request, in milliseconds.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


29
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 29

optional :duration, Float

#metaTelnyx::Models::Storage::Sqldbs::ActionQueryResponse::Data::Meta?



34
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 34

optional :meta, -> { Telnyx::Models::Storage::Sqldbs::ActionQueryResponse::Data::Meta }

#resultsArray<Hash{Symbol=>Object}>?

The result rows, each a map of column name to value. Empty for statements that return no rows.

Returns:

  • (Array<Hash{Symbol=>Object}>, nil)


41
42
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 41

optional :results,
Telnyx::Internal::Type::ArrayOf[Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]]

#successBoolean?

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


47
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 47

optional :success, Telnyx::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


65
# File 'sig/telnyx/models/storage/sqldbs/action_query_response.rbs', line 65

def to_hash: -> {