Class: Telnyx::Models::Storage::Sqldbs::ActionQueryResponse::Data::Meta

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/storage/sqldbs/action_query_response.rb,
sig/telnyx/models/storage/sqldbs/action_query_response.rbs

Overview

See Also:

  • Telnyx::Models::Storage::Sqldbs::ActionQueryResponse::Data#meta

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(changes: nil, duration: nil, last_row_id: nil, rows_read: nil, rows_written: nil) ⇒ Object

Parameters:

  • changes (Integer) (defaults to: nil)

    Number of rows added, changed, or removed by the statement.

  • duration (Float) (defaults to: nil)

    Wall-clock duration of the statement, in milliseconds.

  • last_row_id (Integer) (defaults to: nil)

    Rowid of the last inserted row, when applicable.

  • rows_read (Integer) (defaults to: nil)
  • rows_written (Integer) (defaults to: nil)


# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 93

Instance Attribute Details

#changesInteger?

Number of rows added, changed, or removed by the statement.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


69
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 69

optional :changes, Integer

#durationFloat?

Wall-clock duration of the statement, in milliseconds.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


75
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 75

optional :duration, Float

#last_row_idInteger?

Rowid of the last inserted row, when applicable.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


81
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 81

optional :last_row_id, Integer

#rows_readInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


86
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 86

optional :rows_read, Integer

#rows_writtenInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


91
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 91

optional :rows_written, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


111
# File 'sig/telnyx/models/storage/sqldbs/action_query_response.rbs', line 111

def to_hash: -> {