Module: Telnyx::Models::StreamCodec
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/stream_codec.rb,
sig/telnyx/models/stream_codec.rbs
Overview
Specifies the codec to be used for the streamed audio. When set to 'default' or when transcoding is not possible, the codec from the call will be used.
Constant Summary collapse
- PCMU =
:PCMU- PCMA =
:PCMA- G722 =
:G722- OPUS =
:OPUS- AMR_WB =
:"AMR-WB"- L16 =
:L16- DEFAULT =
:default
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/stream_codec.rb', line 18
|
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::stream_codec]
17 |
# File 'sig/telnyx/models/stream_codec.rbs', line 17
def self?.values: -> ::Array[Telnyx::Models::stream_codec]
|