Class: Telnyx::Models::StreamServerEvent::FinalFrameEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::StreamServerEvent::FinalFrameEvent
- Defined in:
- lib/telnyx/models/stream_server_event.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#audio ⇒ nil
Always ‘null` for the final frame.
-
#is_final ⇒ Boolean, ...
Always ‘true`.
-
#text ⇒ String?
Empty string.
-
#time_to_first_audio_frame_ms ⇒ Integer?
Present if this was the first response frame.
-
#type ⇒ Symbol, ...
Frame type identifier.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(audio: nil, is_final: nil, text: nil, time_to_first_audio_frame_ms: nil, type: nil) ⇒ Object
constructor
Server-to-client frame indicating synthesis is complete for the current text.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(audio: nil, is_final: nil, text: nil, time_to_first_audio_frame_ms: nil, type: nil) ⇒ Object
Server-to-client frame indicating synthesis is complete for the current text.
|
|
# File 'lib/telnyx/models/stream_server_event.rb', line 124
|
Instance Attribute Details
#audio ⇒ nil
Always ‘null` for the final frame.
96 |
# File 'lib/telnyx/models/stream_server_event.rb', line 96 optional :audio, NilClass |
#is_final ⇒ Boolean, ...
Always ‘true`.
102 103 104 |
# File 'lib/telnyx/models/stream_server_event.rb', line 102 optional :is_final, enum: -> { Telnyx::Models::StreamServerEvent::FinalFrameEvent::IsFinal }, api_name: :isFinal |
#text ⇒ String?
Empty string.
110 |
# File 'lib/telnyx/models/stream_server_event.rb', line 110 optional :text, String |
#time_to_first_audio_frame_ms ⇒ Integer?
Present if this was the first response frame.
116 |
# File 'lib/telnyx/models/stream_server_event.rb', line 116 optional :time_to_first_audio_frame_ms, Integer, api_name: :timeToFirstAudioFrameMs |
#type ⇒ Symbol, ...
Frame type identifier.
122 |
# File 'lib/telnyx/models/stream_server_event.rb', line 122 optional :type, enum: -> { Telnyx::Models::StreamServerEvent::FinalFrameEvent::Type } |
Class Method Details
.values ⇒ Array<Boolean>
|
|
# File 'lib/telnyx/models/stream_server_event.rb', line 145
|