Class: Telnyx::Models::SubNumberOrder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sub_number_order.rb,
sig/telnyx/models/sub_number_order.rbs

Defined Under Namespace

Modules: PhoneNumberType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, country_code: nil, created_at: nil, customer_reference: nil, is_block_sub_number_order: nil, order_request_id: nil, phone_number_type: nil, phone_numbers_count: nil, record_type: nil, regulatory_requirements: nil, requirements_met: nil, status: nil, updated_at: nil, user_id: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)
  • country_code (String) (defaults to: nil)
  • created_at (Time) (defaults to: nil)

    An ISO 8901 datetime string denoting when the number order was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • is_block_sub_number_order (Boolean) (defaults to: nil)

    True if the sub number order is a block sub number order

  • order_request_id (String) (defaults to: nil)
  • phone_number_type (Symbol, Telnyx::Models::SubNumberOrder::PhoneNumberType) (defaults to: nil)
  • phone_numbers_count (Integer) (defaults to: nil)

    The count of phone numbers in the number order.

  • record_type (String) (defaults to: nil)
  • regulatory_requirements (Array<Telnyx::Models::SubNumberOrderRegulatoryRequirement>) (defaults to: nil)
  • requirements_met (Boolean) (defaults to: nil)

    True if all requirements are met for every phone number, false otherwise.

  • status (Symbol, Telnyx::Models::SubNumberOrder::Status) (defaults to: nil)

    The status of the order.

  • updated_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the number order was updated.

  • user_id (String) (defaults to: nil)


# File 'lib/telnyx/models/sub_number_order.rb', line 86

Instance Attribute Details

#country_codeString? (readonly)

Returns the value of attribute country_code.

Returns:

  • (String, nil)


46
47
48
# File 'sig/telnyx/models/sub_number_order.rbs', line 46

def country_code
  @country_code
end

#created_atTime? (readonly)

Returns the value of attribute created_at.

Returns:

  • (Time, nil)


50
51
52
# File 'sig/telnyx/models/sub_number_order.rbs', line 50

def created_at
  @created_at
end

#customer_referenceString?

A customer reference string for customer look ups.

Parameters:

  • (String)

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/sub_number_order.rb', line 10

optional :customer_reference, String

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


42
43
44
# File 'sig/telnyx/models/sub_number_order.rbs', line 42

def id
  @id
end

#is_block_sub_number_orderBoolean? (readonly)

Returns the value of attribute is_block_sub_number_order.

Returns:

  • (Boolean, nil)


54
55
56
# File 'sig/telnyx/models/sub_number_order.rbs', line 54

def is_block_sub_number_order
  @is_block_sub_number_order
end

#order_request_idString? (readonly)

Returns the value of attribute order_request_id.

Returns:

  • (String, nil)


58
59
60
# File 'sig/telnyx/models/sub_number_order.rbs', line 58

def order_request_id
  @order_request_id
end

#phone_number_typeSymbol, ...



15
# File 'lib/telnyx/models/sub_number_order.rb', line 15

optional :phone_number_type, enum: -> { Telnyx::SubNumberOrder::PhoneNumberType }

#phone_numbers_countInteger? (readonly)

Returns the value of attribute phone_numbers_count.

Returns:

  • (Integer, nil)


62
63
64
# File 'sig/telnyx/models/sub_number_order.rbs', line 62

def phone_numbers_count
  @phone_numbers_count
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


66
67
68
# File 'sig/telnyx/models/sub_number_order.rbs', line 66

def record_type
  @record_type
end

#regulatory_requirementsArray<Telnyx::Models::SubNumberOrderRegulatoryRequirement>?



20
21
# File 'lib/telnyx/models/sub_number_order.rb', line 20

optional :regulatory_requirements,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::SubNumberOrderRegulatoryRequirement] }

#requirements_metBoolean? (readonly)

Returns the value of attribute requirements_met.

Returns:

  • (Boolean, nil)


70
71
72
# File 'sig/telnyx/models/sub_number_order.rbs', line 70

def requirements_met
  @requirements_met
end

#statusTelnyx::Models::SubNumberOrder::status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::SubNumberOrder::status, nil)


74
75
76
# File 'sig/telnyx/models/sub_number_order.rbs', line 74

def status
  @status
end

#updated_atTime? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (Time, nil)


80
81
82
# File 'sig/telnyx/models/sub_number_order.rbs', line 80

def updated_at
  @updated_at
end

#user_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/sub_number_order.rb', line 26

optional :user_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/sub_number_order.rb', line 126

Instance Method Details

#country_code=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


48
# File 'sig/telnyx/models/sub_number_order.rbs', line 48

def country_code=: (String) -> String

#created_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


52
# File 'sig/telnyx/models/sub_number_order.rbs', line 52

def created_at=: (Time) -> Time

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


44
# File 'sig/telnyx/models/sub_number_order.rbs', line 44

def id=: (String) -> String

#is_block_sub_number_order=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


56
# File 'sig/telnyx/models/sub_number_order.rbs', line 56

def is_block_sub_number_order=: (bool) -> bool

#order_request_id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


60
# File 'sig/telnyx/models/sub_number_order.rbs', line 60

def order_request_id=: (String) -> String

#phone_numbers_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


64
# File 'sig/telnyx/models/sub_number_order.rbs', line 64

def phone_numbers_count=: (Integer) -> Integer

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


68
# File 'sig/telnyx/models/sub_number_order.rbs', line 68

def record_type=: (String) -> String

#requirements_met=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


72
# File 'sig/telnyx/models/sub_number_order.rbs', line 72

def requirements_met=: (bool) -> bool

#status=Object (readonly)



76
# File 'sig/telnyx/models/sub_number_order.rbs', line 76

def status=: (

#to_hash{

Returns:

  • ({)


101
# File 'sig/telnyx/models/sub_number_order.rbs', line 101

def to_hash: -> {

#updated_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


82
# File 'sig/telnyx/models/sub_number_order.rbs', line 82

def updated_at=: (Time) -> Time