Class: Telnyx::Models::SubNumberOrderListParams::Filter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sub_number_order_list_params.rb,
sig/telnyx/models/sub_number_order_list_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country_code: nil, include_phone_numbers: nil, order_request_id: nil, phone_number_type: nil, phone_numbers_count: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SubNumberOrderListParams::Filter for more details.

Consolidated filter parameter (deepObject style). Originally: filter, filter, filter, filter, filter, filter

Parameters:

  • country_code (String) (defaults to: nil)

    ISO alpha-2 country code.

  • include_phone_numbers (Boolean) (defaults to: nil)

    Include the first 50 phone number objects in the results, including their per-nu

  • order_request_id (String) (defaults to: nil)

    ID of the number order the sub number order belongs to

  • phone_number_type (String) (defaults to: nil)

    Phone Number Type

  • phone_numbers_count (Integer) (defaults to: nil)

    Amount of numbers in the sub number order

  • status (String) (defaults to: nil)

    Filter sub number orders by status.



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/telnyx/models/sub_number_order_list_params.rb', line 26

class Filter < Telnyx::Internal::Type::BaseModel
  # @!attribute country_code
  #   ISO alpha-2 country code.
  #
  #   @return [String, nil]
  optional :country_code, String

  # @!attribute include_phone_numbers
  #   Include the first 50 phone number objects in the results, including their
  #   per-number regulatory requirement statuses
  #
  #   @return [Boolean, nil]
  optional :include_phone_numbers, Telnyx::Internal::Type::Boolean

  # @!attribute order_request_id
  #   ID of the number order the sub number order belongs to
  #
  #   @return [String, nil]
  optional :order_request_id, String

  # @!attribute phone_number_type
  #   Phone Number Type
  #
  #   @return [String, nil]
  optional :phone_number_type, String

  # @!attribute phone_numbers_count
  #   Amount of numbers in the sub number order
  #
  #   @return [Integer, nil]
  optional :phone_numbers_count, Integer

  # @!attribute status
  #   Filter sub number orders by status.
  #
  #   @return [String, nil]
  optional :status, String

  # @!method initialize(country_code: nil, include_phone_numbers: nil, order_request_id: nil, phone_number_type: nil, phone_numbers_count: nil, status: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::SubNumberOrderListParams::Filter} for more details.
  #
  #   Consolidated filter parameter (deepObject style). Originally: filter[status],
  #   filter[order_request_id], filter[country_code], filter[phone_number_type],
  #   filter[phone_numbers_count], filter[include_phone_numbers]
  #
  #   @param country_code [String] ISO alpha-2 country code.
  #
  #   @param include_phone_numbers [Boolean] Include the first 50 phone number objects in the results, including their per-nu
  #
  #   @param order_request_id [String] ID of the number order the sub number order belongs to
  #
  #   @param phone_number_type [String] Phone Number Type
  #
  #   @param phone_numbers_count [Integer] Amount of numbers in the sub number order
  #
  #   @param status [String] Filter sub number orders by status.
end

Instance Attribute Details

#country_codeString?

ISO alpha-2 country code.

Parameters:

  • (String)

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/sub_number_order_list_params.rb', line 31

optional :country_code, String

#include_phone_numbersBoolean?

Include the first 50 phone number objects in the results, including their per-number regulatory requirement statuses

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


38
# File 'lib/telnyx/models/sub_number_order_list_params.rb', line 38

optional :include_phone_numbers, Telnyx::Internal::Type::Boolean

#order_request_idString?

ID of the number order the sub number order belongs to

Parameters:

  • (String)

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/sub_number_order_list_params.rb', line 44

optional :order_request_id, String

#phone_number_typeString?

Phone Number Type

Parameters:

  • (String)

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/sub_number_order_list_params.rb', line 50

optional :phone_number_type, String

#phone_numbers_countInteger?

Amount of numbers in the sub number order

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


56
# File 'lib/telnyx/models/sub_number_order_list_params.rb', line 56

optional :phone_numbers_count, Integer

#statusString?

Filter sub number orders by status.

Parameters:

  • (String)

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/sub_number_order_list_params.rb', line 62

optional :status, String

Instance Method Details

#to_hash{

Returns:

  • ({)


71
# File 'sig/telnyx/models/sub_number_order_list_params.rbs', line 71

def to_hash: -> {