Class: Telnyx::Models::SubNumberOrderRegulatoryRequirementWithValue

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sub_number_order_regulatory_requirement_with_value.rb

Defined Under Namespace

Modules: FieldType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(field_type: nil, field_value: nil, record_type: nil, requirement_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SubNumberOrderRegulatoryRequirementWithValue for more details.

Parameters:



# File 'lib/telnyx/models/sub_number_order_regulatory_requirement_with_value.rb', line 31

Instance Attribute Details

#field_valueString?

The value of the requirement, this could be an id to a resource or a string value.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/sub_number_order_regulatory_requirement_with_value.rb', line 11

optional :field_value, String

#requirement_idString?

Unique id for a requirement.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/sub_number_order_regulatory_requirement_with_value.rb', line 17

optional :requirement_id, String