Class: Telnyx::Models::TelephonyCredentialCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::TelephonyCredentialCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/telephony_credential_create_params.rb
Overview
Instance Attribute Summary collapse
-
#connection_id ⇒ String
Identifies the Credential Connection this credential is associated with.
-
#expires_at ⇒ String?
ISO-8601 formatted date indicating when the credential will expire.
- #name ⇒ String?
-
#tag ⇒ String?
Tags a credential.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(connection_id:, expires_at: nil, name: nil, tag: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_id:, expires_at: nil, name: nil, tag: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/telephony_credential_create_params.rb', line 33
|
Instance Attribute Details
#connection_id ⇒ String
Identifies the Credential Connection this credential is associated with.
14 |
# File 'lib/telnyx/models/telephony_credential_create_params.rb', line 14 required :connection_id, String |
#expires_at ⇒ String?
ISO-8601 formatted date indicating when the credential will expire.
20 |
# File 'lib/telnyx/models/telephony_credential_create_params.rb', line 20 optional :expires_at, String |
#name ⇒ String?
25 |
# File 'lib/telnyx/models/telephony_credential_create_params.rb', line 25 optional :name, String |
#tag ⇒ String?
Tags a credential. A single tag can hold at maximum 1000 credentials.
31 |
# File 'lib/telnyx/models/telephony_credential_create_params.rb', line 31 optional :tag, String |