Class: Telnyx::Models::TermsOfServiceRetrieveStatusResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/terms_of_service_retrieve_status_response.rb,
sig/telnyx/models/terms_of_service_retrieve_status_response.rbs

Overview

See Also:

  • Telnyx::Models::TermsOfServiceRetrieveStatusResponse#data

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agreement_required:, current_terms_version:, has_agreed:, product_type:, agreed_at: nil, agreed_version: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::TermsOfServiceRetrieveStatusResponse::Data for more details.

Whether the calling user has agreed to a product's current Terms of Service. The user_id is intentionally omitted on this public surface.

Parameters:

  • agreement_required (Boolean)

    true when the user must agree to the latest version before using the product.

  • current_terms_version (String)

    Latest published version of the ToS for this product.

  • has_agreed (Boolean)

    true if the user has agreed to the latest version.

  • product_type (Symbol, Telnyx::Models::TermsOfService::TosProductType)

    Telnyx product the Terms of Service apply to.

  • agreed_at (Time, nil) (defaults to: nil)
  • agreed_version (String, nil) (defaults to: nil)

    Version the user previously agreed to (may be older than current_terms_version



# File 'lib/telnyx/models/terms_of_service_retrieve_status_response.rb', line 59

Instance Attribute Details

#agreed_atTime?

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


50
# File 'lib/telnyx/models/terms_of_service_retrieve_status_response.rb', line 50

optional :agreed_at, Time, nil?: true

#agreed_versionString?

Version the user previously agreed to (may be older than current_terms_version). null if the user has never agreed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/terms_of_service_retrieve_status_response.rb', line 57

optional :agreed_version, String, nil?: true

#agreement_requiredBoolean

true when the user must agree to the latest version before using the product. Equivalent to !has_agreed.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


27
# File 'lib/telnyx/models/terms_of_service_retrieve_status_response.rb', line 27

required :agreement_required, Telnyx::Internal::Type::Boolean

#current_terms_versionString

Latest published version of the ToS for this product.

Parameters:

  • value (String)

Returns:

  • (String)


33
# File 'lib/telnyx/models/terms_of_service_retrieve_status_response.rb', line 33

required :current_terms_version, String

#has_agreedBoolean

true if the user has agreed to the latest version.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


39
# File 'lib/telnyx/models/terms_of_service_retrieve_status_response.rb', line 39

required :has_agreed, Telnyx::Internal::Type::Boolean

#product_typeSymbol, Telnyx::Models::TermsOfService::TosProductType

Telnyx product the Terms of Service apply to.

Parameters:

  • value (Telnyx::Models::TermsOfService::tos_product_type)

Returns:



45
# File 'lib/telnyx/models/terms_of_service_retrieve_status_response.rb', line 45

required :product_type, enum: -> { Telnyx::TermsOfService::TosProductType }

Instance Method Details

#to_hash{

Returns:

  • ({)


49
# File 'sig/telnyx/models/terms_of_service_retrieve_status_response.rbs', line 49

def to_hash: -> {