Class: Telnyx::Models::Texml::AccountRetrieveRecordingsJsonParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml/account_retrieve_recordings_json_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid:, date_created: nil, page: nil, page_size: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::AccountRetrieveRecordingsJsonParams for more details.

Parameters:

  • account_sid (String)
  • date_created (Time) (defaults to: nil)

    Filters recording by the creation date. Expected format is ISO8601 date or date-

  • page (Integer) (defaults to: nil)

    The number of the page to be displayed, zero-indexed, should be used in conjucti

  • page_size (Integer) (defaults to: nil)

    The number of records to be displayed on a page

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/texml/account_retrieve_recordings_json_params.rb', line 37

Instance Attribute Details

#account_sidString

Returns:

  • (String)


14
# File 'lib/telnyx/models/texml/account_retrieve_recordings_json_params.rb', line 14

required :account_sid, String

#date_createdTime?

Filters recording by the creation date. Expected format is ISO8601 date or date-time, ie. YYYY-MM-DD or YYYY-MM-DDThh:mm:ssZ. Also accepts inequality operators, e.g. DateCreated>=2023-05-22.

Returns:

  • (Time, nil)


22
# File 'lib/telnyx/models/texml/account_retrieve_recordings_json_params.rb', line 22

optional :date_created, Time

#pageInteger?

The number of the page to be displayed, zero-indexed, should be used in conjuction with PageToken.

Returns:

  • (Integer, nil)


29
# File 'lib/telnyx/models/texml/account_retrieve_recordings_json_params.rb', line 29

optional :page, Integer

#page_sizeInteger?

The number of records to be displayed on a page

Returns:

  • (Integer, nil)


35
# File 'lib/telnyx/models/texml/account_retrieve_recordings_json_params.rb', line 35

optional :page_size, Integer