Class: Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb

Overview

Defined Under Namespace

Classes: Transcription

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#end_Integer?

The number of the last element on the page, zero-indexed

Returns:

  • (Integer, nil)


12
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 12

optional :end_, Integer, api_name: :end

#first_page_uriString?

Relative uri to the first page of the query results

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 18

optional :first_page_uri, String

#next_page_uriString?

Relative uri to the next page of the query results

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 24

optional :next_page_uri, String

#pageInteger?

Current page number, zero-indexed.

Returns:

  • (Integer, nil)


30
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 30

optional :page, Integer

#page_sizeInteger?

The number of items on the page

Returns:

  • (Integer, nil)


36
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 36

optional :page_size, Integer

#previous_page_uriString?

Relative uri to the previous page of the query results

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 42

optional :previous_page_uri, String

#startInteger?

The number of the first element on the page, zero-indexed.

Returns:

  • (Integer, nil)


48
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 48

optional :start, Integer

#transcriptionsArray<Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription>?



53
54
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 53

optional :transcriptions,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription] }

#uriString?

The URI of the current page.

Returns:

  • (String, nil)


60
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 60

optional :uri, String