Class: Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription
- Defined in:
- lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
- #account_sid ⇒ String?
-
#api_version ⇒ String?
The version of the API that was used to make the request.
- #call_sid ⇒ String?
- #date_created ⇒ Time?
- #date_updated ⇒ Time?
-
#duration ⇒ String?
The duration of this recording, given in seconds.
-
#recording_sid ⇒ String?
Identifier of a resource.
-
#sid ⇒ String?
Identifier of a resource.
-
#status ⇒ Symbol, ...
The status of the recording transcriptions.
-
#transcription_text ⇒ String?
The recording’s transcribed text.
-
#uri ⇒ String?
The relative URI for the recording transcription resource.
Instance Method Summary collapse
-
#initialize(account_sid: nil, api_version: nil, call_sid: nil, date_created: nil, date_updated: nil, duration: nil, recording_sid: nil, sid: nil, status: nil, transcription_text: nil, uri: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Transcription for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid: nil, api_version: nil, call_sid: nil, date_created: nil, date_updated: nil, duration: nil, recording_sid: nil, sid: nil, status: nil, transcription_text: nil, uri: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription for more details.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 81 class Transcription < Telnyx::Internal::Type::BaseModel # @!attribute account_sid # # @return [String, nil] optional :account_sid, String # @!attribute api_version # The version of the API that was used to make the request. # # @return [String, nil] optional :api_version, String # @!attribute call_sid # # @return [String, nil] optional :call_sid, String # @!attribute date_created # # @return [Time, nil] optional :date_created, Time # @!attribute date_updated # # @return [Time, nil] optional :date_updated, Time # @!attribute duration # The duration of this recording, given in seconds. # # @return [String, nil] optional :duration, String, nil?: true # @!attribute recording_sid # Identifier of a resource. # # @return [String, nil] optional :recording_sid, String # @!attribute sid # Identifier of a resource. # # @return [String, nil] optional :sid, String # @!attribute status # The status of the recording transcriptions. The transcription text will be # available only when the status is completed. # # @return [Symbol, Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription::Status, nil] optional :status, enum: -> { Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription::Status } # @!attribute transcription_text # The recording's transcribed text # # @return [String, nil] optional :transcription_text, String # @!attribute uri # The relative URI for the recording transcription resource. # # @return [String, nil] optional :uri, String # @!method initialize(account_sid: nil, api_version: nil, call_sid: nil, date_created: nil, date_updated: nil, duration: nil, recording_sid: nil, sid: nil, status: nil, transcription_text: nil, uri: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription} # for more details. # # @param account_sid [String] # # @param api_version [String] The version of the API that was used to make the request. # # @param call_sid [String] # # @param date_created [Time] # # @param date_updated [Time] # # @param duration [String, nil] The duration of this recording, given in seconds. # # @param recording_sid [String] Identifier of a resource. # # @param sid [String] Identifier of a resource. # # @param status [Symbol, Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription::Status] The status of the recording transcriptions. The transcription text will be avail # # @param transcription_text [String] The recording's transcribed text # # @param uri [String] The relative URI for the recording transcription resource. # The status of the recording transcriptions. The transcription text will be # available only when the status is completed. # # @see Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription#status module Status extend Telnyx::Internal::Type::Enum IN_PROGRESS = :"in-progress" COMPLETED = :completed # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#account_sid ⇒ String?
85 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 85 optional :account_sid, String |
#api_version ⇒ String?
The version of the API that was used to make the request.
91 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 91 optional :api_version, String |
#call_sid ⇒ String?
96 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 96 optional :call_sid, String |
#date_created ⇒ Time?
101 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 101 optional :date_created, Time |
#date_updated ⇒ Time?
106 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 106 optional :date_updated, Time |
#duration ⇒ String?
The duration of this recording, given in seconds.
112 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 112 optional :duration, String, nil?: true |
#recording_sid ⇒ String?
Identifier of a resource.
118 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 118 optional :recording_sid, String |
#sid ⇒ String?
Identifier of a resource.
124 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 124 optional :sid, String |
#status ⇒ Symbol, ...
The status of the recording transcriptions. The transcription text will be available only when the status is completed.
131 132 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 131 optional :status, enum: -> { Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription::Status } |
#transcription_text ⇒ String?
The recording’s transcribed text
138 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 138 optional :transcription_text, String |
#uri ⇒ String?
The relative URI for the recording transcription resource.
144 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 144 optional :uri, String |