Class: Telnyx::Models::Texml::Accounts::CallCallsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb

Overview

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, DetectionMode, MachineDetection, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackEvent, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 291

Instance Attribute Details

#application_sidString

The ID of the TeXML Application.

Returns:

  • (String)


16
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 16

required :application_sid, String, api_name: :ApplicationSid

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Returns:

  • (Boolean, nil)


37
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 37

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 43

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for ‘AsyncAmdStatusCallback`. The default value is inherited from TeXML Application setting.



50
51
52
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 50

optional :async_amd_status_callback_method,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::AsyncAmdStatusCallbackMethod },
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 61

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


68
69
70
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 68

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


76
77
78
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 76

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#custom_headersArray<Telnyx::Models::Texml::Accounts::CallCallsParams::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.



85
86
87
88
89
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 85

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::CustomHeader]
},
api_name: :CustomHeaders

#detection_modeSymbol, ...

Allows you to chose between Premium and Standard detections.



95
96
97
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 95

optional :detection_mode,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::DetectionMode },
api_name: :DetectionMode

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.

Returns:

  • (String, nil)


104
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 104

optional :fallback_url, String, api_name: :FallbackUrl

#fromString

The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String)


23
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 23

required :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



110
111
112
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 110

optional :machine_detection,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::MachineDetection },
api_name: :MachineDetection

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


119
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 119

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


126
127
128
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 126

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


135
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 135

optional :machine_detection_speech_threshold, Integer, api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Returns:

  • (Integer, nil)


141
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 141

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Returns:

  • (String, nil)


147
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 147

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant’s call leg. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


153
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 153

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to ‘mono`.



159
160
161
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 159

optional :recording_channels,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::RecordingChannels },
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Returns:

  • (String, nil)


167
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 167

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.

Returns:

  • (String, nil)


175
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 175

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.



181
182
183
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 181

optional :recording_status_callback_method,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::RecordingStatusCallbackMethod },
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


192
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 192

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



198
199
200
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 198

optional :recording_track,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::RecordingTrack },
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Returns:

  • (Boolean, nil)


206
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 206

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Returns:

  • (String, nil)


212
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 212

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Returns:

  • (String, nil)


218
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 218

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



224
225
226
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 224

optional :sip_region,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::SipRegion },
api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Returns:

  • (String, nil)


232
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 232

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventSymbol, ...

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.



239
240
241
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 239

optional :status_callback_event,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::StatusCallbackEvent },
api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



247
248
249
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 247

optional :status_callback_method,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::StatusCallbackMethod },
api_name: :StatusCallbackMethod

#supervise_call_sidString?

The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.

Returns:

  • (String, nil)


257
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 257

optional :supervise_call_sid, String, api_name: :SuperviseCallSid

#supervising_roleSymbol, ...

The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge



265
266
267
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 265

optional :supervising_role,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::SupervisingRole },
api_name: :SupervisingRole

#toString

The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String)


30
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 30

required :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.



274
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 274

optional :trim, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Trim }, api_name: :Trim

#urlString?

The URL from which Telnyx will retrieve the TeXML call instructions.

Returns:

  • (String, nil)


280
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 280

optional :url, String, api_name: :Url

#url_methodSymbol, ...

HTTP request type used for ‘Url`. The default value is inherited from TeXML Application setting.



287
288
289
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 287

optional :url_method,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::URLMethod },
api_name: :UrlMethod

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 379