Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Body::ApplicationDefault

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb,
sig/telnyx/models/texml/accounts/call_calls_params.rbs

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MachineDetectionBeepProfile, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1848

Instance Attribute Details

#application_sidString?

The ID of the TeXML Application.

Parameters:

  • (String)

Returns:

  • (String, nil)


1466
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1466

optional :application_sid, String, api_name: :ApplicationSid

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1473
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1473

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Parameters:

  • (String)

Returns:

  • (String, nil)


1479
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1479

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for AsyncAmdStatusCallback. The default value is inherited from TeXML Application setting.



1486
1487
1488
1489
1490
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1486

optional :async_amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::AsyncAmdStatusCallbackMethod
},
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (To number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and -_~!.+ special characters. If ommited, the display name will be the same as the number in the From field.

Parameters:

  • (String)

Returns:

  • (String, nil)


1499
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1499

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on greeting ended detection. Defaults to true.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1506
1507
1508
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1506

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on machine detection. Defaults to true.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1514
1515
1516
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1514

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#custom_headersArray<Telnyx::Models::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with 'name' and 'value' properties.



1523
1524
1525
1526
1527
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1523

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::CustomHeader]
},
api_name: :CustomHeaders

#deepfake_detectionSymbol, ...

Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.



1535
1536
1537
1538
1539
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1535

optional :deepfake_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::DeepfakeDetection
},
api_name: :DeepfakeDetection

#deepfake_detection_callback_methodSymbol, ...

HTTP request type used for DeepfakeDetectionCallbackUrl.



1545
1546
1547
1548
1549
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1545

optional :deepfake_detection_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::DeepfakeDetectionCallbackMethod
},
api_name: :DeepfakeDetectionCallbackMethod

#deepfake_detection_callback_urlString?

URL destination for Telnyx to send deepfake detection callback events to for the call.

Parameters:

  • (String)

Returns:

  • (String, nil)


1556
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1556

optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl

#detection_modeSymbol, ...

Allows you to choose between Regular, Premium, and PremiumCallScreening detections. See https://developers.telnyx.com/docs/voice/programmable-voice/answering-machine-detection



1564
1565
1566
1567
1568
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1564

optional :detection_mode,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::DetectionMode
},
api_name: :DetectionMode

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the Url is not responding.

Parameters:

  • (String)

Returns:

  • (String, nil)


1575
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1575

optional :fallback_url, String, api_name: :FallbackUrl

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a + and country code.

Parameters:

  • (String)

Returns:

  • (String, nil)


1582
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1582

optional :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



1588
1589
1590
1591
1592
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1588

optional :machine_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::MachineDetection
},
api_name: :MachineDetection

#machine_detection_beep_profileSymbol, ...

Selects which detectors must validate a beep. both requires the amplitude and frequency detectors to agree. freq_only uses the frequency detector alone, for beeps whose volume is too unsteady for the default profile. Only used when MachineDetection is enabled.



1601
1602
1603
1604
1605
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1601

optional :machine_detection_beep_profile,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::MachineDetectionBeepProfile
},
api_name: :MachineDetectionBeepProfile

#machine_detection_prompt_end_timeoutInteger?

Silence duration threshold after a call screening prompt before ending prompt detection, in milliseconds. Used when DetectionMode is PremiumCallScreening.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1612
1613
1614
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1612

optional :machine_detection_prompt_end_timeout,
Integer,
api_name: :MachineDetectionPromptEndTimeout

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when premium detection is used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1621
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1621

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when premium detection is used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1628
1629
1630
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1628

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when premium detection is used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1637
1638
1639
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1637

optional :machine_detection_speech_threshold,
Integer,
api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1645
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1645

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the call. When set to SRTP, the call will use Secure Real-time Transport Protocol for media encryption. When set to DTLS, the call will use DTLS for media encryption. Only supported for SIP destinations.



1654
1655
1656
1657
1658
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1654

optional :media_encryption,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::MediaEncryption
},
api_name: :MediaEncryption

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Parameters:

  • (String)

Returns:

  • (String, nil)


1664
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1664

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant's call leg. Defaults to false.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1670
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1670

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to mono.



1676
1677
1678
1679
1680
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1676

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Parameters:

  • (String)

Returns:

  • (String, nil)


1686
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1686

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording's state that should generate a call to RecoridngStatusCallback. Can be: in-progress, completed and absent. Separate multiple values with a space. Defaults to completed.

Parameters:

  • (String)

Returns:

  • (String, nil)


1694
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1694

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for RecordingStatusCallback. Defaults to POST.



1700
1701
1702
1703
1704
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1700

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1713
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1713

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is both.



1719
1720
1721
1722
1723
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1719

optional :recording_track,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::RecordingTrack
},
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1729
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1729

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Parameters:

  • (String)

Returns:

  • (String, nil)


1735
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1735

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Parameters:

  • (String)

Returns:

  • (String, nil)


1741
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1741

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



1747
1748
1749
1750
1751
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1747

optional :sip_region,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::SipRegion
},
api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Parameters:

  • (String)

Returns:

  • (String, nil)


1757
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1757

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventString?

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.

Parameters:

  • (String)

Returns:

  • (String, nil)


1764
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1764

optional :status_callback_event, String, api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for StatusCallback.



1770
1771
1772
1773
1774
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1770

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#supervise_call_sidString?

The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.

Parameters:

  • (String)

Returns:

  • (String, nil)


1782
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1782

optional :supervise_call_sid, String, api_name: :SuperviseCallSid

#supervising_roleSymbol, ...

The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge



1790
1791
1792
1793
1794
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1790

optional :supervising_role,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::SupervisingRole
},
api_name: :SupervisingRole

#texmlString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1799
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1799

optional :texml, String, api_name: :Texml, nil?: true

#time_limitInteger?

The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1806
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1806

optional :time_limit, Integer, api_name: :TimeLimit

#timeoutInteger?

The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1814
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1814

optional :timeout, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a + and country code.

Parameters:

  • (String)

Returns:

  • (String, nil)


1821
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1821

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to trim-silence.



1828
1829
1830
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1828

optional :trim,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::Trim },
api_name: :Trim

#urlString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1835
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1835

optional :url, String, api_name: :Url, nil?: true

#url_methodSymbol, ...

HTTP request type used for Url. The default value is inherited from TeXML Application setting.



1842
1843
1844
1845
1846
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1842

optional :url_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::URLMethod
},
api_name: :UrlMethod

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1955

Instance Method Details

#to_hash{

Returns:

  • ({)


1446
# File 'sig/telnyx/models/texml/accounts/call_calls_params.rbs', line 1446

def to_hash: -> {