Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithURL

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb,
sig/telnyx/models/texml/accounts/call_calls_params.rbs

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MachineDetectionBeepProfile, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 412

Instance Attribute Details

#application_sidString?

The ID of the TeXML Application.

Parameters:

  • (String)

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 49

optional :application_sid, String, api_name: :ApplicationSid

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


56
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 56

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Parameters:

  • (String)

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 62

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for AsyncAmdStatusCallback. The default value is inherited from TeXML Application setting.



69
70
71
72
73
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 69

optional :async_amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::AsyncAmdStatusCallbackMethod
},
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (To number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and -_~!.+ special characters. If ommited, the display name will be the same as the number in the From field.

Parameters:

  • (String)

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 82

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on greeting ended detection. Defaults to true.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


89
90
91
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 89

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on machine detection. Defaults to true.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


97
98
99
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 97

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#custom_headersArray<Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithURL::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with 'name' and 'value' properties.



106
107
108
109
110
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 106

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::CustomHeader]
},
api_name: :CustomHeaders

#deepfake_detectionSymbol, ...

Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.



118
119
120
121
122
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 118

optional :deepfake_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::DeepfakeDetection
},
api_name: :DeepfakeDetection

#deepfake_detection_callback_methodSymbol, ...

HTTP request type used for DeepfakeDetectionCallbackUrl.



128
129
130
131
132
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 128

optional :deepfake_detection_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::DeepfakeDetectionCallbackMethod
},
api_name: :DeepfakeDetectionCallbackMethod

#deepfake_detection_callback_urlString?

URL destination for Telnyx to send deepfake detection callback events to for the call.

Parameters:

  • (String)

Returns:

  • (String, nil)


139
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 139

optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl

#detection_modeSymbol, ...

Allows you to choose between Regular, Premium, and PremiumCallScreening detections. See https://developers.telnyx.com/docs/voice/programmable-voice/answering-machine-detection



147
148
149
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 147

optional :detection_mode,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::DetectionMode },
api_name: :DetectionMode

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the Url is not responding.

Parameters:

  • (String)

Returns:

  • (String, nil)


156
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 156

optional :fallback_url, String, api_name: :FallbackUrl

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a + and country code.

Parameters:

  • (String)

Returns:

  • (String, nil)


163
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 163

optional :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



169
170
171
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 169

optional :machine_detection,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::MachineDetection },
api_name: :MachineDetection

#machine_detection_beep_profileSymbol, ...

Selects which detectors must validate a beep. both requires the amplitude and frequency detectors to agree. freq_only uses the frequency detector alone, for beeps whose volume is too unsteady for the default profile. Only used when MachineDetection is enabled.



180
181
182
183
184
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 180

optional :machine_detection_beep_profile,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::MachineDetectionBeepProfile
},
api_name: :MachineDetectionBeepProfile

#machine_detection_prompt_end_timeoutInteger?

Silence duration threshold after a call screening prompt before ending prompt detection, in milliseconds. Used when DetectionMode is PremiumCallScreening.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


191
192
193
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 191

optional :machine_detection_prompt_end_timeout,
Integer,
api_name: :MachineDetectionPromptEndTimeout

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when premium detection is used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


200
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 200

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when premium detection is used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


207
208
209
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 207

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when premium detection is used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


216
217
218
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 216

optional :machine_detection_speech_threshold,
Integer,
api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


224
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 224

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the call. When set to SRTP, the call will use Secure Real-time Transport Protocol for media encryption. When set to DTLS, the call will use DTLS for media encryption. Only supported for SIP destinations.



233
234
235
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 233

optional :media_encryption,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::MediaEncryption },
api_name: :MediaEncryption

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Parameters:

  • (String)

Returns:

  • (String, nil)


241
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 241

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant's call leg. Defaults to false.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


247
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 247

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to mono.



253
254
255
256
257
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 253

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Parameters:

  • (String)

Returns:

  • (String, nil)


263
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 263

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording's state that should generate a call to RecoridngStatusCallback. Can be: in-progress, completed and absent. Separate multiple values with a space. Defaults to completed.

Parameters:

  • (String)

Returns:

  • (String, nil)


271
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 271

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for RecordingStatusCallback. Defaults to POST.



277
278
279
280
281
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 277

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


290
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 290

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is both.



296
297
298
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 296

optional :recording_track,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::RecordingTrack },
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


304
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 304

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Parameters:

  • (String)

Returns:

  • (String, nil)


310
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 310

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Parameters:

  • (String)

Returns:

  • (String, nil)


316
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 316

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



322
323
324
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 322

optional :sip_region,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::SipRegion },
api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Parameters:

  • (String)

Returns:

  • (String, nil)


330
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 330

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventString?

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.

Parameters:

  • (String)

Returns:

  • (String, nil)


337
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 337

optional :status_callback_event, String, api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for StatusCallback.



343
344
345
346
347
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 343

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#supervise_call_sidString?

The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.

Parameters:

  • (String)

Returns:

  • (String, nil)


355
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 355

optional :supervise_call_sid, String, api_name: :SuperviseCallSid

#supervising_roleSymbol, ...

The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge



363
364
365
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 363

optional :supervising_role,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::SupervisingRole },
api_name: :SupervisingRole

#texmlString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


370
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 370

optional :texml, String, api_name: :Texml, nil?: true

#time_limitInteger?

The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


377
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 377

optional :time_limit, Integer, api_name: :TimeLimit

#timeoutInteger?

The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


385
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 385

optional :timeout, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a + and country code.

Parameters:

  • (String)

Returns:

  • (String, nil)


392
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 392

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to trim-silence.



399
400
401
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 399

optional :trim,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::Trim },
api_name: :Trim

#urlString

The URL from which Telnyx will retrieve the TeXML call instructions.

Parameters:

  • value (String)

Returns:

  • (String)


43
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 43

required :url, String, api_name: :Url

#url_methodSymbol, ...

HTTP request type used for Url. The default value is inherited from TeXML Application setting.



408
409
410
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 408

optional :url_method,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::URLMethod },
api_name: :UrlMethod

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 519

Instance Method Details

#to_hash{

Returns:

  • ({)


352
# File 'sig/telnyx/models/texml/accounts/call_calls_params.rbs', line 352

def to_hash: -> {