Module: Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithURL::StatusCallbackEvent

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb,
sig/telnyx/models/texml/accounts/call_calls_params.rbs

Overview

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.

See Also:

  • Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithURL#status_callback_event

Constant Summary collapse

INITIATED =

Returns:

  • (:initiated)
:initiated
RINGING =

Returns:

  • (:ringing)
:ringing
ANSWERED =

Returns:

  • (:answered)
:answered
COMPLETED =

Returns:

  • (:completed)
:completed

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithURL::status_callback_event]

Returns:

  • (::Array[Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithURL::status_callback_event])


534
# File 'sig/telnyx/models/texml/accounts/call_calls_params.rbs', line 534

def self?.values: -> ::Array[Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithURL::status_callback_event]