Module: Telnyx::Models::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::StatusCallbackEvent
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/texml/accounts/call_calls_params.rb
Overview
The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.
Constant Summary collapse
- INITIATED =
:initiated- RINGING =
:ringing- ANSWERED =
:answered- COMPLETED =
:completed
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info