Class: Telnyx::Models::Texml::Accounts::CallRetrieveCallsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid:, end_time: nil, end_time_gt: nil, end_time_lt: nil, from: nil, page: nil, page_size: nil, page_token: nil, start_time: nil, start_time_gt: nil, start_time_lt: nil, status: nil, to: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallRetrieveCallsParams for more details.

Parameters:

  • account_sid (String)
  • end_time (String) (defaults to: nil)

    Filters calls by their end date. Expected format is YYYY-MM-DD

  • end_time_gt (String) (defaults to: nil)

    Filters calls by their end date (after). Expected format is YYYY-MM-DD

  • end_time_lt (String) (defaults to: nil)

    Filters calls by their end date (before). Expected format is YYYY-MM-DD

  • from (String) (defaults to: nil)

    Filters calls by the from number.

  • page (Integer) (defaults to: nil)

    The number of the page to be displayed, zero-indexed, should be used in conjucti

  • page_size (Integer) (defaults to: nil)

    The number of records to be displayed on a page

  • page_token (String) (defaults to: nil)

    Used to request the next page of results.

  • start_time (String) (defaults to: nil)

    Filters calls by their start date. Expected format is YYYY-MM-DD.

  • start_time_gt (String) (defaults to: nil)

    Filters calls by their start date (after). Expected format is YYYY-MM-DD

  • start_time_lt (String) (defaults to: nil)

    Filters calls by their start date (before). Expected format is YYYY-MM-DD

  • status (Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveCallsParams::Status) (defaults to: nil)

    Filters calls by status.

  • to (String) (defaults to: nil)

    Filters calls by the to number.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 90

Instance Attribute Details

#account_sidString

Returns:

  • (String)


15
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 15

required :account_sid, String

#end_timeString?

Filters calls by their end date. Expected format is YYYY-MM-DD

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 21

optional :end_time, String

#end_time_gtString?

Filters calls by their end date (after). Expected format is YYYY-MM-DD

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 27

optional :end_time_gt, String

#end_time_ltString?

Filters calls by their end date (before). Expected format is YYYY-MM-DD

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 33

optional :end_time_lt, String

#fromString?

Filters calls by the from number.

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 39

optional :from, String

#pageInteger?

The number of the page to be displayed, zero-indexed, should be used in conjuction with PageToken.

Returns:

  • (Integer, nil)


46
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 46

optional :page, Integer

#page_sizeInteger?

The number of records to be displayed on a page

Returns:

  • (Integer, nil)


52
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 52

optional :page_size, Integer

#page_tokenString?

Used to request the next page of results.

Returns:

  • (String, nil)


58
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 58

optional :page_token, String

#start_timeString?

Filters calls by their start date. Expected format is YYYY-MM-DD.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 64

optional :start_time, String

#start_time_gtString?

Filters calls by their start date (after). Expected format is YYYY-MM-DD

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 70

optional :start_time_gt, String

#start_time_ltString?

Filters calls by their start date (before). Expected format is YYYY-MM-DD

Returns:

  • (String, nil)


76
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 76

optional :start_time_lt, String

#statusSymbol, ...

Filters calls by status.



82
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 82

optional :status, enum: -> { Telnyx::Texml::Accounts::CallRetrieveCallsParams::Status }

#toString?

Filters calls by the to number.

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 88

optional :to, String