Class: Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(calls: nil, end_: nil, first_page_uri: nil, next_page_uri: nil, page: nil, page_size: nil, start: nil, uri: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse for more details.

Parameters:

  • calls (Array<Telnyx::Models::Texml::Accounts::CallResource>) (defaults to: nil)
  • end_ (Integer) (defaults to: nil)

    The number of the last element on the page, zero-indexed.

  • first_page_uri (String) (defaults to: nil)

    /v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Calls.json?Page=0&PageSi

  • next_page_uri (String) (defaults to: nil)

    /v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Calls.json?Page=1&PageSi

  • page (Integer) (defaults to: nil)

    Current page number, zero-indexed.

  • page_size (Integer) (defaults to: nil)

    The number of items on the page

  • start (Integer) (defaults to: nil)

    The number of the first element on the page, zero-indexed.

  • uri (String) (defaults to: nil)

    The URI of the current page.



# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 56

Instance Attribute Details

#callsArray<Telnyx::Models::Texml::Accounts::CallResource>?



12
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 12

optional :calls, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallResource] }

#end_Integer?

The number of the last element on the page, zero-indexed.

Returns:

  • (Integer, nil)


18
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 18

optional :end_, Integer, api_name: :end

#first_page_uriString?

/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Calls.json?Page=0&PageSize=1

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 24

optional :first_page_uri, String

#next_page_uriString?

/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Calls.json?Page=1&PageSize=1&PageToken=MTY4AjgyNDkwNzIxMQ

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 30

optional :next_page_uri, String

#pageInteger?

Current page number, zero-indexed.

Returns:

  • (Integer, nil)


36
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 36

optional :page, Integer

#page_sizeInteger?

The number of items on the page

Returns:

  • (Integer, nil)


42
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 42

optional :page_size, Integer

#startInteger?

The number of the first element on the page, zero-indexed.

Returns:

  • (Integer, nil)


48
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 48

optional :start, Integer

#uriString?

The URI of the current page.

Returns:

  • (String, nil)


54
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 54

optional :uri, String