Class: Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb

Defined Under Namespace

Modules: AnsweredBy, Direction, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid: nil, answered_by: nil, caller_name: nil, date_created: nil, date_updated: nil, direction: nil, duration: nil, end_time: nil, from: nil, from_formatted: nil, price: nil, price_unit: nil, sid: nil, start_time: nil, status: nil, to: nil, to_formatted: nil, uri: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call for more details.

Parameters:

  • account_sid (String) (defaults to: nil)

    The id of the account the resource belongs to.

  • answered_by (Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::AnsweredBy) (defaults to: nil)

    The value of the answering machine detection result, if this feature was enabled

  • caller_name (String) (defaults to: nil)

    Caller ID, if present.

  • date_created (String) (defaults to: nil)

    The timestamp of when the resource was created.

  • date_updated (String) (defaults to: nil)

    The timestamp of when the resource was last updated.

  • direction (Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::Direction) (defaults to: nil)

    The direction of this call.

  • duration (String) (defaults to: nil)

    The duration of this call, given in seconds.

  • end_time (String) (defaults to: nil)

    The end time of this call.

  • from (String) (defaults to: nil)

    The phone number or SIP address that made this call.

  • from_formatted (String) (defaults to: nil)

    The from number formatted for display.

  • price (String) (defaults to: nil)

    The price of this call, the currency is specified in the price_unit field. Only

  • price_unit (String) (defaults to: nil)

    The unit in which the price is given.

  • sid (String) (defaults to: nil)

    The identifier of this call.

  • start_time (String) (defaults to: nil)

    The start time of this call.

  • status (Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::Status) (defaults to: nil)

    The status of this call.

  • to (String) (defaults to: nil)

    The phone number or SIP address that received this call.

  • to_formatted (String) (defaults to: nil)

    The to number formatted for display.

  • uri (String) (defaults to: nil)

    The relative URI for this call.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 77

class Call < Telnyx::Internal::Type::BaseModel
  # @!attribute account_sid
  #   The id of the account the resource belongs to.
  #
  #   @return [String, nil]
  optional :account_sid, String

  # @!attribute answered_by
  #   The value of the answering machine detection result, if this feature was enabled
  #   for the call.
  #
  #   @return [Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::AnsweredBy, nil]
  optional :answered_by,
           enum: -> { Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::AnsweredBy }

  # @!attribute caller_name
  #   Caller ID, if present.
  #
  #   @return [String, nil]
  optional :caller_name, String

  # @!attribute date_created
  #   The timestamp of when the resource was created.
  #
  #   @return [String, nil]
  optional :date_created, String

  # @!attribute date_updated
  #   The timestamp of when the resource was last updated.
  #
  #   @return [String, nil]
  optional :date_updated, String

  # @!attribute direction
  #   The direction of this call.
  #
  #   @return [Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::Direction, nil]
  optional :direction,
           enum: -> { Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::Direction }

  # @!attribute duration
  #   The duration of this call, given in seconds.
  #
  #   @return [String, nil]
  optional :duration, String

  # @!attribute end_time
  #   The end time of this call.
  #
  #   @return [String, nil]
  optional :end_time, String

  # @!attribute from
  #   The phone number or SIP address that made this call.
  #
  #   @return [String, nil]
  optional :from, String

  # @!attribute from_formatted
  #   The from number formatted for display.
  #
  #   @return [String, nil]
  optional :from_formatted, String

  # @!attribute price
  #   The price of this call, the currency is specified in the price_unit field. Only
  #   populated when the call cost feature is enabled for the account.
  #
  #   @return [String, nil]
  optional :price, String

  # @!attribute price_unit
  #   The unit in which the price is given.
  #
  #   @return [String, nil]
  optional :price_unit, String

  # @!attribute sid
  #   The identifier of this call.
  #
  #   @return [String, nil]
  optional :sid, String

  # @!attribute start_time
  #   The start time of this call.
  #
  #   @return [String, nil]
  optional :start_time, String

  # @!attribute status
  #   The status of this call.
  #
  #   @return [Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::Status, nil]
  optional :status, enum: -> { Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::Status }

  # @!attribute to
  #   The phone number or SIP address that received this call.
  #
  #   @return [String, nil]
  optional :to, String

  # @!attribute to_formatted
  #   The to number formatted for display.
  #
  #   @return [String, nil]
  optional :to_formatted, String

  # @!attribute uri
  #   The relative URI for this call.
  #
  #   @return [String, nil]
  optional :uri, String

  # @!method initialize(account_sid: nil, answered_by: nil, caller_name: nil, date_created: nil, date_updated: nil, direction: nil, duration: nil, end_time: nil, from: nil, from_formatted: nil, price: nil, price_unit: nil, sid: nil, start_time: nil, status: nil, to: nil, to_formatted: nil, uri: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call} for more
  #   details.
  #
  #   @param account_sid [String] The id of the account the resource belongs to.
  #
  #   @param answered_by [Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::AnsweredBy] The value of the answering machine detection result, if this feature was enabled
  #
  #   @param caller_name [String] Caller ID, if present.
  #
  #   @param date_created [String] The timestamp of when the resource was created.
  #
  #   @param date_updated [String] The timestamp of when the resource was last updated.
  #
  #   @param direction [Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::Direction] The direction of this call.
  #
  #   @param duration [String] The duration of this call, given in seconds.
  #
  #   @param end_time [String] The end time of this call.
  #
  #   @param from [String] The phone number or SIP address that made this call.
  #
  #   @param from_formatted [String] The from number formatted for display.
  #
  #   @param price [String] The price of this call, the currency is specified in the price_unit field. Only
  #
  #   @param price_unit [String] The unit in which the price is given.
  #
  #   @param sid [String] The identifier of this call.
  #
  #   @param start_time [String] The start time of this call.
  #
  #   @param status [Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::Status] The status of this call.
  #
  #   @param to [String] The phone number or SIP address that received this call.
  #
  #   @param to_formatted [String] The to number formatted for display.
  #
  #   @param uri [String] The relative URI for this call.

  # The value of the answering machine detection result, if this feature was enabled
  # for the call.
  #
  # @see Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call#answered_by
  module AnsweredBy
    extend Telnyx::Internal::Type::Enum

    HUMAN = :human
    MACHINE = :machine
    NOT_SURE = :not_sure

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # The direction of this call.
  #
  # @see Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call#direction
  module Direction
    extend Telnyx::Internal::Type::Enum

    INBOUND = :inbound
    OUTBOUND = :outbound

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # The status of this call.
  #
  # @see Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call#status
  module Status
    extend Telnyx::Internal::Type::Enum

    RINGING = :ringing
    IN_PROGRESS = :"in-progress"
    CANCELED = :canceled
    COMPLETED = :completed
    FAILED = :failed
    BUSY = :busy
    NO_ANSWER = :"no-answer"

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#account_sidString?

The id of the account the resource belongs to.

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 82

optional :account_sid, String

#answered_bySymbol, ...

The value of the answering machine detection result, if this feature was enabled for the call.



89
90
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 89

optional :answered_by,
enum: -> { Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::AnsweredBy }

#caller_nameString?

Caller ID, if present.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 96

optional :caller_name, String

#date_createdString?

The timestamp of when the resource was created.

Returns:

  • (String, nil)


102
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 102

optional :date_created, String

#date_updatedString?

The timestamp of when the resource was last updated.

Returns:

  • (String, nil)


108
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 108

optional :date_updated, String

#directionSymbol, ...

The direction of this call.



114
115
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 114

optional :direction,
enum: -> { Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::Direction }

#durationString?

The duration of this call, given in seconds.

Returns:

  • (String, nil)


121
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 121

optional :duration, String

#end_timeString?

The end time of this call.

Returns:

  • (String, nil)


127
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 127

optional :end_time, String

#fromString?

The phone number or SIP address that made this call.

Returns:

  • (String, nil)


133
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 133

optional :from, String

#from_formattedString?

The from number formatted for display.

Returns:

  • (String, nil)


139
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 139

optional :from_formatted, String

#priceString?

The price of this call, the currency is specified in the price_unit field. Only populated when the call cost feature is enabled for the account.

Returns:

  • (String, nil)


146
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 146

optional :price, String

#price_unitString?

The unit in which the price is given.

Returns:

  • (String, nil)


152
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 152

optional :price_unit, String

#sidString?

The identifier of this call.

Returns:

  • (String, nil)


158
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 158

optional :sid, String

#start_timeString?

The start time of this call.

Returns:

  • (String, nil)


164
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 164

optional :start_time, String

#statusSymbol, ...

The status of this call.



170
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 170

optional :status, enum: -> { Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse::Call::Status }

#toString?

The phone number or SIP address that received this call.

Returns:

  • (String, nil)


176
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 176

optional :to, String

#to_formattedString?

The to number formatted for display.

Returns:

  • (String, nil)


182
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 182

optional :to_formatted, String

#uriString?

The relative URI for this call.

Returns:

  • (String, nil)


188
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 188

optional :uri, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 242