Class: Telnyx::Models::Texml::Accounts::CallRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_retrieve_response.rb

Overview

Defined Under Namespace

Modules: AnsweredBy, Direction, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid: nil, answered_by: nil, caller_name: nil, date_created: nil, date_updated: nil, direction: nil, duration: nil, end_time: nil, from: nil, from_formatted: nil, price: nil, price_unit: nil, sid: nil, start_time: nil, status: nil, to: nil, to_formatted: nil, uri: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallRetrieveResponse for more details.

Parameters:

  • account_sid (String) (defaults to: nil)

    The id of the account the resource belongs to.

  • answered_by (Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveResponse::AnsweredBy) (defaults to: nil)

    The value of the answering machine detection result, if this feature was enabled

  • caller_name (String) (defaults to: nil)

    Caller ID, if present.

  • date_created (String) (defaults to: nil)

    The timestamp of when the resource was created.

  • date_updated (String) (defaults to: nil)

    The timestamp of when the resource was last updated.

  • direction (Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveResponse::Direction) (defaults to: nil)

    The direction of this call.

  • duration (String) (defaults to: nil)

    The duration of this call, given in seconds.

  • end_time (String) (defaults to: nil)

    The end time of this call.

  • from (String) (defaults to: nil)

    The phone number or SIP address that made this call.

  • from_formatted (String) (defaults to: nil)

    The from number formatted for display.

  • price (String) (defaults to: nil)

    The price of this call, the currency is specified in the price_unit field. Only

  • price_unit (String) (defaults to: nil)

    The unit in which the price is given.

  • sid (String) (defaults to: nil)

    The identifier of this call.

  • start_time (String) (defaults to: nil)

    The start time of this call.

  • status (Symbol, Telnyx::Models::Texml::Accounts::CallRetrieveResponse::Status) (defaults to: nil)

    The status of this call.

  • to (String) (defaults to: nil)

    The phone number or SIP address that received this call.

  • to_formatted (String) (defaults to: nil)

    The to number formatted for display.

  • uri (String) (defaults to: nil)

    The relative URI for this call.



# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 119

Instance Attribute Details

#account_sidString?

The id of the account the resource belongs to.

Returns:

  • (String, nil)


13
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 13

optional :account_sid, String

#answered_bySymbol, ...

The value of the answering machine detection result, if this feature was enabled for the call.



20
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 20

optional :answered_by, enum: -> { Telnyx::Models::Texml::Accounts::CallRetrieveResponse::AnsweredBy }

#caller_nameString?

Caller ID, if present.

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 26

optional :caller_name, String

#date_createdString?

The timestamp of when the resource was created.

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 32

optional :date_created, String

#date_updatedString?

The timestamp of when the resource was last updated.

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 38

optional :date_updated, String

#directionSymbol, ...

The direction of this call.



44
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 44

optional :direction, enum: -> { Telnyx::Models::Texml::Accounts::CallRetrieveResponse::Direction }

#durationString?

The duration of this call, given in seconds.

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 50

optional :duration, String

#end_timeString?

The end time of this call.

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 56

optional :end_time, String

#fromString?

The phone number or SIP address that made this call.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 62

optional :from, String

#from_formattedString?

The from number formatted for display.

Returns:

  • (String, nil)


68
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 68

optional :from_formatted, String

#priceString?

The price of this call, the currency is specified in the price_unit field. Only populated when the call cost feature is enabled for the account.

Returns:

  • (String, nil)


75
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 75

optional :price, String

#price_unitString?

The unit in which the price is given.

Returns:

  • (String, nil)


81
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 81

optional :price_unit, String

#sidString?

The identifier of this call.

Returns:

  • (String, nil)


87
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 87

optional :sid, String

#start_timeString?

The start time of this call.

Returns:

  • (String, nil)


93
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 93

optional :start_time, String

#statusSymbol, ...

The status of this call.



99
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 99

optional :status, enum: -> { Telnyx::Models::Texml::Accounts::CallRetrieveResponse::Status }

#toString?

The phone number or SIP address that received this call.

Returns:

  • (String, nil)


105
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 105

optional :to, String

#to_formattedString?

The to number formatted for display.

Returns:

  • (String, nil)


111
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 111

optional :to_formatted, String

#uriString?

The relative URI for this call.

Returns:

  • (String, nil)


117
# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 117

optional :uri, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_retrieve_response.rb', line 170