Class: Telnyx::Models::Texml::Accounts::CallSiprecJsonParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml/accounts/call_siprec_json_params.rb,
sig/telnyx/models/texml/accounts/call_siprec_json_params.rbs

Overview

See Also:

  • Telnyx::Resources::Texml::Accounts::Calls#siprec_json

Defined Under Namespace

Modules: IncludeMetadataCustomHeaders, Secure, SipTransport, StatusCallbackMethod, Track

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid:, call_sid:, connector_name: nil, include_metadata_custom_headers: nil, name: nil, secure: nil, session_timeout_secs: nil, sip_transport: nil, status_callback: nil, status_callback_method: nil, track: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallSiprecJsonParams for more details.

Parameters:



# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 94

Instance Attribute Details

#account_sidString

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 15

required :account_sid, String

#call_sidString

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 20

required :call_sid, String

#connector_nameString?

The name of the connector to use for the SIPREC session.

Parameters:

  • (String)

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 26

optional :connector_name, String, api_name: :ConnectorName

#include_metadata_custom_headersBoolean, ...

When set, custom parameters will be added as metadata (recording.session.ExtensionParameters). Otherwise, they’ll be added to sip headers.



34
35
36
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 34

optional :include_metadata_custom_headers,
enum: -> { Telnyx::Texml::Accounts::CallSiprecJsonParams::IncludeMetadataCustomHeaders },
api_name: :IncludeMetadataCustomHeaders

#nameString?

Name of the SIPREC session. May be used to stop the SIPREC session from TeXML instruction.

Parameters:

  • (String)

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 43

optional :name, String, api_name: :Name

#secureBoolean, ...

Controls whether to encrypt media sent to your SRS using SRTP and TLS. When set you need to configure SRS port in your connector to 5061.



50
51
52
53
54
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 50

optional :secure,
enum: -> {
  Telnyx::Texml::Accounts::CallSiprecJsonParams::Secure
},
api_name: :Secure

#session_timeout_secsInteger?

Sets Session-Expires header to the INVITE. A reinvite is sent every half the value set. Usefull for session keep alive. Minimum value is 90, set to 0 to disable.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


62
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 62

optional :session_timeout_secs, Integer, api_name: :SessionTimeoutSecs

#sip_transportSymbol, ...

Specifies SIP transport protocol.



68
69
70
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 68

optional :sip_transport,
enum: -> { Telnyx::Texml::Accounts::CallSiprecJsonParams::SipTransport },
api_name: :SipTransport

#status_callbackString?

URL destination for Telnyx to send status callback events to for the siprec session.

Parameters:

  • (String)

Returns:

  • (String, nil)


77
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 77

optional :status_callback, String, api_name: :StatusCallback

#status_callback_methodSymbol, ...

HTTP request type used for StatusCallback.



83
84
85
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 83

optional :status_callback_method,
enum: -> { Telnyx::Texml::Accounts::CallSiprecJsonParams::StatusCallbackMethod },
api_name: :StatusCallbackMethod

#trackSymbol, ...

The track to be used for siprec session. Can be both_tracks, inbound_track or outbound_track. Defaults to both_tracks.



92
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 92

optional :track, enum: -> { Telnyx::Texml::Accounts::CallSiprecJsonParams::Track }, api_name: :Track

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 131

Instance Method Details

#to_hash{

Returns:

  • ({)


90
# File 'sig/telnyx/models/texml/accounts/call_siprec_json_params.rbs', line 90

def to_hash: -> {