Class: Telnyx::Models::Texml::Accounts::CallSiprecJsonResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::CallSiprecJsonResponse
- Defined in:
- lib/telnyx/models/texml/accounts/call_siprec_json_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#account_sid ⇒ String?
The id of the account the resource belongs to.
-
#call_sid ⇒ String?
The id of the call the resource belongs to.
-
#date_created ⇒ String?
The date and time the siprec session was created.
-
#date_updated ⇒ String?
The date and time the siprec session was last updated.
-
#error_code ⇒ String?
The error code of the siprec session.
-
#sid ⇒ String?
The SID of the siprec session.
-
#start_time ⇒ String?
The date and time the siprec session was started.
-
#status ⇒ Symbol, ...
The status of the siprec session.
-
#track ⇒ Symbol, ...
The track used for the siprec session.
-
#uri ⇒ String?
The URI of the siprec session.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid: nil, call_sid: nil, date_created: nil, date_updated: nil, error_code: nil, sid: nil, start_time: nil, status: nil, track: nil, uri: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 69
|
Instance Attribute Details
#account_sid ⇒ String?
The id of the account the resource belongs to.
13 |
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 13 optional :account_sid, String |
#call_sid ⇒ String?
The id of the call the resource belongs to.
19 |
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 19 optional :call_sid, String |
#date_created ⇒ String?
The date and time the siprec session was created.
25 |
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 25 optional :date_created, String |
#date_updated ⇒ String?
The date and time the siprec session was last updated.
31 |
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 31 optional :date_updated, String |
#error_code ⇒ String?
The error code of the siprec session.
37 |
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 37 optional :error_code, String |
#sid ⇒ String?
The SID of the siprec session.
43 |
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 43 optional :sid, String |
#start_time ⇒ String?
The date and time the siprec session was started.
49 |
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 49 optional :start_time, String |
#status ⇒ Symbol, ...
The status of the siprec session.
55 |
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 55 optional :status, enum: -> { Telnyx::Models::Texml::Accounts::CallSiprecJsonResponse::Status } |
#track ⇒ Symbol, ...
The track used for the siprec session.
61 |
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 61 optional :track, enum: -> { Telnyx::Models::Texml::Accounts::CallSiprecJsonResponse::Track } |
#uri ⇒ String?
The URI of the siprec session.
67 |
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 67 optional :uri, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_response.rb', line 99
|