Class: Telnyx::Models::Texml::Accounts::CallStreamsJsonParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::CallStreamsJsonParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/texml/accounts/call_streams_json_params.rb
Overview
Defined Under Namespace
Modules: BidirectionalCodec, BidirectionalMode, StatusCallbackMethod, Track
Instance Attribute Summary collapse
- #account_sid ⇒ String
-
#bidirectional_codec ⇒ Symbol, ...
Indicates codec for bidirectional streaming RTP payloads.
-
#bidirectional_mode ⇒ Symbol, ...
Configures method of bidirectional streaming (mp3, rtp).
- #call_sid ⇒ String
-
#name ⇒ String?
The user specified name of Stream.
-
#status_callback ⇒ String?
Url where status callbacks will be sent.
-
#status_callback_method ⇒ Symbol, ...
HTTP method used to send status callbacks.
-
#track ⇒ Symbol, ...
Tracks to be included in the stream.
-
#url ⇒ String?
The destination WebSocket address where the stream is going to be delivered.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_sid:, call_sid:, bidirectional_codec: nil, bidirectional_mode: nil, name: nil, status_callback: nil, status_callback_method: nil, track: nil, url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallStreamsJsonParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid:, call_sid:, bidirectional_codec: nil, bidirectional_mode: nil, name: nil, status_callback: nil, status_callback_method: nil, track: nil, url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallStreamsJsonParams for more details.
stream_
|
|
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 75
|
Instance Attribute Details
#account_sid ⇒ String
15 |
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 15 required :account_sid, String |
#bidirectional_codec ⇒ Symbol, ...
Indicates codec for bidirectional streaming RTP payloads. Used only with stream_bidirectional_mode=rtp. Case sensitive.
27 28 29 |
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 27 optional :bidirectional_codec, enum: -> { Telnyx::Texml::Accounts::CallStreamsJsonParams::BidirectionalCodec }, api_name: :BidirectionalCodec |
#bidirectional_mode ⇒ Symbol, ...
Configures method of bidirectional streaming (mp3, rtp).
35 36 37 |
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 35 optional :bidirectional_mode, enum: -> { Telnyx::Texml::Accounts::CallStreamsJsonParams::BidirectionalMode }, api_name: :BidirectionalMode |
#call_sid ⇒ String
20 |
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 20 required :call_sid, String |
#name ⇒ String?
The user specified name of Stream.
43 |
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 43 optional :name, String, api_name: :Name |
#status_callback ⇒ String?
Url where status callbacks will be sent.
49 |
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 49 optional :status_callback, String, api_name: :StatusCallback |
#status_callback_method ⇒ Symbol, ...
HTTP method used to send status callbacks.
55 56 57 |
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 55 optional :status_callback_method, enum: -> { Telnyx::Texml::Accounts::CallStreamsJsonParams::StatusCallbackMethod }, api_name: :StatusCallbackMethod |
#track ⇒ Symbol, ...
Tracks to be included in the stream
63 64 65 66 67 |
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 63 optional :track, enum: -> { Telnyx::Texml::Accounts::CallStreamsJsonParams::Track }, api_name: :Track |
#url ⇒ String?
The destination WebSocket address where the stream is going to be delivered.
73 |
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 73 optional :url, String, api_name: :Url |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/call_streams_json_params.rb', line 109
|