Class: Telnyx::Models::Texml::Accounts::CallUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::CallUpdateResponse
- Defined in:
- lib/telnyx/models/texml/accounts/call_update_response.rb
Overview
Defined Under Namespace
Modules: AnsweredBy, Direction, Status
Instance Attribute Summary collapse
-
#account_sid ⇒ String?
The id of the account the resource belongs to.
-
#answered_by ⇒ Symbol, ...
The value of the answering machine detection result, if this feature was enabled for the call.
-
#caller_name ⇒ String?
Caller ID, if present.
-
#date_created ⇒ String?
The timestamp of when the resource was created.
-
#date_updated ⇒ String?
The timestamp of when the resource was last updated.
-
#direction ⇒ Symbol, ...
The direction of this call.
-
#duration ⇒ String?
The duration of this call, given in seconds.
-
#end_time ⇒ String?
The end time of this call.
-
#from ⇒ String?
The phone number or SIP address that made this call.
-
#from_formatted ⇒ String?
The from number formatted for display.
-
#price ⇒ String?
The price of this call, the currency is specified in the price_unit field.
-
#price_unit ⇒ String?
The unit in which the price is given.
-
#sid ⇒ String?
The identifier of this call.
-
#start_time ⇒ String?
The start time of this call.
-
#status ⇒ Symbol, ...
The status of this call.
-
#to ⇒ String?
The phone number or SIP address that received this call.
-
#to_formatted ⇒ String?
The to number formatted for display.
-
#uri ⇒ String?
The relative URI for this call.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_sid: nil, answered_by: nil, caller_name: nil, date_created: nil, date_updated: nil, direction: nil, duration: nil, end_time: nil, from: nil, from_formatted: nil, price: nil, price_unit: nil, sid: nil, start_time: nil, status: nil, to: nil, to_formatted: nil, uri: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallUpdateResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid: nil, answered_by: nil, caller_name: nil, date_created: nil, date_updated: nil, direction: nil, duration: nil, end_time: nil, from: nil, from_formatted: nil, price: nil, price_unit: nil, sid: nil, start_time: nil, status: nil, to: nil, to_formatted: nil, uri: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallUpdateResponse for more details.
|
|
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 119
|
Instance Attribute Details
#account_sid ⇒ String?
The id of the account the resource belongs to.
13 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 13 optional :account_sid, String |
#answered_by ⇒ Symbol, ...
The value of the answering machine detection result, if this feature was enabled for the call.
20 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 20 optional :answered_by, enum: -> { Telnyx::Models::Texml::Accounts::CallUpdateResponse::AnsweredBy } |
#caller_name ⇒ String?
Caller ID, if present.
26 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 26 optional :caller_name, String |
#date_created ⇒ String?
The timestamp of when the resource was created.
32 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 32 optional :date_created, String |
#date_updated ⇒ String?
The timestamp of when the resource was last updated.
38 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 38 optional :date_updated, String |
#direction ⇒ Symbol, ...
The direction of this call.
44 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 44 optional :direction, enum: -> { Telnyx::Models::Texml::Accounts::CallUpdateResponse::Direction } |
#duration ⇒ String?
The duration of this call, given in seconds.
50 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 50 optional :duration, String |
#end_time ⇒ String?
The end time of this call.
56 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 56 optional :end_time, String |
#from ⇒ String?
The phone number or SIP address that made this call.
62 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 62 optional :from, String |
#from_formatted ⇒ String?
The from number formatted for display.
68 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 68 optional :from_formatted, String |
#price ⇒ String?
The price of this call, the currency is specified in the price_unit field. Only populated when the call cost feature is enabled for the account.
75 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 75 optional :price, String |
#price_unit ⇒ String?
The unit in which the price is given.
81 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 81 optional :price_unit, String |
#sid ⇒ String?
The identifier of this call.
87 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 87 optional :sid, String |
#start_time ⇒ String?
The start time of this call.
93 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 93 optional :start_time, String |
#status ⇒ Symbol, ...
The status of this call.
99 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 99 optional :status, enum: -> { Telnyx::Models::Texml::Accounts::CallUpdateResponse::Status } |
#to ⇒ String?
The phone number or SIP address that received this call.
105 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 105 optional :to, String |
#to_formatted ⇒ String?
The to number formatted for display.
111 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 111 optional :to_formatted, String |
#uri ⇒ String?
The relative URI for this call.
117 |
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 117 optional :uri, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/call_update_response.rb', line 170
|