Class: Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb
Overview
Defined Under Namespace
Modules: RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack
Instance Attribute Summary collapse
- #account_sid ⇒ String
- #call_sid ⇒ String
-
#play_beep ⇒ Boolean?
Whether to play a beep when recording is started.
-
#recording_channels ⇒ Symbol, ...
When ‘dual`, final audio file has the first leg on channel A, and the rest on channel B.
-
#recording_status_callback ⇒ String?
Url where status callbacks will be sent.
-
#recording_status_callback_event ⇒ String?
The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`.
-
#recording_status_callback_method ⇒ Symbol, ...
HTTP method used to send status callbacks.
-
#recording_track ⇒ Symbol, ...
The audio track to record for the call.
-
#send_recording_url ⇒ Boolean?
Whether to send RecordingUrl in webhooks.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_sid:, call_sid:, play_beep: nil, recording_channels: nil, recording_status_callback: nil, recording_status_callback_event: nil, recording_status_callback_method: nil, recording_track: nil, send_recording_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see RecordingsJsonRecordingsJsonParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid:, call_sid:, play_beep: nil, recording_channels: nil, recording_status_callback: nil, recording_status_callback_event: nil, recording_status_callback_method: nil, recording_track: nil, send_recording_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonParams for more details.
|
|
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb', line 80
|
Instance Attribute Details
#account_sid ⇒ String
16 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb', line 16 required :account_sid, String |
#call_sid ⇒ String
21 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb', line 21 required :call_sid, String |
#play_beep ⇒ Boolean?
Whether to play a beep when recording is started.
27 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb', line 27 optional :play_beep, Telnyx::Internal::Type::Boolean, api_name: :PlayBeep |
#recording_channels ⇒ Symbol, ...
When ‘dual`, final audio file has the first leg on channel A, and the rest on channel B. `single` mixes both tracks into a single channel.
34 35 36 37 38 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb', line 34 optional :recording_channels, enum: -> { Telnyx::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonParams::RecordingChannels }, api_name: :RecordingChannels |
#recording_status_callback ⇒ String?
Url where status callbacks will be sent.
44 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb', line 44 optional :recording_status_callback, String, api_name: :RecordingStatusCallback |
#recording_status_callback_event ⇒ String?
The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.
52 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb', line 52 optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent |
#recording_status_callback_method ⇒ Symbol, ...
HTTP method used to send status callbacks.
58 59 60 61 62 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb', line 58 optional :recording_status_callback_method, enum: -> { Telnyx::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonParams::RecordingStatusCallbackMethod }, api_name: :RecordingStatusCallbackMethod |
#recording_track ⇒ Symbol, ...
The audio track to record for the call. The default is ‘both`.
68 69 70 71 72 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb', line 68 optional :recording_track, enum: -> { Telnyx::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonParams::RecordingTrack }, api_name: :RecordingTrack |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb', line 113
|