Module: Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonParams::RecordingChannels

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rb,
sig/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rbs

Overview

When dual, final audio file has the first leg on channel A, and the rest on channel B. single mixes both tracks into a single channel.

Constant Summary collapse

SINGLE =

Returns:

:single
DUAL =

Returns:

:dual

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonParams::recording_channels]

Returns:



96
# File 'sig/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_params.rbs', line 96

def self?.values: -> ::Array[Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonParams::recording_channels]