Class: Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonResponse
- Defined in:
- lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb
Overview
Defined Under Namespace
Modules: Channels, Source, Track
Instance Attribute Summary collapse
- #account_sid ⇒ String?
- #call_sid ⇒ String?
- #channels ⇒ Integer, ...
- #conference_sid ⇒ String?
- #date_created ⇒ Time?
- #date_updated ⇒ Time?
-
#duration ⇒ String?
The duration of this recording, given in seconds.
- #error_code ⇒ String?
-
#price ⇒ String?
The price of this recording, the currency is specified in the price_unit field.
-
#price_unit ⇒ String?
The unit in which the price is given.
-
#sid ⇒ String?
Identifier of a resource.
-
#source ⇒ Symbol, ...
Defines how the recording was created.
- #start_time ⇒ Time?
-
#track ⇒ Symbol, ...
The audio track to record for the call.
-
#uri ⇒ String?
The relative URI for this recording resource.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_sid: nil, call_sid: nil, channels: nil, conference_sid: nil, date_created: nil, date_updated: nil, duration: nil, error_code: nil, price: nil, price_unit: nil, sid: nil, source: nil, start_time: nil, track: nil, uri: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RecordingsJsonRecordingsJsonResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid: nil, call_sid: nil, channels: nil, conference_sid: nil, date_created: nil, date_updated: nil, duration: nil, error_code: nil, price: nil, price_unit: nil, sid: nil, source: nil, start_time: nil, track: nil, uri: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonResponse for more details.
|
|
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 95
|
Instance Attribute Details
#account_sid ⇒ String?
13 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 13 optional :account_sid, String |
#call_sid ⇒ String?
18 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 18 optional :call_sid, String |
#channels ⇒ Integer, ...
23 24 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 23 optional :channels, enum: -> { Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonResponse::Channels } |
#conference_sid ⇒ String?
29 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 29 optional :conference_sid, String, nil?: true |
#date_created ⇒ Time?
34 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 34 optional :date_created, Time |
#date_updated ⇒ Time?
39 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 39 optional :date_updated, Time |
#duration ⇒ String?
The duration of this recording, given in seconds.
45 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 45 optional :duration, String, nil?: true |
#error_code ⇒ String?
50 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 50 optional :error_code, String, nil?: true |
#price ⇒ String?
The price of this recording, the currency is specified in the price_unit field.
56 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 56 optional :price, String, nil?: true |
#price_unit ⇒ String?
The unit in which the price is given.
62 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 62 optional :price_unit, String, nil?: true |
#sid ⇒ String?
Identifier of a resource.
68 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 68 optional :sid, String |
#source ⇒ Symbol, ...
Defines how the recording was created.
74 75 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 74 optional :source, enum: -> { Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonResponse::Source } |
#start_time ⇒ Time?
80 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 80 optional :start_time, Time |
#track ⇒ Symbol, ...
The audio track to record for the call. The default is ‘both`.
86 87 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 86 optional :track, enum: -> { Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRecordingsJsonResponse::Track } |
#uri ⇒ String?
The relative URI for this recording resource.
93 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 93 optional :uri, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_recordings_json_response.rb', line 137
|