Class: Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRetrieveRecordingsJsonResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_: nil, first_page_uri: nil, next_page_uri: nil, page: nil, page_size: nil, previous_page_uri: nil, recordings: nil, start: nil, uri: nil) ⇒ Object

Parameters:

  • end_ (Integer) (defaults to: nil)

    The number of the last element on the page, zero-indexed.

  • first_page_uri (String) (defaults to: nil)

    Relative uri to the first page of the query results

  • next_page_uri (String) (defaults to: nil)

    Relative uri to the next page of the query results

  • page (Integer) (defaults to: nil)

    Current page number, zero-indexed.

  • page_size (Integer) (defaults to: nil)

    The number of items on the page

  • previous_page_uri (String) (defaults to: nil)

    Relative uri to the previous page of the query results

  • recordings (Array<Telnyx::Models::Texml::TexmlGetCallRecordingResponseBody>) (defaults to: nil)
  • start (Integer) (defaults to: nil)

    The number of the first element on the page, zero-indexed.

  • uri (String) (defaults to: nil)

    The URI of the current page.



# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 64

Instance Attribute Details

#end_Integer?

The number of the last element on the page, zero-indexed.

Returns:

  • (Integer, nil)


14
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 14

optional :end_, Integer, api_name: :end

#first_page_uriString?

Relative uri to the first page of the query results

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 20

optional :first_page_uri, String

#next_page_uriString?

Relative uri to the next page of the query results

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 26

optional :next_page_uri, String

#pageInteger?

Current page number, zero-indexed.

Returns:

  • (Integer, nil)


32
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 32

optional :page, Integer

#page_sizeInteger?

The number of items on the page

Returns:

  • (Integer, nil)


38
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 38

optional :page_size, Integer

#previous_page_uriString?

Relative uri to the previous page of the query results

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 44

optional :previous_page_uri, String

#recordingsArray<Telnyx::Models::Texml::TexmlGetCallRecordingResponseBody>?



49
50
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 49

optional :recordings,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::TexmlGetCallRecordingResponseBody] }

#startInteger?

The number of the first element on the page, zero-indexed.

Returns:

  • (Integer, nil)


56
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 56

optional :start, Integer

#uriString?

The URI of the current page.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 62

optional :uri, String