Class: Telnyx::Models::Texml::Accounts::Calls::SiprecSiprecSidJsonResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/calls/siprec_siprec_sid_json_response.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid: nil, call_sid: nil, date_updated: nil, error_code: nil, sid: nil, status: nil, uri: nil) ⇒ Object

Parameters:

  • account_sid (String) (defaults to: nil)

    The id of the account the resource belongs to.

  • call_sid (String) (defaults to: nil)

    The id of the call the resource belongs to.

  • date_updated (String) (defaults to: nil)

    The date and time the siprec session was last updated.

  • error_code (String) (defaults to: nil)

    The error code of the siprec session.

  • sid (String) (defaults to: nil)

    The SID of the siprec session.

  • status (Symbol, Telnyx::Models::Texml::Accounts::Calls::SiprecSiprecSidJsonResponse::Status) (defaults to: nil)

    The status of the siprec session.

  • uri (String) (defaults to: nil)

    The URI of the siprec session.



# File 'lib/telnyx/models/texml/accounts/calls/siprec_siprec_sid_json_response.rb', line 52

Instance Attribute Details

#account_sidString?

The id of the account the resource belongs to.

Returns:

  • (String, nil)


14
# File 'lib/telnyx/models/texml/accounts/calls/siprec_siprec_sid_json_response.rb', line 14

optional :account_sid, String

#call_sidString?

The id of the call the resource belongs to.

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/texml/accounts/calls/siprec_siprec_sid_json_response.rb', line 20

optional :call_sid, String

#date_updatedString?

The date and time the siprec session was last updated.

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/texml/accounts/calls/siprec_siprec_sid_json_response.rb', line 26

optional :date_updated, String

#error_codeString?

The error code of the siprec session.

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/texml/accounts/calls/siprec_siprec_sid_json_response.rb', line 32

optional :error_code, String

#sidString?

The SID of the siprec session.

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/texml/accounts/calls/siprec_siprec_sid_json_response.rb', line 38

optional :sid, String

#statusSymbol, ...

The status of the siprec session.



44
# File 'lib/telnyx/models/texml/accounts/calls/siprec_siprec_sid_json_response.rb', line 44

optional :status, enum: -> { Telnyx::Models::Texml::Accounts::Calls::SiprecSiprecSidJsonResponse::Status }

#uriString?

The URI of the siprec session.

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/texml/accounts/calls/siprec_siprec_sid_json_response.rb', line 50

optional :uri, String