Class: Telnyx::Models::Texml::Accounts::Calls::TexmlCreateCallRecordingResponseBody

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb

Overview

Defined Under Namespace

Modules: Track

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid: nil, call_sid: nil, channels: nil, conference_sid: nil, date_created: nil, date_updated: nil, duration: nil, error_code: nil, price: nil, price_unit: nil, sid: nil, source: nil, start_time: nil, track: nil, uri: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::Calls::TexmlCreateCallRecordingResponseBody for more details.

Parameters:

  • account_sid (String) (defaults to: nil)
  • call_sid (String) (defaults to: nil)
  • channels (Integer, Telnyx::Models::Texml::Accounts::Calls::TwimlRecordingChannels) (defaults to: nil)
  • conference_sid (String, nil) (defaults to: nil)
  • date_created (Time) (defaults to: nil)
  • date_updated (Time) (defaults to: nil)
  • duration (String, nil) (defaults to: nil)

    The duration of this recording, given in seconds.

  • error_code (String, nil) (defaults to: nil)
  • price (String, nil) (defaults to: nil)

    The price of this recording, the currency is specified in the price_unit field.

  • price_unit (String, nil) (defaults to: nil)

    The unit in which the price is given.

  • sid (String) (defaults to: nil)

    Identifier of a resource.

  • source (Symbol, Telnyx::Models::Texml::Accounts::Calls::RecordingSource) (defaults to: nil)

    Defines how the recording was created.

  • start_time (Time) (defaults to: nil)
  • track (Symbol, Telnyx::Models::Texml::Accounts::Calls::TexmlCreateCallRecordingResponseBody::Track) (defaults to: nil)

    The audio track to record for the call. The default is ‘both`.

  • uri (String) (defaults to: nil)

    The relative URI for this recording resource.



# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 92

Instance Attribute Details

#account_sidString?

Returns:

  • (String, nil)


13
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 13

optional :account_sid, String

#call_sidString?

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 18

optional :call_sid, String

#channelsInteger, ...



23
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 23

optional :channels, enum: -> { Telnyx::Texml::Accounts::Calls::TwimlRecordingChannels }

#conference_sidString?

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 28

optional :conference_sid, String, nil?: true

#date_createdTime?

Returns:

  • (Time, nil)


33
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 33

optional :date_created, Time

#date_updatedTime?

Returns:

  • (Time, nil)


38
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 38

optional :date_updated, Time

#durationString?

The duration of this recording, given in seconds.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 44

optional :duration, String, nil?: true

#error_codeString?

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 49

optional :error_code, String, nil?: true

#priceString?

The price of this recording, the currency is specified in the price_unit field.

Returns:

  • (String, nil)


55
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 55

optional :price, String, nil?: true

#price_unitString?

The unit in which the price is given.

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 61

optional :price_unit, String, nil?: true

#sidString?

Identifier of a resource.

Returns:

  • (String, nil)


67
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 67

optional :sid, String

#sourceSymbol, ...

Defines how the recording was created.



73
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 73

optional :source, enum: -> { Telnyx::Texml::Accounts::Calls::RecordingSource }

#start_timeTime?

Returns:

  • (Time, nil)


78
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 78

optional :start_time, Time

#trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



84
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 84

optional :track, enum: -> { Telnyx::Texml::Accounts::Calls::TexmlCreateCallRecordingResponseBody::Track }

#uriString?

The relative URI for this recording resource.

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/texml/accounts/calls/texml_create_call_recording_response_body.rb', line 90

optional :uri, String