Class: Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb

Defined Under Namespace

Modules: ReasonConferenceEnded, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid: nil, api_version: nil, call_sid_ending_conference: nil, date_created: nil, date_updated: nil, friendly_name: nil, reason_conference_ended: nil, region: nil, sid: nil, status: nil, subresource_uris: nil, uri: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference for more details.

Parameters:

  • account_sid (String) (defaults to: nil)

    The id of the account the resource belongs to.

  • api_version (String) (defaults to: nil)

    The version of the API that was used to make the request.

  • call_sid_ending_conference (String) (defaults to: nil)

    Caller ID, if present.

  • date_created (String) (defaults to: nil)

    The timestamp of when the resource was created.

  • date_updated (String) (defaults to: nil)

    The timestamp of when the resource was last updated.

  • friendly_name (String) (defaults to: nil)

    A string that you assigned to describe this conference room.

  • reason_conference_ended (Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference::ReasonConferenceEnded) (defaults to: nil)

    The reason why a conference ended. When a conference is in progress, will be nul

  • region (String) (defaults to: nil)

    A string representing the region where the conference is hosted.

  • sid (String) (defaults to: nil)

    The unique identifier of the conference.

  • status (Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference::Status) (defaults to: nil)

    The status of this conference.

  • subresource_uris (Hash{Symbol=>Object}) (defaults to: nil)

    A list of related resources identified by their relative URIs.

  • uri (String) (defaults to: nil)

    The relative URI for this conference.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 78

class Conference < Telnyx::Internal::Type::BaseModel
  # @!attribute account_sid
  #   The id of the account the resource belongs to.
  #
  #   @return [String, nil]
  optional :account_sid, String

  # @!attribute api_version
  #   The version of the API that was used to make the request.
  #
  #   @return [String, nil]
  optional :api_version, String

  # @!attribute call_sid_ending_conference
  #   Caller ID, if present.
  #
  #   @return [String, nil]
  optional :call_sid_ending_conference, String

  # @!attribute date_created
  #   The timestamp of when the resource was created.
  #
  #   @return [String, nil]
  optional :date_created, String

  # @!attribute date_updated
  #   The timestamp of when the resource was last updated.
  #
  #   @return [String, nil]
  optional :date_updated, String

  # @!attribute friendly_name
  #   A string that you assigned to describe this conference room.
  #
  #   @return [String, nil]
  optional :friendly_name, String

  # @!attribute reason_conference_ended
  #   The reason why a conference ended. When a conference is in progress, will be
  #   null.
  #
  #   @return [Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference::ReasonConferenceEnded, nil]
  optional :reason_conference_ended,
           enum: -> { Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference::ReasonConferenceEnded }

  # @!attribute region
  #   A string representing the region where the conference is hosted.
  #
  #   @return [String, nil]
  optional :region, String

  # @!attribute sid
  #   The unique identifier of the conference.
  #
  #   @return [String, nil]
  optional :sid, String

  # @!attribute status
  #   The status of this conference.
  #
  #   @return [Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference::Status, nil]
  optional :status,
           enum: -> { Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference::Status }

  # @!attribute subresource_uris
  #   A list of related resources identified by their relative URIs.
  #
  #   @return [Hash{Symbol=>Object}, nil]
  optional :subresource_uris, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

  # @!attribute uri
  #   The relative URI for this conference.
  #
  #   @return [String, nil]
  optional :uri, String

  # @!method initialize(account_sid: nil, api_version: nil, call_sid_ending_conference: nil, date_created: nil, date_updated: nil, friendly_name: nil, reason_conference_ended: nil, region: nil, sid: nil, status: nil, subresource_uris: nil, uri: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference}
  #   for more details.
  #
  #   @param account_sid [String] The id of the account the resource belongs to.
  #
  #   @param api_version [String] The version of the API that was used to make the request.
  #
  #   @param call_sid_ending_conference [String] Caller ID, if present.
  #
  #   @param date_created [String] The timestamp of when the resource was created.
  #
  #   @param date_updated [String] The timestamp of when the resource was last updated.
  #
  #   @param friendly_name [String] A string that you assigned to describe this conference room.
  #
  #   @param reason_conference_ended [Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference::ReasonConferenceEnded] The reason why a conference ended. When a conference is in progress, will be nul
  #
  #   @param region [String] A string representing the region where the conference is hosted.
  #
  #   @param sid [String] The unique identifier of the conference.
  #
  #   @param status [Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference::Status] The status of this conference.
  #
  #   @param subresource_uris [Hash{Symbol=>Object}] A list of related resources identified by their relative URIs.
  #
  #   @param uri [String] The relative URI for this conference.

  # The reason why a conference ended. When a conference is in progress, will be
  # null.
  #
  # @see Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference#reason_conference_ended
  module ReasonConferenceEnded
    extend Telnyx::Internal::Type::Enum

    PARTICIPANT_WITH_END_CONFERENCE_ON_EXIT_LEFT = :"participant-with-end-conference-on-exit-left"
    LAST_PARTICIPANT_LEFT = :"last-participant-left"
    CONFERENCE_ENDED_VIA_API = :"conference-ended-via-api"
    TIME_EXCEEDED = :"time-exceeded"

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # The status of this conference.
  #
  # @see Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference#status
  module Status
    extend Telnyx::Internal::Type::Enum

    INIT = :init
    IN_PROGRESS = :"in-progress"
    COMPLETED = :completed

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#account_sidString?

The id of the account the resource belongs to.

Returns:

  • (String, nil)


83
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 83

optional :account_sid, String

#api_versionString?

The version of the API that was used to make the request.

Returns:

  • (String, nil)


89
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 89

optional :api_version, String

#call_sid_ending_conferenceString?

Caller ID, if present.

Returns:

  • (String, nil)


95
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 95

optional :call_sid_ending_conference, String

#date_createdString?

The timestamp of when the resource was created.

Returns:

  • (String, nil)


101
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 101

optional :date_created, String

#date_updatedString?

The timestamp of when the resource was last updated.

Returns:

  • (String, nil)


107
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 107

optional :date_updated, String

#friendly_nameString?

A string that you assigned to describe this conference room.

Returns:

  • (String, nil)


113
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 113

optional :friendly_name, String

#reason_conference_endedSymbol, ...

The reason why a conference ended. When a conference is in progress, will be null.



120
121
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 120

optional :reason_conference_ended,
enum: -> { Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference::ReasonConferenceEnded }

#regionString?

A string representing the region where the conference is hosted.

Returns:

  • (String, nil)


127
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 127

optional :region, String

#sidString?

The unique identifier of the conference.

Returns:

  • (String, nil)


133
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 133

optional :sid, String

#statusSymbol, ...

The status of this conference.



139
140
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 139

optional :status,
enum: -> { Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference::Status }

#subresource_urisHash{Symbol=>Object}?

A list of related resources identified by their relative URIs.

Returns:

  • (Hash{Symbol=>Object}, nil)


146
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 146

optional :subresource_uris, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#uriString?

The relative URI for this conference.

Returns:

  • (String, nil)


152
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 152

optional :uri, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 195