Class: Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb

Overview

Defined Under Namespace

Classes: Recording

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#end_Integer?

The number of the last element on the page, zero-indexed.

Returns:

  • (Integer, nil)


13
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 13

optional :end_, Integer, api_name: :end

#first_page_uriString?

/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Conferences/6dc6cc1a-1ba1-4351-86b8-4c22c95cd98f/Recordings.json?page=0&pagesize=20

Returns:

  • (String, nil)


19
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 19

optional :first_page_uri, String

#next_page_uriString?

/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Conferences/6dc6cc1a-1ba1-4351-86b8-4c22c95cd98f/Recordings.json?Page=1&PageSize=1&PageToken=MTY4AjgyNDkwNzIxMQ

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 25

optional :next_page_uri, String

#pageInteger?

Current page number, zero-indexed.

Returns:

  • (Integer, nil)


31
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 31

optional :page, Integer

#page_sizeInteger?

The number of items on the page

Returns:

  • (Integer, nil)


37
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 37

optional :page_size, Integer

#participantsArray<Hash{Symbol=>Object}>?

List of participant resources.

Returns:

  • (Array<Hash{Symbol=>Object}>, nil)


43
44
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 43

optional :participants,
Telnyx::Internal::Type::ArrayOf[Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]]

#recordingsArray<Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording>?



49
50
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 49

optional :recordings,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording] }

#startInteger?

The number of the first element on the page, zero-indexed.

Returns:

  • (Integer, nil)


56
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 56

optional :start, Integer

#uriString?

The URI of the current page.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 62

optional :uri, String