Class: Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb

Defined Under Namespace

Modules: Source, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid: nil, call_sid: nil, channels: nil, conference_sid: nil, date_created: nil, date_updated: nil, duration: nil, error_code: nil, media_url: nil, sid: nil, source: nil, start_time: nil, status: nil, subresource_uris: nil, uri: nil) ⇒ Object

Parameters:

  • account_sid (String) (defaults to: nil)

    The id of the account the resource belongs to.

  • call_sid (String) (defaults to: nil)

    The identifier of the related participant’s call.

  • channels (Integer) (defaults to: nil)

    The number of channels in the recording.

  • conference_sid (String) (defaults to: nil)

    The identifier of the related conference.

  • date_created (String) (defaults to: nil)

    The timestamp of when the resource was created.

  • date_updated (String) (defaults to: nil)

    The timestamp of when the resource was last updated.

  • duration (Integer) (defaults to: nil)

    Duratin of the recording in seconds.

  • error_code (String) (defaults to: nil)

    The recording error, if any.

  • media_url (String) (defaults to: nil)

    The URL to use to download the recording.

  • sid (String) (defaults to: nil)

    The unique identifier of the recording.

  • source (Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording::Source) (defaults to: nil)

    How the recording was started.

  • start_time (String) (defaults to: nil)

    The timestamp of when the recording was started.

  • status (Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording::Status) (defaults to: nil)

    The status of the recording.

  • subresource_uris (Hash{Symbol=>Object}) (defaults to: nil)

    A list of related resources identified by their relative URIs.

  • uri (String) (defaults to: nil)

    The relative URI for this recording.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 87

class Recording < Telnyx::Internal::Type::BaseModel
  # @!attribute account_sid
  #   The id of the account the resource belongs to.
  #
  #   @return [String, nil]
  optional :account_sid, String

  # @!attribute call_sid
  #   The identifier of the related participant's call.
  #
  #   @return [String, nil]
  optional :call_sid, String

  # @!attribute channels
  #   The number of channels in the recording.
  #
  #   @return [Integer, nil]
  optional :channels, Integer

  # @!attribute conference_sid
  #   The identifier of the related conference.
  #
  #   @return [String, nil]
  optional :conference_sid, String

  # @!attribute date_created
  #   The timestamp of when the resource was created.
  #
  #   @return [String, nil]
  optional :date_created, String

  # @!attribute date_updated
  #   The timestamp of when the resource was last updated.
  #
  #   @return [String, nil]
  optional :date_updated, String

  # @!attribute duration
  #   Duratin of the recording in seconds.
  #
  #   @return [Integer, nil]
  optional :duration, Integer

  # @!attribute error_code
  #   The recording error, if any.
  #
  #   @return [String, nil]
  optional :error_code, String

  # @!attribute media_url
  #   The URL to use to download the recording.
  #
  #   @return [String, nil]
  optional :media_url, String

  # @!attribute sid
  #   The unique identifier of the recording.
  #
  #   @return [String, nil]
  optional :sid, String

  # @!attribute source
  #   How the recording was started.
  #
  #   @return [Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording::Source, nil]
  optional :source,
           enum: -> { Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording::Source }

  # @!attribute start_time
  #   The timestamp of when the recording was started.
  #
  #   @return [String, nil]
  optional :start_time, String

  # @!attribute status
  #   The status of the recording.
  #
  #   @return [Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording::Status, nil]
  optional :status,
           enum: -> { Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording::Status }

  # @!attribute subresource_uris
  #   A list of related resources identified by their relative URIs.
  #
  #   @return [Hash{Symbol=>Object}, nil]
  optional :subresource_uris, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

  # @!attribute uri
  #   The relative URI for this recording.
  #
  #   @return [String, nil]
  optional :uri, String

  # @!method initialize(account_sid: nil, call_sid: nil, channels: nil, conference_sid: nil, date_created: nil, date_updated: nil, duration: nil, error_code: nil, media_url: nil, sid: nil, source: nil, start_time: nil, status: nil, subresource_uris: nil, uri: nil)
  #   @param account_sid [String] The id of the account the resource belongs to.
  #
  #   @param call_sid [String] The identifier of the related participant's call.
  #
  #   @param channels [Integer] The number of channels in the recording.
  #
  #   @param conference_sid [String] The identifier of the related conference.
  #
  #   @param date_created [String] The timestamp of when the resource was created.
  #
  #   @param date_updated [String] The timestamp of when the resource was last updated.
  #
  #   @param duration [Integer] Duratin of the recording in seconds.
  #
  #   @param error_code [String] The recording error, if any.
  #
  #   @param media_url [String] The URL to use to download the recording.
  #
  #   @param sid [String] The unique identifier of the recording.
  #
  #   @param source [Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording::Source] How the recording was started.
  #
  #   @param start_time [String] The timestamp of when the recording was started.
  #
  #   @param status [Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording::Status] The status of the recording.
  #
  #   @param subresource_uris [Hash{Symbol=>Object}] A list of related resources identified by their relative URIs.
  #
  #   @param uri [String] The relative URI for this recording.

  # How the recording was started.
  #
  # @see Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording#source
  module Source
    extend Telnyx::Internal::Type::Enum

    DIAL_VERB = :DialVerb
    CONFERENCE = :Conference
    OUTBOUND_API = :OutboundAPI
    TRUNKING = :Trunking
    RECORD_VERB = :RecordVerb
    START_CALL_RECORDING_API = :StartCallRecordingAPI
    START_CONFERENCE_RECORDING_API = :StartConferenceRecordingAPI

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # The status of the recording.
  #
  # @see Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording#status
  module Status
    extend Telnyx::Internal::Type::Enum

    PROCESSING = :processing
    ABSENT = :absent
    COMPLETED = :completed
    DELETED = :deleted

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#account_sidString?

The id of the account the resource belongs to.

Returns:

  • (String, nil)


92
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 92

optional :account_sid, String

#call_sidString?

The identifier of the related participant’s call.

Returns:

  • (String, nil)


98
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 98

optional :call_sid, String

#channelsInteger?

The number of channels in the recording.

Returns:

  • (Integer, nil)


104
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 104

optional :channels, Integer

#conference_sidString?

The identifier of the related conference.

Returns:

  • (String, nil)


110
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 110

optional :conference_sid, String

#date_createdString?

The timestamp of when the resource was created.

Returns:

  • (String, nil)


116
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 116

optional :date_created, String

#date_updatedString?

The timestamp of when the resource was last updated.

Returns:

  • (String, nil)


122
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 122

optional :date_updated, String

#durationInteger?

Duratin of the recording in seconds.

Returns:

  • (Integer, nil)


128
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 128

optional :duration, Integer

#error_codeString?

The recording error, if any.

Returns:

  • (String, nil)


134
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 134

optional :error_code, String

#media_urlString?

The URL to use to download the recording.

Returns:

  • (String, nil)


140
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 140

optional :media_url, String

#sidString?

The unique identifier of the recording.

Returns:

  • (String, nil)


146
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 146

optional :sid, String

#sourceSymbol, ...

How the recording was started.



152
153
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 152

optional :source,
enum: -> { Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording::Source }

#start_timeString?

The timestamp of when the recording was started.

Returns:

  • (String, nil)


159
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 159

optional :start_time, String

#statusSymbol, ...

The status of the recording.



165
166
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 165

optional :status,
enum: -> { Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse::Recording::Status }

#subresource_urisHash{Symbol=>Object}?

A list of related resources identified by their relative URIs.

Returns:

  • (Hash{Symbol=>Object}, nil)


172
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 172

optional :subresource_uris, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#uriString?

The relative URI for this recording.

Returns:

  • (String, nil)


178
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 178

optional :uri, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/conference_retrieve_recordings_response.rb', line 225