Class: Telnyx::Models::Texml::Accounts::ConferenceUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml/accounts/conference_update_params.rb

Overview

Defined Under Namespace

Modules: AnnounceMethod

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid:, conference_sid:, announce_method: nil, announce_url: nil, status: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::ConferenceUpdateParams for more details.

Parameters:

  • account_sid (String)
  • conference_sid (String)
  • announce_method (Symbol, Telnyx::Models::Texml::Accounts::ConferenceUpdateParams::AnnounceMethod) (defaults to: nil)

    The HTTP method used to call the ‘AnnounceUrl`. Defaults to `POST`.

  • announce_url (String) (defaults to: nil)

    The URL we should call to announce something into the conference. The URL may re

  • status (String) (defaults to: nil)

    The new status of the resource. Specifying ‘completed` will end the conference a

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/texml/accounts/conference_update_params.rb', line 45

Instance Attribute Details

#account_sidString

Returns:

  • (String)


15
# File 'lib/telnyx/models/texml/accounts/conference_update_params.rb', line 15

required :account_sid, String

#announce_methodSymbol, ...

The HTTP method used to call the ‘AnnounceUrl`. Defaults to `POST`.



26
27
28
# File 'lib/telnyx/models/texml/accounts/conference_update_params.rb', line 26

optional :announce_method,
enum: -> { Telnyx::Texml::Accounts::ConferenceUpdateParams::AnnounceMethod },
api_name: :AnnounceMethod

#announce_urlString?

The URL we should call to announce something into the conference. The URL may return an MP3 file, a WAV file, or a TwiML document that contains ‘<Play>`, `<Say>`, `<Pause>`, or `<Redirect>` verbs.

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/texml/accounts/conference_update_params.rb', line 36

optional :announce_url, String, api_name: :AnnounceUrl

#conference_sidString

Returns:

  • (String)


20
# File 'lib/telnyx/models/texml/accounts/conference_update_params.rb', line 20

required :conference_sid, String

#statusString?

The new status of the resource. Specifying ‘completed` will end the conference and hang up all participants.

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/texml/accounts/conference_update_params.rb', line 43

optional :status, String, api_name: :Status