Class: Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/conference_update_response.rb

Overview

Defined Under Namespace

Modules: ReasonConferenceEnded, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid: nil, api_version: nil, call_sid_ending_conference: nil, date_created: nil, date_updated: nil, friendly_name: nil, reason_conference_ended: nil, region: nil, sid: nil, status: nil, subresource_uris: nil, uri: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse for more details.

Parameters:

  • account_sid (String) (defaults to: nil)

    The id of the account the resource belongs to.

  • api_version (String) (defaults to: nil)

    The version of the API that was used to make the request.

  • call_sid_ending_conference (String) (defaults to: nil)

    Caller ID, if present.

  • date_created (String) (defaults to: nil)

    The timestamp of when the resource was created.

  • date_updated (String) (defaults to: nil)

    The timestamp of when the resource was last updated.

  • friendly_name (String) (defaults to: nil)

    A string that you assigned to describe this conference room.

  • reason_conference_ended (Symbol, Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse::ReasonConferenceEnded) (defaults to: nil)

    The reason why a conference ended. When a conference is in progress, will be nul

  • region (String) (defaults to: nil)

    A string representing the region where the conference is hosted.

  • sid (String) (defaults to: nil)

    The unique identifier of the conference.

  • status (Symbol, Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse::Status) (defaults to: nil)

    The status of this conference.

  • subresource_uris (Hash{Symbol=>Object}) (defaults to: nil)

    A list of related resources identified by their relative URIs.

  • uri (String) (defaults to: nil)

    The relative URI for this conference.



# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 83

Instance Attribute Details

#account_sidString?

The id of the account the resource belongs to.

Returns:

  • (String, nil)


13
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 13

optional :account_sid, String

#api_versionString?

The version of the API that was used to make the request.

Returns:

  • (String, nil)


19
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 19

optional :api_version, String

#call_sid_ending_conferenceString?

Caller ID, if present.

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 25

optional :call_sid_ending_conference, String

#date_createdString?

The timestamp of when the resource was created.

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 31

optional :date_created, String

#date_updatedString?

The timestamp of when the resource was last updated.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 37

optional :date_updated, String

#friendly_nameString?

A string that you assigned to describe this conference room.

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 43

optional :friendly_name, String

#reason_conference_endedSymbol, ...

The reason why a conference ended. When a conference is in progress, will be null.



50
51
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 50

optional :reason_conference_ended,
enum: -> { Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse::ReasonConferenceEnded }

#regionString?

A string representing the region where the conference is hosted.

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 57

optional :region, String

#sidString?

The unique identifier of the conference.

Returns:

  • (String, nil)


63
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 63

optional :sid, String

#statusSymbol, ...

The status of this conference.



69
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 69

optional :status, enum: -> { Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse::Status }

#subresource_urisHash{Symbol=>Object}?

A list of related resources identified by their relative URIs.

Returns:

  • (Hash{Symbol=>Object}, nil)


75
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 75

optional :subresource_uris, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#uriString?

The relative URI for this conference.

Returns:

  • (String, nil)


81
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 81

optional :uri, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 123