Class: Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb,
sig/telnyx/models/texml/accounts/conferences/participant_participants_params.rbs
Overview
Defined Under Namespace
Modules: AmdStatusCallbackMethod, Beep, ConferenceRecord, ConferenceRecordingStatusCallbackMethod, ConferenceStatusCallbackMethod, ConferenceTrim, MachineDetection, MachineDetectionBeepProfile, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, StatusCallbackMethod, Trim Classes: CustomHeader
Instance Attribute Summary collapse
- #account_sid ⇒ String
-
#amd_status_callback ⇒ String?
The URL the result of answering machine detection will be sent to.
-
#amd_status_callback_method ⇒ Symbol, ...
HTTP request type used for
AmdStatusCallback. -
#application_sid ⇒ String?
The SID of the TeXML application that will handle the new participant's call.
-
#beep ⇒ Symbol, ...
Whether to play a notification beep to the conference when the participant enters and exits.
-
#call_sid_to_coach ⇒ String?
The SID of the participant who is being coached.
-
#caller_id ⇒ String?
To be used as the caller id name (SIP From Display Name) presented to the destination (
Tonumber). -
#cancel_playback_on_detect_message_end ⇒ Boolean?
Whether to cancel ongoing playback on
greeting endeddetection. -
#cancel_playback_on_machine_detection ⇒ Boolean?
Whether to cancel ongoing playback on
machinedetection. -
#coaching ⇒ Boolean?
Whether the participant is coaching another call.
-
#conference_record ⇒ Symbol, ...
Whether to record the conference the participant is joining.
-
#conference_recording_status_callback ⇒ String?
The URL the conference recording callbacks will be sent to.
-
#conference_recording_status_callback_event ⇒ String?
The changes to the conference recording's state that should generate a call to
RecoridngStatusCallback. -
#conference_recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for
ConferenceRecordingStatusCallback. -
#conference_recording_timeout ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected.
- #conference_sid ⇒ String
-
#conference_status_callback ⇒ String?
The URL the conference callbacks will be sent to.
-
#conference_status_callback_event ⇒ String?
The changes to the conference's state that should generate a call to
ConferenceStatusCallback. -
#conference_status_callback_method ⇒ Symbol, ...
HTTP request type used for
ConferenceStatusCallback. -
#conference_trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the conference recording.
-
#custom_headers ⇒ Array<Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams::CustomHeader>?
Custom HTTP headers to be sent with the call.
-
#early_media ⇒ Boolean?
Whether participant shall be bridged to conference before the participant answers (from early media if available).
-
#end_conference_on_exit ⇒ Boolean?
Whether to end the conference when the participant leaves.
-
#from ⇒ String?
The phone number of the party that initiated the call.
-
#label ⇒ String?
A unique label for the participant that will be added to the conference.
-
#machine_detection ⇒ Symbol, ...
Whether to detect if a human or an answering machine picked up the call.
-
#machine_detection_beep_profile ⇒ Symbol, ...
Selects which detectors must validate a beep.
-
#machine_detection_silence_timeout ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine.
-
#machine_detection_speech_end_threshold ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human.
-
#machine_detection_speech_threshold ⇒ Integer?
Maximum threshold of a human greeting.
-
#machine_detection_timeout ⇒ Integer?
How long answering machine detection should go on for before sending an
Unknownresult. -
#max_participants ⇒ Integer?
The maximum number of participants in the conference.
-
#muted ⇒ Boolean?
Whether the participant should be muted.
-
#preferred_codecs ⇒ String?
The list of comma-separated codecs to be offered on a call.
-
#record ⇒ Boolean?
Whether to record the entire participant's call leg.
-
#recording_channels ⇒ Symbol, ...
The number of channels in the final recording.
-
#recording_status_callback ⇒ String?
The URL the recording callbacks will be sent to.
-
#recording_status_callback_event ⇒ String?
The changes to the recording's state that should generate a call to
RecoridngStatusCallback. -
#recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for
RecordingStatusCallback. -
#recording_track ⇒ Symbol, ...
The audio track to record for the call.
-
#sip_auth_password ⇒ String?
The password to use for SIP authentication.
-
#sip_auth_username ⇒ String?
The username to use for SIP authentication.
-
#start_conference_on_enter ⇒ Boolean?
Whether to start the conference when the participant enters.
-
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events to for the call.
-
#status_callback_event ⇒ String?
The changes to the call's state that should generate a call to
StatusCallback. -
#status_callback_method ⇒ Symbol, ...
HTTP request type used for
StatusCallback. -
#time_limit ⇒ Integer?
The maximum duration of the call in seconds.
-
#timeout_seconds ⇒ Integer?
The number of seconds that we should allow the phone to ring before assuming there is no answer.
-
#to ⇒ String?
The phone number of the called party.
-
#trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the recording.
-
#wait_url ⇒ String?
The URL to call for an audio file to play while the participant is waiting for the conference to start.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(name:, value:) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, value:) ⇒ Object
|
|
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 426
|
Instance Attribute Details
#account_sid ⇒ String
16 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 16 required :account_sid, String |
#amd_status_callback ⇒ String?
The URL the result of answering machine detection will be sent to.
27 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 27 optional :amd_status_callback, String, api_name: :AmdStatusCallback |
#amd_status_callback_method ⇒ Symbol, ...
HTTP request type used for AmdStatusCallback. Defaults to POST.
33 34 35 36 37 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 33 optional :amd_status_callback_method, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::AmdStatusCallbackMethod }, api_name: :AmdStatusCallbackMethod |
#application_sid ⇒ String?
The SID of the TeXML application that will handle the new participant's call. Required unless joining an existing conference by its ConferenceSid.
44 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 44 optional :application_sid, String, api_name: :ApplicationSid |
#beep ⇒ Symbol, ...
Whether to play a notification beep to the conference when the participant enters and exits.
51 52 53 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 51 optional :beep, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::Beep }, api_name: :Beep |
#call_sid_to_coach ⇒ String?
The SID of the participant who is being coached. The participant being coached is the only participant who can hear the participant who is coaching.
69 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 69 optional :call_sid_to_coach, String, api_name: :CallSidToCoach |
#caller_id ⇒ String?
To be used as the caller id name (SIP From Display Name) presented to the
destination (To number). The string should have a maximum of 128 characters,
containing only letters, numbers, spaces, and -_~!.+ special characters. If
ommited, the display name will be the same as the number in the From field.
62 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 62 optional :caller_id, String, api_name: :CallerId |
#cancel_playback_on_detect_message_end ⇒ Boolean?
Whether to cancel ongoing playback on greeting ended detection. Defaults to
true.
76 77 78 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 76 optional :cancel_playback_on_detect_message_end, Telnyx::Internal::Type::Boolean, api_name: :CancelPlaybackOnDetectMessageEnd |
#cancel_playback_on_machine_detection ⇒ Boolean?
Whether to cancel ongoing playback on machine detection. Defaults to true.
84 85 86 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 84 optional :cancel_playback_on_machine_detection, Telnyx::Internal::Type::Boolean, api_name: :CancelPlaybackOnMachineDetection |
#coaching ⇒ Boolean?
Whether the participant is coaching another call. When true, CallSidToCoach
has to be given.
93 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 93 optional :coaching, Telnyx::Internal::Type::Boolean, api_name: :Coaching |
#conference_record ⇒ Symbol, ...
Whether to record the conference the participant is joining. Defualts to
do-not-record. The boolean values true and false are synonymous with
record-from-start and do-not-record respectively.
101 102 103 104 105 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 101 optional :conference_record, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceRecord }, api_name: :ConferenceRecord |
#conference_recording_status_callback ⇒ String?
The URL the conference recording callbacks will be sent to.
111 112 113 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 111 optional :conference_recording_status_callback, String, api_name: :ConferenceRecordingStatusCallback |
#conference_recording_status_callback_event ⇒ String?
The changes to the conference recording's state that should generate a call to
RecoridngStatusCallback. Can be: in-progress, completed and absent.
Separate multiple values with a space. Defaults to completed. failed and
absent are synonymous.
122 123 124 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 122 optional :conference_recording_status_callback_event, String, api_name: :ConferenceRecordingStatusCallbackEvent |
#conference_recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for ConferenceRecordingStatusCallback. Defaults to
POST.
131 132 133 134 135 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 131 optional :conference_recording_status_callback_method, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceRecordingStatusCallbackMethod }, api_name: :ConferenceRecordingStatusCallbackMethod |
#conference_recording_timeout ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)
144 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 144 optional :conference_recording_timeout, Integer, api_name: :ConferenceRecordingTimeout |
#conference_sid ⇒ String
21 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 21 required :conference_sid, String |
#conference_status_callback ⇒ String?
The URL the conference callbacks will be sent to.
150 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 150 optional :conference_status_callback, String, api_name: :ConferenceStatusCallback |
#conference_status_callback_event ⇒ String?
The changes to the conference's state that should generate a call to
ConferenceStatusCallback. Can be: start, end, join and leave. Separate
multiple values with a space. By default no callbacks are sent.
158 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 158 optional :conference_status_callback_event, String, api_name: :ConferenceStatusCallbackEvent |
#conference_status_callback_method ⇒ Symbol, ...
HTTP request type used for ConferenceStatusCallback. Defaults to POST.
164 165 166 167 168 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 164 optional :conference_status_callback_method, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceStatusCallbackMethod }, api_name: :ConferenceStatusCallbackMethod |
#conference_trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the conference recording.
Defaults to trim-silence.
175 176 177 178 179 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 175 optional :conference_trim, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceTrim }, api_name: :ConferenceTrim |
#custom_headers ⇒ Array<Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams::CustomHeader>?
Custom HTTP headers to be sent with the call. Each header should be an object with 'name' and 'value' properties.
186 187 188 189 190 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 186 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::CustomHeader] }, api_name: :CustomHeaders |
#early_media ⇒ Boolean?
Whether participant shall be bridged to conference before the participant
answers (from early media if available). Defaults to false.
197 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 197 optional :early_media, Telnyx::Internal::Type::Boolean, api_name: :EarlyMedia |
#end_conference_on_exit ⇒ Boolean?
Whether to end the conference when the participant leaves. Defaults to false.
203 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 203 optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean, api_name: :EndConferenceOnExit |
#from ⇒ String?
The phone number of the party that initiated the call. Phone numbers are
formatted with a + and country code.
210 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 210 optional :from, String, api_name: :From |
#label ⇒ String?
A unique label for the participant that will be added to the conference. The label can be used to reference the participant for updates via the TeXML REST API.
218 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 218 optional :label, String, api_name: :Label |
#machine_detection ⇒ Symbol, ...
Whether to detect if a human or an answering machine picked up the call. Use
Enable if you would like to ne notified as soon as the called party is
identified. Use DetectMessageEnd, if you would like to leave a message on an
answering machine.
227 228 229 230 231 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 227 optional :machine_detection, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::MachineDetection }, api_name: :MachineDetection |
#machine_detection_beep_profile ⇒ Symbol, ...
Selects which detectors must validate a beep. both requires the amplitude and
frequency detectors to agree. freq_only uses the frequency detector alone, for
beeps whose volume is too unsteady for the default profile. Only used when
MachineDetection is enabled.
240 241 242 243 244 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 240 optional :machine_detection_beep_profile, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::MachineDetectionBeepProfile }, api_name: :MachineDetectionBeepProfile |
#machine_detection_silence_timeout ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine.
Ignored when premium detection is used.
251 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 251 optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout |
#machine_detection_speech_end_threshold ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be
considered human. Ignored when premium detection is used.
258 259 260 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 258 optional :machine_detection_speech_end_threshold, Integer, api_name: :MachineDetectionSpeechEndThreshold |
#machine_detection_speech_threshold ⇒ Integer?
Maximum threshold of a human greeting. If greeting longer than this value,
considered machine. Ignored when premium detection is used.
267 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 267 optional :machine_detection_speech_threshold, Integer, api_name: :MachineDetectionSpeechThreshold |
#machine_detection_timeout ⇒ Integer?
How long answering machine detection should go on for before sending an
Unknown result. Given in milliseconds.
274 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 274 optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout |
#max_participants ⇒ Integer?
The maximum number of participants in the conference. Can be a positive integer from 2 to 800. The default value is 250.
281 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 281 optional :max_participants, Integer, api_name: :MaxParticipants |
#muted ⇒ Boolean?
Whether the participant should be muted.
287 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 287 optional :muted, Telnyx::Internal::Type::Boolean, api_name: :Muted |
#preferred_codecs ⇒ String?
The list of comma-separated codecs to be offered on a call.
293 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 293 optional :preferred_codecs, String, api_name: :PreferredCodecs |
#record ⇒ Boolean?
Whether to record the entire participant's call leg. Defaults to false.
299 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 299 optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record |
#recording_channels ⇒ Symbol, ...
The number of channels in the final recording. Defaults to mono.
305 306 307 308 309 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 305 optional :recording_channels, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::RecordingChannels }, api_name: :RecordingChannels |
#recording_status_callback ⇒ String?
The URL the recording callbacks will be sent to.
315 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 315 optional :recording_status_callback, String, api_name: :RecordingStatusCallback |
#recording_status_callback_event ⇒ String?
The changes to the recording's state that should generate a call to
RecoridngStatusCallback. Can be: in-progress, completed and absent.
Separate multiple values with a space. Defaults to completed.
323 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 323 optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent |
#recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for RecordingStatusCallback. Defaults to POST.
329 330 331 332 333 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 329 optional :recording_status_callback_method, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::RecordingStatusCallbackMethod }, api_name: :RecordingStatusCallbackMethod |
#recording_track ⇒ Symbol, ...
The audio track to record for the call. The default is both.
339 340 341 342 343 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 339 optional :recording_track, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::RecordingTrack }, api_name: :RecordingTrack |
#sip_auth_password ⇒ String?
The password to use for SIP authentication.
349 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 349 optional :sip_auth_password, String, api_name: :SipAuthPassword |
#sip_auth_username ⇒ String?
The username to use for SIP authentication.
355 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 355 optional :sip_auth_username, String, api_name: :SipAuthUsername |
#start_conference_on_enter ⇒ Boolean?
Whether to start the conference when the participant enters. Defaults to true.
361 362 363 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 361 optional :start_conference_on_enter, Telnyx::Internal::Type::Boolean, api_name: :StartConferenceOnEnter |
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events to for the call.
369 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 369 optional :status_callback, String, api_name: :StatusCallback |
#status_callback_event ⇒ String?
The changes to the call's state that should generate a call to StatusCallback.
Can be: initiated, ringing, answered, and completed. Separate multiple
values with a space. The default value is completed.
377 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 377 optional :status_callback_event, String, api_name: :StatusCallbackEvent |
#status_callback_method ⇒ Symbol, ...
HTTP request type used for StatusCallback.
383 384 385 386 387 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 383 optional :status_callback_method, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::StatusCallbackMethod }, api_name: :StatusCallbackMethod |
#time_limit ⇒ Integer?
The maximum duration of the call in seconds.
393 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 393 optional :time_limit, Integer, api_name: :TimeLimit |
#timeout_seconds ⇒ Integer?
The number of seconds that we should allow the phone to ring before assuming there is no answer. Can be an integer between 5 and 120, inclusive. The default value is 30.
401 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 401 optional :timeout_seconds, Integer, api_name: :Timeout |
#to ⇒ String?
The phone number of the called party. Phone numbers are formatted with a + and
country code.
408 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 408 optional :to, String, api_name: :To |
#trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the recording. Defaults to
trim-silence.
415 416 417 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 415 optional :trim, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::Trim }, api_name: :Trim |
#wait_url ⇒ String?
The URL to call for an audio file to play while the participant is waiting for the conference to start.
424 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 424 optional :wait_url, String, api_name: :WaitUrl |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 542
|
Instance Method Details
#to_hash ⇒ {
349 |
# File 'sig/telnyx/models/texml/accounts/conferences/participant_participants_params.rbs', line 349
def to_hash: -> {
|