Module: Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceRecord

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb,
sig/telnyx/models/texml/accounts/conferences/participant_participants_params.rbs

Overview

Whether to record the conference the participant is joining. Defualts to do-not-record. The boolean values true and false are synonymous with record-from-start and do-not-record respectively.

Constant Summary collapse

TRUE =

Returns:

  • (:true)
:true
FALSE =

Returns:

  • (:false)
:false
RECORD_FROM_START =

Returns:

:"record-from-start"
DO_NOT_RECORD =

Returns:

:"do-not-record"

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams::conference_record]

Returns:

  • (::Array[Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams::conference_record])


430
# File 'sig/telnyx/models/texml/accounts/conferences/participant_participants_params.rbs', line 430

def self?.values: -> ::Array[Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams::conference_record]