Class: Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse::Participant

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid: nil, api_version: nil, call_sid: nil, call_sid_legacy: nil, coaching: nil, coaching_call_sid: nil, coaching_call_sid_legacy: nil, conference_sid: nil, date_created: nil, date_updated: nil, end_conference_on_exit: nil, hold: nil, muted: nil, status: nil, uri: nil) ⇒ Object

Parameters:

  • account_sid (String) (defaults to: nil)

    The id of the account the resource belongs to.

  • api_version (String) (defaults to: nil)

    The version of the API that was used to make the request.

  • call_sid (String) (defaults to: nil)

    The identifier of this participant’s call.

  • call_sid_legacy (String) (defaults to: nil)

    The identifier of this participant’s call.

  • coaching (Boolean) (defaults to: nil)

    Whether the participant is coaching another call.

  • coaching_call_sid (String) (defaults to: nil)

    The identifier of the coached participant’s call.

  • coaching_call_sid_legacy (String) (defaults to: nil)

    The identifier of the coached participant’s call.

  • conference_sid (String) (defaults to: nil)

    The unique identifier for the conference.

  • date_created (String) (defaults to: nil)

    The timestamp of when the resource was created.

  • date_updated (String) (defaults to: nil)

    The timestamp of when the resource was last updated.

  • end_conference_on_exit (Boolean) (defaults to: nil)

    Whether the conference ends when the participant leaves.

  • hold (Boolean) (defaults to: nil)

    Whether the participant is on hold.

  • muted (Boolean) (defaults to: nil)

    Whether the participant is muted.

  • status (Symbol, Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse::Participant::Status) (defaults to: nil)

    The status of the participant’s call in the conference.

  • uri (String) (defaults to: nil)

    The relative URI for this participant.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 79

class Participant < Telnyx::Internal::Type::BaseModel
  # @!attribute account_sid
  #   The id of the account the resource belongs to.
  #
  #   @return [String, nil]
  optional :account_sid, String

  # @!attribute api_version
  #   The version of the API that was used to make the request.
  #
  #   @return [String, nil]
  optional :api_version, String

  # @!attribute call_sid
  #   The identifier of this participant's call.
  #
  #   @return [String, nil]
  optional :call_sid, String

  # @!attribute call_sid_legacy
  #   The identifier of this participant's call.
  #
  #   @return [String, nil]
  optional :call_sid_legacy, String

  # @!attribute coaching
  #   Whether the participant is coaching another call.
  #
  #   @return [Boolean, nil]
  optional :coaching, Telnyx::Internal::Type::Boolean

  # @!attribute coaching_call_sid
  #   The identifier of the coached participant's call.
  #
  #   @return [String, nil]
  optional :coaching_call_sid, String

  # @!attribute coaching_call_sid_legacy
  #   The identifier of the coached participant's call.
  #
  #   @return [String, nil]
  optional :coaching_call_sid_legacy, String

  # @!attribute conference_sid
  #   The unique identifier for the conference.
  #
  #   @return [String, nil]
  optional :conference_sid, String

  # @!attribute date_created
  #   The timestamp of when the resource was created.
  #
  #   @return [String, nil]
  optional :date_created, String

  # @!attribute date_updated
  #   The timestamp of when the resource was last updated.
  #
  #   @return [String, nil]
  optional :date_updated, String

  # @!attribute end_conference_on_exit
  #   Whether the conference ends when the participant leaves.
  #
  #   @return [Boolean, nil]
  optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean

  # @!attribute hold
  #   Whether the participant is on hold.
  #
  #   @return [Boolean, nil]
  optional :hold, Telnyx::Internal::Type::Boolean

  # @!attribute muted
  #   Whether the participant is muted.
  #
  #   @return [Boolean, nil]
  optional :muted, Telnyx::Internal::Type::Boolean

  # @!attribute status
  #   The status of the participant's call in the conference.
  #
  #   @return [Symbol, Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse::Participant::Status, nil]
  optional :status,
           enum: -> { Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse::Participant::Status }

  # @!attribute uri
  #   The relative URI for this participant.
  #
  #   @return [String, nil]
  optional :uri, String

  # @!method initialize(account_sid: nil, api_version: nil, call_sid: nil, call_sid_legacy: nil, coaching: nil, coaching_call_sid: nil, coaching_call_sid_legacy: nil, conference_sid: nil, date_created: nil, date_updated: nil, end_conference_on_exit: nil, hold: nil, muted: nil, status: nil, uri: nil)
  #   @param account_sid [String] The id of the account the resource belongs to.
  #
  #   @param api_version [String] The version of the API that was used to make the request.
  #
  #   @param call_sid [String] The identifier of this participant's call.
  #
  #   @param call_sid_legacy [String] The identifier of this participant's call.
  #
  #   @param coaching [Boolean] Whether the participant is coaching another call.
  #
  #   @param coaching_call_sid [String] The identifier of the coached participant's call.
  #
  #   @param coaching_call_sid_legacy [String] The identifier of the coached participant's call.
  #
  #   @param conference_sid [String] The unique identifier for the conference.
  #
  #   @param date_created [String] The timestamp of when the resource was created.
  #
  #   @param date_updated [String] The timestamp of when the resource was last updated.
  #
  #   @param end_conference_on_exit [Boolean] Whether the conference ends when the participant leaves.
  #
  #   @param hold [Boolean] Whether the participant is on hold.
  #
  #   @param muted [Boolean] Whether the participant is muted.
  #
  #   @param status [Symbol, Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse::Participant::Status] The status of the participant's call in the conference.
  #
  #   @param uri [String] The relative URI for this participant.

  # The status of the participant's call in the conference.
  #
  # @see Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse::Participant#status
  module Status
    extend Telnyx::Internal::Type::Enum

    CONNECTING = :connecting
    CONNECTED = :connected
    COMPLETED = :completed

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#account_sidString?

The id of the account the resource belongs to.

Returns:

  • (String, nil)


84
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 84

optional :account_sid, String

#api_versionString?

The version of the API that was used to make the request.

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 90

optional :api_version, String

#call_sidString?

The identifier of this participant’s call.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 96

optional :call_sid, String

#call_sid_legacyString?

The identifier of this participant’s call.

Returns:

  • (String, nil)


102
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 102

optional :call_sid_legacy, String

#coachingBoolean?

Whether the participant is coaching another call.

Returns:

  • (Boolean, nil)


108
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 108

optional :coaching, Telnyx::Internal::Type::Boolean

#coaching_call_sidString?

The identifier of the coached participant’s call.

Returns:

  • (String, nil)


114
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 114

optional :coaching_call_sid, String

#coaching_call_sid_legacyString?

The identifier of the coached participant’s call.

Returns:

  • (String, nil)


120
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 120

optional :coaching_call_sid_legacy, String

#conference_sidString?

The unique identifier for the conference.

Returns:

  • (String, nil)


126
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 126

optional :conference_sid, String

#date_createdString?

The timestamp of when the resource was created.

Returns:

  • (String, nil)


132
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 132

optional :date_created, String

#date_updatedString?

The timestamp of when the resource was last updated.

Returns:

  • (String, nil)


138
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 138

optional :date_updated, String

#end_conference_on_exitBoolean?

Whether the conference ends when the participant leaves.

Returns:

  • (Boolean, nil)


144
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 144

optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean

#holdBoolean?

Whether the participant is on hold.

Returns:

  • (Boolean, nil)


150
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 150

optional :hold, Telnyx::Internal::Type::Boolean

#mutedBoolean?

Whether the participant is muted.

Returns:

  • (Boolean, nil)


156
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 156

optional :muted, Telnyx::Internal::Type::Boolean

#statusSymbol, ...

The status of the participant’s call in the conference.



162
163
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 162

optional :status,
enum: -> { Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse::Participant::Status }

#uriString?

The relative URI for this participant.

Returns:

  • (String, nil)


169
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 169

optional :uri, String