Class: Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid: nil, api_version: nil, call_sid: nil, call_sid_legacy: nil, coaching: nil, coaching_call_sid: nil, coaching_call_sid_legacy: nil, conference_sid: nil, date_created: nil, date_updated: nil, end_conference_on_exit: nil, hold: nil, muted: nil, status: nil, uri: nil) ⇒ Object

Parameters:

  • account_sid (String) (defaults to: nil)

    The id of the account the resource belongs to.

  • api_version (String) (defaults to: nil)

    The version of the API that was used to make the request.

  • call_sid (String) (defaults to: nil)

    The identifier of this participant’s call.

  • call_sid_legacy (String) (defaults to: nil)

    The identifier of this participant’s call.

  • coaching (Boolean) (defaults to: nil)

    Whether the participant is coaching another call.

  • coaching_call_sid (String) (defaults to: nil)

    The identifier of the coached participant’s call.

  • coaching_call_sid_legacy (String) (defaults to: nil)

    The identifier of the coached participant’s call.

  • conference_sid (String) (defaults to: nil)

    The unique identifier for the conference.

  • date_created (String) (defaults to: nil)

    The timestamp of when the resource was created.

  • date_updated (String) (defaults to: nil)

    The timestamp of when the resource was last updated.

  • end_conference_on_exit (Boolean) (defaults to: nil)

    Whether the conference ends when the participant leaves.

  • hold (Boolean) (defaults to: nil)

    Whether the participant is on hold.

  • muted (Boolean) (defaults to: nil)

    Whether the participant is muted.

  • status (Symbol, Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveResponse::Status) (defaults to: nil)

    The status of the participant’s call in the conference.

  • uri (String) (defaults to: nil)

    The relative URI for this participant.



# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 101

Instance Attribute Details

#account_sidString?

The id of the account the resource belongs to.

Returns:

  • (String, nil)


14
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 14

optional :account_sid, String

#api_versionString?

The version of the API that was used to make the request.

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 20

optional :api_version, String

#call_sidString?

The identifier of this participant’s call.

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 26

optional :call_sid, String

#call_sid_legacyString?

The identifier of this participant’s call.

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 32

optional :call_sid_legacy, String

#coachingBoolean?

Whether the participant is coaching another call.

Returns:

  • (Boolean, nil)


38
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 38

optional :coaching, Telnyx::Internal::Type::Boolean

#coaching_call_sidString?

The identifier of the coached participant’s call.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 44

optional :coaching_call_sid, String

#coaching_call_sid_legacyString?

The identifier of the coached participant’s call.

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 50

optional :coaching_call_sid_legacy, String

#conference_sidString?

The unique identifier for the conference.

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 56

optional :conference_sid, String

#date_createdString?

The timestamp of when the resource was created.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 62

optional :date_created, String

#date_updatedString?

The timestamp of when the resource was last updated.

Returns:

  • (String, nil)


68
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 68

optional :date_updated, String

#end_conference_on_exitBoolean?

Whether the conference ends when the participant leaves.

Returns:

  • (Boolean, nil)


74
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 74

optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean

#holdBoolean?

Whether the participant is on hold.

Returns:

  • (Boolean, nil)


80
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 80

optional :hold, Telnyx::Internal::Type::Boolean

#mutedBoolean?

Whether the participant is muted.

Returns:

  • (Boolean, nil)


86
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 86

optional :muted, Telnyx::Internal::Type::Boolean

#statusSymbol, ...

The status of the participant’s call in the conference.



92
93
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 92

optional :status,
enum: -> { Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveResponse::Status }

#uriString?

The relative URI for this participant.

Returns:

  • (String, nil)


99
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 99

optional :uri, String