Class: Telnyx::Models::Texml::Accounts::QueueCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::QueueCreateResponse
- Defined in:
- lib/telnyx/models/texml/accounts/queue_create_response.rb
Overview
Instance Attribute Summary collapse
-
#account_sid ⇒ String?
The id of the account the resource belongs to.
-
#average_wait_time ⇒ Integer?
The average wait time in seconds for members in the queue.
-
#current_size ⇒ Integer?
The current number of members in the queue.
-
#date_created ⇒ String?
The timestamp of when the resource was created.
-
#date_updated ⇒ String?
The timestamp of when the resource was last updated.
-
#max_size ⇒ Integer?
The maximum size of the queue.
-
#sid ⇒ String?
The unique identifier of the queue.
-
#subresource_uris ⇒ Hash{Symbol=>Object}?
A list of related resources identified by their relative URIs.
-
#uri ⇒ String?
The relative URI for this queue.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid: nil, average_wait_time: nil, current_size: nil, date_created: nil, date_updated: nil, max_size: nil, sid: nil, subresource_uris: nil, uri: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/texml/accounts/queue_create_response.rb', line 63
|
Instance Attribute Details
#account_sid ⇒ String?
The id of the account the resource belongs to.
13 |
# File 'lib/telnyx/models/texml/accounts/queue_create_response.rb', line 13 optional :account_sid, String |
#average_wait_time ⇒ Integer?
The average wait time in seconds for members in the queue.
19 |
# File 'lib/telnyx/models/texml/accounts/queue_create_response.rb', line 19 optional :average_wait_time, Integer |
#current_size ⇒ Integer?
The current number of members in the queue.
25 |
# File 'lib/telnyx/models/texml/accounts/queue_create_response.rb', line 25 optional :current_size, Integer |
#date_created ⇒ String?
The timestamp of when the resource was created.
31 |
# File 'lib/telnyx/models/texml/accounts/queue_create_response.rb', line 31 optional :date_created, String |
#date_updated ⇒ String?
The timestamp of when the resource was last updated.
37 |
# File 'lib/telnyx/models/texml/accounts/queue_create_response.rb', line 37 optional :date_updated, String |
#max_size ⇒ Integer?
The maximum size of the queue.
43 |
# File 'lib/telnyx/models/texml/accounts/queue_create_response.rb', line 43 optional :max_size, Integer |
#sid ⇒ String?
The unique identifier of the queue.
49 |
# File 'lib/telnyx/models/texml/accounts/queue_create_response.rb', line 49 optional :sid, String |
#subresource_uris ⇒ Hash{Symbol=>Object}?
A list of related resources identified by their relative URIs.
55 |
# File 'lib/telnyx/models/texml/accounts/queue_create_response.rb', line 55 optional :subresource_uris, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#uri ⇒ String?
The relative URI for this queue.
61 |
# File 'lib/telnyx/models/texml/accounts/queue_create_response.rb', line 61 optional :uri, String |