Class: Telnyx::Models::Texml::Accounts::UpdateCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/update_call.rb

Direct Known Subclasses

CallUpdateParams

Defined Under Namespace

Modules: FallbackMethod, Method, StatusCallbackMethod

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(fallback_method: nil, fallback_url: nil, http_method: nil, status: nil, status_callback: nil, status_callback_method: nil, texml: nil, url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::UpdateCall for more details.

Parameters:

  • fallback_method (Symbol, Telnyx::Models::Texml::Accounts::UpdateCall::FallbackMethod) (defaults to: nil)

    HTTP request type used for ‘FallbackUrl`.

  • fallback_url (String) (defaults to: nil)

    A failover URL for which Telnyx will retrieve the TeXML call instructions if the

  • http_method (Symbol, Telnyx::Models::Texml::Accounts::UpdateCall::Method) (defaults to: nil)

    HTTP request type used for ‘Url`.

  • status (String) (defaults to: nil)

    The value to set the call status to. Setting the status to completed ends the ca

  • status_callback (String) (defaults to: nil)

    URL destination for Telnyx to send status callback events to for the call.

  • status_callback_method (Symbol, Telnyx::Models::Texml::Accounts::UpdateCall::StatusCallbackMethod) (defaults to: nil)

    HTTP request type used for ‘StatusCallback`.

  • texml (String) (defaults to: nil)

    TeXML to replace the current one with.

  • url (String) (defaults to: nil)

    The URL where TeXML will make a request to retrieve a new set of TeXML instructi



# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 63

Instance Attribute Details

#fallback_methodSymbol, ...

HTTP request type used for ‘FallbackUrl`.



12
13
14
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 12

optional :fallback_method,
enum: -> { Telnyx::Texml::Accounts::UpdateCall::FallbackMethod },
api_name: :FallbackMethod

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the Url is not responding.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 21

optional :fallback_url, String, api_name: :FallbackUrl

#http_methodSymbol, ...

HTTP request type used for ‘Url`.



27
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 27

optional :http_method, enum: -> { Telnyx::Texml::Accounts::UpdateCall::Method }, api_name: :Method

#statusString?

The value to set the call status to. Setting the status to completed ends the call.

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 34

optional :status, String, api_name: :Status

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 40

optional :status_callback, String, api_name: :StatusCallback

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



46
47
48
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 46

optional :status_callback_method,
enum: -> { Telnyx::Texml::Accounts::UpdateCall::StatusCallbackMethod },
api_name: :StatusCallbackMethod

#texmlString?

TeXML to replace the current one with.

Returns:

  • (String, nil)


54
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 54

optional :texml, String, api_name: :Texml

#urlString?

The URL where TeXML will make a request to retrieve a new set of TeXML instructions to continue the call flow.

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 61

optional :url, String, api_name: :Url

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 92