Class: Telnyx::Models::TexmlApplication

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml_application.rb

Overview

Defined Under Namespace

Modules: StatusCallbackMethod, VoiceMethod Classes: Inbound, Outbound

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel_limit: nil, outbound_voice_profile_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Outbound for more details.

Parameters:

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the total number of outbound calls to phone numbers as

  • outbound_voice_profile_id (String) (defaults to: nil)

    Identifies the associated outbound voice profile.



# File 'lib/telnyx/models/texml_application.rb', line 126

Instance Attribute Details

#activeBoolean?

Specifies whether the connection can be used.

Returns:

  • (Boolean, nil)


17
# File 'lib/telnyx/models/texml_application.rb', line 17

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



25
# File 'lib/telnyx/models/texml_application.rb', line 25

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#call_cost_in_webhooksBoolean?

Specifies if call cost webhooks should be sent for this TeXML Application.

Returns:

  • (Boolean, nil)


31
# File 'lib/telnyx/models/texml_application.rb', line 31

optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean

#created_atString?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/texml_application.rb', line 37

optional :created_at, String

#dtmf_typeSymbol, ...

Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.

Returns:



44
# File 'lib/telnyx/models/texml_application.rb', line 44

optional :dtmf_type, enum: -> { Telnyx::DtmfType }

#first_command_timeoutBoolean?

Specifies whether calls to phone numbers associated with this connection should hangup after timing out.

Returns:

  • (Boolean, nil)


51
# File 'lib/telnyx/models/texml_application.rb', line 51

optional :first_command_timeout, Telnyx::Internal::Type::Boolean

#first_command_timeout_secsInteger?

Specifies how many seconds to wait before timing out a dial command.

Returns:

  • (Integer, nil)


57
# File 'lib/telnyx/models/texml_application.rb', line 57

optional :first_command_timeout_secs, Integer

#friendly_nameString?

A user-assigned name to help manage the application.

Returns:

  • (String, nil)


63
# File 'lib/telnyx/models/texml_application.rb', line 63

optional :friendly_name, String

#idString?

Uniquely identifies the resource.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/texml_application.rb', line 11

optional :id, String

#inboundTelnyx::Models::TexmlApplication::Inbound?



68
# File 'lib/telnyx/models/texml_application.rb', line 68

optional :inbound, -> { Telnyx::TexmlApplication::Inbound }

#outboundTelnyx::Models::TexmlApplication::Outbound?



73
# File 'lib/telnyx/models/texml_application.rb', line 73

optional :outbound, -> { Telnyx::TexmlApplication::Outbound }

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/texml_application.rb', line 79

optional :record_type, String

#status_callbackString?

URL for Telnyx to send requests to containing information about call progress events.

Returns:

  • (String, nil)


86
# File 'lib/telnyx/models/texml_application.rb', line 86

optional :status_callback, String

#status_callback_methodSymbol, ...

HTTP request method Telnyx should use when requesting the status_callback URL.



92
# File 'lib/telnyx/models/texml_application.rb', line 92

optional :status_callback_method, enum: -> { Telnyx::TexmlApplication::StatusCallbackMethod }

#tagsArray<String>?

Tags associated with the Texml Application.

Returns:

  • (Array<String>, nil)


98
# File 'lib/telnyx/models/texml_application.rb', line 98

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#updated_atString?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (String, nil)


104
# File 'lib/telnyx/models/texml_application.rb', line 104

optional :updated_at, String

#voice_fallback_urlString?

URL to which Telnyx will deliver your XML Translator webhooks if we get an error response from your voice_url.

Returns:

  • (String, nil)


111
# File 'lib/telnyx/models/texml_application.rb', line 111

optional :voice_fallback_url, String

#voice_methodSymbol, ...

HTTP request method Telnyx will use to interact with your XML Translator webhooks. Either ‘get’ or ‘post’.



118
# File 'lib/telnyx/models/texml_application.rb', line 118

optional :voice_method, enum: -> { Telnyx::TexmlApplication::VoiceMethod }

#voice_urlString?

URL to which Telnyx will deliver your XML Translator webhooks.

Returns:

  • (String, nil)


124
# File 'lib/telnyx/models/texml_application.rb', line 124

optional :voice_url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml_application.rb', line 227