Class: Telnyx::Models::TexmlApplicationCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml_application_create_params.rb

Overview

Defined Under Namespace

Modules: StatusCallbackMethod, VoiceMethod Classes: Inbound, Outbound

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel_limit: nil, outbound_voice_profile_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Outbound for more details.

Parameters:

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the total number of outbound calls to phone numbers as

  • outbound_voice_profile_id (String) (defaults to: nil)

    Identifies the associated outbound voice profile.



# File 'lib/telnyx/models/texml_application_create_params.rb', line 218

Instance Attribute Details

#activeBoolean?

Specifies whether the connection can be used.

Returns:

  • (Boolean, nil)


26
# File 'lib/telnyx/models/texml_application_create_params.rb', line 26

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



34
# File 'lib/telnyx/models/texml_application_create_params.rb', line 34

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#call_cost_in_webhooksBoolean?

Specifies if call cost webhooks should be sent for this TeXML Application.

Returns:

  • (Boolean, nil)


40
# File 'lib/telnyx/models/texml_application_create_params.rb', line 40

optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean

#dtmf_typeSymbol, ...

Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.

Returns:



47
# File 'lib/telnyx/models/texml_application_create_params.rb', line 47

optional :dtmf_type, enum: -> { Telnyx::DtmfType }

#first_command_timeoutBoolean?

Specifies whether calls to phone numbers associated with this connection should hangup after timing out.

Returns:

  • (Boolean, nil)


54
# File 'lib/telnyx/models/texml_application_create_params.rb', line 54

optional :first_command_timeout, Telnyx::Internal::Type::Boolean

#first_command_timeout_secsInteger?

Specifies how many seconds to wait before timing out a dial command.

Returns:

  • (Integer, nil)


60
# File 'lib/telnyx/models/texml_application_create_params.rb', line 60

optional :first_command_timeout_secs, Integer

#friendly_nameString

A user-assigned name to help manage the application.

Returns:

  • (String)


14
# File 'lib/telnyx/models/texml_application_create_params.rb', line 14

required :friendly_name, String

#inboundTelnyx::Models::TexmlApplicationCreateParams::Inbound?



65
# File 'lib/telnyx/models/texml_application_create_params.rb', line 65

optional :inbound, -> { Telnyx::TexmlApplicationCreateParams::Inbound }

#outboundTelnyx::Models::TexmlApplicationCreateParams::Outbound?



70
# File 'lib/telnyx/models/texml_application_create_params.rb', line 70

optional :outbound, -> { Telnyx::TexmlApplicationCreateParams::Outbound }

#status_callbackString?

URL for Telnyx to send requests to containing information about call progress events.

Returns:

  • (String, nil)


77
# File 'lib/telnyx/models/texml_application_create_params.rb', line 77

optional :status_callback, String

#status_callback_methodSymbol, ...

HTTP request method Telnyx should use when requesting the status_callback URL.



83
# File 'lib/telnyx/models/texml_application_create_params.rb', line 83

optional :status_callback_method, enum: -> { Telnyx::TexmlApplicationCreateParams::StatusCallbackMethod }

#tagsArray<String>?

Tags associated with the Texml Application.

Returns:

  • (Array<String>, nil)


89
# File 'lib/telnyx/models/texml_application_create_params.rb', line 89

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#voice_fallback_urlString?

URL to which Telnyx will deliver your XML Translator webhooks if we get an error response from your voice_url.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/texml_application_create_params.rb', line 96

optional :voice_fallback_url, String

#voice_methodSymbol, ...

HTTP request method Telnyx will use to interact with your XML Translator webhooks. Either ‘get’ or ‘post’.



103
# File 'lib/telnyx/models/texml_application_create_params.rb', line 103

optional :voice_method, enum: -> { Telnyx::TexmlApplicationCreateParams::VoiceMethod }

#voice_urlString

URL to which Telnyx will deliver your XML Translator webhooks.

Returns:

  • (String)


20
# File 'lib/telnyx/models/texml_application_create_params.rb', line 20

required :voice_url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml_application_create_params.rb', line 199