Class: Telnyx::Models::TexmlApplicationCreateParams::Inbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml_application_create_params.rb

Defined Under Namespace

Modules: SipSubdomainReceiveSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel_limit: nil, shaken_stir_enabled: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::TexmlApplicationCreateParams::Inbound for more details.

Parameters:

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the total number of inbound calls to phone numbers ass

  • shaken_stir_enabled (Boolean) (defaults to: nil)

    When enabled Telnyx will include Shaken/Stir data in the Webhook for new inbound

  • sip_subdomain (String) (defaults to: nil)

    Specifies a subdomain that can be used to receive Inbound calls to a Connection,

  • sip_subdomain_receive_settings (Symbol, Telnyx::Models::TexmlApplicationCreateParams::Inbound::SipSubdomainReceiveSettings) (defaults to: nil)

    This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/telnyx/models/texml_application_create_params.rb', line 141

class Inbound < Telnyx::Internal::Type::BaseModel
  # @!attribute channel_limit
  #   When set, this will limit the total number of inbound calls to phone numbers
  #   associated with this connection.
  #
  #   @return [Integer, nil]
  optional :channel_limit, Integer

  # @!attribute shaken_stir_enabled
  #   When enabled Telnyx will include Shaken/Stir data in the Webhook for new inbound
  #   calls.
  #
  #   @return [Boolean, nil]
  optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean

  # @!attribute sip_subdomain
  #   Specifies a subdomain that can be used to receive Inbound calls to a Connection,
  #   in the same way a phone number is used, from a SIP endpoint. Example: the
  #   subdomain "example.sip.telnyx.com" can be called from any SIP endpoint by using
  #   the SIP URI "sip:@example.sip.telnyx.com" where the user part can be any
  #   alphanumeric value. Please note TLS encrypted calls are not allowed for
  #   subdomain calls.
  #
  #   @return [String, nil]
  optional :sip_subdomain, String

  # @!attribute sip_subdomain_receive_settings
  #   This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in
  #   the public Internet) or "Only my connections" (any connection assigned to the
  #   same Telnyx user).
  #
  #   @return [Symbol, Telnyx::Models::TexmlApplicationCreateParams::Inbound::SipSubdomainReceiveSettings, nil]
  optional :sip_subdomain_receive_settings,
           enum: -> { Telnyx::TexmlApplicationCreateParams::Inbound::SipSubdomainReceiveSettings }

  # @!method initialize(channel_limit: nil, shaken_stir_enabled: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::TexmlApplicationCreateParams::Inbound} for more details.
  #
  #   @param channel_limit [Integer] When set, this will limit the total number of inbound calls to phone numbers ass
  #
  #   @param shaken_stir_enabled [Boolean] When enabled Telnyx will include Shaken/Stir data in the Webhook for new inbound
  #
  #   @param sip_subdomain [String] Specifies a subdomain that can be used to receive Inbound calls to a Connection,
  #
  #   @param sip_subdomain_receive_settings [Symbol, Telnyx::Models::TexmlApplicationCreateParams::Inbound::SipSubdomainReceiveSettings] This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in

  # This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in
  # the public Internet) or "Only my connections" (any connection assigned to the
  # same Telnyx user).
  #
  # @see Telnyx::Models::TexmlApplicationCreateParams::Inbound#sip_subdomain_receive_settings
  module SipSubdomainReceiveSettings
    extend Telnyx::Internal::Type::Enum

    ONLY_MY_CONNECTIONS = :only_my_connections
    FROM_ANYONE = :from_anyone

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#channel_limitInteger?

When set, this will limit the total number of inbound calls to phone numbers associated with this connection.

Returns:

  • (Integer, nil)


147
# File 'lib/telnyx/models/texml_application_create_params.rb', line 147

optional :channel_limit, Integer

#shaken_stir_enabledBoolean?

When enabled Telnyx will include Shaken/Stir data in the Webhook for new inbound calls.

Returns:

  • (Boolean, nil)


154
# File 'lib/telnyx/models/texml_application_create_params.rb', line 154

optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean

#sip_subdomainString?

Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint. Example: the subdomain “example.sip.telnyx.com” can be called from any SIP endpoint by using the SIP URI “sip:@example.sip.telnyx.com” where the user part can be any alphanumeric value. Please note TLS encrypted calls are not allowed for subdomain calls.

Returns:

  • (String, nil)


165
# File 'lib/telnyx/models/texml_application_create_params.rb', line 165

optional :sip_subdomain, String

#sip_subdomain_receive_settingsSymbol, ...

This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).



173
174
# File 'lib/telnyx/models/texml_application_create_params.rb', line 173

optional :sip_subdomain_receive_settings,
enum: -> { Telnyx::TexmlApplicationCreateParams::Inbound::SipSubdomainReceiveSettings }