Class: Telnyx::Models::TexmlApplicationListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml_application_list_params.rb

Overview

Defined Under Namespace

Modules: Sort Classes: Filter

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(friendly_name: nil, outbound_voice_profile_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Filter for more details.

Consolidated filter parameter (deepObject style). Originally: filter, filter

Parameters:

  • friendly_name (String) (defaults to: nil)

    If present, applications with friendly_name containing the given va

  • outbound_voice_profile_id (String) (defaults to: nil)

    Identifies the associated outbound voice profile.



# File 'lib/telnyx/models/texml_application_list_params.rb', line 75

Instance Attribute Details

#filterTelnyx::Models::TexmlApplicationListParams::Filter?

Consolidated filter parameter (deepObject style). Originally: filter, filter



15
# File 'lib/telnyx/models/texml_application_list_params.rb', line 15

optional :filter, -> { Telnyx::TexmlApplicationListParams::Filter }

#page_numberInteger?

Returns:

  • (Integer, nil)


20
# File 'lib/telnyx/models/texml_application_list_params.rb', line 20

optional :page_number, Integer

#page_sizeInteger?

Returns:

  • (Integer, nil)


25
# File 'lib/telnyx/models/texml_application_list_params.rb', line 25

optional :page_size, Integer

#sortSymbol, ...

Specifies the sort order for results. By default sorting direction is ascending. To have the results sorted in descending order add the - prefix.<br/><br/> That is: <ul>

<li>
  <code>friendly_name</code>: sorts the result by the
  <code>friendly_name</code> field in ascending order.
</li>

<li>
  <code>-friendly_name</code>: sorts the result by the
  <code>friendly_name</code> field in descending order.
</li>

</ul> <br/> If not given, results are sorted by created_at in descending order.



44
# File 'lib/telnyx/models/texml_application_list_params.rb', line 44

optional :sort, enum: -> { Telnyx::TexmlApplicationListParams::Sort }