Class: Telnyx::Models::TexmlApplicationUpdateParams::Inbound
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::TexmlApplicationUpdateParams::Inbound
- Defined in:
- lib/telnyx/models/texml_application_update_params.rb
Defined Under Namespace
Modules: SipSubdomainReceiveSettings
Instance Attribute Summary collapse
-
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
-
#shaken_stir_enabled ⇒ Boolean?
When enabled Telnyx will include Shaken/Stir data in the Webhook for new inbound calls.
-
#sip_subdomain ⇒ String?
Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint.
-
#sip_subdomain_receive_settings ⇒ Symbol, ...
This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).
Instance Method Summary collapse
-
#initialize(channel_limit: nil, shaken_stir_enabled: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Inbound for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channel_limit: nil, shaken_stir_enabled: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::TexmlApplicationUpdateParams::Inbound for more details.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/telnyx/models/texml_application_update_params.rb', line 148 class Inbound < Telnyx::Internal::Type::BaseModel # @!attribute channel_limit # When set, this will limit the total number of inbound calls to phone numbers # associated with this connection. # # @return [Integer, nil] optional :channel_limit, Integer # @!attribute shaken_stir_enabled # When enabled Telnyx will include Shaken/Stir data in the Webhook for new inbound # calls. # # @return [Boolean, nil] optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean # @!attribute sip_subdomain # Specifies a subdomain that can be used to receive Inbound calls to a Connection, # in the same way a phone number is used, from a SIP endpoint. Example: the # subdomain "example.sip.telnyx.com" can be called from any SIP endpoint by using # the SIP URI "sip:@example.sip.telnyx.com" where the user part can be any # alphanumeric value. Please note TLS encrypted calls are not allowed for # subdomain calls. # # @return [String, nil] optional :sip_subdomain, String # @!attribute sip_subdomain_receive_settings # This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in # the public Internet) or "Only my connections" (any connection assigned to the # same Telnyx user). # # @return [Symbol, Telnyx::Models::TexmlApplicationUpdateParams::Inbound::SipSubdomainReceiveSettings, nil] optional :sip_subdomain_receive_settings, enum: -> { Telnyx::TexmlApplicationUpdateParams::Inbound::SipSubdomainReceiveSettings } # @!method initialize(channel_limit: nil, shaken_stir_enabled: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::TexmlApplicationUpdateParams::Inbound} for more details. # # @param channel_limit [Integer] When set, this will limit the total number of inbound calls to phone numbers ass # # @param shaken_stir_enabled [Boolean] When enabled Telnyx will include Shaken/Stir data in the Webhook for new inbound # # @param sip_subdomain [String] Specifies a subdomain that can be used to receive Inbound calls to a Connection, # # @param sip_subdomain_receive_settings [Symbol, Telnyx::Models::TexmlApplicationUpdateParams::Inbound::SipSubdomainReceiveSettings] This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in # This option can be enabled to receive calls from: "Anyone" (any SIP endpoint in # the public Internet) or "Only my connections" (any connection assigned to the # same Telnyx user). # # @see Telnyx::Models::TexmlApplicationUpdateParams::Inbound#sip_subdomain_receive_settings module SipSubdomainReceiveSettings extend Telnyx::Internal::Type::Enum ONLY_MY_CONNECTIONS = :only_my_connections FROM_ANYONE = :from_anyone # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
154 |
# File 'lib/telnyx/models/texml_application_update_params.rb', line 154 optional :channel_limit, Integer |
#shaken_stir_enabled ⇒ Boolean?
When enabled Telnyx will include Shaken/Stir data in the Webhook for new inbound calls.
161 |
# File 'lib/telnyx/models/texml_application_update_params.rb', line 161 optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean |
#sip_subdomain ⇒ String?
Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint. Example: the subdomain “example.sip.telnyx.com” can be called from any SIP endpoint by using the SIP URI “sip:@example.sip.telnyx.com” where the user part can be any alphanumeric value. Please note TLS encrypted calls are not allowed for subdomain calls.
172 |
# File 'lib/telnyx/models/texml_application_update_params.rb', line 172 optional :sip_subdomain, String |
#sip_subdomain_receive_settings ⇒ Symbol, ...
This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).
180 181 |
# File 'lib/telnyx/models/texml_application_update_params.rb', line 180 optional :sip_subdomain_receive_settings, enum: -> { Telnyx::TexmlApplicationUpdateParams::Inbound::SipSubdomainReceiveSettings } |