Class: Telnyx::Models::TexmlInitiateAICallParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml_initiate_ai_call_params.rb

Overview

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, ConversationCallbackMethod, DetectionMode, MachineDetection, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackMethod, Trim Classes: CustomHeader

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 301

Instance Attribute Details

#ai_assistant_dynamic_variablesHash{Symbol=>String}?

Key-value map of dynamic variables to pass to the AI assistant.

Returns:

  • (Hash{Symbol=>String}, nil)


39
40
41
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 39

optional :ai_assistant_dynamic_variables,
Telnyx::Internal::Type::HashOf[String],
api_name: :AIAssistantDynamicVariables

#ai_assistant_idString

The ID of the AI assistant to use for the call.

Returns:

  • (String)


19
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 19

required :ai_assistant_id, String, api_name: :AIAssistantId

#ai_assistant_versionString?

The version of the AI assistant to use.

Returns:

  • (String, nil)


47
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 47

optional :ai_assistant_version, String, api_name: :AIAssistantVersion

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Returns:

  • (Boolean, nil)


54
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 54

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Returns:

  • (String, nil)


60
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 60

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for ‘AsyncAmdStatusCallback`.



66
67
68
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 66

optional :async_amd_status_callback_method,
enum: -> { Telnyx::TexmlInitiateAICallParams::AsyncAmdStatusCallbackMethod },
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If omitted, the display name will be the same as the number in the `From` field.

Returns:

  • (String, nil)


77
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 77

optional :caller_id, String, api_name: :CallerId

#connection_idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 13

required :connection_id, String

#conversation_callbackString?

URL destination for Telnyx to send AI conversation callback events for this call. Events include ‘conversation_created` and `conversation_ended`.

Returns:

  • (String, nil)


84
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 84

optional :conversation_callback, String, api_name: :ConversationCallback

#conversation_callback_methodSymbol, ...

HTTP request type used for ‘ConversationCallback` and `ConversationCallbacks`.



90
91
92
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 90

optional :conversation_callback_method,
enum: -> { Telnyx::TexmlInitiateAICallParams::ConversationCallbackMethod },
api_name: :ConversationCallbackMethod

#conversation_callbacksArray<String>?

Array of URL destinations for AI conversation callback events for this call. Events include ‘conversation_created` and `conversation_ended`.

Returns:

  • (Array<String>, nil)


99
100
101
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 99

optional :conversation_callbacks,
Telnyx::Internal::Type::ArrayOf[String],
api_name: :ConversationCallbacks

#custom_headersArray<Telnyx::Models::TexmlInitiateAICallParams::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.



108
109
110
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 108

optional :custom_headers,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::TexmlInitiateAICallParams::CustomHeader] },
api_name: :CustomHeaders

#detection_modeSymbol, ...

Allows you to choose between Premium and Standard detections.



116
117
118
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 116

optional :detection_mode,
enum: -> { Telnyx::TexmlInitiateAICallParams::DetectionMode },
api_name: :DetectionMode

#fromString

The phone number of the party initiating the call. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String)


26
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 26

required :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



124
125
126
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 124

optional :machine_detection,
enum: -> { Telnyx::TexmlInitiateAICallParams::MachineDetection },
api_name: :MachineDetection

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


133
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 133

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


140
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 140

optional :machine_detection_speech_end_threshold, Integer, api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


147
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 147

optional :machine_detection_speech_threshold, Integer, api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Returns:

  • (Integer, nil)


153
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 153

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#passportsString?

A string of passport identifiers to associate with the call.

Returns:

  • (String, nil)


159
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 159

optional :passports, String, api_name: :Passports

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Returns:

  • (String, nil)


165
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 165

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant’s call leg. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


171
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 171

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to ‘mono`.



177
178
179
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 177

optional :recording_channels,
enum: -> { Telnyx::TexmlInitiateAICallParams::RecordingChannels },
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Returns:

  • (String, nil)


185
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 185

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording’s state that should generate a call to ‘RecordingStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.

Returns:

  • (String, nil)


193
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 193

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.



199
200
201
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 199

optional :recording_status_callback_method,
enum: -> { Telnyx::TexmlInitiateAICallParams::RecordingStatusCallbackMethod },
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. The minimum value is 0. The default value is 0 (infinite).

Returns:

  • (Integer, nil)


209
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 209

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



215
216
217
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 215

optional :recording_track,
enum: -> { Telnyx::TexmlInitiateAICallParams::RecordingTrack },
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Returns:

  • (Boolean, nil)


223
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 223

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Returns:

  • (String, nil)


229
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 229

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Returns:

  • (String, nil)


235
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 235

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



241
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 241

optional :sip_region, enum: -> { Telnyx::TexmlInitiateAICallParams::SipRegion }, api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events for this AI call. When provided, this per-call value overrides the status callback URL configured on the TeXML application/connection.

Returns:

  • (String, nil)


249
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 249

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventString?

The status callback events for which Telnyx should send a webhook for this AI call. Multiple events can be defined when separated by a space. Valid values: initiated, ringing, answered, completed, no-answer, busy, canceled, failed, analyzed. When provided, this per-call value overrides the status callback events configured on the TeXML application/connection.

Returns:

  • (String, nil)


259
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 259

optional :status_callback_event, String, api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback` and `StatusCallbacks` for this AI call. When provided, this per-call value overrides the status callback method configured on the TeXML application/connection.



267
268
269
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 267

optional :status_callback_method,
enum: -> { Telnyx::TexmlInitiateAICallParams::StatusCallbackMethod },
api_name: :StatusCallbackMethod

#status_callbacksArray<String>?

Array of URL destinations for Telnyx to send status callback events for this AI call. When provided, these per-call values override the status callback URL configured on the TeXML application/connection.

Returns:

  • (Array<String>, nil)


277
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 277

optional :status_callbacks, Telnyx::Internal::Type::ArrayOf[String], api_name: :StatusCallbacks

#time_limitInteger?

The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.

Returns:

  • (Integer, nil)


284
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 284

optional :time_limit, Integer, api_name: :TimeLimit

#timeout_secondsInteger?

The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.

Returns:

  • (Integer, nil)


292
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 292

optional :timeout_seconds, Integer, api_name: :Timeout

#toString

The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String)


33
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 33

required :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.



299
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 299

optional :trim, enum: -> { Telnyx::TexmlInitiateAICallParams::Trim }, api_name: :Trim

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 394