Class: Telnyx::Models::TexmlSecretsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::TexmlSecretsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/texml_secrets_params.rb
Overview
Instance Attribute Summary collapse
-
#name ⇒ String
Name used as a reference for the secret, if the name already exists within the account its value will be replaced.
-
#value ⇒ String
Secret value which will be used when rendering the TeXML template.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(name:, value:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TexmlSecretsParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, value:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::TexmlSecretsParams for more details.
|
|
# File 'lib/telnyx/models/texml_secrets_params.rb', line 23
|
Instance Attribute Details
#name ⇒ String
Name used as a reference for the secret, if the name already exists within the account its value will be replaced
15 |
# File 'lib/telnyx/models/texml_secrets_params.rb', line 15 required :name, String |
#value ⇒ String
Secret value which will be used when rendering the TeXML template
21 |
# File 'lib/telnyx/models/texml_secrets_params.rb', line 21 required :value, String |