Class: Telnyx::Models::TextToSpeechGenerateParams::Azure

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/text_to_speech_generate_params.rb

Defined Under Namespace

Modules: TextType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_key: nil, deployment_id: nil, effect: nil, gender: nil, language_code: nil, output_format: nil, region: nil, text_type: nil) ⇒ Object

Azure Cognitive Services provider-specific parameters.

Parameters:

  • api_key (String) (defaults to: nil)

    Custom Azure API key. If not provided, the default Telnyx key is used.

  • deployment_id (String) (defaults to: nil)

    Custom Azure deployment ID.

  • effect (String) (defaults to: nil)

    Azure audio effect to apply.

  • gender (String) (defaults to: nil)

    Voice gender preference.

  • language_code (String) (defaults to: nil)

    Language code (e.g. ‘en-US`).

  • output_format (String) (defaults to: nil)

    Azure audio output format.

  • region (String) (defaults to: nil)

    Azure region (e.g. ‘eastus`, `westeurope`).

  • text_type (Symbol, ::Telnyx::Models::TextToSpeechGenerateParams::Azure::TextType) (defaults to: nil)

    Input text type. Use ‘ssml` for SSML-formatted input.



# File 'lib/telnyx/models/text_to_speech_generate_params.rb', line 252

Instance Attribute Details

#api_keyString?

Custom Azure API key. If not provided, the default Telnyx key is used.

Returns:

  • (String, nil)


208
# File 'lib/telnyx/models/text_to_speech_generate_params.rb', line 208

optional :api_key, String

#deployment_idString?

Custom Azure deployment ID.

Returns:

  • (String, nil)


214
# File 'lib/telnyx/models/text_to_speech_generate_params.rb', line 214

optional :deployment_id, String

#effectString?

Azure audio effect to apply.

Returns:

  • (String, nil)


220
# File 'lib/telnyx/models/text_to_speech_generate_params.rb', line 220

optional :effect, String

#genderString?

Voice gender preference.

Returns:

  • (String, nil)


226
# File 'lib/telnyx/models/text_to_speech_generate_params.rb', line 226

optional :gender, String

#language_codeString?

Language code (e.g. ‘en-US`).

Returns:

  • (String, nil)


232
# File 'lib/telnyx/models/text_to_speech_generate_params.rb', line 232

optional :language_code, String

#output_formatString?

Azure audio output format.

Returns:

  • (String, nil)


238
# File 'lib/telnyx/models/text_to_speech_generate_params.rb', line 238

optional :output_format, String

#regionString?

Azure region (e.g. ‘eastus`, `westeurope`).

Returns:

  • (String, nil)


244
# File 'lib/telnyx/models/text_to_speech_generate_params.rb', line 244

optional :region, String

#text_typeSymbol, ...

Input text type. Use ‘ssml` for SSML-formatted input.



250
# File 'lib/telnyx/models/text_to_speech_generate_params.rb', line 250

optional :text_type, enum: -> { ::Telnyx::TextToSpeechGenerateParams::Azure::TextType }