Class: Telnyx::Models::TextToSpeechListVoicesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::TextToSpeechListVoicesParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/text_to_speech_list_voices_params.rb
Overview
Defined Under Namespace
Modules: Provider
Instance Attribute Summary collapse
-
#api_key ⇒ String?
API key for providers that require one to list voices (e.g. ElevenLabs).
-
#provider ⇒ Symbol, ...
Filter voices by provider.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(api_key: nil, provider: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/text_to_speech_list_voices_params.rb', line 22
|
Instance Attribute Details
#api_key ⇒ String?
API key for providers that require one to list voices (e.g. ElevenLabs).
14 |
# File 'lib/telnyx/models/text_to_speech_list_voices_params.rb', line 14 optional :api_key, String |
#provider ⇒ Symbol, ...
Filter voices by provider. If omitted, voices from all providers are returned.
20 |
# File 'lib/telnyx/models/text_to_speech_list_voices_params.rb', line 20 optional :provider, enum: -> { Telnyx::TextToSpeechListVoicesParams::Provider } |