Module: Telnyx::Models::TranscribeServerEvent
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/transcribe_server_event.rb,
sig/telnyx/models/transcribe_server_event.rbs
Overview
Union of all server-to-client WebSocket events for STT streaming.
Defined Under Namespace
Classes: Error, Transcript
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(transcript:, confidence: nil, is_final: nil, type: :transcript) ⇒ Object
Some parameter documentations has been truncated, see Transcript for more details.
- #self?.variants ⇒ ::Array[Telnyx::Models::transcribe_server_event]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Telnyx::Models::TranscribeServerEvent::Transcript, Telnyx::Models::TranscribeServerEvent::Error)
|
|
# File 'lib/telnyx/models/transcribe_server_event.rb', line 80
|
Instance Method Details
#initialize(transcript:, confidence: nil, is_final: nil, type: :transcript) ⇒ Object
Some parameter documentations has been truncated, see Transcript for more details.
Server-to-client frame containing a transcription result.
|
|
# File 'lib/telnyx/models/transcribe_server_event.rb', line 43
|
#self?.variants ⇒ ::Array[Telnyx::Models::transcribe_server_event]
58 |
# File 'sig/telnyx/models/transcribe_server_event.rbs', line 58
def self?.variants: -> ::Array[Telnyx::Models::transcribe_server_event]
|