Class: Telnyx::Models::TranscriptCompletedWebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::TranscriptCompletedWebhookEvent::Data
- Defined in:
- lib/telnyx/models/transcript_completed_webhook_event.rb,
sig/telnyx/models/transcript_completed_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#ended_at ⇒ Time?
Session end time, or null when unavailable.
-
#last_seq ⇒ Integer?
Last transcript segment sequence number, or null for an empty transcript.
-
#segment_count ⇒ Integer
Number of transcript segments observed during finalization.
-
#session_id ⇒ String
The meeting session this event belongs to.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
56 |
# File 'sig/telnyx/models/transcript_completed_webhook_event.rbs', line 56
def initialize: (
|
Instance Attribute Details
#ended_at ⇒ Time?
Session end time, or null when unavailable.
53 |
# File 'lib/telnyx/models/transcript_completed_webhook_event.rb', line 53 required :ended_at, Time, nil?: true |
#last_seq ⇒ Integer?
Last transcript segment sequence number, or null for an empty transcript.
59 |
# File 'lib/telnyx/models/transcript_completed_webhook_event.rb', line 59 required :last_seq, Integer, nil?: true |
#segment_count ⇒ Integer
Number of transcript segments observed during finalization.
65 |
# File 'lib/telnyx/models/transcript_completed_webhook_event.rb', line 65 required :segment_count, Integer |
#session_id ⇒ String
The meeting session this event belongs to.
71 |
# File 'lib/telnyx/models/transcript_completed_webhook_event.rb', line 71 required :session_id, String |
Instance Method Details
#to_hash ⇒ {
63 |
# File 'sig/telnyx/models/transcript_completed_webhook_event.rbs', line 63
def to_hash: -> {
|