Class: Telnyx::Models::TranscriptionWebhookEvent::Data::Payload::TranscriptionData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/transcription_webhook_event.rb

Overview

Defined Under Namespace

Modules: TranscriptionTrack

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(confidence: nil, is_final: nil, transcript: nil, transcription_track: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::TranscriptionWebhookEvent::Data::Payload::TranscriptionData for more details.

Parameters:



# File 'lib/telnyx/models/transcription_webhook_event.rb', line 152

Instance Attribute Details

#confidenceFloat?

Speech recognition confidence level.

Returns:

  • (Float, nil)


130
# File 'lib/telnyx/models/transcription_webhook_event.rb', line 130

optional :confidence, Float

#is_finalBoolean?

When false, it means that this is an interim result.

Returns:

  • (Boolean, nil)


136
# File 'lib/telnyx/models/transcription_webhook_event.rb', line 136

optional :is_final, Telnyx::Internal::Type::Boolean

#transcriptString?

Recognized text.

Returns:

  • (String, nil)


142
# File 'lib/telnyx/models/transcription_webhook_event.rb', line 142

optional :transcript, String

#transcription_trackSymbol, ...

Indicates which leg of the call has been transcribed. This is only available when ‘transcription_engine` is set to `B`.



149
150
# File 'lib/telnyx/models/transcription_webhook_event.rb', line 149

optional :transcription_track,
enum: -> { Telnyx::TranscriptionWebhookEvent::Data::Payload::TranscriptionData::TranscriptionTrack }