Class: Telnyx::Models::URLShortenerSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/url_shortener_settings.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(domain:, prefix: nil, replace_blacklist_only: nil, send_webhooks: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::URLShortenerSettings for more details.

The URL shortener feature allows automatic replacement of URLs that were generated using a public URL shortener service. Some examples include bit.do, bit.ly, goo.gl, ht.ly, is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com. Such URLs are replaced with with links generated by Telnyx. The use of custom links can improve branding and message deliverability.

To disable this feature, set the object field to ‘null`.

Parameters:

  • domain (String)

    One of the domains provided by the Telnyx URL shortener service.

  • prefix (String) (defaults to: nil)

    Optional prefix that can be used to identify your brand, and will appear in the

  • replace_blacklist_only (Boolean) (defaults to: nil)

    Use the link replacement tool only for links that are specifically blacklisted b

  • send_webhooks (Boolean) (defaults to: nil)

    Receive webhooks for when your replaced links are clicked. Webhooks are sent to



# File 'lib/telnyx/models/url_shortener_settings.rb', line 33

Instance Attribute Details

#domainString

One of the domains provided by the Telnyx URL shortener service.

Returns:

  • (String)


10
# File 'lib/telnyx/models/url_shortener_settings.rb', line 10

required :domain, String

#prefixString?

Optional prefix that can be used to identify your brand, and will appear in the Telnyx generated URLs after the domain name.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/url_shortener_settings.rb', line 17

optional :prefix, String

#replace_blacklist_onlyBoolean?

Use the link replacement tool only for links that are specifically blacklisted by Telnyx.

Returns:

  • (Boolean, nil)


24
# File 'lib/telnyx/models/url_shortener_settings.rb', line 24

optional :replace_blacklist_only, Telnyx::Internal::Type::Boolean

#send_webhooksBoolean?

Receive webhooks for when your replaced links are clicked. Webhooks are sent to the webhooks on the messaging profile.

Returns:

  • (Boolean, nil)


31
# File 'lib/telnyx/models/url_shortener_settings.rb', line 31

optional :send_webhooks, Telnyx::Internal::Type::Boolean