Class: Telnyx::Models::UacConnection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/uac_connection.rb

Overview

Defined Under Namespace

Modules: Authentication, FqdnOutboundAuthentication, NoiseSuppression, SipUriCallingPreference, WebhookAPIVersion

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, active: nil, anchorsite_override: nil, android_push_credential_id: nil, authentication: nil, call_cost_in_webhooks: nil, connection_name: nil, created_at: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, external_uac_settings: nil, fqdn: nil, fqdn_outbound_authentication: nil, fqdns: nil, inbound: nil, internal_uac_settings: nil, ios_push_credential_id: nil, jitter_buffer: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, password: nil, record_type: nil, registration_status: nil, registration_status_updated_at: nil, rtcp_settings: nil, sip_uri_calling_preference: nil, tags: nil, updated_at: nil, user_name: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::UacConnection for more details.

A UAC (User Agent Client) Connection registers Telnyx to your PBX — the opposite of a standard SIP trunk, where the PBX registers to Telnyx. Use UAC when your PBX doesn’t support outbound SIP registration or you need Telnyx to maintain the registration.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the type of resource.

  • active (Boolean) (defaults to: nil)

    Defaults to true

  • anchorsite_override (Symbol, Telnyx::Models::AnchorsiteOverride) (defaults to: nil)

    ‘Latency` directs Telnyx to route media through the site with the lowest round-t

  • android_push_credential_id (String, nil) (defaults to: nil)

    The uuid of the push credential for Android

  • authentication (Symbol, Telnyx::Models::UacConnection::Authentication) (defaults to: nil)

    The authentication strategy used by this connection.

  • call_cost_in_webhooks (Boolean) (defaults to: nil)

    Specifies if call cost webhooks should be sent for this connection.

  • connection_name (String) (defaults to: nil)
  • created_at (String) (defaults to: nil)

    ISO-8601 formatted date indicating when the resource was created.

  • default_on_hold_comfort_noise_enabled (Boolean) (defaults to: nil)

    When enabled, Telnyx will generate comfort noise when you place the call on hold

  • dtmf_type (Symbol, Telnyx::Models::DtmfType) (defaults to: nil)

    Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF

  • encode_contact_header_enabled (Boolean) (defaults to: nil)

    Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scen

  • encrypted_media (Symbol, Telnyx::Models::EncryptedMedia, nil) (defaults to: nil)

    Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TL

  • external_uac_settings (Telnyx::Models::UacExternalSettings) (defaults to: nil)

    External SIP peer settings used by Telnyx when registering to your PBX and routi

  • fqdn (String) (defaults to: nil)

    The Telnyx-managed FQDN generated for the UAC connection.

  • fqdn_outbound_authentication (Symbol, Telnyx::Models::UacConnection::FqdnOutboundAuthentication) (defaults to: nil)

    The fixed outbound authentication mode used by UAC FQDN records.

  • fqdns (Array<Telnyx::Models::Fqdn>) (defaults to: nil)

    FQDN records managed automatically by the UAC connection lifecycle.

  • inbound (Telnyx::Models::UacInbound) (defaults to: nil)
  • internal_uac_settings (Telnyx::Models::UacInternalSettings) (defaults to: nil)

    Internal Telnyx-side settings for a UAC connection.

  • ios_push_credential_id (String, nil) (defaults to: nil)

    The uuid of the push credential for Ios

  • jitter_buffer (Telnyx::Models::ConnectionJitterBuffer) (defaults to: nil)

    Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams o

  • noise_suppression (Symbol, Telnyx::Models::UacConnection::NoiseSuppression) (defaults to: nil)

    Controls when noise suppression is applied to calls. When set to ‘inbound’, nois

  • noise_suppression_details (Telnyx::Models::ConnectionNoiseSuppressionDetails) (defaults to: nil)

    Configuration options for noise suppression. These settings are stored regardles

  • onnet_t38_passthrough_enabled (Boolean) (defaults to: nil)

    Enable on-net T38 if you prefer the sender and receiver negotiating T38 directly

  • outbound (Telnyx::Models::UacOutbound) (defaults to: nil)
  • password (String) (defaults to: nil)

    The password to be used as part of the credentials. Must be 8 to 128 characters

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • registration_status (String, nil) (defaults to: nil)

    The most recently known SIP registration status for this UAC connection.

  • registration_status_updated_at (String, nil) (defaults to: nil)

    ISO 8601 formatted date indicating when the registration status was last updated

  • rtcp_settings (Telnyx::Models::ConnectionRtcpSettings) (defaults to: nil)
  • sip_uri_calling_preference (Symbol, Telnyx::Models::UacConnection::SipUriCallingPreference) (defaults to: nil)

    This feature enables inbound SIP URI calls to your Credential Auth Connection. I

  • tags (Array<String>) (defaults to: nil)

    Tags associated with the connection.

  • updated_at (String) (defaults to: nil)

    ISO-8601 formatted date indicating when the resource was updated.

  • user_name (String) (defaults to: nil)

    The user name to be used as part of the credentials. Must be 4-32 characters lon

  • webhook_api_version (Symbol, Telnyx::Models::UacConnection::WebhookAPIVersion) (defaults to: nil)

    Determines which webhook format will be used, Telnyx API v1 or v2.

  • webhook_event_failover_url (String, nil) (defaults to: nil)

    The failover URL where webhooks related to this connection will be sent if sendi

  • webhook_event_url (String) (defaults to: nil)

    The URL where webhooks related to this connection will be sent. Must include a s

  • webhook_timeout_secs (Integer, nil) (defaults to: nil)

    Specifies how many seconds to wait before timing out a webhook.



# File 'lib/telnyx/models/uac_connection.rb', line 255

Instance Attribute Details

#activeBoolean?

Defaults to true

Returns:

  • (Boolean, nil)


17
# File 'lib/telnyx/models/uac_connection.rb', line 17

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



25
# File 'lib/telnyx/models/uac_connection.rb', line 25

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#android_push_credential_idString?

The uuid of the push credential for Android

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/uac_connection.rb', line 31

optional :android_push_credential_id, String, nil?: true

#authenticationSymbol, ...

The authentication strategy used by this connection.



37
# File 'lib/telnyx/models/uac_connection.rb', line 37

optional :authentication, enum: -> { Telnyx::UacConnection::Authentication }

#call_cost_in_webhooksBoolean?

Specifies if call cost webhooks should be sent for this connection.

Returns:

  • (Boolean, nil)


43
# File 'lib/telnyx/models/uac_connection.rb', line 43

optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean

#connection_nameString?

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/uac_connection.rb', line 48

optional :connection_name, String

#created_atString?

ISO-8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


54
# File 'lib/telnyx/models/uac_connection.rb', line 54

optional :created_at, String

#default_on_hold_comfort_noise_enabledBoolean?

When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.

Returns:

  • (Boolean, nil)


62
# File 'lib/telnyx/models/uac_connection.rb', line 62

optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean

#dtmf_typeSymbol, ...

Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.

Returns:



69
# File 'lib/telnyx/models/uac_connection.rb', line 69

optional :dtmf_type, enum: -> { Telnyx::DtmfType }

#encode_contact_header_enabledBoolean?

Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.

Returns:

  • (Boolean, nil)


76
# File 'lib/telnyx/models/uac_connection.rb', line 76

optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean

#encrypted_mediaSymbol, ...

Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.

Returns:



83
# File 'lib/telnyx/models/uac_connection.rb', line 83

optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true

#external_uac_settingsTelnyx::Models::UacExternalSettings?

External SIP peer settings used by Telnyx when registering to your PBX and routing outbound calls.



90
# File 'lib/telnyx/models/uac_connection.rb', line 90

optional :external_uac_settings, -> { Telnyx::UacExternalSettings }

#fqdnString?

The Telnyx-managed FQDN generated for the UAC connection.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/uac_connection.rb', line 96

optional :fqdn, String

#fqdn_outbound_authenticationSymbol, ...

The fixed outbound authentication mode used by UAC FQDN records.



102
# File 'lib/telnyx/models/uac_connection.rb', line 102

optional :fqdn_outbound_authentication, enum: -> { Telnyx::UacConnection::FqdnOutboundAuthentication }

#fqdnsArray<Telnyx::Models::Fqdn>?

FQDN records managed automatically by the UAC connection lifecycle.

Returns:



108
# File 'lib/telnyx/models/uac_connection.rb', line 108

optional :fqdns, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Fqdn] }

#idString?

Identifies the type of resource.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/uac_connection.rb', line 11

optional :id, String

#inboundTelnyx::Models::UacInbound?

Returns:



113
# File 'lib/telnyx/models/uac_connection.rb', line 113

optional :inbound, -> { Telnyx::UacInbound }

#internal_uac_settingsTelnyx::Models::UacInternalSettings?

Internal Telnyx-side settings for a UAC connection.



119
# File 'lib/telnyx/models/uac_connection.rb', line 119

optional :internal_uac_settings, -> { Telnyx::UacInternalSettings }

#ios_push_credential_idString?

The uuid of the push credential for Ios

Returns:

  • (String, nil)


125
# File 'lib/telnyx/models/uac_connection.rb', line 125

optional :ios_push_credential_id, String, nil?: true

#jitter_bufferTelnyx::Models::ConnectionJitterBuffer?

Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.



135
# File 'lib/telnyx/models/uac_connection.rb', line 135

optional :jitter_buffer, -> { Telnyx::ConnectionJitterBuffer }

#noise_suppressionSymbol, ...

Controls when noise suppression is applied to calls. When set to ‘inbound’, noise suppression is applied to incoming audio. When set to ‘outbound’, it’s applied to outgoing audio. When set to ‘both’, it’s applied in both directions. When set to ‘disabled’, noise suppression is turned off.



144
# File 'lib/telnyx/models/uac_connection.rb', line 144

optional :noise_suppression, enum: -> { Telnyx::UacConnection::NoiseSuppression }

#noise_suppression_detailsTelnyx::Models::ConnectionNoiseSuppressionDetails?

Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not ‘disabled’. If you disable noise suppression and later re-enable it, the previously configured settings will be used.



153
# File 'lib/telnyx/models/uac_connection.rb', line 153

optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails }

#onnet_t38_passthrough_enabledBoolean?

Enable on-net T38 if you prefer the sender and receiver negotiating T38 directly if both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call depending on each leg’s settings.

Returns:

  • (Boolean, nil)


161
# File 'lib/telnyx/models/uac_connection.rb', line 161

optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean

#outboundTelnyx::Models::UacOutbound?

Returns:



166
# File 'lib/telnyx/models/uac_connection.rb', line 166

optional :outbound, -> { Telnyx::UacOutbound }

#passwordString?

The password to be used as part of the credentials. Must be 8 to 128 characters long.

Returns:

  • (String, nil)


173
# File 'lib/telnyx/models/uac_connection.rb', line 173

optional :password, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


179
# File 'lib/telnyx/models/uac_connection.rb', line 179

optional :record_type, String

#registration_statusString?

The most recently known SIP registration status for this UAC connection.

Returns:

  • (String, nil)


185
# File 'lib/telnyx/models/uac_connection.rb', line 185

optional :registration_status, String, nil?: true

#registration_status_updated_atString?

ISO 8601 formatted date indicating when the registration status was last updated.

Returns:

  • (String, nil)


192
# File 'lib/telnyx/models/uac_connection.rb', line 192

optional :registration_status_updated_at, String, nil?: true

#rtcp_settingsTelnyx::Models::ConnectionRtcpSettings?



197
# File 'lib/telnyx/models/uac_connection.rb', line 197

optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings }

#sip_uri_calling_preferenceSymbol, ...

This feature enables inbound SIP URI calls to your Credential Auth Connection. If enabled for all (unrestricted) then anyone who calls the SIP URI <your-username>@telnyx.com will be connected to your Connection. You can also choose to allow only calls that are originated on any Connections under your account (internal).



207
# File 'lib/telnyx/models/uac_connection.rb', line 207

optional :sip_uri_calling_preference, enum: -> { Telnyx::UacConnection::SipUriCallingPreference }

#tagsArray<String>?

Tags associated with the connection.

Returns:

  • (Array<String>, nil)


213
# File 'lib/telnyx/models/uac_connection.rb', line 213

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#updated_atString?

ISO-8601 formatted date indicating when the resource was updated.

Returns:

  • (String, nil)


219
# File 'lib/telnyx/models/uac_connection.rb', line 219

optional :updated_at, String

#user_nameString?

The user name to be used as part of the credentials. Must be 4-32 characters long and alphanumeric values only (no spaces or special characters). At least one of the first 5 characters must be a letter.

Returns:

  • (String, nil)


227
# File 'lib/telnyx/models/uac_connection.rb', line 227

optional :user_name, String

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1 or v2.



233
# File 'lib/telnyx/models/uac_connection.rb', line 233

optional :webhook_api_version, enum: -> { Telnyx::UacConnection::WebhookAPIVersion }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


240
# File 'lib/telnyx/models/uac_connection.rb', line 240

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


247
# File 'lib/telnyx/models/uac_connection.rb', line 247

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


253
# File 'lib/telnyx/models/uac_connection.rb', line 253

optional :webhook_timeout_secs, Integer, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/uac_connection.rb', line 346