Class: Telnyx::Models::UacConnectionCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/uac_connection_create_params.rb

Overview

Defined Under Namespace

Modules: NoiseSuppression, SipUriCallingPreference, WebhookAPIVersion Classes: ExternalUacSettings, Inbound, InternalUacSettings, Outbound

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(destination_uri: nil) ⇒ Object

Some parameter documentations has been truncated, see InternalUacSettings for more details.

Internal Telnyx-side settings for a UAC connection.

Parameters:

  • destination_uri (String) (defaults to: nil)

    The SIP URI that Telnyx will call when handling an inbound request from the exte



# File 'lib/telnyx/models/uac_connection_create_params.rb', line 555

Instance Attribute Details

#activeBoolean?

Defaults to true

Returns:

  • (Boolean, nil)


20
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 20

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



28
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 28

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#android_push_credential_idString?

The uuid of the push credential for Android

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 34

optional :android_push_credential_id, String, nil?: true

#call_cost_in_webhooksBoolean?

Specifies if call cost webhooks should be sent for this connection.

Returns:

  • (Boolean, nil)


40
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 40

optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean

#connection_nameString

A user-assigned name to help manage the connection.

Returns:

  • (String)


14
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 14

required :connection_name, String

#default_on_hold_comfort_noise_enabledBoolean?

When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.

Returns:

  • (Boolean, nil)


48
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 48

optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean

#dtmf_typeSymbol, ...

Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.

Returns:



55
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 55

optional :dtmf_type, enum: -> { Telnyx::DtmfType }

#encode_contact_header_enabledBoolean?

Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.

Returns:

  • (Boolean, nil)


62
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 62

optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean

#encrypted_mediaSymbol, ...

Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.

Returns:



69
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 69

optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true

#external_uac_settingsTelnyx::Models::UacConnectionCreateParams::ExternalUacSettings?

External SIP peer settings used by Telnyx when registering to your PBX and routing outbound calls.



76
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 76

optional :external_uac_settings, -> { Telnyx::UacConnectionCreateParams::ExternalUacSettings }

#inboundTelnyx::Models::UacConnectionCreateParams::Inbound?

Inbound settings that can be supplied when creating or updating a UAC connection. The SIP subdomain fields returned in UAC connection responses are generated by Telnyx and are not accepted as request parameters.



84
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 84

optional :inbound, -> { Telnyx::UacConnectionCreateParams::Inbound }

#internal_uac_settingsTelnyx::Models::UacConnectionCreateParams::InternalUacSettings?

Internal Telnyx-side settings for a UAC connection.



90
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 90

optional :internal_uac_settings, -> { Telnyx::UacConnectionCreateParams::InternalUacSettings }

#ios_push_credential_idString?

The uuid of the push credential for Ios

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 96

optional :ios_push_credential_id, String, nil?: true

#jitter_bufferTelnyx::Models::ConnectionJitterBuffer?

Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.



106
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 106

optional :jitter_buffer, -> { Telnyx::ConnectionJitterBuffer }

#noise_suppressionSymbol, ...

Controls when noise suppression is applied to calls. When set to ‘inbound’, noise suppression is applied to incoming audio. When set to ‘outbound’, it’s applied to outgoing audio. When set to ‘both’, it’s applied in both directions. When set to ‘disabled’, noise suppression is turned off.



115
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 115

optional :noise_suppression, enum: -> { Telnyx::UacConnectionCreateParams::NoiseSuppression }

#noise_suppression_detailsTelnyx::Models::ConnectionNoiseSuppressionDetails?

Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not ‘disabled’. If you disable noise suppression and later re-enable it, the previously configured settings will be used.



124
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 124

optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails }

#onnet_t38_passthrough_enabledBoolean?

Enable on-net T38 if you prefer the sender and receiver negotiating T38 directly if both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call depending on each leg’s settings.

Returns:

  • (Boolean, nil)


132
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 132

optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean

#outboundTelnyx::Models::UacConnectionCreateParams::Outbound?



137
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 137

optional :outbound, -> { Telnyx::UacConnectionCreateParams::Outbound }

#passwordString?

The password to be used as part of the credentials. Must be 8 to 128 characters long.

Returns:

  • (String, nil)


144
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 144

optional :password, String

#rtcp_settingsTelnyx::Models::ConnectionRtcpSettings?



149
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 149

optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings }

#sip_uri_calling_preferenceSymbol, ...

This feature enables inbound SIP URI calls to your Credential Auth Connection. If enabled for all (unrestricted) then anyone who calls the SIP URI <your-username>@telnyx.com will be connected to your Connection. You can also choose to allow only calls that are originated on any Connections under your account (internal).



159
160
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 159

optional :sip_uri_calling_preference,
enum: -> { Telnyx::UacConnectionCreateParams::SipUriCallingPreference }

#tagsArray<String>?

Tags associated with the connection.

Returns:

  • (Array<String>, nil)


166
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 166

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#user_nameString?

The user name to be used as part of the credentials. Must be 4-32 characters long and alphanumeric values only (no spaces or special characters).

Returns:

  • (String, nil)


173
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 173

optional :user_name, String

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1, v2 or texml. Note - texml can only be set when the outbound object parameter call_parking_enabled is included and set to true.



181
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 181

optional :webhook_api_version, enum: -> { Telnyx::UacConnectionCreateParams::WebhookAPIVersion }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


188
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 188

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


195
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 195

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


201
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 201

optional :webhook_timeout_secs, Integer, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/uac_connection_create_params.rb', line 357