Class: Telnyx::Models::UacConnectionCreateParams::Inbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/uac_connection_create_params.rb

Defined Under Namespace

Modules: AniNumberFormat, DefaultRoutingMethod, DnisNumberFormat, SimultaneousRinging

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, simultaneous_ringing: nil, sip_compact_headers_enabled: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::UacConnectionCreateParams::Inbound for more details.

Inbound settings that can be supplied when creating or updating a UAC connection. The SIP subdomain fields returned in UAC connection responses are generated by Telnyx and are not accepted as request parameters.

Parameters:

  • ani_number_format (Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::AniNumberFormat) (defaults to: nil)

    This setting allows you to set the format with which the caller’s number (ANI) i

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the total number of inbound calls to phone numbers ass

  • codecs (Array<String>) (defaults to: nil)

    Defines the list of codecs that Telnyx will send for inbound calls to a specific

  • default_routing_method (Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::DefaultRoutingMethod) (defaults to: nil)

    Default routing method to be used when a number is associated with the connectio

  • dnis_number_format (Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::DnisNumberFormat) (defaults to: nil)
  • generate_ringback_tone (Boolean) (defaults to: nil)

    Generate ringback tone through 183 session progress message with early media.

  • isup_headers_enabled (Boolean) (defaults to: nil)

    When set, inbound phone calls will receive ISUP parameters via SIP headers. (Onl

  • prack_enabled (Boolean) (defaults to: nil)

    Enable PRACK messages as defined in RFC3262.

  • shaken_stir_enabled (Boolean) (defaults to: nil)

    When enabled the SIP Connection will receive the Identity header with Shaken/Sti

  • simultaneous_ringing (Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::SimultaneousRinging) (defaults to: nil)

    When enabled, allows multiple devices to ring simultaneously on incoming calls.

  • sip_compact_headers_enabled (Boolean) (defaults to: nil)

    Defaults to true.

  • timeout_1xx_secs (Integer) (defaults to: nil)

    Time(sec) before aborting if connection is not made.

  • timeout_2xx_secs (Integer) (defaults to: nil)

    Time(sec) before aborting if call is unanswered (min: 1, max: 600).



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 263

class Inbound < Telnyx::Internal::Type::BaseModel
  # @!attribute ani_number_format
  #   This setting allows you to set the format with which the caller's number (ANI)
  #   is sent for inbound phone calls.
  #
  #   @return [Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::AniNumberFormat, nil]
  optional :ani_number_format, enum: -> { Telnyx::UacConnectionCreateParams::Inbound::AniNumberFormat }

  # @!attribute channel_limit
  #   When set, this will limit the total number of inbound calls to phone numbers
  #   associated with this connection.
  #
  #   @return [Integer, nil]
  optional :channel_limit, Integer

  # @!attribute codecs
  #   Defines the list of codecs that Telnyx will send for inbound calls to a specific
  #   number on your portal account, in priority order. This only works when the
  #   Connection the number is assigned to uses Media Handling mode: default. OPUS and
  #   H.264 codecs are available only when using TCP or TLS transport for SIP.
  #
  #   @return [Array<String>, nil]
  optional :codecs, Telnyx::Internal::Type::ArrayOf[String]

  # @!attribute default_routing_method
  #   Default routing method to be used when a number is associated with the
  #   connection. Must be one of the routing method types or left blank, other values
  #   are not allowed.
  #
  #   @return [Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::DefaultRoutingMethod, nil]
  optional :default_routing_method,
           enum: -> { Telnyx::UacConnectionCreateParams::Inbound::DefaultRoutingMethod }

  # @!attribute dnis_number_format
  #
  #   @return [Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::DnisNumberFormat, nil]
  optional :dnis_number_format, enum: -> { Telnyx::UacConnectionCreateParams::Inbound::DnisNumberFormat }

  # @!attribute generate_ringback_tone
  #   Generate ringback tone through 183 session progress message with early media.
  #
  #   @return [Boolean, nil]
  optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean

  # @!attribute isup_headers_enabled
  #   When set, inbound phone calls will receive ISUP parameters via SIP headers.
  #   (Only when available and only when using TCP or TLS transport.)
  #
  #   @return [Boolean, nil]
  optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean

  # @!attribute prack_enabled
  #   Enable PRACK messages as defined in RFC3262.
  #
  #   @return [Boolean, nil]
  optional :prack_enabled, Telnyx::Internal::Type::Boolean

  # @!attribute shaken_stir_enabled
  #   When enabled the SIP Connection will receive the Identity header with
  #   Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP
  #   transport.
  #
  #   @return [Boolean, nil]
  optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean

  # @!attribute simultaneous_ringing
  #   When enabled, allows multiple devices to ring simultaneously on incoming calls.
  #
  #   @return [Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::SimultaneousRinging, nil]
  optional :simultaneous_ringing,
           enum: -> { Telnyx::UacConnectionCreateParams::Inbound::SimultaneousRinging }

  # @!attribute sip_compact_headers_enabled
  #   Defaults to true.
  #
  #   @return [Boolean, nil]
  optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean

  # @!attribute timeout_1xx_secs
  #   Time(sec) before aborting if connection is not made.
  #
  #   @return [Integer, nil]
  optional :timeout_1xx_secs, Integer

  # @!attribute timeout_2xx_secs
  #   Time(sec) before aborting if call is unanswered (min: 1, max: 600).
  #
  #   @return [Integer, nil]
  optional :timeout_2xx_secs, Integer

  # @!method initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, simultaneous_ringing: nil, sip_compact_headers_enabled: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::UacConnectionCreateParams::Inbound} for more details.
  #
  #   Inbound settings that can be supplied when creating or updating a UAC
  #   connection. The SIP subdomain fields returned in UAC connection responses are
  #   generated by Telnyx and are not accepted as request parameters.
  #
  #   @param ani_number_format [Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::AniNumberFormat] This setting allows you to set the format with which the caller's number (ANI) i
  #
  #   @param channel_limit [Integer] When set, this will limit the total number of inbound calls to phone numbers ass
  #
  #   @param codecs [Array<String>] Defines the list of codecs that Telnyx will send for inbound calls to a specific
  #
  #   @param default_routing_method [Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::DefaultRoutingMethod] Default routing method to be used when a number is associated with the connectio
  #
  #   @param dnis_number_format [Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::DnisNumberFormat]
  #
  #   @param generate_ringback_tone [Boolean] Generate ringback tone through 183 session progress message with early media.
  #
  #   @param isup_headers_enabled [Boolean] When set, inbound phone calls will receive ISUP parameters via SIP headers. (Onl
  #
  #   @param prack_enabled [Boolean] Enable PRACK messages as defined in RFC3262.
  #
  #   @param shaken_stir_enabled [Boolean] When enabled the SIP Connection will receive the Identity header with Shaken/Sti
  #
  #   @param simultaneous_ringing [Symbol, Telnyx::Models::UacConnectionCreateParams::Inbound::SimultaneousRinging] When enabled, allows multiple devices to ring simultaneously on incoming calls.
  #
  #   @param sip_compact_headers_enabled [Boolean] Defaults to true.
  #
  #   @param timeout_1xx_secs [Integer] Time(sec) before aborting if connection is not made.
  #
  #   @param timeout_2xx_secs [Integer] Time(sec) before aborting if call is unanswered (min: 1, max: 600).

  # This setting allows you to set the format with which the caller's number (ANI)
  # is sent for inbound phone calls.
  #
  # @see Telnyx::Models::UacConnectionCreateParams::Inbound#ani_number_format
  module AniNumberFormat
    extend Telnyx::Internal::Type::Enum

    PLUS_E_164 = :"+E.164"
    E_164 = :"E.164"
    PLUS_E_164_NATIONAL = :"+E.164-national"
    E_164_NATIONAL = :"E.164-national"

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # Default routing method to be used when a number is associated with the
  # connection. Must be one of the routing method types or left blank, other values
  # are not allowed.
  #
  # @see Telnyx::Models::UacConnectionCreateParams::Inbound#default_routing_method
  module DefaultRoutingMethod
    extend Telnyx::Internal::Type::Enum

    SEQUENTIAL = :sequential
    ROUND_ROBIN = :"round-robin"

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # @see Telnyx::Models::UacConnectionCreateParams::Inbound#dnis_number_format
  module DnisNumberFormat
    extend Telnyx::Internal::Type::Enum

    PLUS_E164 = :"+e164"
    E164 = :e164
    NATIONAL = :national
    SIP_USERNAME = :sip_username

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # When enabled, allows multiple devices to ring simultaneously on incoming calls.
  #
  # @see Telnyx::Models::UacConnectionCreateParams::Inbound#simultaneous_ringing
  module SimultaneousRinging
    extend Telnyx::Internal::Type::Enum

    DISABLED = :disabled
    ENABLED = :enabled

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#ani_number_formatSymbol, ...

This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.



269
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 269

optional :ani_number_format, enum: -> { Telnyx::UacConnectionCreateParams::Inbound::AniNumberFormat }

#channel_limitInteger?

When set, this will limit the total number of inbound calls to phone numbers associated with this connection.

Returns:

  • (Integer, nil)


276
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 276

optional :channel_limit, Integer

#codecsArray<String>?

Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order. This only works when the Connection the number is assigned to uses Media Handling mode: default. OPUS and H.264 codecs are available only when using TCP or TLS transport for SIP.

Returns:

  • (Array<String>, nil)


285
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 285

optional :codecs, Telnyx::Internal::Type::ArrayOf[String]

#default_routing_methodSymbol, ...

Default routing method to be used when a number is associated with the connection. Must be one of the routing method types or left blank, other values are not allowed.



293
294
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 293

optional :default_routing_method,
enum: -> { Telnyx::UacConnectionCreateParams::Inbound::DefaultRoutingMethod }

#dnis_number_formatSymbol, ...



299
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 299

optional :dnis_number_format, enum: -> { Telnyx::UacConnectionCreateParams::Inbound::DnisNumberFormat }

#generate_ringback_toneBoolean?

Generate ringback tone through 183 session progress message with early media.

Returns:

  • (Boolean, nil)


305
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 305

optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean

#isup_headers_enabledBoolean?

When set, inbound phone calls will receive ISUP parameters via SIP headers. (Only when available and only when using TCP or TLS transport.)

Returns:

  • (Boolean, nil)


312
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 312

optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean

#prack_enabledBoolean?

Enable PRACK messages as defined in RFC3262.

Returns:

  • (Boolean, nil)


318
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 318

optional :prack_enabled, Telnyx::Internal::Type::Boolean

#shaken_stir_enabledBoolean?

When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.

Returns:

  • (Boolean, nil)


326
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 326

optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean

#simultaneous_ringingSymbol, ...

When enabled, allows multiple devices to ring simultaneously on incoming calls.



332
333
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 332

optional :simultaneous_ringing,
enum: -> { Telnyx::UacConnectionCreateParams::Inbound::SimultaneousRinging }

#sip_compact_headers_enabledBoolean?

Defaults to true.

Returns:

  • (Boolean, nil)


339
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 339

optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean

#timeout_1xx_secsInteger?

Time(sec) before aborting if connection is not made.

Returns:

  • (Integer, nil)


345
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 345

optional :timeout_1xx_secs, Integer

#timeout_2xx_secsInteger?

Time(sec) before aborting if call is unanswered (min: 1, max: 600).

Returns:

  • (Integer, nil)


351
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 351

optional :timeout_2xx_secs, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/uac_connection_create_params.rb', line 399