Module: Telnyx::Models::UacConnectionCreateParams::WebhookAPIVersion

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/uac_connection_create_params.rb,
sig/telnyx/models/uac_connection_create_params.rbs

Overview

Determines which webhook format will be used, Telnyx API v1, v2 or texml. Note - texml can only be set when the outbound object parameter call_parking_enabled is included and set to true.

Constant Summary collapse

V1 =

Returns:

  • (:"1")
:"1"
V2 =

Returns:

  • (:"2")
:"2"
TEXML =

Returns:

  • (:texml)
:texml

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/uac_connection_create_params.rb', line 289

Instance Method Details

#self?.values::Array[Telnyx::Models::UacConnectionCreateParams::webhook_api_version]

Returns:

  • (::Array[Telnyx::Models::UacConnectionCreateParams::webhook_api_version])


236
# File 'sig/telnyx/models/uac_connection_create_params.rbs', line 236

def self?.values: -> ::Array[Telnyx::Models::UacConnectionCreateParams::webhook_api_version]