Class: Telnyx::Models::UacConnectionDeleteResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/uac_connection_delete_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Authentication, FqdnOutboundAuthentication, NoiseSuppression, SipUriCallingPreference, WebhookAPIVersion Classes: ExternalUacSettings, Inbound, InternalUacSettings, Outbound

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(destination_uri: nil) ⇒ Object

Some parameter documentations has been truncated, see InternalUacSettings for more details.

Internal Telnyx-side settings for a UAC connection.

Parameters:

  • destination_uri (String) (defaults to: nil)

    The SIP URI that Telnyx will call when handling an inbound request from the exte



# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 278

Instance Attribute Details

#activeBoolean?

Defaults to true

Returns:

  • (Boolean, nil)


34
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 34

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



42
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 42

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#android_push_credential_idString?

The uuid of the push credential for Android

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 48

optional :android_push_credential_id, String, nil?: true

#authenticationSymbol, ...

The authentication strategy used by this connection.



54
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 54

optional :authentication, enum: -> { Telnyx::Models::UacConnectionDeleteResponse::Data::Authentication }

#call_cost_in_webhooksBoolean?

Specifies if call cost webhooks should be sent for this connection.

Returns:

  • (Boolean, nil)


60
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 60

optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean

#connection_nameString?

Returns:

  • (String, nil)


65
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 65

optional :connection_name, String

#created_atString?

ISO-8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


71
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 71

optional :created_at, String

#default_on_hold_comfort_noise_enabledBoolean?

When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.

Returns:

  • (Boolean, nil)


79
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 79

optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean

#dtmf_typeSymbol, ...

Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.

Returns:



86
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 86

optional :dtmf_type, enum: -> { Telnyx::DtmfType }

#encode_contact_header_enabledBoolean?

Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.

Returns:

  • (Boolean, nil)


93
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 93

optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean

#encrypted_mediaSymbol, ...

Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.

Returns:



100
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 100

optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true

#external_uac_settingsTelnyx::Models::UacConnectionDeleteResponse::Data::ExternalUacSettings?

External SIP peer settings used by Telnyx when registering to your PBX and routing outbound calls.



107
108
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 107

optional :external_uac_settings,
-> { Telnyx::Models::UacConnectionDeleteResponse::Data::ExternalUacSettings }

#fqdnString?

The Telnyx-managed FQDN generated for the UAC connection.

Returns:

  • (String, nil)


114
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 114

optional :fqdn, String

#fqdn_outbound_authenticationSymbol, ...

The fixed outbound authentication mode used by UAC FQDN records.



120
121
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 120

optional :fqdn_outbound_authentication,
enum: -> { Telnyx::Models::UacConnectionDeleteResponse::Data::FqdnOutboundAuthentication }

#fqdnsArray<Telnyx::Models::Fqdn>?

FQDN records managed automatically by the UAC connection lifecycle.

Returns:



127
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 127

optional :fqdns, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Fqdn] }

#idString?

Identifies the type of resource.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 28

optional :id, String

#inboundTelnyx::Models::UacConnectionDeleteResponse::Data::Inbound?



132
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 132

optional :inbound, -> { Telnyx::Models::UacConnectionDeleteResponse::Data::Inbound }

#internal_uac_settingsTelnyx::Models::UacConnectionDeleteResponse::Data::InternalUacSettings?

Internal Telnyx-side settings for a UAC connection.



138
139
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 138

optional :internal_uac_settings,
-> { Telnyx::Models::UacConnectionDeleteResponse::Data::InternalUacSettings }

#ios_push_credential_idString?

The uuid of the push credential for Ios

Returns:

  • (String, nil)


145
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 145

optional :ios_push_credential_id, String, nil?: true

#jitter_bufferTelnyx::Models::ConnectionJitterBuffer?

Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.



155
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 155

optional :jitter_buffer, -> { Telnyx::ConnectionJitterBuffer }

#noise_suppressionSymbol, ...

Controls when noise suppression is applied to calls. When set to ‘inbound’, noise suppression is applied to incoming audio. When set to ‘outbound’, it’s applied to outgoing audio. When set to ‘both’, it’s applied in both directions. When set to ‘disabled’, noise suppression is turned off.



164
165
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 164

optional :noise_suppression,
enum: -> { Telnyx::Models::UacConnectionDeleteResponse::Data::NoiseSuppression }

#noise_suppression_detailsTelnyx::Models::ConnectionNoiseSuppressionDetails?

Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not ‘disabled’. If you disable noise suppression and later re-enable it, the previously configured settings will be used.



174
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 174

optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails }

#onnet_t38_passthrough_enabledBoolean?

Enable on-net T38 if you prefer the sender and receiver negotiating T38 directly if both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call depending on each leg’s settings.

Returns:

  • (Boolean, nil)


182
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 182

optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean

#outboundTelnyx::Models::UacConnectionDeleteResponse::Data::Outbound?



187
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 187

optional :outbound, -> { Telnyx::Models::UacConnectionDeleteResponse::Data::Outbound }

#passwordString?

The password to be used as part of the credentials. Must be 8 to 128 characters long.

Returns:

  • (String, nil)


194
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 194

optional :password, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


200
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 200

optional :record_type, String

#registration_statusString?

The most recently known SIP registration status for this UAC connection.

Returns:

  • (String, nil)


206
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 206

optional :registration_status, String, nil?: true

#registration_status_updated_atString?

ISO 8601 formatted date indicating when the registration status was last updated.

Returns:

  • (String, nil)


213
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 213

optional :registration_status_updated_at, String, nil?: true

#rtcp_settingsTelnyx::Models::ConnectionRtcpSettings?



218
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 218

optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings }

#sip_uri_calling_preferenceSymbol, ...

This feature enables inbound SIP URI calls to your Credential Auth Connection. If enabled for all (unrestricted) then anyone who calls the SIP URI <your-username>@telnyx.com will be connected to your Connection. You can also choose to allow only calls that are originated on any Connections under your account (internal).



228
229
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 228

optional :sip_uri_calling_preference,
enum: -> { Telnyx::Models::UacConnectionDeleteResponse::Data::SipUriCallingPreference }

#tagsArray<String>?

Tags associated with the connection.

Returns:

  • (Array<String>, nil)


235
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 235

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#updated_atString?

ISO-8601 formatted date indicating when the resource was updated.

Returns:

  • (String, nil)


241
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 241

optional :updated_at, String

#user_nameString?

The user name to be used as part of the credentials. Must be 4-32 characters long and alphanumeric values only (no spaces or special characters). At least one of the first 5 characters must be a letter.

Returns:

  • (String, nil)


249
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 249

optional :user_name, String

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1 or v2.



255
256
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 255

optional :webhook_api_version,
enum: -> { Telnyx::Models::UacConnectionDeleteResponse::Data::WebhookAPIVersion }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


263
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 263

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


270
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 270

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


276
# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 276

optional :webhook_timeout_secs, Integer, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/uac_connection_delete_response.rb', line 369