Class: Telnyx::Models::UacConnectionListResponse::InternalUacSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/uac_connection_list_response.rb

Overview

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#destination_uriString?

The SIP URI that Telnyx will call when handling an inbound request from the external peer. Do not include a ‘sip:` prefix. The value must be in the format `userinfo@sip.telnyx.com` or `userinfo@sipdev.telnyx.com`; the userinfo portion may contain only letters, digits, hyphens, and underscores.

Returns:

  • (String, nil)


685
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 685

optional :destination_uri, String