Class: Telnyx::Models::UacConnectionListResponse::Outbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/uac_connection_list_response.rb

Overview

See Also:

Defined Under Namespace

Modules: AniOverrideType, T38ReinviteSource

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ani_override: nil, ani_override_type: nil, call_parking_enabled: nil, channel_limit: nil, generate_ringback_tone: nil, instant_ringback_enabled: nil, localization: nil, outbound_voice_profile_id: nil, t38_reinvite_source: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::UacConnectionListResponse::Outbound for more details.

Parameters:

  • ani_override (String) (defaults to: nil)

    Set a phone number as the ani_override value to override caller id number on out

  • ani_override_type (Symbol, Telnyx::Models::UacConnectionListResponse::Outbound::AniOverrideType) (defaults to: nil)

    Specifies when we apply your ani_override setting. Only applies when ani_overrid

  • call_parking_enabled (Boolean, nil) (defaults to: nil)

    Forces all SIP calls originated on this connection to be “parked” instead of “br

  • channel_limit (Integer) (defaults to: nil)

    When set, this will limit the total number of outbound calls to phone numbers as

  • generate_ringback_tone (Boolean) (defaults to: nil)

    Generate ringback tone through 183 session progress message with early media.

  • instant_ringback_enabled (Boolean) (defaults to: nil)

    When set, ringback will not wait for indication before sending ringback tone to

  • localization (String) (defaults to: nil)

    A 2-character country code specifying the country whose national dialing rules s

  • outbound_voice_profile_id (String) (defaults to: nil)

    Identifies the associated outbound voice profile.

  • t38_reinvite_source (Symbol, Telnyx::Models::UacConnectionListResponse::Outbound::T38ReinviteSource) (defaults to: nil)

    This setting only affects connections with Fax-type Outbound Voice Profiles. The



# File 'lib/telnyx/models/uac_connection_list_response.rb', line 786

Instance Attribute Details

#ani_overrideString?

Set a phone number as the ani_override value to override caller id number on outbound calls.

Returns:

  • (String, nil)


722
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 722

optional :ani_override, String

#ani_override_typeSymbol, ...

Specifies when we apply your ani_override setting. Only applies when ani_override is not blank.



729
730
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 729

optional :ani_override_type,
enum: -> { Telnyx::Models::UacConnectionListResponse::Outbound::AniOverrideType }

#call_parking_enabledBoolean?

Forces all SIP calls originated on this connection to be “parked” instead of “bridged” to the destination specified on the URI. Parked calls will return ringback to the caller and will await for a Call Control command to define which action will be taken next.

Returns:

  • (Boolean, nil)


739
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 739

optional :call_parking_enabled, Telnyx::Internal::Type::Boolean, nil?: true

#channel_limitInteger?

When set, this will limit the total number of outbound calls to phone numbers associated with this connection.

Returns:

  • (Integer, nil)


746
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 746

optional :channel_limit, Integer

#generate_ringback_toneBoolean?

Generate ringback tone through 183 session progress message with early media.

Returns:

  • (Boolean, nil)


752
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 752

optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean

#instant_ringback_enabledBoolean?

When set, ringback will not wait for indication before sending ringback tone to calling party.

Returns:

  • (Boolean, nil)


759
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 759

optional :instant_ringback_enabled, Telnyx::Internal::Type::Boolean

#localizationString?

A 2-character country code specifying the country whose national dialing rules should be used. For example, if set to ‘US` then any US number can be dialed without preprending +1 to the number. When left blank, Telnyx will try US and GB dialing rules, in that order, by default.

Returns:

  • (String, nil)


768
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 768

optional :localization, String

#outbound_voice_profile_idString?

Identifies the associated outbound voice profile.

Returns:

  • (String, nil)


774
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 774

optional :outbound_voice_profile_id, String

#t38_reinvite_sourceSymbol, ...

This setting only affects connections with Fax-type Outbound Voice Profiles. The setting dictates whether or not Telnyx sends a t.38 reinvite.<br/><br/> By default, Telnyx will send the re-invite. If set to ‘customer`, the caller is expected to send the t.38 reinvite.



783
784
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 783

optional :t38_reinvite_source,
enum: -> { Telnyx::Models::UacConnectionListResponse::Outbound::T38ReinviteSource }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/uac_connection_list_response.rb', line 819