Class: Telnyx::Models::UacConnectionRetrieveResponse::Data::ExternalUacSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/uac_connection_retrieve_response.rb

Overview

Defined Under Namespace

Modules: Transport

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(auth_username: nil, expiration_sec: nil, from_user: nil, outbound_proxy: nil, password: nil, proxy: nil, transport: nil, username: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::UacConnectionRetrieveResponse::Data::ExternalUacSettings for more details.

External SIP peer settings used by Telnyx when registering to your PBX and routing outbound calls.

Parameters:

  • auth_username (String, nil) (defaults to: nil)

    The authentication username used in SIP digest authentication. If not set, the U

  • expiration_sec (Integer, nil) (defaults to: nil)

    The registration interval, in seconds, indicating how often the system refreshes

  • from_user (String, nil) (defaults to: nil)

    The user portion of the SIP From header used in outbound requests. This controls

  • outbound_proxy (String, nil) (defaults to: nil)

    An optional SIP proxy used to route outbound requests before reaching the extern

  • password (String) (defaults to: nil)

    The SIP password used for digest authentication with the external SIP peer.

  • proxy (String) (defaults to: nil)

    The SIP proxy address of the external SIP peer used for registrations and outbou

  • transport (Symbol, Telnyx::Models::UacConnectionRetrieveResponse::Data::ExternalUacSettings::Transport, nil) (defaults to: nil)

    The transport protocol used for SIP signaling when communicating with the extern

  • username (String) (defaults to: nil)

    The SIP username used to authenticate with the external SIP peer for registratio



# File 'lib/telnyx/models/uac_connection_retrieve_response.rb', line 433

Instance Attribute Details

#auth_usernameString?

The authentication username used in SIP digest authentication. If not set, the Username value will be used.

Returns:

  • (String, nil)


380
# File 'lib/telnyx/models/uac_connection_retrieve_response.rb', line 380

optional :auth_username, String, nil?: true

#expiration_secInteger?

The registration interval, in seconds, indicating how often the system refreshes the SIP registration with the external SIP peer.

Returns:

  • (Integer, nil)


387
# File 'lib/telnyx/models/uac_connection_retrieve_response.rb', line 387

optional :expiration_sec, Integer, nil?: true

#from_userString?

The user portion of the SIP From header used in outbound requests. This controls the caller identity presented to the external SIP peer.

Returns:

  • (String, nil)


394
# File 'lib/telnyx/models/uac_connection_retrieve_response.rb', line 394

optional :from_user, String, nil?: true

#outbound_proxyString?

An optional SIP proxy used to route outbound requests before reaching the external SIP peer.

Returns:

  • (String, nil)


401
# File 'lib/telnyx/models/uac_connection_retrieve_response.rb', line 401

optional :outbound_proxy, String, nil?: true

#passwordString?

The SIP password used for digest authentication with the external SIP peer.

Returns:

  • (String, nil)


407
# File 'lib/telnyx/models/uac_connection_retrieve_response.rb', line 407

optional :password, String

#proxyString?

The SIP proxy address of the external SIP peer used for registrations and outbound call routing.

Returns:

  • (String, nil)


414
# File 'lib/telnyx/models/uac_connection_retrieve_response.rb', line 414

optional :proxy, String

#transportSymbol, ...

The transport protocol used for SIP signaling when communicating with the external SIP peer. One of UDP, TLS, or TCP.



421
422
423
# File 'lib/telnyx/models/uac_connection_retrieve_response.rb', line 421

optional :transport,
enum: -> { Telnyx::Models::UacConnectionRetrieveResponse::Data::ExternalUacSettings::Transport },
nil?: true

#usernameString?

The SIP username used to authenticate with the external SIP peer for registrations and outbound calls. Must start with a letter or number and contain only letters, numbers, hyphens, and underscores.

Returns:

  • (String, nil)


431
# File 'lib/telnyx/models/uac_connection_retrieve_response.rb', line 431

optional :username, String