Class: Telnyx::Models::UacConnectionUpdateParams::Inbound
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::UacConnectionUpdateParams::Inbound
- Defined in:
- lib/telnyx/models/uac_connection_update_params.rb
Defined Under Namespace
Modules: AniNumberFormat, DefaultRoutingMethod, DnisNumberFormat, SimultaneousRinging
Instance Attribute Summary collapse
-
#ani_number_format ⇒ Symbol, ...
This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.
-
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
-
#codecs ⇒ Array<String>?
Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order.
-
#default_routing_method ⇒ Symbol, ...
Default routing method to be used when a number is associated with the connection.
- #dnis_number_format ⇒ Symbol, ...
-
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
-
#isup_headers_enabled ⇒ Boolean?
When set, inbound phone calls will receive ISUP parameters via SIP headers.
-
#prack_enabled ⇒ Boolean?
Enable PRACK messages as defined in RFC3262.
-
#shaken_stir_enabled ⇒ Boolean?
When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.
-
#simultaneous_ringing ⇒ Symbol, ...
When enabled, allows multiple devices to ring simultaneously on incoming calls.
-
#sip_compact_headers_enabled ⇒ Boolean?
Defaults to true.
-
#timeout_1xx_secs ⇒ Integer?
Time(sec) before aborting if connection is not made.
-
#timeout_2xx_secs ⇒ Integer?
Time(sec) before aborting if call is unanswered (min: 1, max: 600).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, simultaneous_ringing: nil, sip_compact_headers_enabled: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Inbound for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, simultaneous_ringing: nil, sip_compact_headers_enabled: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::UacConnectionUpdateParams::Inbound for more details.
Inbound settings that can be supplied when creating or updating a UAC connection. The SIP subdomain fields returned in UAC connection responses are generated by Telnyx and are not accepted as request parameters.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 268 class Inbound < Telnyx::Internal::Type::BaseModel # @!attribute ani_number_format # This setting allows you to set the format with which the caller's number (ANI) # is sent for inbound phone calls. # # @return [Symbol, Telnyx::Models::UacConnectionUpdateParams::Inbound::AniNumberFormat, nil] optional :ani_number_format, enum: -> { Telnyx::UacConnectionUpdateParams::Inbound::AniNumberFormat } # @!attribute channel_limit # When set, this will limit the total number of inbound calls to phone numbers # associated with this connection. # # @return [Integer, nil] optional :channel_limit, Integer # @!attribute codecs # Defines the list of codecs that Telnyx will send for inbound calls to a specific # number on your portal account, in priority order. This only works when the # Connection the number is assigned to uses Media Handling mode: default. OPUS and # H.264 codecs are available only when using TCP or TLS transport for SIP. # # @return [Array<String>, nil] optional :codecs, Telnyx::Internal::Type::ArrayOf[String] # @!attribute default_routing_method # Default routing method to be used when a number is associated with the # connection. Must be one of the routing method types or left blank, other values # are not allowed. # # @return [Symbol, Telnyx::Models::UacConnectionUpdateParams::Inbound::DefaultRoutingMethod, nil] optional :default_routing_method, enum: -> { Telnyx::UacConnectionUpdateParams::Inbound::DefaultRoutingMethod } # @!attribute dnis_number_format # # @return [Symbol, Telnyx::Models::UacConnectionUpdateParams::Inbound::DnisNumberFormat, nil] optional :dnis_number_format, enum: -> { Telnyx::UacConnectionUpdateParams::Inbound::DnisNumberFormat } # @!attribute generate_ringback_tone # Generate ringback tone through 183 session progress message with early media. # # @return [Boolean, nil] optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean # @!attribute isup_headers_enabled # When set, inbound phone calls will receive ISUP parameters via SIP headers. # (Only when available and only when using TCP or TLS transport.) # # @return [Boolean, nil] optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean # @!attribute prack_enabled # Enable PRACK messages as defined in RFC3262. # # @return [Boolean, nil] optional :prack_enabled, Telnyx::Internal::Type::Boolean # @!attribute shaken_stir_enabled # When enabled the SIP Connection will receive the Identity header with # Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP # transport. # # @return [Boolean, nil] optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean # @!attribute simultaneous_ringing # When enabled, allows multiple devices to ring simultaneously on incoming calls. # # @return [Symbol, Telnyx::Models::UacConnectionUpdateParams::Inbound::SimultaneousRinging, nil] optional :simultaneous_ringing, enum: -> { Telnyx::UacConnectionUpdateParams::Inbound::SimultaneousRinging } # @!attribute sip_compact_headers_enabled # Defaults to true. # # @return [Boolean, nil] optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean # @!attribute timeout_1xx_secs # Time(sec) before aborting if connection is not made. # # @return [Integer, nil] optional :timeout_1xx_secs, Integer # @!attribute timeout_2xx_secs # Time(sec) before aborting if call is unanswered (min: 1, max: 600). # # @return [Integer, nil] optional :timeout_2xx_secs, Integer # @!method initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, simultaneous_ringing: nil, sip_compact_headers_enabled: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::UacConnectionUpdateParams::Inbound} for more details. # # Inbound settings that can be supplied when creating or updating a UAC # connection. The SIP subdomain fields returned in UAC connection responses are # generated by Telnyx and are not accepted as request parameters. # # @param ani_number_format [Symbol, Telnyx::Models::UacConnectionUpdateParams::Inbound::AniNumberFormat] This setting allows you to set the format with which the caller's number (ANI) i # # @param channel_limit [Integer] When set, this will limit the total number of inbound calls to phone numbers ass # # @param codecs [Array<String>] Defines the list of codecs that Telnyx will send for inbound calls to a specific # # @param default_routing_method [Symbol, Telnyx::Models::UacConnectionUpdateParams::Inbound::DefaultRoutingMethod] Default routing method to be used when a number is associated with the connectio # # @param dnis_number_format [Symbol, Telnyx::Models::UacConnectionUpdateParams::Inbound::DnisNumberFormat] # # @param generate_ringback_tone [Boolean] Generate ringback tone through 183 session progress message with early media. # # @param isup_headers_enabled [Boolean] When set, inbound phone calls will receive ISUP parameters via SIP headers. (Onl # # @param prack_enabled [Boolean] Enable PRACK messages as defined in RFC3262. # # @param shaken_stir_enabled [Boolean] When enabled the SIP Connection will receive the Identity header with Shaken/Sti # # @param simultaneous_ringing [Symbol, Telnyx::Models::UacConnectionUpdateParams::Inbound::SimultaneousRinging] When enabled, allows multiple devices to ring simultaneously on incoming calls. # # @param sip_compact_headers_enabled [Boolean] Defaults to true. # # @param timeout_1xx_secs [Integer] Time(sec) before aborting if connection is not made. # # @param timeout_2xx_secs [Integer] Time(sec) before aborting if call is unanswered (min: 1, max: 600). # This setting allows you to set the format with which the caller's number (ANI) # is sent for inbound phone calls. # # @see Telnyx::Models::UacConnectionUpdateParams::Inbound#ani_number_format module AniNumberFormat extend Telnyx::Internal::Type::Enum PLUS_E_164 = :"+E.164" E_164 = :"E.164" PLUS_E_164_NATIONAL = :"+E.164-national" E_164_NATIONAL = :"E.164-national" # @!method self.values # @return [Array<Symbol>] end # Default routing method to be used when a number is associated with the # connection. Must be one of the routing method types or left blank, other values # are not allowed. # # @see Telnyx::Models::UacConnectionUpdateParams::Inbound#default_routing_method module DefaultRoutingMethod extend Telnyx::Internal::Type::Enum SEQUENTIAL = :sequential ROUND_ROBIN = :"round-robin" # @!method self.values # @return [Array<Symbol>] end # @see Telnyx::Models::UacConnectionUpdateParams::Inbound#dnis_number_format module DnisNumberFormat extend Telnyx::Internal::Type::Enum PLUS_E164 = :"+e164" E164 = :e164 NATIONAL = :national SIP_USERNAME = :sip_username # @!method self.values # @return [Array<Symbol>] end # When enabled, allows multiple devices to ring simultaneously on incoming calls. # # @see Telnyx::Models::UacConnectionUpdateParams::Inbound#simultaneous_ringing module SimultaneousRinging extend Telnyx::Internal::Type::Enum DISABLED = :disabled ENABLED = :enabled # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#ani_number_format ⇒ Symbol, ...
This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.
274 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 274 optional :ani_number_format, enum: -> { Telnyx::UacConnectionUpdateParams::Inbound::AniNumberFormat } |
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
281 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 281 optional :channel_limit, Integer |
#codecs ⇒ Array<String>?
Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order. This only works when the Connection the number is assigned to uses Media Handling mode: default. OPUS and H.264 codecs are available only when using TCP or TLS transport for SIP.
290 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 290 optional :codecs, Telnyx::Internal::Type::ArrayOf[String] |
#default_routing_method ⇒ Symbol, ...
Default routing method to be used when a number is associated with the connection. Must be one of the routing method types or left blank, other values are not allowed.
298 299 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 298 optional :default_routing_method, enum: -> { Telnyx::UacConnectionUpdateParams::Inbound::DefaultRoutingMethod } |
#dnis_number_format ⇒ Symbol, ...
304 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 304 optional :dnis_number_format, enum: -> { Telnyx::UacConnectionUpdateParams::Inbound::DnisNumberFormat } |
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
310 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 310 optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean |
#isup_headers_enabled ⇒ Boolean?
When set, inbound phone calls will receive ISUP parameters via SIP headers. (Only when available and only when using TCP or TLS transport.)
317 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 317 optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean |
#prack_enabled ⇒ Boolean?
Enable PRACK messages as defined in RFC3262.
323 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 323 optional :prack_enabled, Telnyx::Internal::Type::Boolean |
#shaken_stir_enabled ⇒ Boolean?
When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.
331 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 331 optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean |
#simultaneous_ringing ⇒ Symbol, ...
When enabled, allows multiple devices to ring simultaneously on incoming calls.
337 338 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 337 optional :simultaneous_ringing, enum: -> { Telnyx::UacConnectionUpdateParams::Inbound::SimultaneousRinging } |
#sip_compact_headers_enabled ⇒ Boolean?
Defaults to true.
344 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 344 optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean |
#timeout_1xx_secs ⇒ Integer?
Time(sec) before aborting if connection is not made.
350 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 350 optional :timeout_1xx_secs, Integer |
#timeout_2xx_secs ⇒ Integer?
Time(sec) before aborting if call is unanswered (min: 1, max: 600).
356 |
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 356 optional :timeout_2xx_secs, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/uac_connection_update_params.rb', line 404
|