Module: Telnyx::Models::UacConnectionUpdateParams::SipUriCallingPreference

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/uac_connection_update_params.rb,
sig/telnyx/models/uac_connection_update_params.rbs

Overview

This feature enables inbound SIP URI calls to your Credential Auth Connection. If enabled for all (unrestricted) then anyone who calls the SIP URI @telnyx.com will be connected to your Connection. You can also choose to allow only calls that are originated on any Connections under your account (internal).

Constant Summary collapse

DISABLED =

Returns:

  • (:disabled)
:disabled
UNRESTRICTED =

Returns:

  • (:unrestricted)
:unrestricted
INTERNAL =

Returns:

  • (:internal)
:internal

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Telnyx::Models::UacConnectionUpdateParams::sip_uri_calling_preference]

Returns:

  • (::Array[Telnyx::Models::UacConnectionUpdateParams::sip_uri_calling_preference])


231
# File 'sig/telnyx/models/uac_connection_update_params.rbs', line 231

def self?.values: -> ::Array[Telnyx::Models::UacConnectionUpdateParams::sip_uri_calling_preference]