Class: Telnyx::Models::UpdatePhoneNumberMessagingSettingsRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/update_phone_number_messaging_settings_request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(messaging_product: nil, messaging_profile_id: nil, tags: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::UpdatePhoneNumberMessagingSettingsRequest for more details.

Parameters:

  • messaging_product (String) (defaults to: nil)

    Configure the messaging product for this number:

  • messaging_profile_id (String) (defaults to: nil)

    Configure the messaging profile this phone number is assigned to:

  • tags (Array<String>) (defaults to: nil)

    Tags to set on this phone number.



# File 'lib/telnyx/models/update_phone_number_messaging_settings_request.rb', line 32

Instance Attribute Details

#messaging_productString?

Configure the messaging product for this number:

  • Omit this field or set its value to ‘null` to keep the current value.

  • Set this field to a quoted product ID to set this phone number to that product

Returns:

  • (String, nil)


13
# File 'lib/telnyx/models/update_phone_number_messaging_settings_request.rb', line 13

optional :messaging_product, String

#messaging_profile_idString?

Configure the messaging profile this phone number is assigned to:

  • Omit this field or set its value to ‘null` to keep the current value.

  • Set this field to ‘“”` to unassign the number from its messaging profile

  • Set this field to a quoted UUID of a messaging profile to assign this number to that messaging profile

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/update_phone_number_messaging_settings_request.rb', line 24

optional :messaging_profile_id, String

#tagsArray<String>?

Tags to set on this phone number.

Returns:

  • (Array<String>, nil)


30
# File 'lib/telnyx/models/update_phone_number_messaging_settings_request.rb', line 30

optional :tags, Telnyx::Internal::Type::ArrayOf[String]