Class: Telnyx::Models::UpdateRegulatoryRequirement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/update_regulatory_requirement.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(field_value: nil, requirement_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::UpdateRegulatoryRequirement for more details.

Parameters:

  • field_value (String) (defaults to: nil)

    The value of the requirement. For address and document requirements, this should

  • requirement_id (String) (defaults to: nil)

    Unique id for a requirement.



# File 'lib/telnyx/models/update_regulatory_requirement.rb', line 20

Instance Attribute Details

#field_valueString?

The value of the requirement. For address and document requirements, this should be the ID of the resource. For textual, this should be the value of the requirement.

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/update_regulatory_requirement.rb', line 12

optional :field_value, String

#requirement_idString?

Unique id for a requirement.

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/update_regulatory_requirement.rb', line 18

optional :requirement_id, String