Class: Telnyx::Models::UsageReportListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/usage_report_list_params.rb

Overview

Defined Under Namespace

Modules: Format

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dimensions:, metrics:, product:, date_range: nil, end_date: nil, filter: nil, format_: nil, managed_accounts: nil, page_number: nil, page_size: nil, sort: nil, start_date: nil, authorization_bearer: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::UsageReportListParams for more details.

Parameters:

  • dimensions (Array<String>)

    Breakout by specified product dimensions

  • metrics (Array<String>)

    Specified product usage values

  • product (String)

    Telnyx product

  • date_range (String) (defaults to: nil)

    A more user-friendly way to specify the timespan you want to filter by. More opt

  • end_date (String) (defaults to: nil)

    The end date for the time range you are interested in. The maximum time range is

  • filter (String) (defaults to: nil)

    Filter records on dimensions

  • format_ (Symbol, Telnyx::Models::UsageReportListParams::Format) (defaults to: nil)

    Specify the response format (csv or json). JSON is returned by default, even if

  • managed_accounts (Boolean) (defaults to: nil)

    Return the aggregations for all Managed Accounts under the user making the reque

  • page_number (Integer) (defaults to: nil)
  • page_size (Integer) (defaults to: nil)
  • sort (Array<String>) (defaults to: nil)

    Specifies the sort order for results

  • start_date (String) (defaults to: nil)

    The start date for the time range you are interested in. The maximum time range

  • authorization_bearer (String) (defaults to: nil)

    Authenticates the request with your Telnyx API V2 KEY

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/usage_report_list_params.rb', line 91

Instance Attribute Details

#authorization_bearerString?

Authenticates the request with your Telnyx API V2 KEY

Returns:

  • (String, nil)


89
# File 'lib/telnyx/models/usage_report_list_params.rb', line 89

optional :authorization_bearer, String

#date_rangeString?

A more user-friendly way to specify the timespan you want to filter by. More options can be found in the Telnyx API Reference docs.

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/usage_report_list_params.rb', line 33

optional :date_range, String

#dimensionsArray<String>

Breakout by specified product dimensions

Returns:

  • (Array<String>)


14
# File 'lib/telnyx/models/usage_report_list_params.rb', line 14

required :dimensions, Telnyx::Internal::Type::ArrayOf[String]

#end_dateString?

The end date for the time range you are interested in. The maximum time range is 31 days. Format: YYYY-MM-DDTHH:mm:ssZ

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/usage_report_list_params.rb', line 40

optional :end_date, String

#filterString?

Filter records on dimensions

Returns:

  • (String, nil)


46
# File 'lib/telnyx/models/usage_report_list_params.rb', line 46

optional :filter, String

#format_Symbol, ...

Specify the response format (csv or json). JSON is returned by default, even if not specified.



53
# File 'lib/telnyx/models/usage_report_list_params.rb', line 53

optional :format_, enum: -> { Telnyx::UsageReportListParams::Format }

#managed_accountsBoolean?

Return the aggregations for all Managed Accounts under the user making the request.

Returns:

  • (Boolean, nil)


60
# File 'lib/telnyx/models/usage_report_list_params.rb', line 60

optional :managed_accounts, Telnyx::Internal::Type::Boolean

#metricsArray<String>

Specified product usage values

Returns:

  • (Array<String>)


20
# File 'lib/telnyx/models/usage_report_list_params.rb', line 20

required :metrics, Telnyx::Internal::Type::ArrayOf[String]

#page_numberInteger?

Returns:

  • (Integer, nil)


65
# File 'lib/telnyx/models/usage_report_list_params.rb', line 65

optional :page_number, Integer

#page_sizeInteger?

Returns:

  • (Integer, nil)


70
# File 'lib/telnyx/models/usage_report_list_params.rb', line 70

optional :page_size, Integer

#productString

Telnyx product

Returns:

  • (String)


26
# File 'lib/telnyx/models/usage_report_list_params.rb', line 26

required :product, String

#sortArray<String>?

Specifies the sort order for results

Returns:

  • (Array<String>, nil)


76
# File 'lib/telnyx/models/usage_report_list_params.rb', line 76

optional :sort, Telnyx::Internal::Type::ArrayOf[String]

#start_dateString?

The start date for the time range you are interested in. The maximum time range is 31 days. Format: YYYY-MM-DDTHH:mm:ssZ

Returns:

  • (String, nil)


83
# File 'lib/telnyx/models/usage_report_list_params.rb', line 83

optional :start_date, String