Class: Telnyx::Models::UserTagListResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/user_tag_list_response.rb,
sig/telnyx/models/user_tag_list_response.rbs

Overview

See Also:

  • Telnyx::Models::UserTagListResponse#data

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(number_tags: nil, outbound_profile_tags: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::UserTagListResponse::Data for more details.

Parameters:

  • number_tags (Array<String>) (defaults to: nil)

    A list of your tags on the given resource type. NOTE: The casing of the tags ret

  • outbound_profile_tags (Array<String>) (defaults to: nil)

    A list of your tags on the given resource type. NOTE: The casing of the tags ret



# File 'lib/telnyx/models/user_tag_list_response.rb', line 35


Instance Attribute Details

#number_tagsArray<String>?

A list of your tags on the given resource type. NOTE: The casing of the tags returned will not necessarily match the casing of the tags when they were added to a resource. This is because the tags will have the casing of the first time they were used within the Telnyx system regardless of source.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


24
# File 'lib/telnyx/models/user_tag_list_response.rb', line 24

optional :number_tags, Telnyx::Internal::Type::ArrayOf[String]

#outbound_profile_tagsArray<String>?

A list of your tags on the given resource type. NOTE: The casing of the tags returned will not necessarily match the casing of the tags when they were added to a resource. This is because the tags will have the casing of the first time they were used within the Telnyx system regardless of source.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


33
# File 'lib/telnyx/models/user_tag_list_response.rb', line 33

optional :outbound_profile_tags, Telnyx::Internal::Type::ArrayOf[String]

Instance Method Details

#to_hash{

Returns:

  • ({)


34
# File 'sig/telnyx/models/user_tag_list_response.rbs', line 34

def to_hash: -> {