Class: Telnyx::Models::Verification

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/verification.rb

Defined Under Namespace

Modules: RecordType, Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, custom_code: nil, phone_number: nil, record_type: nil, status: nil, timeout_secs: nil, type: nil, updated_at: nil, verify_profile_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Verification for more details.

Parameters:

  • id (String) (defaults to: nil)
  • created_at (String) (defaults to: nil)
  • custom_code (String, nil) (defaults to: nil)

    Send a self-generated numeric code to the end-user

  • phone_number (String) (defaults to: nil)

    +E164 formatted phone number.

  • record_type (Symbol, Telnyx::Models::Verification::RecordType) (defaults to: nil)

    The possible verification record types.

  • status (Symbol, Telnyx::Models::Verification::Status) (defaults to: nil)

    The possible statuses of the verification request.

  • timeout_secs (Integer) (defaults to: nil)

    This is the number of seconds before the code of the request is expired. Once th

  • type (Symbol, Telnyx::Models::Verification::Type) (defaults to: nil)

    The possible types of verification.

  • updated_at (String) (defaults to: nil)
  • verify_profile_id (String) (defaults to: nil)

    The identifier of the associated Verify profile.



# File 'lib/telnyx/models/verification.rb', line 65

Instance Attribute Details

#created_atString?

Returns:

  • (String, nil)


14
# File 'lib/telnyx/models/verification.rb', line 14

optional :created_at, String

#custom_codeString?

Send a self-generated numeric code to the end-user

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/verification.rb', line 20

optional :custom_code, String, nil?: true

#idString?

Returns:

  • (String, nil)


9
# File 'lib/telnyx/models/verification.rb', line 9

optional :id, String

#phone_numberString?

+E164 formatted phone number.

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/verification.rb', line 26

optional :phone_number, String

#record_typeSymbol, ...

The possible verification record types.



32
# File 'lib/telnyx/models/verification.rb', line 32

optional :record_type, enum: -> { Telnyx::Verification::RecordType }

#statusSymbol, ...

The possible statuses of the verification request.

Returns:



38
# File 'lib/telnyx/models/verification.rb', line 38

optional :status, enum: -> { Telnyx::Verification::Status }

#timeout_secsInteger?

This is the number of seconds before the code of the request is expired. Once this request has expired, the code will no longer verify the user. Note: this will override the ‘default_verification_timeout_secs` on the Verify profile.

Returns:

  • (Integer, nil)


46
# File 'lib/telnyx/models/verification.rb', line 46

optional :timeout_secs, Integer

#typeSymbol, ...

The possible types of verification.

Returns:



52
# File 'lib/telnyx/models/verification.rb', line 52

optional :type, enum: -> { Telnyx::Verification::Type }

#updated_atString?

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/verification.rb', line 57

optional :updated_at, String

#verify_profile_idString?

The identifier of the associated Verify profile.

Returns:

  • (String, nil)


63
# File 'lib/telnyx/models/verification.rb', line 63

optional :verify_profile_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/verification.rb', line 97