Class: Telnyx::Models::VerificationTriggerCallParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/verification_trigger_call_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(phone_number:, verify_profile_id:, custom_code: nil, extension: nil, timeout_secs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VerificationTriggerCallParams for more details.

Parameters:

  • phone_number (String)

    +E164 formatted phone number.

  • verify_profile_id (String)

    The identifier of the associated Verify profile.

  • custom_code (String, nil) (defaults to: nil)

    Send a self-generated numeric code to the end-user

  • extension (String, nil) (defaults to: nil)

    Optional extension to dial after call is answered using DTMF digits. Valid digit

  • timeout_secs (Integer) (defaults to: nil)

    The number of seconds the verification code is valid for.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/verification_trigger_call_params.rb', line 41

Instance Attribute Details

#custom_codeString?

Send a self-generated numeric code to the end-user

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/verification_trigger_call_params.rb', line 26

optional :custom_code, String, nil?: true

#extensionString?

Optional extension to dial after call is answered using DTMF digits. Valid digits are 0-9, A-D, *, and #. Pauses can be added using w (0.5s) and W (1s).

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/verification_trigger_call_params.rb', line 33

optional :extension, String, nil?: true

#phone_numberString

+E164 formatted phone number.

Returns:

  • (String)


14
# File 'lib/telnyx/models/verification_trigger_call_params.rb', line 14

required :phone_number, String

#timeout_secsInteger?

The number of seconds the verification code is valid for.

Returns:

  • (Integer, nil)


39
# File 'lib/telnyx/models/verification_trigger_call_params.rb', line 39

optional :timeout_secs, Integer

#verify_profile_idString

The identifier of the associated Verify profile.

Returns:

  • (String)


20
# File 'lib/telnyx/models/verification_trigger_call_params.rb', line 20

required :verify_profile_id, String