Class: Telnyx::Models::VerificationTriggerSMSParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VerificationTriggerSMSParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/verification_trigger_sms_params.rb
Overview
Instance Attribute Summary collapse
-
#custom_code ⇒ String?
Send a self-generated numeric code to the end-user.
-
#phone_number ⇒ String
+E164 formatted phone number.
-
#timeout_secs ⇒ Integer?
The number of seconds the verification code is valid for.
-
#verify_profile_id ⇒ String
The identifier of the associated Verify profile.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(phone_number:, verify_profile_id:, custom_code: nil, timeout_secs: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/telnyx/models/verification_trigger_sms_params.rb', line 34
|
Instance Attribute Details
#custom_code ⇒ String?
Send a self-generated numeric code to the end-user
26 |
# File 'lib/telnyx/models/verification_trigger_sms_params.rb', line 26 optional :custom_code, String, nil?: true |
#phone_number ⇒ String
+E164 formatted phone number.
14 |
# File 'lib/telnyx/models/verification_trigger_sms_params.rb', line 14 required :phone_number, String |
#timeout_secs ⇒ Integer?
The number of seconds the verification code is valid for.
32 |
# File 'lib/telnyx/models/verification_trigger_sms_params.rb', line 32 optional :timeout_secs, Integer |
#verify_profile_id ⇒ String
The identifier of the associated Verify profile.
20 |
# File 'lib/telnyx/models/verification_trigger_sms_params.rb', line 20 required :verify_profile_id, String |