Class: Telnyx::Models::VerifiedNumberCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/verified_number_create_params.rb

Overview

Defined Under Namespace

Modules: VerificationMethod

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(phone_number:, verification_method:, extension: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VerifiedNumberCreateParams for more details.

Parameters:



# File 'lib/telnyx/models/verified_number_create_params.rb', line 31

Instance Attribute Details

#extensionString?

Optional DTMF extension sequence to dial after the call is answered. This parameter enables verification of phone numbers behind IVR systems that require extension dialing. Valid characters: digits 0-9, letters A-D, symbols * and #. Pauses: w = 0.5 second pause, W = 1 second pause. Maximum length: 50 characters. Only works with ‘call’ verification method.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/verified_number_create_params.rb', line 29

optional :extension, String

#phone_numberString

Returns:

  • (String)


13
# File 'lib/telnyx/models/verified_number_create_params.rb', line 13

required :phone_number, String

#verification_methodSymbol, Telnyx::Models::VerifiedNumberCreateParams::VerificationMethod

Verification method.



19
# File 'lib/telnyx/models/verified_number_create_params.rb', line 19

required :verification_method, enum: -> { Telnyx::VerifiedNumberCreateParams::VerificationMethod }