Class: Telnyx::Models::VerifyProfile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/verify_profile.rb

Overview

Defined Under Namespace

Modules: RecordType Classes: Call, Flashcall, Rcs, SMS

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(app_name: nil, code_length: nil, default_verification_timeout_secs: nil, messaging_template_id: nil, sms_fallback: nil, whitelisted_destinations: nil) ⇒ Object

Some parameter documentations has been truncated, see Rcs for more details.

Parameters:

  • app_name (String) (defaults to: nil)

    The name that identifies the application requesting 2fa in the verification mess

  • code_length (Integer) (defaults to: nil)

    The length of the verify code to generate.

  • default_verification_timeout_secs (Integer) (defaults to: nil)

    For every request that is initiated via this Verify profile, this sets the numbe

  • messaging_template_id (String) (defaults to: nil)

    The message template identifier selected from /verify_profiles/templates

  • sms_fallback (Boolean) (defaults to: nil)

    Enable SMS fallback when RCS delivery fails.

  • whitelisted_destinations (Array<String>) (defaults to: nil)

    Enabled country destinations to send verification codes. The elements in the lis



# File 'lib/telnyx/models/verify_profile.rb', line 68

Instance Attribute Details

#callTelnyx::Models::VerifyProfile::Call?



15
# File 'lib/telnyx/models/verify_profile.rb', line 15

optional :call, -> { Telnyx::VerifyProfile::Call }

#created_atString?

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/verify_profile.rb', line 20

optional :created_at, String

#flashcallTelnyx::Models::VerifyProfile::Flashcall?



25
# File 'lib/telnyx/models/verify_profile.rb', line 25

optional :flashcall, -> { Telnyx::VerifyProfile::Flashcall }

#idString?

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/verify_profile.rb', line 10

optional :id, String

#languageString?

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/verify_profile.rb', line 30

optional :language, String

#nameString?

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/verify_profile.rb', line 35

optional :name, String

#rcsTelnyx::Models::VerifyProfile::Rcs?



40
# File 'lib/telnyx/models/verify_profile.rb', line 40

optional :rcs, -> { Telnyx::VerifyProfile::Rcs }

#record_typeSymbol, ...

The possible verification profile record types.



46
# File 'lib/telnyx/models/verify_profile.rb', line 46

optional :record_type, enum: -> { Telnyx::VerifyProfile::RecordType }

#smsTelnyx::Models::VerifyProfile::SMS?



51
# File 'lib/telnyx/models/verify_profile.rb', line 51

optional :sms, -> { Telnyx::VerifyProfile::SMS }

#updated_atString?

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/verify_profile.rb', line 56

optional :updated_at, String

#webhook_failover_urlString?

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/verify_profile.rb', line 61

optional :webhook_failover_url, String

#webhook_urlString?

Returns:

  • (String, nil)


66
# File 'lib/telnyx/models/verify_profile.rb', line 66

optional :webhook_url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/verify_profile.rb', line 242