Class: Telnyx::Models::VerifyProfile::Flashcall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/verify_profile.rb,
sig/telnyx/models/verify_profile.rbs

Overview

See Also:

  • Telnyx::Models::VerifyProfile#flashcall

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



177
# File 'sig/telnyx/models/verify_profile.rbs', line 177

def initialize: (

Instance Attribute Details

#app_nameString?

The name that identifies the application requesting 2fa in the verification message.

Parameters:

  • (String)

Returns:

  • (String, nil)


171
# File 'lib/telnyx/models/verify_profile.rb', line 171

optional :app_name, String

#default_verification_timeout_secsInteger?

For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires. Once the verification request expires, the user cannot use the code to verify their identity.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


180
# File 'lib/telnyx/models/verify_profile.rb', line 180

optional :default_verification_timeout_secs, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


182
# File 'sig/telnyx/models/verify_profile.rbs', line 182

def to_hash: -> {