Class: Telnyx::Models::VerifyProfile::Rcs
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VerifyProfile::Rcs
- Defined in:
- lib/telnyx/models/verify_profile.rb
Overview
Instance Attribute Summary collapse
-
#app_name ⇒ String?
The name that identifies the application requesting 2fa in the verification message.
-
#code_length ⇒ Integer?
The length of the verify code to generate.
-
#default_verification_timeout_secs ⇒ Integer?
For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires.
-
#messaging_template_id ⇒ String?
The message template identifier selected from /verify_profiles/templates.
-
#sms_fallback ⇒ Boolean?
Enable SMS fallback when RCS delivery fails.
-
#whitelisted_destinations ⇒ Array<String>?
Enabled country destinations to send verification codes.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#app_name ⇒ String?
The name that identifies the application requesting 2fa in the verification message.
180 |
# File 'lib/telnyx/models/verify_profile.rb', line 180 optional :app_name, String |
#code_length ⇒ Integer?
The length of the verify code to generate.
186 |
# File 'lib/telnyx/models/verify_profile.rb', line 186 optional :code_length, Integer |
#default_verification_timeout_secs ⇒ Integer?
For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires. Once the verification request expires, the user cannot use the code to verify their identity.
195 |
# File 'lib/telnyx/models/verify_profile.rb', line 195 optional :default_verification_timeout_secs, Integer |
#messaging_template_id ⇒ String?
The message template identifier selected from /verify_profiles/templates
201 |
# File 'lib/telnyx/models/verify_profile.rb', line 201 optional :messaging_template_id, String |
#sms_fallback ⇒ Boolean?
Enable SMS fallback when RCS delivery fails.
207 |
# File 'lib/telnyx/models/verify_profile.rb', line 207 optional :sms_fallback, Telnyx::Internal::Type::Boolean |
#whitelisted_destinations ⇒ Array<String>?
Enabled country destinations to send verification codes. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ‘[“*”]`, all destinations will be allowed.
215 |
# File 'lib/telnyx/models/verify_profile.rb', line 215 optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String] |