Class: Telnyx::Models::VerifyProfile::SMS

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/verify_profile.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(alpha_sender: nil, app_name: nil, code_length: nil, default_verification_timeout_secs: nil, messaging_template_id: nil, whitelisted_destinations: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VerifyProfile::SMS for more details.

Parameters:

  • alpha_sender (String, nil) (defaults to: nil)

    The alphanumeric sender ID to use when sending to destinations that require an a

  • app_name (String) (defaults to: nil)

    The name that identifies the application requesting 2fa in the verification mess

  • code_length (Integer) (defaults to: nil)

    The length of the verify code to generate.

  • default_verification_timeout_secs (Integer) (defaults to: nil)

    For every request that is initiated via this Verify profile, this sets the numbe

  • messaging_template_id (String) (defaults to: nil)

    The message template identifier selected from /verify_profiles/templates

  • whitelisted_destinations (Array<String>) (defaults to: nil)

    Enabled country destinations to send verification codes. The elements in the lis



# File 'lib/telnyx/models/verify_profile.rb', line 291

Instance Attribute Details

#alpha_senderString?

The alphanumeric sender ID to use when sending to destinations that require an alphanumeric sender ID.

Returns:

  • (String, nil)


253
# File 'lib/telnyx/models/verify_profile.rb', line 253

optional :alpha_sender, String, nil?: true

#app_nameString?

The name that identifies the application requesting 2fa in the verification message.

Returns:

  • (String, nil)


260
# File 'lib/telnyx/models/verify_profile.rb', line 260

optional :app_name, String

#code_lengthInteger?

The length of the verify code to generate.

Returns:

  • (Integer, nil)


266
# File 'lib/telnyx/models/verify_profile.rb', line 266

optional :code_length, Integer

#default_verification_timeout_secsInteger?

For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires. Once the verification request expires, the user cannot use the code to verify their identity.

Returns:

  • (Integer, nil)


275
# File 'lib/telnyx/models/verify_profile.rb', line 275

optional :default_verification_timeout_secs, Integer

#messaging_template_idString?

The message template identifier selected from /verify_profiles/templates

Returns:

  • (String, nil)


281
# File 'lib/telnyx/models/verify_profile.rb', line 281

optional :messaging_template_id, String

#whitelisted_destinationsArray<String>?

Enabled country destinations to send verification codes. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ‘[“*”]`, all destinations will be allowed.

Returns:

  • (Array<String>, nil)


289
# File 'lib/telnyx/models/verify_profile.rb', line 289

optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String]