Class: Telnyx::Models::VerifyProfileCreateParams
Overview
Defined Under Namespace
Classes: Call, Flashcall, SMS, Whatsapp
Instance Attribute Summary collapse
#request_options
Instance Method Summary
collapse
dump_request
included
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(alpha_sender: nil, app_name: nil, code_length: nil, default_verification_timeout_secs: nil, messaging_template_id: nil, whitelisted_destinations: nil) ⇒ Object
Some parameter documentations has been truncated, see
SMS for more details.
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 124
|
Instance Attribute Details
18
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 18
optional :call, -> { Telnyx::VerifyProfileCreateParams::Call }
|
#daily_spend_limit ⇒ Float?
The maximum daily spend allowed on this verify profile, in USD.
24
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 24
optional :daily_spend_limit, Float
|
#daily_spend_limit_enabled ⇒ Boolean?
Whether the daily spend limit is enforced for this verify profile.
30
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 30
optional :daily_spend_limit_enabled, Telnyx::Internal::Type::Boolean
|
35
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 35
optional :flashcall, -> { Telnyx::VerifyProfileCreateParams::Flashcall }
|
#language ⇒ String?
40
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 40
optional :language, String
|
#name ⇒ String
13
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 13
required :name, String
|
45
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 45
optional :sms, -> { Telnyx::VerifyProfileCreateParams::SMS }
|
#webhook_failover_url ⇒ String?
50
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 50
optional :webhook_failover_url, String
|
#webhook_url ⇒ String?
55
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 55
optional :webhook_url, String
|
60
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 60
optional :whatsapp, -> { Telnyx::VerifyProfileCreateParams::Whatsapp }
|
Instance Method Details
#to_hash ⇒ {
82
|
# File 'sig/telnyx/models/verify_profile_create_params.rbs', line 82
def to_hash: -> {
|