Class: Telnyx::Models::VerifyProfileCreateParams::Call

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/verify_profile_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, call: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, flashcall: nil, language: nil, sms: nil, webhook_failover_url: nil, webhook_url: nil, whatsapp: nil, request_options: {}) ⇒ Object

Parameters:



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 85

class Call < Telnyx::Internal::Type::BaseModel
  # @!attribute app_name
  #   The name that identifies the application requesting 2fa in the verification
  #   message.
  #
  #   @return [String, nil]
  optional :app_name, String

  # @!attribute code_length
  #   The length of the verify code to generate.
  #
  #   @return [Integer, nil]
  optional :code_length, Integer

  # @!attribute default_verification_timeout_secs
  #   For every request that is initiated via this Verify profile, this sets the
  #   number of seconds before a verification request code expires. Once the
  #   verification request expires, the user cannot use the code to verify their
  #   identity.
  #
  #   @return [Integer, nil]
  optional :default_verification_timeout_secs, Integer

  # @!attribute messaging_template_id
  #   The message template identifier selected from /verify_profiles/templates
  #
  #   @return [String, nil]
  optional :messaging_template_id, String

  # @!attribute whitelisted_destinations
  #   Enabled country destinations to send verification codes. The elements in the
  #   list must be valid ISO 3166-1 alpha-2 country codes. If set to `["*"]`, all
  #   destinations will be allowed. **Conditionally required:** this field must be
  #   provided when your organization is configured to require explicit whitelisted
  #   destinations; otherwise it is optional.
  #
  #   @return [Array<String>, nil]
  optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String]

  # @!method initialize(app_name: nil, code_length: nil, default_verification_timeout_secs: nil, messaging_template_id: nil, whitelisted_destinations: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::VerifyProfileCreateParams::Call} for more details.
  #
  #   @param app_name [String] The name that identifies the application requesting 2fa in the verification mess
  #
  #   @param code_length [Integer] The length of the verify code to generate.
  #
  #   @param default_verification_timeout_secs [Integer] For every request that is initiated via this Verify profile, this sets the numbe
  #
  #   @param messaging_template_id [String] The message template identifier selected from /verify_profiles/templates
  #
  #   @param whitelisted_destinations [Array<String>] Enabled country destinations to send verification codes. The elements in the lis
end

Instance Attribute Details

#app_nameString?

The name that identifies the application requesting 2fa in the verification message.

Returns:

  • (String, nil)


91
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 91

optional :app_name, String

#code_lengthInteger?

The length of the verify code to generate.

Returns:

  • (Integer, nil)


97
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 97

optional :code_length, Integer

#default_verification_timeout_secsInteger?

For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires. Once the verification request expires, the user cannot use the code to verify their identity.

Returns:

  • (Integer, nil)


106
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 106

optional :default_verification_timeout_secs, Integer

#messaging_template_idString?

The message template identifier selected from /verify_profiles/templates

Returns:

  • (String, nil)


112
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 112

optional :messaging_template_id, String

#whitelisted_destinationsArray<String>?

Enabled country destinations to send verification codes. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ‘[“*”]`, all destinations will be allowed. **Conditionally required:** this field must be provided when your organization is configured to require explicit whitelisted destinations; otherwise it is optional.

Returns:

  • (Array<String>, nil)


122
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 122

optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String]