Class: Telnyx::Models::VerifyProfileCreateParams::Whatsapp
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VerifyProfileCreateParams::Whatsapp
- Defined in:
- lib/telnyx/models/verify_profile_create_params.rb
Instance Attribute Summary collapse
-
#default_verification_timeout_secs ⇒ Integer?
For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires.
-
#sender_phone_number ⇒ String?
Phone number registered on the customer WABA to send OTPs from.
-
#template_id ⇒ String?
Customer pre-approved authentication template name registered on Meta.
-
#waba_id ⇒ String?
Customer Meta WABA ID for Bring-Your-Own-WABA sending.
-
#whitelisted_destinations ⇒ Array<String>?
Enabled country destinations to send verification codes.
Instance Method Summary collapse
-
#initialize(default_verification_timeout_secs: nil, sender_phone_number: nil, template_id: nil, waba_id: nil, whitelisted_destinations: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Whatsapp for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(default_verification_timeout_secs: nil, sender_phone_number: nil, template_id: nil, waba_id: nil, whitelisted_destinations: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VerifyProfileCreateParams::Whatsapp for more details.
|
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 322
|
Instance Attribute Details
#default_verification_timeout_secs ⇒ Integer?
For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires. Once the verification request expires, the user cannot use the code to verify their identity.
292 |
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 292 optional :default_verification_timeout_secs, Integer |
#sender_phone_number ⇒ String?
Phone number registered on the customer WABA to send OTPs from
298 |
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 298 optional :sender_phone_number, String, nil?: true |
#template_id ⇒ String?
Customer pre-approved authentication template name registered on Meta
304 |
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 304 optional :template_id, String, nil?: true |
#waba_id ⇒ String?
Customer Meta WABA ID for Bring-Your-Own-WABA sending
310 |
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 310 optional :waba_id, String, nil?: true |
#whitelisted_destinations ⇒ Array<String>?
Enabled country destinations to send verification codes. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ‘[“*”]`, all destinations will be allowed. **Conditionally required:** this field must be provided when your organization is configured to require explicit whitelisted destinations; otherwise it is optional.
320 |
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 320 optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String] |