Class: Telnyx::Models::VerifyProfileUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/verify_profile_update_params.rb

Overview

Defined Under Namespace

Classes: Call, Flashcall, SMS

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(default_verification_timeout_secs: nil, whitelisted_destinations: nil) ⇒ Object

Some parameter documentations has been truncated, see Flashcall for more details.

Parameters:

  • default_verification_timeout_secs (Integer) (defaults to: nil)

    For every request that is initiated via this Verify profile, this sets the numbe

  • whitelisted_destinations (Array<String>) (defaults to: nil)

    Enabled country destinations to send verification codes. The elements in the lis



# File 'lib/telnyx/models/verify_profile_update_params.rb', line 92

Instance Attribute Details

#callTelnyx::Models::VerifyProfileUpdateParams::Call?



13
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 13

optional :call, -> { Telnyx::VerifyProfileUpdateParams::Call }

#flashcallTelnyx::Models::VerifyProfileUpdateParams::Flashcall?



18
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 18

optional :flashcall, -> { Telnyx::VerifyProfileUpdateParams::Flashcall }

#languageString?

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 23

optional :language, String

#nameString?

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 28

optional :name, String

#smsTelnyx::Models::VerifyProfileUpdateParams::SMS?



33
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 33

optional :sms, -> { Telnyx::VerifyProfileUpdateParams::SMS }

#webhook_failover_urlString?

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 38

optional :webhook_failover_url, String

#webhook_urlString?

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 43

optional :webhook_url, String