Class: Telnyx::Models::VerifyProfileUpdateParams::Whatsapp

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/verify_profile_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(default_verification_timeout_secs: nil, sender_phone_number: nil, template_id: nil, waba_id: nil, whitelisted_destinations: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VerifyProfileUpdateParams::Whatsapp for more details.

Parameters:

  • default_verification_timeout_secs (Integer) (defaults to: nil)

    For every request that is initiated via this Verify profile, this sets the numbe

  • sender_phone_number (String, nil) (defaults to: nil)

    Phone number registered on the customer WABA to send OTPs from

  • template_id (String, nil) (defaults to: nil)

    Customer pre-approved authentication template name registered on Meta

  • waba_id (String, nil) (defaults to: nil)

    Customer Meta WABA ID for Bring-Your-Own-WABA sending

  • whitelisted_destinations (Array<String>) (defaults to: nil)

    Enabled country destinations to send verification codes. The elements in the lis



# File 'lib/telnyx/models/verify_profile_update_params.rb', line 328

Instance Attribute Details

#default_verification_timeout_secsInteger?

For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires. Once the verification request expires, the user cannot use the code to verify their identity.

Returns:

  • (Integer, nil)


298
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 298

optional :default_verification_timeout_secs, Integer

#sender_phone_numberString?

Phone number registered on the customer WABA to send OTPs from

Returns:

  • (String, nil)


304
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 304

optional :sender_phone_number, String, nil?: true

#template_idString?

Customer pre-approved authentication template name registered on Meta

Returns:

  • (String, nil)


310
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 310

optional :template_id, String, nil?: true

#waba_idString?

Customer Meta WABA ID for Bring-Your-Own-WABA sending

Returns:

  • (String, nil)


316
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 316

optional :waba_id, String, nil?: true

#whitelisted_destinationsArray<String>?

Enabled country destinations to send verification codes. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ‘[“*”]`, all destinations will be allowed. **Conditionally required:** this field must be provided when your organization is configured to require explicit whitelisted destinations; otherwise it is optional.

Returns:

  • (Array<String>, nil)


326
# File 'lib/telnyx/models/verify_profile_update_params.rb', line 326

optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String]