Class: Telnyx::Models::VideoRegion
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VideoRegion
- Defined in:
- lib/telnyx/models/video_region.rb
Instance Attribute Summary collapse
-
#height ⇒ Integer?
Height of the video region.
-
#max_columns ⇒ Integer?
Maximum number of columns of the region’s placement grid.
-
#max_rows ⇒ Integer?
Maximum number of rows of the region’s placement grid.
-
#video_sources ⇒ Array<String>?
Array of video recording ids to be composed in the region.
-
#width ⇒ Integer?
Width of the video region.
-
#x_pos ⇒ Integer?
X axis value (in pixels) of the region’s upper left corner relative to the upper left corner of the whole room composition viewport.
-
#y_pos ⇒ Integer?
Y axis value (in pixels) of the region’s upper left corner relative to the upper left corner of the whole room composition viewport.
-
#z_pos ⇒ Integer?
Regions with higher z_pos values are stacked on top of regions with lower z_pos values.
Instance Method Summary collapse
-
#initialize(height: nil, max_columns: nil, max_rows: nil, video_sources: nil, width: nil, x_pos: nil, y_pos: nil, z_pos: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see VideoRegion for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(height: nil, max_columns: nil, max_rows: nil, video_sources: nil, width: nil, x_pos: nil, y_pos: nil, z_pos: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VideoRegion for more details.
specify
|
|
# File 'lib/telnyx/models/video_region.rb', line 60
|
Instance Attribute Details
#height ⇒ Integer?
Height of the video region
10 |
# File 'lib/telnyx/models/video_region.rb', line 10 optional :height, Integer |
#max_columns ⇒ Integer?
Maximum number of columns of the region’s placement grid. By default, the region has as many columns as needed to layout all the specified video sources.
17 |
# File 'lib/telnyx/models/video_region.rb', line 17 optional :max_columns, Integer |
#max_rows ⇒ Integer?
Maximum number of rows of the region’s placement grid. By default, the region has as many rows as needed to layout all the specified video sources.
24 |
# File 'lib/telnyx/models/video_region.rb', line 24 optional :max_rows, Integer |
#video_sources ⇒ Array<String>?
Array of video recording ids to be composed in the region. Can be “*” to specify all video recordings in the session
31 |
# File 'lib/telnyx/models/video_region.rb', line 31 optional :video_sources, Telnyx::Internal::Type::ArrayOf[String] |
#width ⇒ Integer?
Width of the video region
37 |
# File 'lib/telnyx/models/video_region.rb', line 37 optional :width, Integer |
#x_pos ⇒ Integer?
X axis value (in pixels) of the region’s upper left corner relative to the upper left corner of the whole room composition viewport.
44 |
# File 'lib/telnyx/models/video_region.rb', line 44 optional :x_pos, Integer |
#y_pos ⇒ Integer?
Y axis value (in pixels) of the region’s upper left corner relative to the upper left corner of the whole room composition viewport.
51 |
# File 'lib/telnyx/models/video_region.rb', line 51 optional :y_pos, Integer |
#z_pos ⇒ Integer?
Regions with higher z_pos values are stacked on top of regions with lower z_pos values
58 |
# File 'lib/telnyx/models/video_region.rb', line 58 optional :z_pos, Integer |