Class: Telnyx::Models::VirtualCrossConnectCombined

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/virtual_cross_connect_combined.rb

Overview

Defined Under Namespace

Modules: CloudProvider Classes: Region

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, bandwidth_mbps: nil, bgp_asn: nil, cloud_provider: nil, cloud_provider_region: nil, created_at: nil, name: nil, network_id: nil, primary_bgp_key: nil, primary_cloud_account_id: nil, primary_cloud_ip: nil, primary_enabled: nil, primary_routing_announcement: nil, primary_telnyx_ip: nil, record_type: nil, region: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VirtualCrossConnectCombined for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • bandwidth_mbps (Float) (defaults to: nil)

    The desired throughput in Megabits per Second (Mbps) for your Virtual Cross Conn

  • bgp_asn (Float) (defaults to: nil)

    The Border Gateway Protocol (BGP) Autonomous System Number (ASN).

  • cloud_provider (Symbol, Telnyx::Models::VirtualCrossConnectCombined::CloudProvider) (defaults to: nil)

    The Virtual Private Cloud with which you would like to establish a cross connect

  • cloud_provider_region (String) (defaults to: nil)

    The region where your Virtual Private Cloud hosts are located.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • primary_bgp_key (String) (defaults to: nil)

    The authentication key for BGP peer configuration.

  • primary_cloud_account_id (String) (defaults to: nil)

    The identifier for your Virtual Private Cloud.

  • primary_cloud_ip (String) (defaults to: nil)

    The IP address assigned for your side of the Virtual Cross Connect.

  • primary_enabled (Boolean) (defaults to: nil)

    Indicates whether the primary circuit is enabled.

  • primary_routing_announcement (Boolean) (defaults to: nil)

    Whether

  • primary_telnyx_ip (String) (defaults to: nil)

    The IP address assigned to the Telnyx side of the Virtual Cross Connect.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • region (Telnyx::Models::VirtualCrossConnectCombined::Region) (defaults to: nil)
  • region_code (String) (defaults to: nil)

    The region interface is deployed to.

  • status (Symbol, Telnyx::Models::InterfaceStatus) (defaults to: nil)

    The current status of the interface deployment.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 124

Instance Attribute Details

#bandwidth_mbpsFloat?

The desired throughput in Megabits per Second (Mbps) for your Virtual Cross Connect.

Returns:

  • (Float, nil)


12
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 12

optional :bandwidth_mbps, Float

#bgp_asnFloat?

The Border Gateway Protocol (BGP) Autonomous System Number (ASN).

Returns:

  • (Float, nil)


18
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 18

optional :bgp_asn, Float

#cloud_providerSymbol, ...

The Virtual Private Cloud with which you would like to establish a cross connect.



25
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 25

optional :cloud_provider, enum: -> { Telnyx::VirtualCrossConnectCombined::CloudProvider }

#cloud_provider_regionString?

The region where your Virtual Private Cloud hosts are located.

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 31

optional :cloud_provider_region, String

#nameString?

A user specified name for the interface.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 37

optional :name, String

#network_idString?

The id of the network associated with the interface.

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 43

optional :network_id, String

#primary_bgp_keyString?

The authentication key for BGP peer configuration.

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 49

optional :primary_bgp_key, String

#primary_cloud_account_idString?

The identifier for your Virtual Private Cloud.

Returns:

  • (String, nil)


55
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 55

optional :primary_cloud_account_id, String

#primary_cloud_ipString?

The IP address assigned for your side of the Virtual Cross Connect.

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 61

optional :primary_cloud_ip, String

#primary_enabledBoolean?

Indicates whether the primary circuit is enabled.

Returns:

  • (Boolean, nil)


67
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 67

optional :primary_enabled, Telnyx::Internal::Type::Boolean

#primary_routing_announcementBoolean?

Whether

Returns:

  • (Boolean, nil)


73
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 73

optional :primary_routing_announcement, Telnyx::Internal::Type::Boolean

#primary_telnyx_ipString?

The IP address assigned to the Telnyx side of the Virtual Cross Connect.

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 79

optional :primary_telnyx_ip, String

#regionTelnyx::Models::VirtualCrossConnectCombined::Region?



84
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 84

optional :region, -> { Telnyx::VirtualCrossConnectCombined::Region }

#region_codeString?

The region interface is deployed to.

Returns:

  • (String, nil)


90
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 90

optional :region_code, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 177