Class: Telnyx::Models::VirtualCrossConnectCreate

Inherits:
Record show all
Defined in:
lib/telnyx/models/virtual_cross_connect_create.rb,
sig/telnyx/models/virtual_cross_connect_create.rbs

Direct Known Subclasses

VirtualCrossConnectCreateParams

Defined Under Namespace

Modules: CloudProvider

Instance Attribute Summary collapse

Attributes inherited from Record

#created_at, #id, #record_type, #updated_at

Instance Method Summary collapse

Methods inherited from Record

#created_at=, #id=, #record_type=, #updated_at=

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(region_code:, name: nil, network_id: nil, status: nil, bandwidth_mbps: nil, bgp_asn: nil, cloud_provider: nil, cloud_provider_region: nil, primary_bgp_key: nil, primary_cloud_account_id: nil, primary_cloud_ip: nil, primary_enabled: nil, primary_telnyx_ip: nil, secondary_bgp_key: nil, secondary_cloud_account_id: nil, secondary_cloud_ip: nil, secondary_enabled: nil, secondary_telnyx_ip: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VirtualCrossConnectCreate for more details.

Parameters:

  • region_code (String)

    The region the interface should be deployed to.

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • status (Symbol, Telnyx::Models::InterfaceStatus) (defaults to: nil)

    The current status of the interface deployment.

  • bandwidth_mbps (Float) (defaults to: nil)

    The desired throughput in Megabits per Second (Mbps) for your Virtual Cross Conn

  • bgp_asn (Float) (defaults to: nil)

    The Border Gateway Protocol (BGP) Autonomous System Number (ASN). If null, value

  • cloud_provider (Symbol, Telnyx::Models::VirtualCrossConnectCreate::CloudProvider) (defaults to: nil)

    The Virtual Private Cloud with which you would like to establish a cross connect

  • cloud_provider_region (String) (defaults to: nil)

    The region where your Virtual Private Cloud hosts are located.

    The av

  • primary_bgp_key (String) (defaults to: nil)

    The authentication key for BGP peer configuration.

  • primary_cloud_account_id (String) (defaults to: nil)

    The identifier for your Virtual Private Cloud. The number will be different base

  • primary_cloud_ip (String) (defaults to: nil)

    The IP address assigned for your side of the Virtual Cross Connect.

    I

  • primary_enabled (Boolean) (defaults to: nil)

    Indicates whether the primary circuit is enabled. Setting this to false will d

  • primary_telnyx_ip (String) (defaults to: nil)

    The IP address assigned to the Telnyx side of the Virtual Cross Connect.
    <b

  • secondary_bgp_key (String) (defaults to: nil)

    The authentication key for BGP peer configuration.

  • secondary_cloud_account_id (String) (defaults to: nil)

    The identifier for your Virtual Private Cloud. The number will be different base

  • secondary_cloud_ip (String) (defaults to: nil)

    The IP address assigned for your side of the Virtual Cross Connect.

    I

  • secondary_enabled (Boolean) (defaults to: nil)

    Indicates whether the secondary circuit is enabled. Setting this to false will

  • secondary_telnyx_ip (String) (defaults to: nil)

    The IP address assigned to the Telnyx side of the Virtual Cross Connect.
    <b



# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 139

Instance Attribute Details

#bandwidth_mbpsFloat?

The desired throughput in Megabits per Second (Mbps) for your Virtual Cross Connect.

The available bandwidths can be found using the /virtual_cross_connect_regions endpoint.

Parameters:

  • _ (Float)

Returns:

  • (Float, nil)


30
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 30

optional :bandwidth_mbps, Float

#bgp_asnFloat?

The Border Gateway Protocol (BGP) Autonomous System Number (ASN). If null, value will be assigned by Telnyx.

Parameters:

  • _ (Float)

Returns:

  • (Float, nil)


37
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 37

optional :bgp_asn, Float

#cloud_providerSymbol, ...

The Virtual Private Cloud with which you would like to establish a cross connect.



44
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 44

optional :cloud_provider, enum: -> { Telnyx::VirtualCrossConnectCreate::CloudProvider }

#cloud_provider_regionString?

The region where your Virtual Private Cloud hosts are located.

The available regions can be found using the /virtual_cross_connect_regions endpoint.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


52
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 52

optional :cloud_provider_region, String

#nameString?

A user specified name for the interface.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 10

optional :name, String

#network_idString?

The id of the network associated with the interface.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 16

optional :network_id, String

#primary_bgp_keyString?

The authentication key for BGP peer configuration.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


58
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 58

optional :primary_bgp_key, String

#primary_cloud_account_idString?

The identifier for your Virtual Private Cloud. The number will be different based upon your Cloud provider.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


65
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 65

optional :primary_cloud_account_id, String

#primary_cloud_ipString?

The IP address assigned for your side of the Virtual Cross Connect.

If none is provided, one will be generated for you.

This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 74

optional :primary_cloud_ip, String

#primary_telnyx_ipString?

The IP address assigned to the Telnyx side of the Virtual Cross Connect.

If none is provided, one will be generated for you.

This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


83
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 83

optional :primary_telnyx_ip, String

#region_codeString

The region the interface should be deployed to.

Parameters:

  • _ (String)

Returns:

  • (String)


22
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 22

required :region_code, String

#secondary_bgp_keyString?

The authentication key for BGP peer configuration.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


89
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 89

optional :secondary_bgp_key, String

#secondary_cloud_account_idString?

The identifier for your Virtual Private Cloud. The number will be different based upon your Cloud provider.

This attribute is only necessary for GCE.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


97
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 97

optional :secondary_cloud_account_id, String

#secondary_cloud_ipString?

The IP address assigned for your side of the Virtual Cross Connect.

If none is provided, one will be generated for you.

This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


106
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 106

optional :secondary_cloud_ip, String

#secondary_telnyx_ipString?

The IP address assigned to the Telnyx side of the Virtual Cross Connect.

If none is provided, one will be generated for you.

This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


115
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 115

optional :secondary_telnyx_ip, String

Instance Method Details

#primary_enabledBoolean?

Returns:

  • (Boolean, nil)


94
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 94

def primary_enabled: -> bool?

#primary_enabled=Boolean

Parameters:

  • _ (Boolean)

Returns:

  • (Boolean)


96
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 96

def primary_enabled=: (bool _) -> bool

#secondary_enabledBoolean?

Returns:

  • (Boolean, nil)


98
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 98

def secondary_enabled: -> bool?

#secondary_enabled=Boolean

Parameters:

  • _ (Boolean)

Returns:

  • (Boolean)


100
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 100

def secondary_enabled=: (bool _) -> bool

#statusTelnyx::Models::interface_status?

Returns:

  • (Telnyx::Models::interface_status, nil)


88
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 88

def status: -> Telnyx::Models::interface_status?

#status=Object



90
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 90

def status=: (

#to_hash{

Returns:

  • ({)


123
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 123

def to_hash: -> {