Class: Telnyx::Models::VirtualCrossConnectCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/virtual_cross_connect_create_params.rb

Overview

Defined Under Namespace

Modules: CloudProvider

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(region_code:, bandwidth_mbps: nil, bgp_asn: nil, cloud_provider: nil, cloud_provider_region: nil, name: nil, network_id: nil, primary_bgp_key: nil, primary_cloud_account_id: nil, primary_cloud_ip: nil, primary_telnyx_ip: nil, secondary_bgp_key: nil, secondary_cloud_account_id: nil, secondary_cloud_ip: nil, secondary_telnyx_ip: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VirtualCrossConnectCreateParams for more details.

Parameters:

  • region_code (String)

    The region the interface should be deployed to.

  • bandwidth_mbps (Float) (defaults to: nil)

    The desired throughput in Megabits per Second (Mbps) for your Virtual Cross Conn

  • bgp_asn (Float) (defaults to: nil)

    The Border Gateway Protocol (BGP) Autonomous System Number (ASN). If null, value

  • cloud_provider (Symbol, Telnyx::Models::VirtualCrossConnectCreateParams::CloudProvider) (defaults to: nil)

    The Virtual Private Cloud with which you would like to establish a cross connect

  • cloud_provider_region (String) (defaults to: nil)

    The region where your Virtual Private Cloud hosts are located.<br /><br />The av

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • primary_bgp_key (String) (defaults to: nil)

    The authentication key for BGP peer configuration.

  • primary_cloud_account_id (String) (defaults to: nil)

    The identifier for your Virtual Private Cloud. The number will be different base

  • primary_cloud_ip (String) (defaults to: nil)

    The IP address assigned for your side of the Virtual Cross Connect.<br /><br />I

  • primary_telnyx_ip (String) (defaults to: nil)

    The IP address assigned to the Telnyx side of the Virtual Cross Connect.<br /><b

  • secondary_bgp_key (String) (defaults to: nil)

    The authentication key for BGP peer configuration.

  • secondary_cloud_account_id (String) (defaults to: nil)

    The identifier for your Virtual Private Cloud. The number will be different base

  • secondary_cloud_ip (String) (defaults to: nil)

    The IP address assigned for your side of the Virtual Cross Connect.<br /><br />I

  • secondary_telnyx_ip (String) (defaults to: nil)

    The IP address assigned to the Telnyx side of the Virtual Cross Connect.<br /><b

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 121

Instance Attribute Details

#bandwidth_mbpsFloat?

The desired throughput in Megabits per Second (Mbps) for your Virtual Cross Connect.<br /><br />The available bandwidths can be found using the /virtual_cross_connect_regions endpoint.

Returns:

  • (Float, nil)


22
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 22

optional :bandwidth_mbps, Float

#bgp_asnFloat?

The Border Gateway Protocol (BGP) Autonomous System Number (ASN). If null, value will be assigned by Telnyx.

Returns:

  • (Float, nil)


29
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 29

optional :bgp_asn, Float

#cloud_providerSymbol, ...

The Virtual Private Cloud with which you would like to establish a cross connect.



36
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 36

optional :cloud_provider, enum: -> { Telnyx::VirtualCrossConnectCreateParams::CloudProvider }

#cloud_provider_regionString?

The region where your Virtual Private Cloud hosts are located.<br /><br />The available regions can be found using the /virtual_cross_connect_regions endpoint.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 44

optional :cloud_provider_region, String

#nameString?

A user specified name for the interface.

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 50

optional :name, String

#network_idString?

The id of the network associated with the interface.

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 56

optional :network_id, String

#primary_bgp_keyString?

The authentication key for BGP peer configuration.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 62

optional :primary_bgp_key, String

#primary_cloud_account_idString?

The identifier for your Virtual Private Cloud. The number will be different based upon your Cloud provider.

Returns:

  • (String, nil)


69
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 69

optional :primary_cloud_account_id, String

#primary_cloud_ipString?

The IP address assigned for your side of the Virtual Cross Connect.<br /><br />If none is provided, one will be generated for you.<br /><br />This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted.

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 78

optional :primary_cloud_ip, String

#primary_telnyx_ipString?

The IP address assigned to the Telnyx side of the Virtual Cross Connect.<br /><br />If none is provided, one will be generated for you.<br /><br />This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted.

Returns:

  • (String, nil)


87
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 87

optional :primary_telnyx_ip, String

#region_codeString

The region the interface should be deployed to.

Returns:

  • (String)


14
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 14

required :region_code, String

#secondary_bgp_keyString?

The authentication key for BGP peer configuration.

Returns:

  • (String, nil)


93
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 93

optional :secondary_bgp_key, String

#secondary_cloud_account_idString?

The identifier for your Virtual Private Cloud. The number will be different based upon your Cloud provider.<br /><br />This attribute is only necessary for GCE.

Returns:

  • (String, nil)


101
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 101

optional :secondary_cloud_account_id, String

#secondary_cloud_ipString?

The IP address assigned for your side of the Virtual Cross Connect.<br /><br />If none is provided, one will be generated for you.<br /><br />This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted.

Returns:

  • (String, nil)


110
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 110

optional :secondary_cloud_ip, String

#secondary_telnyx_ipString?

The IP address assigned to the Telnyx side of the Virtual Cross Connect.<br /><br />If none is provided, one will be generated for you.<br /><br />This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted.

Returns:

  • (String, nil)


119
# File 'lib/telnyx/models/virtual_cross_connect_create_params.rb', line 119

optional :secondary_telnyx_ip, String