Class: Telnyx::Models::VirtualCrossConnectPatch

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/virtual_cross_connect_patch.rb,
sig/telnyx/models/virtual_cross_connect_patch.rbs

Direct Known Subclasses

VirtualCrossConnectUpdateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(primary_cloud_ip: nil, primary_enabled: nil, primary_routing_announcement: nil, secondary_cloud_ip: nil, secondary_enabled: nil, secondary_routing_announcement: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VirtualCrossConnectPatch for more details.

Parameters:

  • primary_cloud_ip (String) (defaults to: nil)

    The IP address assigned for your side of the Virtual Cross Connect.

    I

  • primary_enabled (Boolean) (defaults to: nil)

    Indicates whether the primary circuit is enabled. Setting this to false will d

  • primary_routing_announcement (Boolean) (defaults to: nil)

    Whether the primary BGP route is being announced.

  • secondary_cloud_ip (String) (defaults to: nil)

    The IP address assigned for your side of the Virtual Cross Connect.

    I

  • secondary_enabled (Boolean) (defaults to: nil)

    Indicates whether the secondary circuit is enabled. Setting this to false will

  • secondary_routing_announcement (Boolean) (defaults to: nil)

    Whether the secondary BGP route is being announced.



# File 'lib/telnyx/models/virtual_cross_connect_patch.rb', line 48

Instance Attribute Details

#primary_cloud_ipString?

The IP address assigned for your side of the Virtual Cross Connect.

If none is provided, one will be generated for you.

This value can not be patched once the VXC has bene provisioned.

Parameters:

  • (String)

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/virtual_cross_connect_patch.rb', line 12

optional :primary_cloud_ip, String

#primary_enabledBoolean?

Indicates whether the primary circuit is enabled. Setting this to false will disable the circuit.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


19
# File 'lib/telnyx/models/virtual_cross_connect_patch.rb', line 19

optional :primary_enabled, Telnyx::Internal::Type::Boolean

#primary_routing_announcementBoolean?

Whether the primary BGP route is being announced.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


25
# File 'lib/telnyx/models/virtual_cross_connect_patch.rb', line 25

optional :primary_routing_announcement, Telnyx::Internal::Type::Boolean

#secondary_cloud_ipString?

The IP address assigned for your side of the Virtual Cross Connect.

If none is provided, one will be generated for you.

This value can not be patched once the VXC has bene provisioned.

Parameters:

  • (String)

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/virtual_cross_connect_patch.rb', line 33

optional :secondary_cloud_ip, String

#secondary_enabledBoolean?

Indicates whether the secondary circuit is enabled. Setting this to false will disable the circuit.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


40
# File 'lib/telnyx/models/virtual_cross_connect_patch.rb', line 40

optional :secondary_enabled, Telnyx::Internal::Type::Boolean

#secondary_routing_announcementBoolean?

Whether the secondary BGP route is being announced.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


46
# File 'lib/telnyx/models/virtual_cross_connect_patch.rb', line 46

optional :secondary_routing_announcement, Telnyx::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


47
# File 'sig/telnyx/models/virtual_cross_connect_patch.rbs', line 47

def to_hash: -> {