Class: Telnyx::Models::VirtualCrossConnectUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/virtual_cross_connect_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, primary_cloud_ip: nil, primary_enabled: nil, primary_routing_announcement: nil, secondary_cloud_ip: nil, secondary_enabled: nil, secondary_routing_announcement: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VirtualCrossConnectUpdateParams for more details.

Parameters:

  • id (String)
  • primary_cloud_ip (String) (defaults to: nil)

    The IP address assigned for your side of the Virtual Cross Connect.<br /><br />I

  • primary_enabled (Boolean) (defaults to: nil)

    Indicates whether the primary circuit is enabled. Setting this to ‘false` will d

  • primary_routing_announcement (Boolean) (defaults to: nil)

    Whether the primary BGP route is being announced.

  • secondary_cloud_ip (String) (defaults to: nil)

    The IP address assigned for your side of the Virtual Cross Connect.<br /><br />I

  • secondary_enabled (Boolean) (defaults to: nil)

    Indicates whether the secondary circuit is enabled. Setting this to ‘false` will

  • secondary_routing_announcement (Boolean) (defaults to: nil)

    Whether the secondary BGP route is being announced.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 57

Instance Attribute Details

#idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 13

required :id, String

#primary_cloud_ipString?

The IP address assigned for your side of the Virtual Cross Connect.<br /><br />If none is provided, one will be generated for you.<br /><br />This value can not be patched once the VXC has bene provisioned.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 21

optional :primary_cloud_ip, String

#primary_enabledBoolean?

Indicates whether the primary circuit is enabled. Setting this to ‘false` will disable the circuit.

Returns:

  • (Boolean, nil)


28
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 28

optional :primary_enabled, Telnyx::Internal::Type::Boolean

#primary_routing_announcementBoolean?

Whether the primary BGP route is being announced.

Returns:

  • (Boolean, nil)


34
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 34

optional :primary_routing_announcement, Telnyx::Internal::Type::Boolean

#secondary_cloud_ipString?

The IP address assigned for your side of the Virtual Cross Connect.<br /><br />If none is provided, one will be generated for you.<br /><br />This value can not be patched once the VXC has bene provisioned.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 42

optional :secondary_cloud_ip, String

#secondary_enabledBoolean?

Indicates whether the secondary circuit is enabled. Setting this to ‘false` will disable the circuit.

Returns:

  • (Boolean, nil)


49
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 49

optional :secondary_enabled, Telnyx::Internal::Type::Boolean

#secondary_routing_announcementBoolean?

Whether the secondary BGP route is being announced.

Returns:

  • (Boolean, nil)


55
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 55

optional :secondary_routing_announcement, Telnyx::Internal::Type::Boolean