Class: Telnyx::Models::VirtualCrossConnectsCoverageListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/virtual_cross_connects_coverage_list_response.rb

Overview

Defined Under Namespace

Modules: CloudProvider

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(available_bandwidth: nil, cloud_provider: nil, cloud_provider_region: nil, location: nil, record_type: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VirtualCrossConnectsCoverageListResponse for more details.

Parameters:

  • available_bandwidth (Array<Float>) (defaults to: nil)

    The available throughput in Megabits per Second (Mbps) for your Virtual Cross Co

  • cloud_provider (Symbol, Telnyx::Models::VirtualCrossConnectsCoverageListResponse::CloudProvider) (defaults to: nil)

    The Virtual Private Cloud with which you would like to establish a cross connect

  • cloud_provider_region (String) (defaults to: nil)

    The region where your Virtual Private Cloud hosts are located. Should be identic

  • location (Telnyx::Models::NetappsLocation) (defaults to: nil)
  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.



# File 'lib/telnyx/models/virtual_cross_connects_coverage_list_response.rb', line 43

Instance Attribute Details

#available_bandwidthArray<Float>?

The available throughput in Megabits per Second (Mbps) for your Virtual Cross Connect.

Returns:

  • (Array<Float>, nil)


12
# File 'lib/telnyx/models/virtual_cross_connects_coverage_list_response.rb', line 12

optional :available_bandwidth, Telnyx::Internal::Type::ArrayOf[Float]

#cloud_providerSymbol, ...

The Virtual Private Cloud with which you would like to establish a cross connect.



19
20
# File 'lib/telnyx/models/virtual_cross_connects_coverage_list_response.rb', line 19

optional :cloud_provider,
enum: -> { Telnyx::Models::VirtualCrossConnectsCoverageListResponse::CloudProvider }

#cloud_provider_regionString?

The region where your Virtual Private Cloud hosts are located. Should be identical to how the cloud provider names region, i.e. us-east-1 for AWS but Frankfurt for Azure

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/virtual_cross_connects_coverage_list_response.rb', line 28

optional :cloud_provider_region, String

#locationTelnyx::Models::NetappsLocation?



33
# File 'lib/telnyx/models/virtual_cross_connects_coverage_list_response.rb', line 33

optional :location, -> { Telnyx::NetappsLocation }