Class: Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/voice_clone_create_from_design_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Gender, RecordType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, gender: nil, label: nil, language: nil, name: nil, record_type: nil, source_voice_design_id: nil, source_voice_design_version: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data for more details.

A voice clone object.

Parameters:

  • id (String) (defaults to: nil)

    Unique identifier for the voice clone.

  • created_at (Time) (defaults to: nil)

    Timestamp when the voice clone was created.

  • gender (Symbol, Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data::Gender, nil) (defaults to: nil)

    Gender of the voice clone.

  • label (String, nil) (defaults to: nil)

    Voice style description. If not explicitly set on upload, falls back to the sour

  • language (String, nil) (defaults to: nil)

    ISO 639-1 language code of the voice clone.

  • name (String) (defaults to: nil)

    Name of the voice clone.

  • record_type (Symbol, Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data::RecordType) (defaults to: nil)

    Identifies the resource type.

  • source_voice_design_id (String, nil) (defaults to: nil)

    UUID of the source voice design. ‘null` for upload-based clones.

  • source_voice_design_version (Integer, nil) (defaults to: nil)

    Version of the source voice design used. ‘null` for upload-based clones.

  • updated_at (Time) (defaults to: nil)

    Timestamp when the voice clone was last updated.



# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 83

Instance Attribute Details

#created_atTime?

Timestamp when the voice clone was created.

Returns:

  • (Time, nil)


30
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 30

optional :created_at, Time

#genderSymbol, ...

Gender of the voice clone.



36
37
38
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 36

optional :gender,
enum: -> { Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data::Gender },
nil?: true

#idString?

Unique identifier for the voice clone.

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 24

optional :id, String

#labelString?

Voice style description. If not explicitly set on upload, falls back to the source design’s prompt text.

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 45

optional :label, String, nil?: true

#languageString?

ISO 639-1 language code of the voice clone.

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 51

optional :language, String, nil?: true

#nameString?

Name of the voice clone.

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 57

optional :name, String

#record_typeSymbol, ...

Identifies the resource type.



63
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 63

optional :record_type, enum: -> { Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data::RecordType }

#source_voice_design_idString?

UUID of the source voice design. ‘null` for upload-based clones.

Returns:

  • (String, nil)


69
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 69

optional :source_voice_design_id, String, nil?: true

#source_voice_design_versionInteger?

Version of the source voice design used. ‘null` for upload-based clones.

Returns:

  • (Integer, nil)


75
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 75

optional :source_voice_design_version, Integer, nil?: true

#updated_atTime?

Timestamp when the voice clone was last updated.

Returns:

  • (Time, nil)


81
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 81

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 119