Class: Telnyx::Models::VoiceCloneCreateParams::Params::MinimaxDesignClone
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VoiceCloneCreateParams::Params::MinimaxDesignClone
- Defined in:
- lib/telnyx/models/voice_clone_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#gender ⇒ Symbol, Telnyx::Models::VoiceCloneCreateParams::Params::MinimaxDesignClone::Gender
Gender of the voice clone.
-
#language ⇒ String
ISO 639-1 language code for the clone.
-
#name ⇒ String
Name for the voice clone.
-
#provider ⇒ Symbol, Telnyx::Models::VoiceCloneCreateParams::Params::MinimaxDesignClone::Provider
Voice synthesis provider.
-
#voice_design_id ⇒ String
UUID of the source voice design to clone.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(gender:, language:, name:, provider:, voice_design_id:) ⇒ Object
constructor
Create a voice clone from a voice design using the Minimax provider.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(gender:, language:, name:, provider:, voice_design_id:) ⇒ Object
Create a voice clone from a voice design using the Minimax provider.
|
|
# File 'lib/telnyx/models/voice_clone_create_params.rb', line 141
|
Instance Attribute Details
#gender ⇒ Symbol, Telnyx::Models::VoiceCloneCreateParams::Params::MinimaxDesignClone::Gender
Gender of the voice clone.
115 |
# File 'lib/telnyx/models/voice_clone_create_params.rb', line 115 required :gender, enum: -> { Telnyx::VoiceCloneCreateParams::Params::MinimaxDesignClone::Gender } |
#language ⇒ String
ISO 639-1 language code for the clone. Supports the Minimax language set.
121 |
# File 'lib/telnyx/models/voice_clone_create_params.rb', line 121 required :language, String |
#name ⇒ String
Name for the voice clone.
127 |
# File 'lib/telnyx/models/voice_clone_create_params.rb', line 127 required :name, String |
#provider ⇒ Symbol, Telnyx::Models::VoiceCloneCreateParams::Params::MinimaxDesignClone::Provider
Voice synthesis provider. Must be ‘minimax`.
133 |
# File 'lib/telnyx/models/voice_clone_create_params.rb', line 133 required :provider, enum: -> { Telnyx::VoiceCloneCreateParams::Params::MinimaxDesignClone::Provider } |
#voice_design_id ⇒ String
UUID of the source voice design to clone.
139 |
# File 'lib/telnyx/models/voice_clone_create_params.rb', line 139 required :voice_design_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/voice_clone_create_params.rb', line 164
|