Class: Telnyx::Models::VoiceCloneData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/voice_clone_data.rb

Overview

Defined Under Namespace

Modules: Gender, ModelID, Provider, RecordType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, gender: nil, label: nil, language: nil, model_id: nil, name: nil, provider: nil, provider_supported_models: nil, provider_voice_id: nil, record_type: nil, source_voice_design_id: nil, source_voice_design_version: nil, status: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VoiceCloneData for more details.

A voice clone object.

Parameters:

  • id (String) (defaults to: nil)

    Unique identifier for the voice clone.

  • created_at (Time) (defaults to: nil)

    Timestamp when the voice clone was created.

  • gender (Symbol, Telnyx::Models::VoiceCloneData::Gender, nil) (defaults to: nil)

    Gender of the voice clone.

  • label (String, nil) (defaults to: nil)

    Voice style description. If not explicitly set on upload, falls back to the sour

  • language (String, nil) (defaults to: nil)

    ISO 639-1 language code of the voice clone.

  • model_id (Symbol, Telnyx::Models::VoiceCloneData::ModelID) (defaults to: nil)

    TTS model identifier for the voice clone.

  • name (String) (defaults to: nil)

    Name of the voice clone.

  • provider (Symbol, Telnyx::Models::VoiceCloneData::Provider) (defaults to: nil)

    Voice synthesis provider used for this clone.

  • provider_supported_models (Array<String>) (defaults to: nil)

    List of TTS model identifiers supported by this clone’s provider.

  • provider_voice_id (String, nil) (defaults to: nil)

    Provider-specific voice identifier used for TTS synthesis. May differ from the c

  • record_type (Symbol, Telnyx::Models::VoiceCloneData::RecordType) (defaults to: nil)

    Identifies the resource type.

  • source_voice_design_id (String, nil) (defaults to: nil)

    UUID of the source voice design. ‘null` for upload-based clones.

  • source_voice_design_version (Integer, nil) (defaults to: nil)

    Version of the source voice design used. ‘null` for upload-based clones.

  • status (Symbol, Telnyx::Models::VoiceCloneData::Status) (defaults to: nil)

    Clone status. pending for Ultra clones while on-prem import is in progress, acti

  • updated_at (Time) (defaults to: nil)

    Timestamp when the voice clone was last updated.



# File 'lib/telnyx/models/voice_clone_data.rb', line 100

Instance Attribute Details

#created_atTime?

Timestamp when the voice clone was created.

Returns:

  • (Time, nil)


17
# File 'lib/telnyx/models/voice_clone_data.rb', line 17

optional :created_at, Time

#genderSymbol, ...

Gender of the voice clone.

Returns:



23
# File 'lib/telnyx/models/voice_clone_data.rb', line 23

optional :gender, enum: -> { Telnyx::VoiceCloneData::Gender }, nil?: true

#idString?

Unique identifier for the voice clone.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/voice_clone_data.rb', line 11

optional :id, String

#labelString?

Voice style description. If not explicitly set on upload, falls back to the source design’s prompt text.

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/voice_clone_data.rb', line 30

optional :label, String, nil?: true

#languageString?

ISO 639-1 language code of the voice clone.

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/voice_clone_data.rb', line 36

optional :language, String, nil?: true

#model_idSymbol, ...

TTS model identifier for the voice clone.

Returns:



42
# File 'lib/telnyx/models/voice_clone_data.rb', line 42

optional :model_id, enum: -> { Telnyx::VoiceCloneData::ModelID }

#nameString?

Name of the voice clone.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/voice_clone_data.rb', line 48

optional :name, String

#providerSymbol, ...

Voice synthesis provider used for this clone.



54
# File 'lib/telnyx/models/voice_clone_data.rb', line 54

optional :provider, enum: -> { Telnyx::VoiceCloneData::Provider }

#provider_supported_modelsArray<String>?

List of TTS model identifiers supported by this clone’s provider.

Returns:

  • (Array<String>, nil)


60
# File 'lib/telnyx/models/voice_clone_data.rb', line 60

optional :provider_supported_models, Telnyx::Internal::Type::ArrayOf[String]

#provider_voice_idString?

Provider-specific voice identifier used for TTS synthesis. May differ from the clone UUID depending on the provider and model.

Returns:

  • (String, nil)


67
# File 'lib/telnyx/models/voice_clone_data.rb', line 67

optional :provider_voice_id, String, nil?: true

#record_typeSymbol, ...

Identifies the resource type.



73
# File 'lib/telnyx/models/voice_clone_data.rb', line 73

optional :record_type, enum: -> { Telnyx::VoiceCloneData::RecordType }

#source_voice_design_idString?

UUID of the source voice design. ‘null` for upload-based clones.

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/voice_clone_data.rb', line 79

optional :source_voice_design_id, String, nil?: true

#source_voice_design_versionInteger?

Version of the source voice design used. ‘null` for upload-based clones.

Returns:

  • (Integer, nil)


85
# File 'lib/telnyx/models/voice_clone_data.rb', line 85

optional :source_voice_design_version, Integer, nil?: true

#statusSymbol, ...

Clone status. pending for Ultra clones while on-prem import is in progress, active once ready, failed if verification timed out, expired if not kept alive.

Returns:



92
# File 'lib/telnyx/models/voice_clone_data.rb', line 92

optional :status, enum: -> { Telnyx::VoiceCloneData::Status }

#updated_atTime?

Timestamp when the voice clone was last updated.

Returns:

  • (Time, nil)


98
# File 'lib/telnyx/models/voice_clone_data.rb', line 98

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/voice_clone_data.rb', line 146