Class: Telnyx::Models::VoiceDesignData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/voice_design_data.rb

Defined Under Namespace

Modules: Provider, RecordType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, name: nil, prompt: nil, provider: nil, provider_supported_models: nil, provider_voice_id: nil, record_type: nil, text: nil, updated_at: nil, version: nil, version_created_at: nil, voice_sample_size: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::VoiceDesignData for more details.

A voice design object with full version detail.

Parameters:

  • id (String) (defaults to: nil)

    Unique identifier for the voice design.

  • created_at (Time) (defaults to: nil)

    Timestamp when the voice design was first created.

  • name (String) (defaults to: nil)

    Name of the voice design.

  • prompt (String) (defaults to: nil)

    Natural language prompt used to define the voice style for this version.

  • provider (Symbol, Telnyx::Models::VoiceDesignData::Provider, nil) (defaults to: nil)

    Voice synthesis provider used for this design.

  • provider_supported_models (Array<String>) (defaults to: nil)

    List of TTS model identifiers supported by this design’s provider (e.g. ‘Qwen3TT

  • provider_voice_id (String, nil) (defaults to: nil)

    Provider-specific voice identifier. For Telnyx designs this is the design versio

  • record_type (Symbol, Telnyx::Models::VoiceDesignData::RecordType) (defaults to: nil)

    Identifies the resource type.

  • text (String) (defaults to: nil)

    Sample text used to synthesize this version.

  • updated_at (Time) (defaults to: nil)

    Timestamp when the voice design was last updated.

  • version (Integer) (defaults to: nil)

    Version number of this voice design.

  • version_created_at (Time) (defaults to: nil)

    Timestamp when this specific version was created.

  • voice_sample_size (Integer) (defaults to: nil)

    Size of the voice sample audio in bytes.



# File 'lib/telnyx/models/voice_design_data.rb', line 86

Instance Attribute Details

#created_atTime?

Timestamp when the voice design was first created.

Returns:

  • (Time, nil)


16
# File 'lib/telnyx/models/voice_design_data.rb', line 16

optional :created_at, Time

#idString?

Unique identifier for the voice design.

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/voice_design_data.rb', line 10

optional :id, String

#nameString?

Name of the voice design.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/voice_design_data.rb', line 22

optional :name, String

#promptString?

Natural language prompt used to define the voice style for this version.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/voice_design_data.rb', line 28

optional :prompt, String

#providerSymbol, ...

Voice synthesis provider used for this design.



34
# File 'lib/telnyx/models/voice_design_data.rb', line 34

optional :provider, enum: -> { Telnyx::VoiceDesignData::Provider }, nil?: true

#provider_supported_modelsArray<String>?

List of TTS model identifiers supported by this design’s provider (e.g. ‘Qwen3TTS`, `speech-02-turbo`).

Returns:

  • (Array<String>, nil)


41
# File 'lib/telnyx/models/voice_design_data.rb', line 41

optional :provider_supported_models, Telnyx::Internal::Type::ArrayOf[String]

#provider_voice_idString?

Provider-specific voice identifier. For Telnyx designs this is the design version ID; for Minimax it is the Minimax-assigned voice ID.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/voice_design_data.rb', line 48

optional :provider_voice_id, String, nil?: true

#record_typeSymbol, ...

Identifies the resource type.



54
# File 'lib/telnyx/models/voice_design_data.rb', line 54

optional :record_type, enum: -> { Telnyx::VoiceDesignData::RecordType }

#textString?

Sample text used to synthesize this version.

Returns:

  • (String, nil)


60
# File 'lib/telnyx/models/voice_design_data.rb', line 60

optional :text, String

#updated_atTime?

Timestamp when the voice design was last updated.

Returns:

  • (Time, nil)


66
# File 'lib/telnyx/models/voice_design_data.rb', line 66

optional :updated_at, Time

#versionInteger?

Version number of this voice design.

Returns:

  • (Integer, nil)


72
# File 'lib/telnyx/models/voice_design_data.rb', line 72

optional :version, Integer

#version_created_atTime?

Timestamp when this specific version was created.

Returns:

  • (Time, nil)


78
# File 'lib/telnyx/models/voice_design_data.rb', line 78

optional :version_created_at, Time

#voice_sample_sizeInteger?

Size of the voice sample audio in bytes.

Returns:

  • (Integer, nil)


84
# File 'lib/telnyx/models/voice_design_data.rb', line 84

optional :voice_sample_size, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/voice_design_data.rb', line 127