Module: Telnyx::Models::VoiceSDKCallReport::Logs
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/voice_sdk_call_report.rb,
sig/telnyx/models/voice_sdk_call_report.rbs
Overview
Raw logs payload emitted by the Voice SDK and stored without normalization. Live responses commonly return an array of log entries, but object-shaped log payloads are also allowed for compatibility.
Defined Under Namespace
Classes: Entries
Constant Summary collapse
- VoiceSDKCallReportLogEntryArray =
Telnyx::Internal::Type::ArrayOf[-> { Telnyx::VoiceSDKCallReportLogEntry }]
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(entries: nil) ⇒ Object
Raw logs object emitted by the Voice SDK when logs are grouped under an entries field.
- #self?.variants ⇒ ::Array[Telnyx::Models::VoiceSDKCallReport::logs]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Array<Telnyx::Models::VoiceSDKCallReportLogEntry>, Telnyx::Models::VoiceSDKCallReport::Logs::Entries)
|
|
# File 'lib/telnyx/models/voice_sdk_call_report.rb', line 203
|
Instance Method Details
#initialize(entries: nil) ⇒ Object
Raw logs object emitted by the Voice SDK when logs are grouped under an entries field.
|
|
# File 'lib/telnyx/models/voice_sdk_call_report.rb', line 196
|
#self?.variants ⇒ ::Array[Telnyx::Models::VoiceSDKCallReport::logs]
169 |
# File 'sig/telnyx/models/voice_sdk_call_report.rbs', line 169
def self?.variants: -> ::Array[Telnyx::Models::VoiceSDKCallReport::logs]
|