Module: Telnyx::Models::VoiceSDKCallReportListParams::Sort

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/voice_sdk_call_report_list_params.rb,
sig/telnyx/models/voice_sdk_call_report_list_params.rbs

Overview

Set the order of the results by creation date. asc and created_at sort oldest reports first; desc and -created_at sort newest reports first. If not given, results are sorted by creation date in descending order.

Constant Summary collapse

ASC =

Returns:

  • (:asc)
:asc
DESC =

Returns:

  • (:desc)
:desc
CREATED_AT =

Returns:

  • (:created_at)
:created_at
CREATED_AT_DESC =

Returns:

  • (:"-created_at")
:"-created_at"

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/voice_sdk_call_report_list_params.rb', line 51

Instance Method Details

#self?.values::Array[Telnyx::Models::VoiceSDKCallReportListParams::sort]

Returns:

  • (::Array[Telnyx::Models::VoiceSDKCallReportListParams::sort])


53
# File 'sig/telnyx/models/voice_sdk_call_report_list_params.rbs', line 53

def self?.values: -> ::Array[Telnyx::Models::VoiceSDKCallReportListParams::sort]