Class: Telnyx::Models::VoiceSDKCallReportListResponse::Stats::UnionMember1
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VoiceSDKCallReportListResponse::Stats::UnionMember1
- Defined in:
- lib/telnyx/models/voice_sdk_call_report_list_response.rb
Instance Attribute Summary collapse
-
#audio ⇒ Hash{Symbol=>Object}?
Raw audio stats such as inbound/outbound packet, byte, jitter, packet-loss, bitrate, and audio-level metrics.
-
#connection ⇒ Hash{Symbol=>Object}?
Raw connection stats such as round-trip time, packets, and bytes sent or received.
-
#ice ⇒ Hash{Symbol=>Object}?
Raw ICE candidate-pair information, including selected pair, local/remote candidates, state, and nomination data when provided by the SDK.
-
#transport ⇒ Hash{Symbol=>Object}?
Raw transport stats such as ICE state, DTLS state, SRTP cipher, TLS version, and selected-candidate-pair changes.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#audio ⇒ Hash{Symbol=>Object}?
Raw audio stats such as inbound/outbound packet, byte, jitter, packet-loss, bitrate, and audio-level metrics.
337 |
# File 'lib/telnyx/models/voice_sdk_call_report_list_response.rb', line 337 optional :audio, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#connection ⇒ Hash{Symbol=>Object}?
Raw connection stats such as round-trip time, packets, and bytes sent or received.
344 |
# File 'lib/telnyx/models/voice_sdk_call_report_list_response.rb', line 344 optional :connection, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#ice ⇒ Hash{Symbol=>Object}?
Raw ICE candidate-pair information, including selected pair, local/remote candidates, state, and nomination data when provided by the SDK.
351 |
# File 'lib/telnyx/models/voice_sdk_call_report_list_response.rb', line 351 optional :ice, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#transport ⇒ Hash{Symbol=>Object}?
Raw transport stats such as ICE state, DTLS state, SRTP cipher, TLS version, and selected-candidate-pair changes.
358 |
# File 'lib/telnyx/models/voice_sdk_call_report_list_response.rb', line 358 optional :transport, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |