Module: Telnyx::Models::VoiceSDKCallReportRetrieveResponseItem::Logs

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/voice_sdk_call_report_retrieve_response.rb

Overview

Raw logs payload emitted by the Voice SDK and stored without normalization. Live responses commonly return an array of log entries, but object-shaped log payloads are also allowed for compatibility.

See Also:

Defined Under Namespace

Classes: Entries

Constant Summary collapse

VoiceSDKCallReportLogEntryArray =
Telnyx::Internal::Type::ArrayOf[-> { Telnyx::VoiceSDKCallReportLogEntry }]

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

Instance Method Details

#initialize(entries: nil) ⇒ Object

Raw logs object emitted by the Voice SDK when logs are grouped under an entries field.

Parameters:



# File 'lib/telnyx/models/voice_sdk_call_report_retrieve_response.rb', line 195