Class: Telnyx::Models::WebhookDeliveryListParams::Filter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/webhook_delivery_list_params.rb,
sig/telnyx/models/webhook_delivery_list_params.rbs

Defined Under Namespace

Classes: Attempts, FinishedAt, StartedAt, Status, Webhook

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(gte: nil, lte: nil) ⇒ Object

Some parameter documentations has been truncated, see StartedAt for more details.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/telnyx/models/webhook_delivery_list_params.rb', line 41

class Filter < Telnyx::Internal::Type::BaseModel
  # @!attribute attempts
  #
  #   @return [Telnyx::Models::WebhookDeliveryListParams::Filter::Attempts, nil]
  optional :attempts, -> { Telnyx::WebhookDeliveryListParams::Filter::Attempts }

  # @!attribute event_type
  #   Return only webhook_deliveries matching the given value of `event_type`. Accepts
  #   multiple values separated by a `,`.
  #
  #   @return [String, nil]
  optional :event_type, String

  # @!attribute finished_at
  #
  #   @return [Telnyx::Models::WebhookDeliveryListParams::Filter::FinishedAt, nil]
  optional :finished_at, -> { Telnyx::WebhookDeliveryListParams::Filter::FinishedAt }

  # @!attribute started_at
  #
  #   @return [Telnyx::Models::WebhookDeliveryListParams::Filter::StartedAt, nil]
  optional :started_at, -> { Telnyx::WebhookDeliveryListParams::Filter::StartedAt }

  # @!attribute status
  #
  #   @return [Telnyx::Models::WebhookDeliveryListParams::Filter::Status, nil]
  optional :status, -> { Telnyx::WebhookDeliveryListParams::Filter::Status }

  # @!attribute webhook
  #
  #   @return [Telnyx::Models::WebhookDeliveryListParams::Filter::Webhook, nil]
  optional :webhook, -> { Telnyx::WebhookDeliveryListParams::Filter::Webhook }

  # @!method initialize(attempts: nil, event_type: nil, finished_at: nil, started_at: nil, status: nil, webhook: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::WebhookDeliveryListParams::Filter} for more details.
  #
  #   Consolidated filter parameter (deepObject style). Originally:
  #   filter[status][eq], filter[event_type], filter[webhook][contains],
  #   filter[attempts][contains], filter[started_at][gte], filter[started_at][lte],
  #   filter[finished_at][gte], filter[finished_at][lte]
  #
  #   @param attempts [Telnyx::Models::WebhookDeliveryListParams::Filter::Attempts]
  #
  #   @param event_type [String] Return only webhook_deliveries matching the given value of `event_type`. Accepts
  #
  #   @param finished_at [Telnyx::Models::WebhookDeliveryListParams::Filter::FinishedAt]
  #
  #   @param started_at [Telnyx::Models::WebhookDeliveryListParams::Filter::StartedAt]
  #
  #   @param status [Telnyx::Models::WebhookDeliveryListParams::Filter::Status]
  #
  #   @param webhook [Telnyx::Models::WebhookDeliveryListParams::Filter::Webhook]

  # @see Telnyx::Models::WebhookDeliveryListParams::Filter#attempts
  class Attempts < Telnyx::Internal::Type::BaseModel
    # @!attribute contains
    #   Return only webhook_deliveries whose `attempts` component contains the given
    #   text
    #
    #   @return [String, nil]
    optional :contains, String

    # @!method initialize(contains: nil)
    #   Some parameter documentations has been truncated, see
    #   {Telnyx::Models::WebhookDeliveryListParams::Filter::Attempts} for more details.
    #
    #   @param contains [String] Return only webhook_deliveries whose `attempts` component contains the given tex
  end

  # @see Telnyx::Models::WebhookDeliveryListParams::Filter#finished_at
  class FinishedAt < Telnyx::Internal::Type::BaseModel
    # @!attribute gte
    #   Return only webhook_deliveries whose delivery finished later than or at given
    #   ISO 8601 datetime
    #
    #   @return [String, nil]
    optional :gte, String

    # @!attribute lte
    #   Return only webhook_deliveries whose delivery finished earlier than or at given
    #   ISO 8601 datetime
    #
    #   @return [String, nil]
    optional :lte, String

    # @!method initialize(gte: nil, lte: nil)
    #   Some parameter documentations has been truncated, see
    #   {Telnyx::Models::WebhookDeliveryListParams::Filter::FinishedAt} for more
    #   details.
    #
    #   @param gte [String] Return only webhook_deliveries whose delivery finished later than or at given IS
    #
    #   @param lte [String] Return only webhook_deliveries whose delivery finished earlier than or at given
  end

  # @see Telnyx::Models::WebhookDeliveryListParams::Filter#started_at
  class StartedAt < Telnyx::Internal::Type::BaseModel
    # @!attribute gte
    #   Return only webhook_deliveries whose delivery started later than or at given ISO
    #   8601 datetime
    #
    #   @return [String, nil]
    optional :gte, String

    # @!attribute lte
    #   Return only webhook_deliveries whose delivery started earlier than or at given
    #   ISO 8601 datetime
    #
    #   @return [String, nil]
    optional :lte, String

    # @!method initialize(gte: nil, lte: nil)
    #   Some parameter documentations has been truncated, see
    #   {Telnyx::Models::WebhookDeliveryListParams::Filter::StartedAt} for more details.
    #
    #   @param gte [String] Return only webhook_deliveries whose delivery started later than or at given ISO
    #
    #   @param lte [String] Return only webhook_deliveries whose delivery started earlier than or at given I
  end

  # @see Telnyx::Models::WebhookDeliveryListParams::Filter#status
  class Status < Telnyx::Internal::Type::BaseModel
    # @!attribute eq
    #   Return only webhook_deliveries matching the given `status`
    #
    #   @return [Symbol, Telnyx::Models::WebhookDeliveryListParams::Filter::Status::Eq, nil]
    optional :eq, enum: -> { Telnyx::WebhookDeliveryListParams::Filter::Status::Eq }

    # @!method initialize(eq: nil)
    #   @param eq [Symbol, Telnyx::Models::WebhookDeliveryListParams::Filter::Status::Eq] Return only webhook_deliveries matching the given `status`

    # Return only webhook_deliveries matching the given `status`
    #
    # @see Telnyx::Models::WebhookDeliveryListParams::Filter::Status#eq
    module Eq
      extend Telnyx::Internal::Type::Enum

      DELIVERED = :delivered
      FAILED = :failed

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @see Telnyx::Models::WebhookDeliveryListParams::Filter#webhook
  class Webhook < Telnyx::Internal::Type::BaseModel
    # @!attribute contains
    #   Return only webhook deliveries whose `webhook` component contains the given text
    #
    #   @return [String, nil]
    optional :contains, String

    # @!method initialize(contains: nil)
    #   Some parameter documentations has been truncated, see
    #   {Telnyx::Models::WebhookDeliveryListParams::Filter::Webhook} for more details.
    #
    #   @param contains [String] Return only webhook deliveries whose `webhook` component contains the given text
  end
end

Instance Attribute Details

#attemptsTelnyx::Models::WebhookDeliveryListParams::Filter::Attempts?



45
# File 'lib/telnyx/models/webhook_delivery_list_params.rb', line 45

optional :attempts, -> { Telnyx::WebhookDeliveryListParams::Filter::Attempts }

#event_typeString?

Return only webhook_deliveries matching the given value of event_type. Accepts multiple values separated by a ,.



52
# File 'lib/telnyx/models/webhook_delivery_list_params.rb', line 52

optional :event_type, String

#finished_atTelnyx::Models::WebhookDeliveryListParams::Filter::FinishedAt?



57
# File 'lib/telnyx/models/webhook_delivery_list_params.rb', line 57

optional :finished_at, -> { Telnyx::WebhookDeliveryListParams::Filter::FinishedAt }

#started_atTelnyx::Models::WebhookDeliveryListParams::Filter::StartedAt?



62
# File 'lib/telnyx/models/webhook_delivery_list_params.rb', line 62

optional :started_at, -> { Telnyx::WebhookDeliveryListParams::Filter::StartedAt }

#statusTelnyx::Models::WebhookDeliveryListParams::Filter::Status?



67
# File 'lib/telnyx/models/webhook_delivery_list_params.rb', line 67

optional :status, -> { Telnyx::WebhookDeliveryListParams::Filter::Status }

#webhookTelnyx::Models::WebhookDeliveryListParams::Filter::Webhook?



72
# File 'lib/telnyx/models/webhook_delivery_list_params.rb', line 72

optional :webhook, -> { Telnyx::WebhookDeliveryListParams::Filter::Webhook }

Class Method Details

.valuesArray<Symbol>



# File 'lib/telnyx/models/webhook_delivery_list_params.rb', line 182


Instance Method Details

#to_hash{



97
# File 'sig/telnyx/models/webhook_delivery_list_params.rbs', line 97

def to_hash: -> {