Class: Telnyx::Models::WebhookDeliveryListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/webhook_delivery_list_response.rb

Overview

Defined Under Namespace

Modules: Status Classes: Webhook

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, attempts: nil, finished_at: nil, record_type: nil, started_at: nil, status: nil, user_id: nil, webhook: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::WebhookDeliveryListResponse for more details.

Record of all attempts to deliver a webhook.

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the webhook_delivery record.

  • attempts (Array<Telnyx::Models::Attempt>) (defaults to: nil)

    Detailed delivery attempts, ordered by most recent.

  • finished_at (Time) (defaults to: nil)

    ISO 8601 timestamp indicating when the last webhook response has been received.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • started_at (Time) (defaults to: nil)

    ISO 8601 timestamp indicating when the first request attempt was initiated.

  • status (Symbol, Telnyx::Models::WebhookDeliveryListResponse::Status) (defaults to: nil)

    Delivery status: ‘delivered’ when successfuly delivered or ‘failed’ if all attem

  • user_id (String) (defaults to: nil)

    Uniquely identifies the user that owns the webhook_delivery record.

  • webhook (Telnyx::Models::WebhookDeliveryListResponse::Webhook) (defaults to: nil)

    Original webhook JSON data. Payload fields vary according to event type.



# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 56

Instance Attribute Details

#attemptsArray<Telnyx::Models::Attempt>?

Detailed delivery attempts, ordered by most recent.

Returns:



17
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 17

optional :attempts, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Attempt] }

#finished_atTime?

ISO 8601 timestamp indicating when the last webhook response has been received.

Returns:

  • (Time, nil)


23
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 23

optional :finished_at, Time

#idString?

Uniquely identifies the webhook_delivery record.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 11

optional :id, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 29

optional :record_type, String

#started_atTime?

ISO 8601 timestamp indicating when the first request attempt was initiated.

Returns:

  • (Time, nil)


35
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 35

optional :started_at, Time

#statusSymbol, ...

Delivery status: ‘delivered’ when successfuly delivered or ‘failed’ if all attempts have failed.



42
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 42

optional :status, enum: -> { Telnyx::Models::WebhookDeliveryListResponse::Status }

#user_idString?

Uniquely identifies the user that owns the webhook_delivery record.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 48

optional :user_id, String

#webhookTelnyx::Models::WebhookDeliveryListResponse::Webhook?

Original webhook JSON data. Payload fields vary according to event type.



54
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 54

optional :webhook, -> { Telnyx::Models::WebhookDeliveryListResponse::Webhook }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 88