Class: Telnyx::Models::WebhookDeliveryRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::WebhookDeliveryRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/webhook_delivery_retrieve_response.rb
Overview
Defined Under Namespace
Modules: Status Classes: Webhook
Instance Attribute Summary collapse
-
#attempts ⇒ Array<Telnyx::Models::Attempt>?
Detailed delivery attempts, ordered by most recent.
-
#finished_at ⇒ Time?
ISO 8601 timestamp indicating when the last webhook response has been received.
-
#id ⇒ String?
Uniquely identifies the webhook_delivery record.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#started_at ⇒ Time?
ISO 8601 timestamp indicating when the first request attempt was initiated.
-
#status ⇒ Symbol, ...
Delivery status: ‘delivered’ when successfuly delivered or ‘failed’ if all attempts have failed.
-
#user_id ⇒ String?
Uniquely identifies the user that owns the webhook_delivery record.
-
#webhook ⇒ Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Webhook?
Original webhook JSON data.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, attempts: nil, finished_at: nil, record_type: nil, started_at: nil, status: nil, user_id: nil, webhook: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, attempts: nil, finished_at: nil, record_type: nil, started_at: nil, status: nil, user_id: nil, webhook: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::WebhookDeliveryRetrieveResponse::Data for more details.
Record of all attempts to deliver a webhook.
|
|
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 67
|
Instance Attribute Details
#attempts ⇒ Array<Telnyx::Models::Attempt>?
Detailed delivery attempts, ordered by most recent.
28 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 28 optional :attempts, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Attempt] } |
#finished_at ⇒ Time?
ISO 8601 timestamp indicating when the last webhook response has been received.
34 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 34 optional :finished_at, Time |
#id ⇒ String?
Uniquely identifies the webhook_delivery record.
22 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 22 optional :id, String |
#record_type ⇒ String?
Identifies the type of the resource.
40 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 40 optional :record_type, String |
#started_at ⇒ Time?
ISO 8601 timestamp indicating when the first request attempt was initiated.
46 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 46 optional :started_at, Time |
#status ⇒ Symbol, ...
Delivery status: ‘delivered’ when successfuly delivered or ‘failed’ if all attempts have failed.
53 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 53 optional :status, enum: -> { Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Status } |
#user_id ⇒ String?
Uniquely identifies the user that owns the webhook_delivery record.
59 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 59 optional :user_id, String |
#webhook ⇒ Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Webhook?
Original webhook JSON data. Payload fields vary according to event type.
65 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 65 optional :webhook, -> { Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Webhook } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 99
|