Class: Telnyx::Models::Whatsapp::BusinessAccountListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/whatsapp/business_account_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, account_review_status: nil, business_verification_status: nil, country: nil, created_at: nil, name: nil, phone_numbers_count: nil, record_type: nil, status: nil, waba_id: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Internal ID of Whatsapp business account

  • account_review_status (String) (defaults to: nil)

    Account review status of Whatsapp business account

  • business_verification_status (String) (defaults to: nil)

    Business verification status of Whatsapp business account

  • country (String) (defaults to: nil)

    Country associated with Whatsapp business account

  • created_at (Time) (defaults to: nil)
  • name (String) (defaults to: nil)

    Name of Whatsapp business account

  • phone_numbers_count (Integer) (defaults to: nil)

    Count of phone numbers associated with Whatsapp business account

  • record_type (String) (defaults to: nil)
  • status (String) (defaults to: nil)

    Status of Whatsapp business account

  • waba_id (String) (defaults to: nil)

    WABA ID of Whatsapp business account



# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 66

Instance Attribute Details

#account_review_statusString?

Account review status of Whatsapp business account

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 18

optional :account_review_status, String

#business_verification_statusString?

Business verification status of Whatsapp business account

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 24

optional :business_verification_status, String

#countryString?

Country associated with Whatsapp business account

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 30

optional :country, String

#created_atTime?

Returns:

  • (Time, nil)


35
# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 35

optional :created_at, Time

#idString?

Internal ID of Whatsapp business account

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 12

optional :id, String

#nameString?

Name of Whatsapp business account

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 41

optional :name, String

#phone_numbers_countInteger?

Count of phone numbers associated with Whatsapp business account

Returns:

  • (Integer, nil)


47
# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 47

optional :phone_numbers_count, Integer

#record_typeString?

Returns:

  • (String, nil)


52
# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 52

optional :record_type, String

#statusString?

Status of Whatsapp business account

Returns:

  • (String, nil)


58
# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 58

optional :status, String

#waba_idString?

WABA ID of Whatsapp business account

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/whatsapp/business_account_list_response.rb', line 64

optional :waba_id, String