Class: Telnyx::Models::Whatsapp::PhoneNumberRetrieveConversationWindowResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/whatsapp/phone_number_retrieve_conversation_window_response.rb,
sig/telnyx/models/whatsapp/phone_number_retrieve_conversation_window_response.rbs

Overview

See Also:

  • Telnyx::Models::Whatsapp::PhoneNumberRetrieveConversationWindowResponse#data

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(last_user_message_at: nil, window_active: nil, window_expires_at: nil, window_type: nil) ⇒ Object

Parameters:

  • last_user_message_at (Time) (defaults to: nil)

    Timestamp of the last inbound message that opened the window

  • window_active (Boolean) (defaults to: nil)

    Whether the 24-hour conversation window is currently open

  • window_expires_at (Time) (defaults to: nil)

    When the window closes. Null if no active window.

  • window_type (String) (defaults to: nil)

    Window type. Currently always 24h when present.



# File 'lib/telnyx/models/whatsapp/phone_number_retrieve_conversation_window_response.rb', line 42

Instance Attribute Details

#last_user_message_atTime?

Timestamp of the last inbound message that opened the window

Parameters:

  • (Time)

Returns:

  • (Time, nil)


22
# File 'lib/telnyx/models/whatsapp/phone_number_retrieve_conversation_window_response.rb', line 22

optional :last_user_message_at, Time

#window_activeBoolean?

Whether the 24-hour conversation window is currently open

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


28
# File 'lib/telnyx/models/whatsapp/phone_number_retrieve_conversation_window_response.rb', line 28

optional :window_active, Telnyx::Internal::Type::Boolean

#window_expires_atTime?

When the window closes. Null if no active window.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


34
# File 'lib/telnyx/models/whatsapp/phone_number_retrieve_conversation_window_response.rb', line 34

optional :window_expires_at, Time

#window_typeString?

Window type. Currently always 24h when present.

Parameters:

  • (String)

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/whatsapp/phone_number_retrieve_conversation_window_response.rb', line 40

optional :window_type, String

Instance Method Details

#to_hash{

Returns:

  • ({)


56
# File 'sig/telnyx/models/whatsapp/phone_number_retrieve_conversation_window_response.rbs', line 56

def to_hash: -> {