Class: Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Header
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Header
- Defined in:
- lib/telnyx/models/whatsapp/template_create_params.rb
Defined Under Namespace
Modules: Format Classes: Example
Instance Attribute Summary collapse
-
#example ⇒ Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Header::Example?
Sample values for header variables.
-
#file_format ⇒ Symbol, Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Header::Format
Header format type: TEXT (supports one variable), IMAGE, VIDEO, DOCUMENT, or LOCATION.
-
#text ⇒ String?
Header text.
- #type ⇒ Symbol, :HEADER
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(file_format:, example: nil, text: nil, type: :HEADER) ⇒ Object
constructor
Some parameter documentations has been truncated, see Header for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_format:, example: nil, text: nil, type: :HEADER) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Header for more details.
Optional header displayed at the top of the message.
|
|
# File 'lib/telnyx/models/whatsapp/template_create_params.rb', line 122
|
Instance Attribute Details
#example ⇒ Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Header::Example?
Sample values for header variables.
113 |
# File 'lib/telnyx/models/whatsapp/template_create_params.rb', line 113 optional :example, -> { Telnyx::Whatsapp::TemplateCreateParams::Component::Header::Example } |
#file_format ⇒ Symbol, Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Header::Format
Header format type: TEXT (supports one variable), IMAGE, VIDEO, DOCUMENT, or LOCATION.
100 101 102 |
# File 'lib/telnyx/models/whatsapp/template_create_params.rb', line 100 required :file_format, enum: -> { Telnyx::Whatsapp::TemplateCreateParams::Component::Header::Format }, api_name: :format |
#text ⇒ String?
Header text. Required when format is TEXT. Supports one variable ({1}). Variables cannot be at the start or end.
120 |
# File 'lib/telnyx/models/whatsapp/template_create_params.rb', line 120 optional :text, String |
#type ⇒ Symbol, :HEADER
107 |
# File 'lib/telnyx/models/whatsapp/template_create_params.rb', line 107 required :type, const: :HEADER |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/whatsapp/template_create_params.rb', line 150
|