Class: Telnyx::Models::WhatsappMessageContent::Template
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::WhatsappMessageContent::Template
- Defined in:
- lib/telnyx/models/whatsapp_message_content.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#components ⇒ Array<Telnyx::Models::WhatsappMessageContent::Template::Component>?
Template parameter values for header, body, and button components.
-
#language ⇒ Telnyx::Models::WhatsappMessageContent::Template::Language?
Template language.
-
#name ⇒ String?
Template name as registered with Meta.
-
#template_id ⇒ String?
Telnyx template ID (the id field from template list/get responses).
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#components ⇒ Array<Telnyx::Models::WhatsappMessageContent::Template::Component>?
Template parameter values for header, body, and button components.
111 112 |
# File 'lib/telnyx/models/whatsapp_message_content.rb', line 111 optional :components, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::WhatsappMessageContent::Template::Component] } |
#language ⇒ Telnyx::Models::WhatsappMessageContent::Template::Language?
Template language. Required unless template_id is provided.
118 |
# File 'lib/telnyx/models/whatsapp_message_content.rb', line 118 optional :language, -> { Telnyx::WhatsappMessageContent::Template::Language } |
#name ⇒ String?
Template name as registered with Meta. Required unless template_id is provided.
124 |
# File 'lib/telnyx/models/whatsapp_message_content.rb', line 124 optional :name, String |
#template_id ⇒ String?
Telnyx template ID (the id field from template list/get responses). When provided, name and language are resolved automatically.
131 |
# File 'lib/telnyx/models/whatsapp_message_content.rb', line 131 optional :template_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/whatsapp_message_content.rb', line 230
|