Class: Telnyx::Models::WhatsappMessageTemplateUpdateParams::Component::Carousel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::WhatsappMessageTemplateUpdateParams::Component::Carousel
- Defined in:
- lib/telnyx/models/whatsapp_message_template_update_params.rb
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#cards ⇒ Array<Telnyx::Models::WhatsappMessageTemplateUpdateParams::Component::Carousel::Card>
Array of card objects, each with its own components.
- #type ⇒ Symbol, :CAROUSEL
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#cards ⇒ Array<Telnyx::Models::WhatsappMessageTemplateUpdateParams::Component::Carousel::Card>
Array of card objects, each with its own components.
413 414 |
# File 'lib/telnyx/models/whatsapp_message_template_update_params.rb', line 413 required :cards, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::WhatsappMessageTemplateUpdateParams::Component::Carousel::Card] } |
#type ⇒ Symbol, :CAROUSEL
419 |
# File 'lib/telnyx/models/whatsapp_message_template_update_params.rb', line 419 required :type, const: :CAROUSEL |