Class: Telnyx::Models::WireguardInterface

Inherits:
Record show all
Defined in:
lib/telnyx/models/wireguard_interface.rb,
sig/telnyx/models/wireguard_interface.rbs

Instance Attribute Summary collapse

Attributes inherited from Record

#created_at, #id, #record_type, #updated_at

Instance Method Summary collapse

Methods inherited from Record

#created_at=, #id=, #record_type=, #updated_at=

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil, network_id: nil, enable_sip_trunking: nil) ⇒ Object

Parameters:

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • enable_sip_trunking (Boolean) (defaults to: nil)

    Enable SIP traffic forwarding over VPN interface.



# File 'lib/telnyx/models/wireguard_interface.rb', line 24

Instance Attribute Details

#enable_sip_trunkingBoolean?

Enable SIP traffic forwarding over VPN interface.

Parameters:

  • _ (Boolean)

Returns:

  • (Boolean, nil)


22
# File 'lib/telnyx/models/wireguard_interface.rb', line 22

optional :enable_sip_trunking, Telnyx::Internal::Type::Boolean

#nameString?

A user specified name for the interface.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/wireguard_interface.rb', line 10

optional :name, String

#network_idString?

The id of the network associated with the interface.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/wireguard_interface.rb', line 16

optional :network_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


32
# File 'sig/telnyx/models/wireguard_interface.rbs', line 32

def to_hash: -> {