Class: Telnyx::Models::WireguardInterfaceCreateParams::Body

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/wireguard_interface_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil, network_id: nil, enable_sip_trunking: nil, region_code: nil) ⇒ Object

Parameters:

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • enable_sip_trunking (Boolean) (defaults to: nil)

    Enable SIP traffic forwarding over VPN interface.

  • region_code (String) (defaults to: nil)

    The region the interface should be deployed to.



19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/telnyx/models/wireguard_interface_create_params.rb', line 19

class Body < Telnyx::Internal::Type::BaseModel
  # @!attribute name
  #   A user specified name for the interface.
  #
  #   @return [String, nil]
  optional :name, String

  # @!attribute network_id
  #   The id of the network associated with the interface.
  #
  #   @return [String, nil]
  optional :network_id, String

  # @!attribute enable_sip_trunking
  #   Enable SIP traffic forwarding over VPN interface.
  #
  #   @return [Boolean, nil]
  optional :enable_sip_trunking, Telnyx::Internal::Type::Boolean

  # @!attribute region_code
  #   The region the interface should be deployed to.
  #
  #   @return [String, nil]
  optional :region_code, String

  # @!method initialize(name: nil, network_id: nil, enable_sip_trunking: nil, region_code: nil)
  #   @param name [String] A user specified name for the interface.
  #
  #   @param network_id [String] The id of the network associated with the interface.
  #
  #   @param enable_sip_trunking [Boolean] Enable SIP traffic forwarding over VPN interface.
  #
  #   @param region_code [String] The region the interface should be deployed to.
end

Instance Attribute Details

#enable_sip_trunkingBoolean?

Enable SIP traffic forwarding over VPN interface.

Returns:

  • (Boolean, nil)


36
# File 'lib/telnyx/models/wireguard_interface_create_params.rb', line 36

optional :enable_sip_trunking, Telnyx::Internal::Type::Boolean

#nameString?

A user specified name for the interface.

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/wireguard_interface_create_params.rb', line 24

optional :name, String

#network_idString?

The id of the network associated with the interface.

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/wireguard_interface_create_params.rb', line 30

optional :network_id, String

#region_codeString?

The region the interface should be deployed to.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/wireguard_interface_create_params.rb', line 42

optional :region_code, String