Class: Telnyx::Models::WireguardInterfaceRead

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/wireguard_interface_read.rb,
sig/telnyx/models/wireguard_interface_read.rbs

Overview

See Also:

  • Telnyx::Resources::WireguardInterfaces#list

Defined Under Namespace

Classes: Region

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, enable_sip_trunking: nil, endpoint: nil, name: nil, network_id: nil, public_key: nil, record_type: nil, region: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • enable_sip_trunking (Boolean) (defaults to: nil)

    Enable SIP traffic forwarding over VPN interface.

  • endpoint (String) (defaults to: nil)

    The Telnyx WireGuard peers Peer.endpoint value.

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • public_key (String) (defaults to: nil)

    The Telnyx WireGuard peers Peer.PublicKey.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • region (Telnyx::Models::WireguardInterfaceRead::Region) (defaults to: nil)
  • region_code (String) (defaults to: nil)

    The region interface is deployed to.

  • status (Symbol, Telnyx::Models::InterfaceStatus) (defaults to: nil)

    The current status of the interface deployment.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/wireguard_interface_read.rb', line 80

Instance Attribute Details

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


46
47
48
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 46

def created_at
  @created_at
end

#enable_sip_trunkingBoolean?

Enable SIP traffic forwarding over VPN interface.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


11
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 11

optional :enable_sip_trunking, Telnyx::Internal::Type::Boolean

#endpointString? (readonly)

Returns the value of attribute endpoint.

Returns:

  • (String, nil)


50
51
52
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 50

def endpoint
  @endpoint
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


42
43
44
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 42

def id
  @id
end

#nameString?

A user specified name for the interface.

Parameters:

  • (String)

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 17

optional :name, String

#network_idString?

The id of the network associated with the interface.

Parameters:

  • (String)

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 23

optional :network_id, String

#public_keyString? (readonly)

Returns the value of attribute public_key.

Returns:

  • (String, nil)


54
55
56
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 54

def public_key
  @public_key
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


58
59
60
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 58

def record_type
  @record_type
end

#regionTelnyx::Models::WireguardInterfaceRead::Region?



28
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 28

optional :region, -> { Telnyx::WireguardInterfaceRead::Region }

#region_codeString?

The region interface is deployed to.

Parameters:

  • (String)

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 34

optional :region_code, String

#statusTelnyx::Models::interface_status? (readonly)

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::interface_status, nil)


62
63
64
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 62

def status
  @status
end

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


68
69
70
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 68

def updated_at
  @updated_at
end

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


48
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 48

def created_at=: (String) -> String

#endpoint=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


52
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 52

def endpoint=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


44
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 44

def id=: (String) -> String

#public_key=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


56
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 56

def public_key=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


60
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 60

def record_type=: (String) -> String

#status=Object (readonly)



64
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 64

def status=: (

#to_hash{

Returns:

  • ({)


87
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 87

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


70
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 70

def updated_at=: (String) -> String