Class: Telnyx::Models::WireguardPeerListResponse

Inherits:
Record show all
Defined in:
lib/telnyx/models/wireguard_peer_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(last_seen: nil, private_key: nil, wireguard_interface_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::WireguardPeerListResponse for more details.

Parameters:

  • last_seen (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when peer sent traffic last time.

  • private_key (String) (defaults to: nil)

    Your WireGuard ‘Interface.PrivateKey`.<br /><br />This attribute is only ever ut

  • wireguard_interface_id (String) (defaults to: nil)

    The id of the wireguard interface associated with the peer.



# File 'lib/telnyx/models/wireguard_peer_list_response.rb', line 31

Instance Attribute Details

#wireguard_interface_idString?

The id of the wireguard interface associated with the peer.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/wireguard_peer_list_response.rb', line 11

optional :wireguard_interface_id, String