Class: Telnyx::Models::Wireless::WdrReport

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/wireless/wdr_report.rb,
sig/telnyx/models/wireless/wdr_report.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, end_time: nil, record_type: nil, report_url: nil, start_time: nil, status: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • end_time (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating the end time.

  • record_type (String) (defaults to: nil)
  • report_url (String) (defaults to: nil)

    The URL where the report content, when generated, will be published to.

  • start_time (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating the start time.

  • status (Symbol, Telnyx::Models::Wireless::WdrReport::Status) (defaults to: nil)

    Indicates the status of the report, which is updated asynchronously.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/wireless/wdr_report.rb', line 56

Instance Attribute Details

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


39
40
41
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 39

def created_at
  @created_at
end

#end_timeString?

ISO 8601 formatted date-time indicating the end time.

Parameters:

  • (String)

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 11

optional :end_time, String

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


35
36
37
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 35

def id
  @id
end

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


43
44
45
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 43

def record_type
  @record_type
end

#report_urlString?

The URL where the report content, when generated, will be published to.

Parameters:

  • (String)

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 17

optional :report_url, String

#start_timeString?

ISO 8601 formatted date-time indicating the start time.

Parameters:

  • (String)

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 23

optional :start_time, String

#statusSymbol, ...

Indicates the status of the report, which is updated asynchronously.



29
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 29

optional :status, enum: -> { Telnyx::Wireless::WdrReport::Status }

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


47
48
49
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 47

def updated_at
  @updated_at
end

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


41
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 41

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


37
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 37

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


45
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 45

def record_type=: (String) -> String

#to_hash{

Returns:

  • ({)


62
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 62

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


49
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 49

def updated_at=: (String) -> String