Class: Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data
- Defined in:
- lib/telnyx/models/x402/credit_account_create_quote_response.rb
Overview
Defined Under Namespace
Modules: RecordType Classes: PaymentRequirements
Instance Attribute Summary collapse
-
#amount_crypto ⇒ String?
The equivalent amount in the payment cryptocurrency’s smallest unit (e.g. USDC has 6 decimals, so $50.00 = “50000000”).
-
#amount_usd ⇒ String?
The quoted amount in USD.
-
#expires_at ⇒ Time?
ISO 8601 timestamp when the quote expires.
-
#id ⇒ String?
Unique quote identifier.
-
#network ⇒ String?
The blockchain network for the payment in CAIP-2 format (e.g. eip155:8453 for Base).
-
#payment_requirements ⇒ Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements?
x402 protocol v2 payment requirements.
- #record_type ⇒ Symbol, ...
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, amount_crypto: nil, amount_usd: nil, expires_at: nil, network: nil, payment_requirements: nil, record_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, amount_crypto: nil, amount_usd: nil, expires_at: nil, network: nil, payment_requirements: nil, record_type: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data for more details.
|
|
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 64
|
Instance Attribute Details
#amount_crypto ⇒ String?
The equivalent amount in the payment cryptocurrency’s smallest unit (e.g. USDC has 6 decimals, so $50.00 = “50000000”).
29 |
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 29 optional :amount_crypto, String |
#amount_usd ⇒ String?
The quoted amount in USD.
35 |
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 35 optional :amount_usd, String |
#expires_at ⇒ Time?
ISO 8601 timestamp when the quote expires.
41 |
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 41 optional :expires_at, Time |
#id ⇒ String?
Unique quote identifier. Use this to settle the payment.
22 |
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 22 optional :id, String |
#network ⇒ String?
The blockchain network for the payment in CAIP-2 format (e.g. eip155:8453 for Base).
48 |
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 48 optional :network, String |
#payment_requirements ⇒ Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements?
x402 protocol v2 payment requirements. Contains all information needed to construct and sign a payment authorization.
55 56 |
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 55 optional :payment_requirements, -> { Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements } |
#record_type ⇒ Symbol, ...
61 62 |
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 61 optional :record_type, enum: -> { Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::RecordType } |
Class Method Details
.values ⇒ Array<Integer>
|
|
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 256
|