Class: Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements::Accept

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/x402/credit_account_create_quote_response.rb

Defined Under Namespace

Classes: Extra

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount: nil, asset: nil, extra: nil, max_timeout_seconds: nil, network: nil, pay_to: nil, scheme: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements::Accept for more details.

Parameters:

  • amount (String) (defaults to: nil)

    Amount in the token’s smallest unit.

  • asset (String) (defaults to: nil)

    Token contract address (e.g. USDC on Base).

  • extra (Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements::Accept::Extra) (defaults to: nil)

    Additional scheme-specific parameters including EIP-712 domain info and the faci

  • max_timeout_seconds (Integer) (defaults to: nil)

    Maximum time in seconds before the payment authorization expires.

  • network (String) (defaults to: nil)

    Blockchain network identifier in CAIP-2 format (e.g. “eip155:8453” for Base).

  • pay_to (String) (defaults to: nil)

    Recipient wallet address.

  • scheme (String) (defaults to: nil)

    Payment scheme (e.g. “exact”).



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 116

class Accept < Telnyx::Internal::Type::BaseModel
  # @!attribute amount
  #   Amount in the token's smallest unit.
  #
  #   @return [String, nil]
  optional :amount, String

  # @!attribute asset
  #   Token contract address (e.g. USDC on Base).
  #
  #   @return [String, nil]
  optional :asset, String

  # @!attribute extra
  #   Additional scheme-specific parameters including EIP-712 domain info and the
  #   facilitator URL.
  #
  #   @return [Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements::Accept::Extra, nil]
  optional :extra,
           -> { Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements::Accept::Extra }

  # @!attribute max_timeout_seconds
  #   Maximum time in seconds before the payment authorization expires.
  #
  #   @return [Integer, nil]
  optional :max_timeout_seconds, Integer, api_name: :maxTimeoutSeconds

  # @!attribute network
  #   Blockchain network identifier in CAIP-2 format (e.g. "eip155:8453" for Base).
  #
  #   @return [String, nil]
  optional :network, String

  # @!attribute pay_to
  #   Recipient wallet address.
  #
  #   @return [String, nil]
  optional :pay_to, String, api_name: :payTo

  # @!attribute scheme
  #   Payment scheme (e.g. "exact").
  #
  #   @return [String, nil]
  optional :scheme, String

  # @!method initialize(amount: nil, asset: nil, extra: nil, max_timeout_seconds: nil, network: nil, pay_to: nil, scheme: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements::Accept}
  #   for more details.
  #
  #   @param amount [String] Amount in the token's smallest unit.
  #
  #   @param asset [String] Token contract address (e.g. USDC on Base).
  #
  #   @param extra [Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements::Accept::Extra] Additional scheme-specific parameters including EIP-712 domain info and the faci
  #
  #   @param max_timeout_seconds [Integer] Maximum time in seconds before the payment authorization expires.
  #
  #   @param network [String] Blockchain network identifier in CAIP-2 format (e.g. "eip155:8453" for Base).
  #
  #   @param pay_to [String] Recipient wallet address.
  #
  #   @param scheme [String] Payment scheme (e.g. "exact").

  # @see Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements::Accept#extra
  class Extra < Telnyx::Internal::Type::BaseModel
    # @!attribute facilitator_url
    #
    #   @return [String, nil]
    optional :facilitator_url, String, api_name: :facilitatorUrl

    # @!attribute name
    #   EIP-712 domain name (e.g. "USD Coin").
    #
    #   @return [String, nil]
    optional :name, String

    # @!attribute quote_id
    #
    #   @return [String, nil]
    optional :quote_id, String, api_name: :quoteId

    # @!attribute version
    #   EIP-712 domain version.
    #
    #   @return [String, nil]
    optional :version, String

    # @!method initialize(facilitator_url: nil, name: nil, quote_id: nil, version: nil)
    #   Additional scheme-specific parameters including EIP-712 domain info and the
    #   facilitator URL.
    #
    #   @param facilitator_url [String]
    #
    #   @param name [String] EIP-712 domain name (e.g. "USD Coin").
    #
    #   @param quote_id [String]
    #
    #   @param version [String] EIP-712 domain version.
  end
end

Instance Attribute Details

#amountString?

Amount in the token’s smallest unit.

Returns:

  • (String, nil)


121
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 121

optional :amount, String

#assetString?

Token contract address (e.g. USDC on Base).

Returns:

  • (String, nil)


127
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 127

optional :asset, String

#extraTelnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements::Accept::Extra?

Additional scheme-specific parameters including EIP-712 domain info and the facilitator URL.



134
135
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 134

optional :extra,
-> { Telnyx::Models::X402::CreditAccountCreateQuoteResponse::Data::PaymentRequirements::Accept::Extra }

#max_timeout_secondsInteger?

Maximum time in seconds before the payment authorization expires.

Returns:

  • (Integer, nil)


141
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 141

optional :max_timeout_seconds, Integer, api_name: :maxTimeoutSeconds

#networkString?

Blockchain network identifier in CAIP-2 format (e.g. “eip155:8453” for Base).

Returns:

  • (String, nil)


147
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 147

optional :network, String

#pay_toString?

Recipient wallet address.

Returns:

  • (String, nil)


153
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 153

optional :pay_to, String, api_name: :payTo

#schemeString?

Payment scheme (e.g. “exact”).

Returns:

  • (String, nil)


159
# File 'lib/telnyx/models/x402/credit_account_create_quote_response.rb', line 159

optional :scheme, String