Class: Telnyx::Resources::AI::Integrations
- Inherits:
-
Object
- Object
- Telnyx::Resources::AI::Integrations
- Defined in:
- lib/telnyx/resources/ai/integrations.rb,
lib/telnyx/resources/ai/integrations/connections.rb,
sig/telnyx/resources/ai/integrations.rbs,
sig/telnyx/resources/ai/integrations/connections.rbs
Defined Under Namespace
Classes: Connections
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(client:) ⇒ Integrations
constructor
private
A new instance of Integrations.
-
#list(request_options: {}) ⇒ Telnyx::Models::AI::IntegrationListResponse
Returns the list of third-party integrations available to connect to your AI assistants and workflows.
-
#retrieve(integration_id, request_options: {}) ⇒ Telnyx::Models::AI::Integration
Returns the details of a single available integration, including its configuration details.
Constructor Details
#initialize(client:) ⇒ Integrations
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Integrations.
53 54 55 56 |
# File 'lib/telnyx/resources/ai/integrations.rb', line 53 def initialize(client:) @client = client @connections = Telnyx::Resources::AI::Integrations::Connections.new(client: client) end |
Instance Attribute Details
#connections ⇒ Telnyx::Resources::AI::Integrations::Connections (readonly)
8 9 10 |
# File 'lib/telnyx/resources/ai/integrations.rb', line 8 def connections @connections end |
Instance Method Details
#list(request_options: {}) ⇒ Telnyx::Models::AI::IntegrationListResponse
Returns the list of third-party integrations available to connect to your AI assistants and workflows.
41 42 43 44 45 46 47 48 |
# File 'lib/telnyx/resources/ai/integrations.rb', line 41 def list(params = {}) @client.request( method: :get, path: "ai/integrations", model: Telnyx::Models::AI::IntegrationListResponse, options: params[:request_options] ) end |
#retrieve(integration_id, request_options: {}) ⇒ Telnyx::Models::AI::Integration
Returns the details of a single available integration, including its configuration details.
22 23 24 25 26 27 28 29 |
# File 'lib/telnyx/resources/ai/integrations.rb', line 22 def retrieve(integration_id, params = {}) @client.request( method: :get, path: ["ai/integrations/%1$s", integration_id], model: Telnyx::AI::Integration, options: params[:request_options] ) end |