Class: Telnyx::Resources::AI::Integrations::Connections
- Inherits:
-
Object
- Object
- Telnyx::Resources::AI::Integrations::Connections
- Defined in:
- lib/telnyx/resources/ai/integrations/connections.rb,
sig/telnyx/resources/ai/integrations/connections.rbs
Instance Method Summary collapse
-
#delete(user_connection_id, request_options: {}) ⇒ nil
Delete a specific integration connection.
-
#initialize(client:) ⇒ Connections
constructor
private
A new instance of Connections.
-
#list(request_options: {}) ⇒ Telnyx::Models::AI::Integrations::ConnectionListResponse
Returns the list of integration connections you have set up, linking your account to third-party services.
-
#retrieve(user_connection_id, request_options: {}) ⇒ Telnyx::Models::AI::Integrations::ConnectionRetrieveResponse
Returns the details of a single integration connection by its ID.
Constructor Details
#initialize(client:) ⇒ Connections
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Connections.
70 71 72 |
# File 'lib/telnyx/resources/ai/integrations/connections.rb', line 70 def initialize(client:) @client = client end |
Instance Method Details
#delete(user_connection_id, request_options: {}) ⇒ nil
Delete a specific integration connection.
58 59 60 61 62 63 64 65 |
# File 'lib/telnyx/resources/ai/integrations/connections.rb', line 58 def delete(user_connection_id, params = {}) @client.request( method: :delete, path: ["ai/integrations/connections/%1$s", user_connection_id], model: NilClass, options: params[:request_options] ) end |
#list(request_options: {}) ⇒ Telnyx::Models::AI::Integrations::ConnectionListResponse
Returns the list of integration connections you have set up, linking your account to third-party services.
38 39 40 41 42 43 44 45 |
# File 'lib/telnyx/resources/ai/integrations/connections.rb', line 38 def list(params = {}) @client.request( method: :get, path: "ai/integrations/connections", model: Telnyx::Models::AI::Integrations::ConnectionListResponse, options: params[:request_options] ) end |
#retrieve(user_connection_id, request_options: {}) ⇒ Telnyx::Models::AI::Integrations::ConnectionRetrieveResponse
Returns the details of a single integration connection by its ID.
19 20 21 22 23 24 25 26 |
# File 'lib/telnyx/resources/ai/integrations/connections.rb', line 19 def retrieve(user_connection_id, params = {}) @client.request( method: :get, path: ["ai/integrations/connections/%1$s", user_connection_id], model: Telnyx::Models::AI::Integrations::ConnectionRetrieveResponse, options: params[:request_options] ) end |