Class: Telnyx::Resources::Calls::Actions
- Inherits:
-
Object
- Object
- Telnyx::Resources::Calls::Actions
- Defined in:
- lib/telnyx/resources/calls/actions.rb,
sig/telnyx/resources/calls/actions.rbs
Overview
Call Control command operations
Instance Method Summary collapse
-
#add_ai_assistant_messages(call_control_id, client_state: nil, command_id: nil, messages: nil, trigger_response: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionAddAIAssistantMessagesResponse
Some parameter documentations has been truncated, see Models::Calls::ActionAddAIAssistantMessagesParams for more details.
-
#answer(call_control_id, assistant: nil, billing_group_id: nil, client_state: nil, command_id: nil, conversation_relay_config: nil, custom_headers: nil, deepfake_detection: nil, preferred_codecs: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, send_silence_when_idle: nil, sip_headers: nil, sound_modifications: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, transcription: nil, transcription_config: nil, webhook_retries_policies: nil, webhook_url: nil, webhook_url_method: nil, webhook_urls: nil, webhook_urls_method: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionAnswerResponse
Some parameter documentations has been truncated, see Models::Calls::ActionAnswerParams for more details.
-
#bridge(call_control_id_to_bridge, call_control_id_to_bridge_with:, client_state: nil, command_id: nil, hold_after_unbridge: nil, mute_dtmf: nil, park_after_unbridge: nil, play_ringtone: nil, prevent_double_bridge: nil, queue: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, ringtone: nil, video_room_context: nil, video_room_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionBridgeResponse
Some parameter documentations has been truncated, see Models::Calls::ActionBridgeParams for more details.
-
#enqueue(call_control_id, queue_name:, client_state: nil, command_id: nil, keep_after_hangup: nil, max_size: nil, max_wait_time_secs: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionEnqueueResponse
Some parameter documentations has been truncated, see Models::Calls::ActionEnqueueParams for more details.
-
#gather(call_control_id, client_state: nil, command_id: nil, gather_id: nil, initial_timeout_millis: nil, inter_digit_timeout_millis: nil, maximum_digits: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherParams for more details.
-
#gather_using_ai(call_control_id, parameters:, assistant: nil, client_state: nil, command_id: nil, gather_ended_speech: nil, greeting: nil, interruption_settings: nil, language: nil, message_history: nil, send_message_history_updates: nil, send_partial_results: nil, transcription: nil, user_response_timeout_ms: nil, voice: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingAIResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingAIParams for more details.
-
#gather_using_audio(call_control_id, audio_url: nil, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_audio_url: nil, invalid_media_name: nil, maximum_digits: nil, maximum_tries: nil, media_name: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingAudioResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingAudioParams for more details.
-
#gather_using_speak(call_control_id, payload:, voice:, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_payload: nil, language: nil, maximum_digits: nil, maximum_tries: nil, minimum_digits: nil, payload_type: nil, service_level: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingSpeakResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingSpeakParams for more details.
-
#hangup(call_control_id, client_state: nil, command_id: nil, custom_headers: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionHangupResponse
Some parameter documentations has been truncated, see Models::Calls::ActionHangupParams for more details.
-
#initialize(client:) ⇒ Actions
constructor
private
A new instance of Actions.
-
#join_ai_assistant(call_control_id, conversation_id:, participant:, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionJoinAIAssistantResponse
Some parameter documentations has been truncated, see Models::Calls::ActionJoinAIAssistantParams for more details.
-
#leave_queue(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionLeaveQueueResponse
Some parameter documentations has been truncated, see Models::Calls::ActionLeaveQueueParams for more details.
-
#pause_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionPauseRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionPauseRecordingParams for more details.
-
#pay(call_control_id, amount: nil, client_state: nil, command_id: nil, connector_name: nil, currency: nil, description: nil, inter_digit_timeout_millis: nil, language: nil, max_attempts: nil, metadata: nil, parameters: nil, payment_method: nil, payment_token: nil, prompts: nil, service_level: nil, timeout_millis: nil, transaction_type: nil, valid_card_types: nil, voice: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionPayResponse
Some parameter documentations has been truncated, see Models::Calls::ActionPayParams for more details.
-
#refer(call_control_id, sip_address:, client_state: nil, command_id: nil, custom_headers: nil, sip_auth_password: nil, sip_auth_username: nil, sip_headers: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionReferResponse
Some parameter documentations has been truncated, see Models::Calls::ActionReferParams for more details.
-
#reject(call_control_id, cause:, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionRejectResponse
Some parameter documentations has been truncated, see Models::Calls::ActionRejectParams for more details.
-
#resume_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionResumeRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionResumeRecordingParams for more details.
-
#send_dtmf(call_control_id, digits:, client_state: nil, command_id: nil, duration_millis: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSendDtmfResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSendDtmfParams for more details.
-
#send_sip_info(call_control_id, body:, content_type:, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSendSipInfoResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSendSipInfoParams for more details.
-
#speak(call_control_id, payload:, voice:, client_state: nil, command_id: nil, language: nil, loop_: nil, payload_type: nil, service_level: nil, stop: nil, target_legs: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSpeakResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSpeakParams for more details.
-
#start_ai_assistant(call_control_id, assistant: nil, client_state: nil, command_id: nil, greeting: nil, interruption_settings: nil, message_history: nil, participants: nil, send_message_history_updates: nil, transcription: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartAIAssistantResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartAIAssistantParams for more details.
-
#start_conversation_relay(call_control_id, assistant: nil, client_state: nil, command_id: nil, conversation_relay_dtmf_detection: nil, conversation_relay_settings: nil, conversation_relay_url: nil, custom_parameters: nil, dtmf_detection: nil, greeting: nil, interruptible: nil, interruptible_greeting: nil, interruption_settings: nil, language: nil, languages: nil, provider: nil, structured_provider: nil, transcription: nil, transcription_engine: nil, transcription_engine_config: nil, tts_provider: nil, url: nil, voice: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartConversationRelayResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartConversationRelayParams for more details.
-
#start_forking(call_control_id, client_state: nil, command_id: nil, rx: nil, stream_type: nil, tx: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartForkingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartForkingParams for more details.
-
#start_noise_suppression(call_control_id, client_state: nil, command_id: nil, direction: nil, noise_suppression_engine: nil, noise_suppression_engine_config: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartNoiseSuppressionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartNoiseSuppressionParams for more details.
-
#start_playback(call_control_id, audio_type: nil, audio_url: nil, cache_audio: nil, client_state: nil, command_id: nil, loop_: nil, media_name: nil, overlay: nil, playback_content: nil, stop: nil, target_legs: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartPlaybackResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartPlaybackParams for more details.
-
#start_recording(call_control_id, channels:, format_:, client_state: nil, command_id: nil, custom_file_name: nil, max_length: nil, play_beep: nil, recording_track: nil, timeout_secs: nil, transcription: nil, transcription_engine: nil, transcription_language: nil, transcription_max_speaker_count: nil, transcription_min_speaker_count: nil, transcription_profanity_filter: nil, transcription_speaker_diarization: nil, trim: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartRecordingParams for more details.
-
#start_siprec(call_control_id, client_state: nil, connector_name: nil, include_metadata_custom_headers: nil, secure: nil, session_timeout_secs: nil, sip_transport: nil, siprec_track: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartSiprecResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartSiprecParams for more details.
-
#start_streaming(call_control_id, client_state: nil, command_id: nil, custom_parameters: nil, dialogflow_config: nil, enable_dialogflow: nil, stream_auth_token: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_sampling_rate: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartStreamingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartStreamingParams for more details.
-
#start_transcription(call_control_id, client_state: nil, command_id: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_tracks: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartTranscriptionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartTranscriptionParams for more details.
-
#stop_ai_assistant(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopAIAssistantResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopAIAssistantParams for more details.
-
#stop_conversation_relay(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopConversationRelayResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopConversationRelayParams for more details.
-
#stop_forking(call_control_id, client_state: nil, command_id: nil, stream_type: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopForkingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopForkingParams for more details.
-
#stop_gather(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopGatherResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopGatherParams for more details.
-
#stop_noise_suppression(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopNoiseSuppressionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopNoiseSuppressionParams for more details.
-
#stop_playback(call_control_id, client_state: nil, command_id: nil, overlay: nil, stop: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopPlaybackResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopPlaybackParams for more details.
-
#stop_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopRecordingParams for more details.
-
#stop_siprec(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopSiprecResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopSiprecParams for more details.
-
#stop_streaming(call_control_id, client_state: nil, command_id: nil, stream_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopStreamingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopStreamingParams for more details.
-
#stop_transcription(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopTranscriptionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopTranscriptionParams for more details.
-
#switch_supervisor_role(call_control_id, role:, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSwitchSupervisorRoleResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSwitchSupervisorRoleParams for more details.
-
#transfer(call_control_id, to:, answering_machine_detection: nil, answering_machine_detection_config: nil, audio_url: nil, client_state: nil, command_id: nil, custom_headers: nil, early_media: nil, from: nil, from_display_name: nil, media_encryption: nil, media_name: nil, mute_dtmf: nil, park_after_unbridge: nil, preferred_codecs: nil, privacy: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, route_to_mobile: nil, send_digits_on_answer: nil, sip_auth_password: nil, sip_auth_username: nil, sip_headers: nil, sip_region: nil, sip_transport_protocol: nil, sound_modifications: nil, target_leg_client_state: nil, time_limit_secs: nil, timeout_secs: nil, webhook_retries_policies: nil, webhook_url: nil, webhook_url_method: nil, webhook_urls: nil, webhook_urls_method: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionTransferResponse
Some parameter documentations has been truncated, see Models::Calls::ActionTransferParams for more details.
-
#update_client_state(call_control_id, client_state:, request_options: {}) ⇒ Telnyx::Models::Calls::ActionUpdateClientStateResponse
Some parameter documentations has been truncated, see Models::Calls::ActionUpdateClientStateParams for more details.
Constructor Details
#initialize(client:) ⇒ Actions
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Actions.
1953 1954 1955 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1953 def initialize(client:) @client = client end |
Instance Method Details
#add_ai_assistant_messages(call_control_id, client_state: nil, command_id: nil, messages: nil, trigger_response: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionAddAIAssistantMessagesResponse
Some parameter documentations has been truncated, see Models::Calls::ActionAddAIAssistantMessagesParams for more details.
Add messages to the conversation started by an AI assistant on the call.
30 31 32 33 34 35 36 37 38 39 |
# File 'lib/telnyx/resources/calls/actions.rb', line 30 def (call_control_id, params = {}) parsed, = Telnyx::Calls::ActionAddAIAssistantMessagesParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/ai_assistant_add_messages", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionAddAIAssistantMessagesResponse, options: ) end |
#answer(call_control_id, assistant: nil, billing_group_id: nil, client_state: nil, command_id: nil, conversation_relay_config: nil, custom_headers: nil, deepfake_detection: nil, preferred_codecs: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, send_silence_when_idle: nil, sip_headers: nil, sound_modifications: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, transcription: nil, transcription_config: nil, webhook_retries_policies: nil, webhook_url: nil, webhook_url_method: nil, webhook_urls: nil, webhook_urls_method: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionAnswerResponse
Some parameter documentations has been truncated, see Models::Calls::ActionAnswerParams for more details.
Answer an incoming call. You must issue this command before executing subsequent commands on an incoming call.
Expected Webhooks:
call.answeredcall.holdandcall.unholdif the call is held/unheldcall.deepfake_detection.resultifdeepfake_detectionwas enabledcall.deepfake_detection.errorifdeepfake_detectionwas enabled and an error occurredstreaming.started,streaming.stoppedorstreaming.failedifstream_urlwas set
When the record parameter is set to record-from-answer, the response will
include a recording_id field.
stream_
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/telnyx/resources/calls/actions.rb', line 134 def answer(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionAnswerParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/answer", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionAnswerResponse, options: ) end |
#bridge(call_control_id_to_bridge, call_control_id_to_bridge_with:, client_state: nil, command_id: nil, hold_after_unbridge: nil, mute_dtmf: nil, park_after_unbridge: nil, play_ringtone: nil, prevent_double_bridge: nil, queue: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, ringtone: nil, video_room_context: nil, video_room_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionBridgeResponse
Some parameter documentations has been truncated, see Models::Calls::ActionBridgeParams for more details.
Bridge two call control calls.
Expected Webhooks:
call.bridgedfor Leg Acall.bridgedfor Leg B
call_
205 206 207 208 209 210 211 212 213 214 |
# File 'lib/telnyx/resources/calls/actions.rb', line 205 def bridge(call_control_id_to_bridge, params) parsed, = Telnyx::Calls::ActionBridgeParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/bridge", call_control_id_to_bridge], body: parsed, model: Telnyx::Models::Calls::ActionBridgeResponse, options: ) end |
#enqueue(call_control_id, queue_name:, client_state: nil, command_id: nil, keep_after_hangup: nil, max_size: nil, max_wait_time_secs: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionEnqueueResponse
Some parameter documentations has been truncated, see Models::Calls::ActionEnqueueParams for more details.
Places the call into a queue, where it waits until it is removed or bridged to another leg. Queue behavior is configured through the request body.
243 244 245 246 247 248 249 250 251 252 |
# File 'lib/telnyx/resources/calls/actions.rb', line 243 def enqueue(call_control_id, params) parsed, = Telnyx::Calls::ActionEnqueueParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/enqueue", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionEnqueueResponse, options: ) end |
#gather(call_control_id, client_state: nil, command_id: nil, gather_id: nil, initial_timeout_millis: nil, inter_digit_timeout_millis: nil, maximum_digits: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherParams for more details.
Gather DTMF signals to build interactive menus.
You can pass a list of valid digits. The Answer command must be issued before
the gather command.
Expected Webhooks:
call.dtmf.received(you may receive many of these webhooks)call.gather.ended
296 297 298 299 300 301 302 303 304 305 |
# File 'lib/telnyx/resources/calls/actions.rb', line 296 def gather(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionGatherParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/gather", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionGatherResponse, options: ) end |
#gather_using_ai(call_control_id, parameters:, assistant: nil, client_state: nil, command_id: nil, gather_ended_speech: nil, greeting: nil, interruption_settings: nil, language: nil, message_history: nil, send_message_history_updates: nil, send_partial_results: nil, transcription: nil, user_response_timeout_ms: nil, voice: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingAIResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingAIParams for more details.
Gather parameters defined in the request payload using a voice assistant.
You can pass parameters described as a JSON Schema object and the voice assistant will attempt to gather these informations.
Expected Webhooks:
call.ai_gather.endedcall.conversation.endedcall.ai_gather.partial_results(ifsend_partial_resultsis set totrue)call.ai_gather.message_history_updated(ifsend_message_history_updatesis set totrue)
362 363 364 365 366 367 368 369 370 371 |
# File 'lib/telnyx/resources/calls/actions.rb', line 362 def gather_using_ai(call_control_id, params) parsed, = Telnyx::Calls::ActionGatherUsingAIParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/gather_using_ai", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionGatherUsingAIResponse, options: ) end |
#gather_using_audio(call_control_id, audio_url: nil, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_audio_url: nil, invalid_media_name: nil, maximum_digits: nil, maximum_tries: nil, media_name: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingAudioResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingAudioParams for more details.
Play an audio file on the call until the required DTMF signals are gathered to build interactive menus.
You can pass a list of valid digits along with an 'invalid_audio_url', which
will be played back at the beginning of each prompt. Playback will be
interrupted when a DTMF signal is received. The
Answer command must be issued before the gather_using_audio` command.
Expected Webhooks:
call.playback.startedcall.playback.endedcall.dtmf.received(you may receive many of these webhooks)call.gather.ended
426 427 428 429 430 431 432 433 434 435 |
# File 'lib/telnyx/resources/calls/actions.rb', line 426 def gather_using_audio(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionGatherUsingAudioParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/gather_using_audio", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionGatherUsingAudioResponse, options: ) end |
#gather_using_speak(call_control_id, payload:, voice:, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_payload: nil, language: nil, maximum_digits: nil, maximum_tries: nil, minimum_digits: nil, payload_type: nil, service_level: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingSpeakResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingSpeakParams for more details.
Convert text to speech and play it on the call until the required DTMF signals are gathered to build interactive menus.
You can pass a list of valid digits along with an 'invalid_payload', which will
be played back at the beginning of each prompt. Speech will be interrupted when
a DTMF signal is received. The Answer command must be issued before the
gather_using_speak command.
Expected Webhooks:
call.dtmf.received(you may receive many of these webhooks)call.gather.ended
`valid_
495 496 497 498 499 500 501 502 503 504 |
# File 'lib/telnyx/resources/calls/actions.rb', line 495 def gather_using_speak(call_control_id, params) parsed, = Telnyx::Calls::ActionGatherUsingSpeakParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/gather_using_speak", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionGatherUsingSpeakResponse, options: ) end |
#hangup(call_control_id, client_state: nil, command_id: nil, custom_headers: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionHangupResponse
Some parameter documentations has been truncated, see Models::Calls::ActionHangupParams for more details.
Hang up the call.
Expected Webhooks:
call.hangupcall.recording.saved
531 532 533 534 535 536 537 538 539 540 |
# File 'lib/telnyx/resources/calls/actions.rb', line 531 def hangup(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionHangupParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/hangup", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionHangupResponse, options: ) end |
#join_ai_assistant(call_control_id, conversation_id:, participant:, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionJoinAIAssistantResponse
Some parameter documentations has been truncated, see Models::Calls::ActionJoinAIAssistantParams for more details.
Add a participant to an existing AI assistant conversation. Use this command to bring an additional call leg into a running AI conversation.
565 566 567 568 569 570 571 572 573 574 |
# File 'lib/telnyx/resources/calls/actions.rb', line 565 def join_ai_assistant(call_control_id, params) parsed, = Telnyx::Calls::ActionJoinAIAssistantParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/ai_assistant_join", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionJoinAIAssistantResponse, options: ) end |
#leave_queue(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionLeaveQueueResponse
Some parameter documentations has been truncated, see Models::Calls::ActionLeaveQueueParams for more details.
Removes the call from the queue it is currently waiting in. The call remains active and can be directed with further call commands.
595 596 597 598 599 600 601 602 603 604 |
# File 'lib/telnyx/resources/calls/actions.rb', line 595 def leave_queue(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionLeaveQueueParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/leave_queue", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionLeaveQueueResponse, options: ) end |
#pause_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionPauseRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionPauseRecordingParams for more details.
Pause recording the call. Recording can be resumed via Resume recording command.
Expected Webhooks:
There are no webhooks associated with this command.
630 631 632 633 634 635 636 637 638 639 |
# File 'lib/telnyx/resources/calls/actions.rb', line 630 def pause_recording(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionPauseRecordingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/record_pause", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionPauseRecordingResponse, options: ) end |
#pay(call_control_id, amount: nil, client_state: nil, command_id: nil, connector_name: nil, currency: nil, description: nil, inter_digit_timeout_millis: nil, language: nil, max_attempts: nil, metadata: nil, parameters: nil, payment_method: nil, payment_token: nil, prompts: nil, service_level: nil, timeout_millis: nil, transaction_type: nil, valid_card_types: nil, voice: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionPayResponse
Some parameter documentations has been truncated, see Models::Calls::ActionPayParams for more details.
Collect payment details from the caller using DTMF and either charge or tokenize the payment method through a configured Pay connector. Pay pauses active call recordings while sensitive payment details are collected.
When payment_token is supplied, the DTMF collection steps are skipped and the
existing token is sent to the connector.
Expected Webhooks:
call.payment.progresscall.payment.completed
Test mode card numbers: 4111111111111111 (Visa), 5555555555554444
(Mastercard), 378282246310005 (American Express), 6011111111111117
(Discover), 3065930009020004 (Diners Club), 3566002020360505 (JCB),
6200000000000005 (UnionPay), and 6771798021000008 (Maestro). Test-mode
connectors reject other card numbers before contacting the configured processor.
The UnionPay and Maestro numbers are accepted for processor testing, but Pay
currently does not emit a card type for them.
711 712 713 714 715 716 717 718 719 720 |
# File 'lib/telnyx/resources/calls/actions.rb', line 711 def pay(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionPayParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/pay", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionPayResponse, options: ) end |
#refer(call_control_id, sip_address:, client_state: nil, command_id: nil, custom_headers: nil, sip_auth_password: nil, sip_auth_username: nil, sip_headers: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionReferResponse
Some parameter documentations has been truncated, see Models::Calls::ActionReferParams for more details.
Initiate a SIP Refer on a Call Control call. You can initiate a SIP Refer at any point in the duration of a call.
Expected Webhooks:
call.refer.startedcall.refer.completedcall.refer.failed
757 758 759 760 761 762 763 764 765 766 |
# File 'lib/telnyx/resources/calls/actions.rb', line 757 def refer(call_control_id, params) parsed, = Telnyx::Calls::ActionReferParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/refer", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionReferResponse, options: ) end |
#reject(call_control_id, cause:, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionRejectResponse
Some parameter documentations has been truncated, see Models::Calls::ActionRejectParams for more details.
Reject an incoming call.
Expected Webhooks:
call.hangup
792 793 794 795 796 797 798 799 800 801 |
# File 'lib/telnyx/resources/calls/actions.rb', line 792 def reject(call_control_id, params) parsed, = Telnyx::Calls::ActionRejectParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/reject", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionRejectResponse, options: ) end |
#resume_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionResumeRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionResumeRecordingParams for more details.
Resume recording the call.
Expected Webhooks:
There are no webhooks associated with this command.
827 828 829 830 831 832 833 834 835 836 |
# File 'lib/telnyx/resources/calls/actions.rb', line 827 def resume_recording(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionResumeRecordingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/record_resume", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionResumeRecordingResponse, options: ) end |
#send_dtmf(call_control_id, digits:, client_state: nil, command_id: nil, duration_millis: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSendDtmfResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSendDtmfParams for more details.
Sends DTMF tones from this leg. DTMF tones will be heard by the other end of the call.
Expected Webhooks:
There are no webhooks associated with this command.
us
866 867 868 869 870 871 872 873 874 875 |
# File 'lib/telnyx/resources/calls/actions.rb', line 866 def send_dtmf(call_control_id, params) parsed, = Telnyx::Calls::ActionSendDtmfParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/send_dtmf", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionSendDtmfResponse, options: ) end |
#send_sip_info(call_control_id, body:, content_type:, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSendSipInfoResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSendSipInfoParams for more details.
Sends SIP info from this leg.
Expected Webhooks:
call.sip_info.received(to be received on the target call leg)
903 904 905 906 907 908 909 910 911 912 |
# File 'lib/telnyx/resources/calls/actions.rb', line 903 def send_sip_info(call_control_id, params) parsed, = Telnyx::Calls::ActionSendSipInfoParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/send_sip_info", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionSendSipInfoResponse, options: ) end |
#speak(call_control_id, payload:, voice:, client_state: nil, command_id: nil, language: nil, loop_: nil, payload_type: nil, service_level: nil, stop: nil, target_legs: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSpeakResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSpeakParams for more details.
Convert text to speech and play it back on the call. If multiple speak text commands are issued consecutively, the audio files will be placed in a queue awaiting playback.
Expected Webhooks:
call.speak.startedcall.speak.ended
957 958 959 960 961 962 963 964 965 966 |
# File 'lib/telnyx/resources/calls/actions.rb', line 957 def speak(call_control_id, params) parsed, = Telnyx::Calls::ActionSpeakParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/speak", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionSpeakResponse, options: ) end |
#start_ai_assistant(call_control_id, assistant: nil, client_state: nil, command_id: nil, greeting: nil, interruption_settings: nil, message_history: nil, participants: nil, send_message_history_updates: nil, transcription: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartAIAssistantResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartAIAssistantParams for more details.
Start an AI assistant on the call.
Expected Webhooks:
call.conversation.endedcall.conversation_insights.generated
1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1005 def start_ai_assistant(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartAIAssistantParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/ai_assistant_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartAIAssistantResponse, options: ) end |
#start_conversation_relay(call_control_id, assistant: nil, client_state: nil, command_id: nil, conversation_relay_dtmf_detection: nil, conversation_relay_settings: nil, conversation_relay_url: nil, custom_parameters: nil, dtmf_detection: nil, greeting: nil, interruptible: nil, interruptible_greeting: nil, interruption_settings: nil, language: nil, languages: nil, provider: nil, structured_provider: nil, transcription: nil, transcription_engine: nil, transcription_engine_config: nil, tts_provider: nil, url: nil, voice: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartConversationRelayResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartConversationRelayParams for more details.
Start a Conversation Relay session on an active call. Conversation Relay connects the call audio to your WebSocket so your application can exchange realtime messages with the caller while Telnyx handles speech recognition and text-to-speech. Only one AI Assistant or Conversation Relay session can be active on a call at a time.
Expected Webhooks:
call.conversation.ended- Sent when the Conversation Relay session ends. If the customer WebSocket disconnects, the webhook payloadreasoniscustomer_disconnect.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1086 def start_conversation_relay(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartConversationRelayParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/conversation_relay_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartConversationRelayResponse, options: ) end |
#start_forking(call_control_id, client_state: nil, command_id: nil, rx: nil, stream_type: nil, tx: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartForkingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartForkingParams for more details.
Call forking allows you to stream the media from a call to a specific target in
realtime. This stream can be used to enable realtime audio analysis to support a
variety of use cases, including fraud detection, or the creation of AI-generated
audio responses. Requests must specify either the target attribute or the rx
and tx attributes.
Expected Webhooks:
call.fork.startedcall.fork.stopped
1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1130 def start_forking(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartForkingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/fork_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartForkingResponse, options: ) end |
#start_noise_suppression(call_control_id, client_state: nil, command_id: nil, direction: nil, noise_suppression_engine: nil, noise_suppression_engine_config: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartNoiseSuppressionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartNoiseSuppressionParams for more details.
Start noise suppression on an active call to reduce background noise. This feature is currently in beta.
1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1166 def start_noise_suppression(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartNoiseSuppressionParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/suppression_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartNoiseSuppressionResponse, options: ) end |
#start_playback(call_control_id, audio_type: nil, audio_url: nil, cache_audio: nil, client_state: nil, command_id: nil, loop_: nil, media_name: nil, overlay: nil, playback_content: nil, stop: nil, target_legs: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartPlaybackResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartPlaybackParams for more details.
Play an audio file on the call. If multiple play audio commands are issued consecutively, the audio files will be placed in a queue awaiting playback.
Notes:
- When
overlayis enabled,target_legsis limited toself. - A customer cannot Play Audio with
overlay=trueunless there is a Play Audio withoverlay=falseactively playing.
Expected Webhooks:
call.playback.startedcall.playback.ended
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1225 def start_playback(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartPlaybackParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/playback_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartPlaybackResponse, options: ) end |
#start_recording(call_control_id, channels:, format_:, client_state: nil, command_id: nil, custom_file_name: nil, max_length: nil, play_beep: nil, recording_track: nil, timeout_secs: nil, transcription: nil, transcription_engine: nil, transcription_language: nil, transcription_max_speaker_count: nil, transcription_min_speaker_count: nil, transcription_profanity_filter: nil, transcription_speaker_diarization: nil, trim: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartRecordingParams for more details.
Start recording the call. Recording will stop on call hang-up, or can be initiated via the Stop Recording command.
Expected Webhooks:
call.recording.savedcall.recording.transcription.savedcall.recording.error
1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1291 def start_recording(call_control_id, params) parsed, = Telnyx::Calls::ActionStartRecordingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/record_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartRecordingResponse, options: ) end |
#start_siprec(call_control_id, client_state: nil, connector_name: nil, include_metadata_custom_headers: nil, secure: nil, session_timeout_secs: nil, sip_transport: nil, siprec_track: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartSiprecResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartSiprecParams for more details.
Start siprec session to configured in SIPREC connector SRS.
Expected Webhooks:
siprec.startedsiprec.stoppedsiprec.failed
1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1336 def start_siprec(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartSiprecParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/siprec_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartSiprecResponse, options: ) end |
#start_streaming(call_control_id, client_state: nil, command_id: nil, custom_parameters: nil, dialogflow_config: nil, enable_dialogflow: nil, stream_auth_token: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_sampling_rate: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartStreamingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartStreamingParams for more details.
Start streaming the media from a call to a specific WebSocket address or Dialogflow connection in near-realtime. Audio will be delivered as base64-encoded RTP payload (raw audio), wrapped in JSON payloads.
Please find more details about media streaming messages specification under the link.
stream_
1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1393 def start_streaming(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartStreamingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/streaming_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartStreamingResponse, options: ) end |
#start_transcription(call_control_id, client_state: nil, command_id: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_tracks: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartTranscriptionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartTranscriptionParams for more details.
Start real-time transcription. Transcription will stop on call hang-up, or can be initiated via the Transcription stop command.
Expected Webhooks:
call.transcription
1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1433 def start_transcription(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartTranscriptionParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/transcription_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartTranscriptionResponse, options: ) end |
#stop_ai_assistant(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopAIAssistantResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopAIAssistantParams for more details.
Stops the AI assistant currently engaged on the call. The call remains active and can continue with other call control commands.
1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1463 def stop_ai_assistant(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopAIAssistantParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/ai_assistant_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopAIAssistantResponse, options: ) end |
#stop_conversation_relay(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopConversationRelayResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopConversationRelayParams for more details.
Stop the active Conversation Relay session on a call.
1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1492 def stop_conversation_relay(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopConversationRelayParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/conversation_relay_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopConversationRelayResponse, options: ) end |
#stop_forking(call_control_id, client_state: nil, command_id: nil, stream_type: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopForkingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopForkingParams for more details.
Stop forking a call.
Expected Webhooks:
call.fork.stopped
1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1527 def stop_forking(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopForkingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/fork_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopForkingResponse, options: ) end |
#stop_gather(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopGatherResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopGatherParams for more details.
Stop current gather.
Expected Webhooks:
call.gather.ended
1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1560 def stop_gather(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopGatherParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/gather_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopGatherResponse, options: ) end |
#stop_noise_suppression(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopNoiseSuppressionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopNoiseSuppressionParams for more details.
Stop noise suppression previously started on an active call. This feature is currently in beta.
1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1590 def stop_noise_suppression(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopNoiseSuppressionParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/suppression_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopNoiseSuppressionResponse, options: ) end |
#stop_playback(call_control_id, client_state: nil, command_id: nil, overlay: nil, stop: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopPlaybackResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopPlaybackParams for more details.
Stop audio being played on the call.
Expected Webhooks:
call.playback.endedorcall.speak.ended
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1627 def stop_playback(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopPlaybackParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/playback_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopPlaybackResponse, options: ) end |
#stop_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopRecordingParams for more details.
Stop recording the call.
Expected Webhooks:
call.recording.saved
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1662 def stop_recording(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopRecordingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/record_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopRecordingResponse, options: ) end |
#stop_siprec(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopSiprecResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopSiprecParams for more details.
Stop SIPREC session.
Expected Webhooks:
siprec.stopped
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1695 def stop_siprec(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopSiprecParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/siprec_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopSiprecResponse, options: ) end |
#stop_streaming(call_control_id, client_state: nil, command_id: nil, stream_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopStreamingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopStreamingParams for more details.
Stop streaming a call to a WebSocket.
Expected Webhooks:
streaming.stopped
1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1730 def stop_streaming(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopStreamingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/streaming_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopStreamingResponse, options: ) end |
#stop_transcription(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopTranscriptionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopTranscriptionParams for more details.
Stops real-time transcription on the call. Transcription webhooks cease once the command takes effect; the call itself is unaffected.
1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1760 def stop_transcription(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopTranscriptionParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/transcription_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopTranscriptionResponse, options: ) end |
#switch_supervisor_role(call_control_id, role:, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSwitchSupervisorRoleResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSwitchSupervisorRoleParams for more details.
Switch the supervisor role for a bridged call. This allows switching between different supervisor modes during an active call
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1788 def switch_supervisor_role(call_control_id, params) parsed, = Telnyx::Calls::ActionSwitchSupervisorRoleParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/switch_supervisor_role", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionSwitchSupervisorRoleResponse, options: ) end |
#transfer(call_control_id, to:, answering_machine_detection: nil, answering_machine_detection_config: nil, audio_url: nil, client_state: nil, command_id: nil, custom_headers: nil, early_media: nil, from: nil, from_display_name: nil, media_encryption: nil, media_name: nil, mute_dtmf: nil, park_after_unbridge: nil, preferred_codecs: nil, privacy: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, route_to_mobile: nil, send_digits_on_answer: nil, sip_auth_password: nil, sip_auth_username: nil, sip_headers: nil, sip_region: nil, sip_transport_protocol: nil, sound_modifications: nil, target_leg_client_state: nil, time_limit_secs: nil, timeout_secs: nil, webhook_retries_policies: nil, webhook_url: nil, webhook_url_method: nil, webhook_urls: nil, webhook_urls_method: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionTransferResponse
Some parameter documentations has been truncated, see Models::Calls::ActionTransferParams for more details.
Transfer a call to a new destination. If the transfer is unsuccessful, a
call.hangup webhook for the other call (Leg B) will be sent indicating that
the transfer could not be completed. The original call will remain active and
may be issued additional commands, potentially transfering the call to an
alternate destination.
Expected Webhooks:
call.initiatedcall.bridgedto Leg Bcall.answeredorcall.hangupcall.machine.detection.endedifanswering_machine_detectionwas requestedcall.machine.greeting.endedifanswering_machine_detectionwas requested to detect the end of machine greetingcall.machine.premium.detection.endedifanswering_machine_detection=premiumwas requestedcall.machine.premium.greeting.endedifanswering_machine_detection=premiumwas requested and a beep was detected
1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1910 def transfer(call_control_id, params) parsed, = Telnyx::Calls::ActionTransferParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/transfer", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionTransferResponse, options: ) end |
#update_client_state(call_control_id, client_state:, request_options: {}) ⇒ Telnyx::Models::Calls::ActionUpdateClientStateResponse
Some parameter documentations has been truncated, see Models::Calls::ActionUpdateClientStateParams for more details.
Updates the client state associated with the call. Client state is an opaque value echoed back in subsequent webhooks for the call, letting you correlate events with your application's state.
1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1939 def update_client_state(call_control_id, params) parsed, = Telnyx::Calls::ActionUpdateClientStateParams.dump_request(params) @client.request( method: :put, path: ["calls/%1$s/actions/client_state_update", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionUpdateClientStateResponse, options: ) end |