Class: Telnyx::Resources::DynamicEmergencyEndpoints

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/dynamic_emergency_endpoints.rb

Overview

Dynamic Emergency Endpoints

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ DynamicEmergencyEndpoints

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of DynamicEmergencyEndpoints.

Parameters:



107
108
109
# File 'lib/telnyx/resources/dynamic_emergency_endpoints.rb', line 107

def initialize(client:)
  @client = client
end

Instance Method Details

#create(callback_number:, caller_name:, dynamic_emergency_address_id:, request_options: {}) ⇒ Telnyx::Models::DynamicEmergencyEndpointCreateResponse

Creates a dynamic emergency endpoints.

Parameters:

  • callback_number (String)
  • caller_name (String)
  • dynamic_emergency_address_id (String)

    An id of a currently active dynamic emergency location.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



22
23
24
25
26
27
28
29
30
31
# File 'lib/telnyx/resources/dynamic_emergency_endpoints.rb', line 22

def create(params)
  parsed, options = Telnyx::DynamicEmergencyEndpointCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "dynamic_emergency_endpoints",
    body: parsed,
    model: Telnyx::Models::DynamicEmergencyEndpointCreateResponse,
    options: options
  )
end

#delete(id, request_options: {}) ⇒ Telnyx::Models::DynamicEmergencyEndpointDeleteResponse

Deletes the dynamic emergency endpoint based on the ID provided

Parameters:

  • id (String)

    Dynamic Emergency Endpoint id

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



95
96
97
98
99
100
101
102
# File 'lib/telnyx/resources/dynamic_emergency_endpoints.rb', line 95

def delete(id, params = {})
  @client.request(
    method: :delete,
    path: ["dynamic_emergency_endpoints/%1$s", id],
    model: Telnyx::Models::DynamicEmergencyEndpointDeleteResponse,
    options: params[:request_options]
  )
end

#list(filter: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::DynamicEmergencyEndpoint>

Some parameter documentations has been truncated, see Models::DynamicEmergencyEndpointListParams for more details.

Returns the dynamic emergency endpoints according to filters

Parameters:

Returns:

See Also:



71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/telnyx/resources/dynamic_emergency_endpoints.rb', line 71

def list(params = {})
  parsed, options = Telnyx::DynamicEmergencyEndpointListParams.dump_request(params)
  query = Telnyx::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "dynamic_emergency_endpoints",
    query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"),
    page: Telnyx::Internal::DefaultFlatPagination,
    model: Telnyx::DynamicEmergencyEndpoint,
    options: options
  )
end

#retrieve(id, request_options: {}) ⇒ Telnyx::Models::DynamicEmergencyEndpointRetrieveResponse

Returns the dynamic emergency endpoint based on the ID provided

Parameters:

  • id (String)

    Dynamic Emergency Endpoint id

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



44
45
46
47
48
49
50
51
# File 'lib/telnyx/resources/dynamic_emergency_endpoints.rb', line 44

def retrieve(id, params = {})
  @client.request(
    method: :get,
    path: ["dynamic_emergency_endpoints/%1$s", id],
    model: Telnyx::Models::DynamicEmergencyEndpointRetrieveResponse,
    options: params[:request_options]
  )
end