Class: Telnyx::Resources::ExternalConnections::Releases
- Inherits:
-
Object
- Object
- Telnyx::Resources::ExternalConnections::Releases
- Defined in:
- lib/telnyx/resources/external_connections/releases.rb
Overview
External Connections operations
Instance Method Summary collapse
-
#initialize(client:) ⇒ Releases
constructor
private
A new instance of Releases.
-
#list(id, filter: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::ExternalConnections::ReleaseListResponse>
Some parameter documentations has been truncated, see Models::ExternalConnections::ReleaseListParams for more details.
-
#retrieve(release_id, id:, request_options: {}) ⇒ Telnyx::Models::ExternalConnections::ReleaseRetrieveResponse
Return the details of a Release request and its phone numbers.
Constructor Details
#initialize(client:) ⇒ Releases
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Releases.
73 74 75 |
# File 'lib/telnyx/resources/external_connections/releases.rb', line 73 def initialize(client:) @client = client end |
Instance Method Details
#list(id, filter: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::ExternalConnections::ReleaseListResponse>
Some parameter documentations has been truncated, see Models::ExternalConnections::ReleaseListParams for more details.
Returns a list of your Releases for the given external connection. These are automatically created when you change the ‘connection_id` of a phone number that is currently on Microsoft Teams.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/telnyx/resources/external_connections/releases.rb', line 57 def list(id, params = {}) parsed, = Telnyx::ExternalConnections::ReleaseListParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["external_connections/%1$s/releases", id], query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"), page: Telnyx::Internal::DefaultFlatPagination, model: Telnyx::Models::ExternalConnections::ReleaseListResponse, options: ) end |
#retrieve(release_id, id:, request_options: {}) ⇒ Telnyx::Models::ExternalConnections::ReleaseRetrieveResponse
Return the details of a Release request and its phone numbers.
21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/telnyx/resources/external_connections/releases.rb', line 21 def retrieve(release_id, params) parsed, = Telnyx::ExternalConnections::ReleaseRetrieveParams.dump_request(params) id = parsed.delete(:id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["external_connections/%1$s/releases/%2$s", id, release_id], model: Telnyx::Models::ExternalConnections::ReleaseRetrieveResponse, options: ) end |