Class: Telnyx::Resources::LedgerBillingGroupReports
- Inherits:
-
Object
- Object
- Telnyx::Resources::LedgerBillingGroupReports
- Defined in:
- lib/telnyx/resources/ledger_billing_group_reports.rb,
sig/telnyx/resources/ledger_billing_group_reports.rbs
Overview
Ledger billing reports
Instance Method Summary collapse
-
#create(month: nil, year: nil, request_options: {}) ⇒ Telnyx::Models::LedgerBillingGroupReportCreateResponse
Create a ledger billing group report, which aggregates ledger activity by billing group.
-
#initialize(client:) ⇒ LedgerBillingGroupReports
constructor
private
A new instance of LedgerBillingGroupReports.
-
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::LedgerBillingGroupReportRetrieveResponse
Retrieve the details and status of a previously created ledger billing group report.
Constructor Details
#initialize(client:) ⇒ LedgerBillingGroupReports
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of LedgerBillingGroupReports.
56 57 58 |
# File 'lib/telnyx/resources/ledger_billing_group_reports.rb', line 56 def initialize(client:) @client = client end |
Instance Method Details
#create(month: nil, year: nil, request_options: {}) ⇒ Telnyx::Models::LedgerBillingGroupReportCreateResponse
Create a ledger billing group report, which aggregates ledger activity by billing group.
21 22 23 24 25 26 27 28 29 30 |
# File 'lib/telnyx/resources/ledger_billing_group_reports.rb', line 21 def create(params = {}) parsed, = Telnyx::LedgerBillingGroupReportCreateParams.dump_request(params) @client.request( method: :post, path: "ledger_billing_group_reports", body: parsed, model: Telnyx::Models::LedgerBillingGroupReportCreateResponse, options: ) end |
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::LedgerBillingGroupReportRetrieveResponse
Retrieve the details and status of a previously created ledger billing group report.
44 45 46 47 48 49 50 51 |
# File 'lib/telnyx/resources/ledger_billing_group_reports.rb', line 44 def retrieve(id, params = {}) @client.request( method: :get, path: ["ledger_billing_group_reports/%1$s", id], model: Telnyx::Models::LedgerBillingGroupReportRetrieveResponse, options: params[:request_options] ) end |