Class: Telnyx::Resources::Messaging10dlc::Brand::ExternalVetting

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/messaging_10dlc/brand/external_vetting.rb

Overview

Brand operations

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ ExternalVetting

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of ExternalVetting.

Parameters:



92
93
94
# File 'lib/telnyx/resources/messaging_10dlc/brand/external_vetting.rb', line 92

def initialize(client:)
  @client = client
end

Instance Method Details

#imports(brand_id, evp_id:, vetting_id:, vetting_token: nil, request_options: {}) ⇒ Telnyx::Models::Messaging10dlc::Brand::ExternalVettingImportsResponse

Some parameter documentations has been truncated, see Models::Messaging10dlc::Brand::ExternalVettingImportsParams for more details.

This operation can be used to import an external vetting record from a TCR-approved vetting provider. If the vetting provider confirms validity of the record, it will be saved with the brand and will be considered for future campaign qualification.

Parameters:

  • brand_id (String)
  • evp_id (String)

    External vetting provider ID for the brand.

  • vetting_id (String)

    Unique ID that identifies a vetting transaction performed by a vetting provider.

  • vetting_token (String)

    Required by some providers for vetting record confirmation.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



52
53
54
55
56
57
58
59
60
61
# File 'lib/telnyx/resources/messaging_10dlc/brand/external_vetting.rb', line 52

def imports(brand_id, params)
  parsed, options = Telnyx::Messaging10dlc::Brand::ExternalVettingImportsParams.dump_request(params)
  @client.request(
    method: :put,
    path: ["10dlc/brand/%1$s/externalVetting", brand_id],
    body: parsed,
    model: Telnyx::Models::Messaging10dlc::Brand::ExternalVettingImportsResponse,
    options: options
  )
end

#list(brand_id, request_options: {}) ⇒ Array<Telnyx::Models::Messaging10dlc::Brand::ExternalVettingListResponseItem>

Get list of valid external vetting record for a given brand

Parameters:

Returns:

See Also:



19
20
21
22
23
24
25
26
# File 'lib/telnyx/resources/messaging_10dlc/brand/external_vetting.rb', line 19

def list(brand_id, params = {})
  @client.request(
    method: :get,
    path: ["10dlc/brand/%1$s/externalVetting", brand_id],
    model: Telnyx::Internal::Type::ArrayOf[Telnyx::Models::Messaging10dlc::Brand::ExternalVettingListResponseItem],
    options: params[:request_options]
  )
end

#order(brand_id, evp_id:, vetting_class:, request_options: {}) ⇒ Telnyx::Models::Messaging10dlc::Brand::ExternalVettingOrderResponse

Order new external vetting for a brand

Parameters:

  • brand_id (String)
  • evp_id (String)

    External vetting provider ID for the brand.

  • vetting_class (String)

    Identifies the vetting classification.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



78
79
80
81
82
83
84
85
86
87
# File 'lib/telnyx/resources/messaging_10dlc/brand/external_vetting.rb', line 78

def order(brand_id, params)
  parsed, options = Telnyx::Messaging10dlc::Brand::ExternalVettingOrderParams.dump_request(params)
  @client.request(
    method: :post,
    path: ["10dlc/brand/%1$s/externalVetting", brand_id],
    body: parsed,
    model: Telnyx::Models::Messaging10dlc::Brand::ExternalVettingOrderResponse,
    options: options
  )
end