Class: Telnyx::Resources::Messaging10dlc::CampaignBuilder::Brand

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/messaging_10dlc/campaign_builder/brand.rb

Overview

Campaign operations

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Brand

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Brand.

Parameters:



39
40
41
# File 'lib/telnyx/resources/messaging_10dlc/campaign_builder/brand.rb', line 39

def initialize(client:)
  @client = client
end

Instance Method Details

#qualify_by_usecase(usecase, brand_id:, request_options: {}) ⇒ Telnyx::Models::Messaging10dlc::CampaignBuilder::BrandQualifyByUsecaseResponse

This endpoint allows you to see whether or not the supplied brand is suitable for your desired campaign use case.

Parameters:

Returns:

See Also:



21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/telnyx/resources/messaging_10dlc/campaign_builder/brand.rb', line 21

def qualify_by_usecase(usecase, params)
  parsed, options =
    Telnyx::Messaging10dlc::CampaignBuilder::BrandQualifyByUsecaseParams.dump_request(params)
  brand_id =
    parsed.delete(:brand_id) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :get,
    path: ["10dlc/campaignBuilder/brand/%1$s/usecase/%2$s", brand_id, usecase],
    model: Telnyx::Models::Messaging10dlc::CampaignBuilder::BrandQualifyByUsecaseResponse,
    options: options
  )
end