Class: Telnyx::Resources::MessagingProfileMetrics
- Inherits:
-
Object
- Object
- Telnyx::Resources::MessagingProfileMetrics
- Defined in:
- lib/telnyx/resources/messaging_profile_metrics.rb
Instance Method Summary collapse
-
#initialize(client:) ⇒ MessagingProfileMetrics
constructor
private
A new instance of MessagingProfileMetrics.
-
#list(time_frame: nil, request_options: {}) ⇒ Telnyx::Models::MessagingProfileMetricListResponse
List high-level metrics for all messaging profiles belonging to the authenticated user.
Constructor Details
#initialize(client:) ⇒ MessagingProfileMetrics
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of MessagingProfileMetrics.
33 34 35 |
# File 'lib/telnyx/resources/messaging_profile_metrics.rb', line 33 def initialize(client:) @client = client end |
Instance Method Details
#list(time_frame: nil, request_options: {}) ⇒ Telnyx::Models::MessagingProfileMetricListResponse
List high-level metrics for all messaging profiles belonging to the authenticated user.
18 19 20 21 22 23 24 25 26 27 28 |
# File 'lib/telnyx/resources/messaging_profile_metrics.rb', line 18 def list(params = {}) parsed, = Telnyx::MessagingProfileMetricListParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "messaging_profile_metrics", query: query, model: Telnyx::Models::MessagingProfileMetricListResponse, options: ) end |