Class: Telnyx::Resources::MobileNetworkOperators

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/mobile_network_operators.rb

Overview

Mobile network operators operations

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ MobileNetworkOperators

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of MobileNetworkOperators.

Parameters:



45
46
47
# File 'lib/telnyx/resources/mobile_network_operators.rb', line 45

def initialize(client:)
  @client = client
end

Instance Method Details

#list(filter: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::MobileNetworkOperatorListResponse>

Some parameter documentations has been truncated, see Models::MobileNetworkOperatorListParams for more details.

Telnyx has a set of GSM mobile operators partners that are available through our mobile network roaming. This resource is entirely managed by Telnyx and may change over time. That means that this resource won’t allow any write operations for it. Still, it’s available so it can be used as a support resource that can be related to other resources or become a configuration option.

Parameters:

Returns:

See Also:



29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/telnyx/resources/mobile_network_operators.rb', line 29

def list(params = {})
  parsed, options = Telnyx::MobileNetworkOperatorListParams.dump_request(params)
  query = Telnyx::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "mobile_network_operators",
    query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"),
    page: Telnyx::Internal::DefaultFlatPagination,
    model: Telnyx::Models::MobileNetworkOperatorListResponse,
    options: options
  )
end