Class: Telnyx::Resources::OperatorConnect::Actions

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/operator_connect/actions.rb

Overview

External Connections operations

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Actions

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Actions.

Parameters:



33
34
35
# File 'lib/telnyx/resources/operator_connect/actions.rb', line 33

def initialize(client:)
  @client = client
end

Instance Method Details

#refresh(request_options: {}) ⇒ Telnyx::Models::OperatorConnect::ActionRefreshResponse

This endpoint will make an asynchronous request to refresh the Operator Connect integration with Microsoft Teams for the current user. This will create new external connections on the user’s account if needed, and/or report the integration results as [log messages](developers.telnyx.com/api-reference/external-connections/list-all-log-messages#list-all-log-messages).

Parameters:

Returns:

See Also:



21
22
23
24
25
26
27
28
# File 'lib/telnyx/resources/operator_connect/actions.rb', line 21

def refresh(params = {})
  @client.request(
    method: :post,
    path: "operator_connect/actions/refresh",
    model: Telnyx::Models::OperatorConnect::ActionRefreshResponse,
    options: params[:request_options]
  )
end