Class: Telnyx::Resources::Portouts::SupportingDocuments
- Inherits:
-
Object
- Object
- Telnyx::Resources::Portouts::SupportingDocuments
- Defined in:
- lib/telnyx/resources/portouts/supporting_documents.rb
Overview
Number portout operations
Instance Method Summary collapse
-
#create(id, documents: nil, request_options: {}) ⇒ Telnyx::Models::Portouts::SupportingDocumentCreateResponse
Creates a list of supporting documents on a portout request.
-
#initialize(client:) ⇒ SupportingDocuments
constructor
private
A new instance of SupportingDocuments.
-
#list(id, request_options: {}) ⇒ Telnyx::Models::Portouts::SupportingDocumentListResponse
List every supporting documents for a portout request.
Constructor Details
#initialize(client:) ⇒ SupportingDocuments
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of SupportingDocuments.
55 56 57 |
# File 'lib/telnyx/resources/portouts/supporting_documents.rb', line 55 def initialize(client:) @client = client end |
Instance Method Details
#create(id, documents: nil, request_options: {}) ⇒ Telnyx::Models::Portouts::SupportingDocumentCreateResponse
Creates a list of supporting documents on a portout request.
21 22 23 24 25 26 27 28 29 30 |
# File 'lib/telnyx/resources/portouts/supporting_documents.rb', line 21 def create(id, params = {}) parsed, = Telnyx::Portouts::SupportingDocumentCreateParams.dump_request(params) @client.request( method: :post, path: ["portouts/%1$s/supporting_documents", id], body: parsed, model: Telnyx::Models::Portouts::SupportingDocumentCreateResponse, options: ) end |
#list(id, request_options: {}) ⇒ Telnyx::Models::Portouts::SupportingDocumentListResponse
List every supporting documents for a portout request.
43 44 45 46 47 48 49 50 |
# File 'lib/telnyx/resources/portouts/supporting_documents.rb', line 43 def list(id, params = {}) @client.request( method: :get, path: ["portouts/%1$s/supporting_documents", id], model: Telnyx::Models::Portouts::SupportingDocumentListResponse, options: params[:request_options] ) end |