Class: Telnyx::Resources::Regions
- Inherits:
-
Object
- Object
- Telnyx::Resources::Regions
- Defined in:
- lib/telnyx/resources/regions.rb
Overview
Regions
Instance Method Summary collapse
-
#initialize(client:) ⇒ Regions
constructor
private
A new instance of Regions.
-
#list(request_options: {}) ⇒ Telnyx::Models::RegionListResponse
List all regions and the interfaces that region supports.
Constructor Details
#initialize(client:) ⇒ Regions
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Regions.
28 29 30 |
# File 'lib/telnyx/resources/regions.rb', line 28 def initialize(client:) @client = client end |
Instance Method Details
#list(request_options: {}) ⇒ Telnyx::Models::RegionListResponse
List all regions and the interfaces that region supports
16 17 18 19 20 21 22 23 |
# File 'lib/telnyx/resources/regions.rb', line 16 def list(params = {}) @client.request( method: :get, path: "regions", model: Telnyx::Models::RegionListResponse, options: params[:request_options] ) end |