Class: Telnyx::Resources::RegulatoryRequirements

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/regulatory_requirements.rb,
sig/telnyx/resources/regulatory_requirements.rbs

Overview

Regulatory Requirements

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ RegulatoryRequirements

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of RegulatoryRequirements.



38
39
40
# File 'lib/telnyx/resources/regulatory_requirements.rb', line 38

def initialize(client:)
  @client = client
end

Instance Method Details

#retrieve(filter: nil, request_options: {}) ⇒ Telnyx::Models::RegulatoryRequirementRetrieveResponse

Some parameter documentations has been truncated, see Models::RegulatoryRequirementRetrieveParams for more details.

Returns regulatory requirements for number ordering, porting, or other supported actions. Results can be filtered by phone number, requirement group, country, number type, and action.



23
24
25
26
27
28
29
30
31
32
33
# File 'lib/telnyx/resources/regulatory_requirements.rb', line 23

def retrieve(params = {})
  parsed, options = Telnyx::RegulatoryRequirementRetrieveParams.dump_request(params)
  query = Telnyx::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "regulatory_requirements",
    query: query,
    model: Telnyx::Models::RegulatoryRequirementRetrieveResponse,
    options: options
  )
end