Class: Telnyx::Resources::Reputation
- Inherits:
-
Object
- Object
- Telnyx::Resources::Reputation
- Defined in:
- lib/telnyx/resources/reputation.rb,
lib/telnyx/resources/reputation/numbers.rb
Defined Under Namespace
Classes: Numbers
Instance Attribute Summary collapse
-
#numbers ⇒ Telnyx::Resources::Reputation::Numbers
readonly
Associate phone numbers with an enterprise for reputation monitoring and retrieve reputation scores.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Reputation
constructor
private
A new instance of Reputation.
Constructor Details
#initialize(client:) ⇒ Reputation
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Reputation.
14 15 16 17 |
# File 'lib/telnyx/resources/reputation.rb', line 14 def initialize(client:) @client = client @numbers = Telnyx::Resources::Reputation::Numbers.new(client: client) end |
Instance Attribute Details
#numbers ⇒ Telnyx::Resources::Reputation::Numbers (readonly)
Associate phone numbers with an enterprise for reputation monitoring and retrieve reputation scores
9 10 11 |
# File 'lib/telnyx/resources/reputation.rb', line 9 def numbers @numbers end |