Class: Telnyx::Resources::RoomRecordings

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/room_recordings.rb,
sig/telnyx/resources/room_recordings.rbs

Overview

Rooms Recordings operations.

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ RoomRecordings

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of RoomRecordings.

Parameters:



117
118
119
# File 'lib/telnyx/resources/room_recordings.rb', line 117

def initialize(client:)
  @client = client
end

Instance Method Details

#delete(room_recording_id, request_options: {}) ⇒ nil

Synchronously deletes the specified video room recording. The recording's media is removed permanently.

Parameters:

  • room_recording_id (String)

    The unique identifier of a room recording.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

  • (nil)

See Also:



73
74
75
76
77
78
79
80
# File 'lib/telnyx/resources/room_recordings.rb', line 73

def delete(room_recording_id, params = {})
  @client.request(
    method: :delete,
    path: ["room_recordings/%1$s", room_recording_id],
    model: NilClass,
    options: params[:request_options]
  )
end

#delete_bulk(filter: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Models::RoomRecordingDeleteBulkResponse

Some parameter documentations has been truncated, see Models::RoomRecordingDeleteBulkParams for more details.

Deletes the room recordings that match the supplied filters and returns the number of recordings affected. Filters support room, session, participant, recording type, status, duration, and start or end dates.

Parameters:

Returns:

See Also:



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/telnyx/resources/room_recordings.rb', line 102

def delete_bulk(params = {})
  parsed, options = Telnyx::RoomRecordingDeleteBulkParams.dump_request(params)
  query = Telnyx::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :delete,
    path: "room_recordings",
    query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"),
    model: Telnyx::Models::RoomRecordingDeleteBulkResponse,
    options: options
  )
end

#list(filter: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::RoomRecording>

Some parameter documentations has been truncated, see Models::RoomRecordingListParams for more details.

Returns a paginated list of room recordings. Filter recordings by room, session, participant, recording type, status, duration, or start and end dates.

Parameters:

Returns:

See Also:



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/telnyx/resources/room_recordings.rb', line 48

def list(params = {})
  parsed, options = Telnyx::RoomRecordingListParams.dump_request(params)
  query = Telnyx::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "room_recordings",
    query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"),
    page: Telnyx::Internal::DefaultFlatPagination,
    model: Telnyx::RoomRecording,
    options: options
  )
end

#retrieve(room_recording_id, request_options: {}) ⇒ Telnyx::Models::RoomRecordingRetrieveResponse

Returns the recording identified by room_recording_id, including its room, session, participant, status, media details, lifecycle timestamps, and download URL.

Parameters:

  • room_recording_id (String)

    The unique identifier of a room recording.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



20
21
22
23
24
25
26
27
# File 'lib/telnyx/resources/room_recordings.rb', line 20

def retrieve(room_recording_id, params = {})
  @client.request(
    method: :get,
    path: ["room_recordings/%1$s", room_recording_id],
    model: Telnyx::Models::RoomRecordingRetrieveResponse,
    options: params[:request_options]
  )
end