Class: Telnyx::Resources::Rooms::Sessions::Actions
- Inherits:
-
Object
- Object
- Telnyx::Resources::Rooms::Sessions::Actions
- Defined in:
- lib/telnyx/resources/rooms/sessions/actions.rb,
sig/telnyx/resources/rooms/sessions/actions.rbs
Overview
Rooms Sessions operations.
Instance Method Summary collapse
-
#end_(room_session_id, request_options: {}) ⇒ Telnyx::Models::Rooms::Sessions::ActionEndResponse
Note: this will also kick all participants currently present in the room.
-
#initialize(client:) ⇒ Actions
constructor
private
A new instance of Actions.
-
#kick(room_session_id, exclude: nil, participants: nil, request_options: {}) ⇒ Telnyx::Models::Rooms::Sessions::ActionKickResponse
Some parameter documentations has been truncated, see Models::Rooms::Sessions::ActionKickParams for more details.
-
#mute(room_session_id, exclude: nil, participants: nil, request_options: {}) ⇒ Telnyx::Models::Rooms::Sessions::ActionMuteResponse
Some parameter documentations has been truncated, see Models::Rooms::Sessions::ActionMuteParams for more details.
-
#unmute(room_session_id, exclude: nil, participants: nil, request_options: {}) ⇒ Telnyx::Models::Rooms::Sessions::ActionUnmuteResponse
Some parameter documentations has been truncated, see Models::Rooms::Sessions::ActionUnmuteParams for more details.
Constructor Details
#initialize(client:) ⇒ Actions
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Actions.
125 126 127 |
# File 'lib/telnyx/resources/rooms/sessions/actions.rb', line 125 def initialize(client:) @client = client end |
Instance Method Details
#end_(room_session_id, request_options: {}) ⇒ Telnyx::Models::Rooms::Sessions::ActionEndResponse
Note: this will also kick all participants currently present in the room
20 21 22 23 24 25 26 27 |
# File 'lib/telnyx/resources/rooms/sessions/actions.rb', line 20 def end_(room_session_id, params = {}) @client.request( method: :post, path: ["room_sessions/%1$s/actions/end", room_session_id], model: Telnyx::Models::Rooms::Sessions::ActionEndResponse, options: params[:request_options] ) end |
#kick(room_session_id, exclude: nil, participants: nil, request_options: {}) ⇒ Telnyx::Models::Rooms::Sessions::ActionKickResponse
Some parameter documentations has been truncated, see Models::Rooms::Sessions::ActionKickParams for more details.
Removes the selected participants from the specified room session. Apply the
action to a list of participant IDs or to all, with optional participant IDs
excluded from the action.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/telnyx/resources/rooms/sessions/actions.rb', line 49 def kick(room_session_id, params = {}) parsed, = Telnyx::Rooms::Sessions::ActionKickParams.dump_request(params) @client.request( method: :post, path: ["room_sessions/%1$s/actions/kick", room_session_id], body: parsed, model: Telnyx::Models::Rooms::Sessions::ActionKickResponse, options: ) end |
#mute(room_session_id, exclude: nil, participants: nil, request_options: {}) ⇒ Telnyx::Models::Rooms::Sessions::ActionMuteResponse
Some parameter documentations has been truncated, see Models::Rooms::Sessions::ActionMuteParams for more details.
Mutes the selected participants in the specified room session. Apply the action
to a list of participant IDs or to all, with optional participant IDs excluded
from the action.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/telnyx/resources/rooms/sessions/actions.rb', line 80 def mute(room_session_id, params = {}) parsed, = Telnyx::Rooms::Sessions::ActionMuteParams.dump_request(params) @client.request( method: :post, path: ["room_sessions/%1$s/actions/mute", room_session_id], body: parsed, model: Telnyx::Models::Rooms::Sessions::ActionMuteResponse, options: ) end |
#unmute(room_session_id, exclude: nil, participants: nil, request_options: {}) ⇒ Telnyx::Models::Rooms::Sessions::ActionUnmuteResponse
Some parameter documentations has been truncated, see Models::Rooms::Sessions::ActionUnmuteParams for more details.
Unmutes the selected participants in the specified room session. Apply the
action to a list of participant IDs or to all, with optional participant IDs
excluded from the action.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/telnyx/resources/rooms/sessions/actions.rb', line 111 def unmute(room_session_id, params = {}) parsed, = Telnyx::Rooms::Sessions::ActionUnmuteParams.dump_request(params) @client.request( method: :post, path: ["room_sessions/%1$s/actions/unmute", room_session_id], body: parsed, model: Telnyx::Models::Rooms::Sessions::ActionUnmuteResponse, options: ) end |