Class: Telnyx::Resources::Seti
- Inherits:
-
Object
- Object
- Telnyx::Resources::Seti
- Defined in:
- lib/telnyx/resources/seti.rb
Overview
Observability into Telnyx platform stability and performance.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Seti
constructor
private
A new instance of Seti.
-
#retrieve_black_box_test_results(filter: nil, request_options: {}) ⇒ Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse
Returns the results of the various black box tests.
Constructor Details
#initialize(client:) ⇒ Seti
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Seti.
33 34 35 |
# File 'lib/telnyx/resources/seti.rb', line 33 def initialize(client:) @client = client end |
Instance Method Details
#retrieve_black_box_test_results(filter: nil, request_options: {}) ⇒ Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse
Returns the results of the various black box tests
18 19 20 21 22 23 24 25 26 27 28 |
# File 'lib/telnyx/resources/seti.rb', line 18 def retrieve_black_box_test_results(params = {}) parsed, = Telnyx::SetiRetrieveBlackBoxTestResultsParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "seti/black_box_test_results", query: query, model: Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse, options: ) end |