Class: Telnyx::Resources::Storage

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/storage.rb,
lib/telnyx/resources/storage/kvs.rb,
lib/telnyx/resources/storage/buckets.rb,
lib/telnyx/resources/storage/kvs/keys.rb,
lib/telnyx/resources/storage/migrations.rb,
lib/telnyx/resources/storage/buckets/usage.rb,
lib/telnyx/resources/storage/migration_sources.rb,
lib/telnyx/resources/storage/migrations/actions.rb,
lib/telnyx/resources/storage/buckets/ssl_certificate.rb,
sig/telnyx/resources/storage.rbs,
sig/telnyx/resources/storage/kvs.rbs,
sig/telnyx/resources/storage/buckets.rbs,
sig/telnyx/resources/storage/kvs/keys.rbs,
sig/telnyx/resources/storage/migrations.rbs,
sig/telnyx/resources/storage/buckets/usage.rbs,
sig/telnyx/resources/storage/migration_sources.rbs,
sig/telnyx/resources/storage/migrations/actions.rbs,
sig/telnyx/resources/storage/buckets/ssl_certificate.rbs

Overview

Migrate data from an external provider into Telnyx Cloud Storage

Defined Under Namespace

Classes: Buckets, Kvs, MigrationSources, Migrations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Storage

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Storage.

Parameters:



44
45
46
47
48
49
50
# File 'lib/telnyx/resources/storage.rb', line 44

def initialize(client:)
  @client = client
  @buckets = Telnyx::Resources::Storage::Buckets.new(client: client)
  @migration_sources = Telnyx::Resources::Storage::MigrationSources.new(client: client)
  @migrations = Telnyx::Resources::Storage::Migrations.new(client: client)
  @kvs = Telnyx::Resources::Storage::Kvs.new(client: client)
end

Instance Attribute Details

#bucketsTelnyx::Resources::Storage::Buckets (readonly)

Presigned object URL operations



9
10
11
# File 'lib/telnyx/resources/storage.rb', line 9

def buckets
  @buckets
end

#kvsTelnyx::Resources::Storage::Kvs (readonly)

Manage KV storage namespaces



21
22
23
# File 'lib/telnyx/resources/storage.rb', line 21

def kvs
  @kvs
end

#migration_sourcesTelnyx::Resources::Storage::MigrationSources (readonly)

Migrate data from an external provider into Telnyx Cloud Storage



13
14
15
# File 'lib/telnyx/resources/storage.rb', line 13

def migration_sources
  @migration_sources
end

#migrationsTelnyx::Resources::Storage::Migrations (readonly)

Migrate data from an external provider into Telnyx Cloud Storage



17
18
19
# File 'lib/telnyx/resources/storage.rb', line 17

def migrations
  @migrations
end

Instance Method Details

#list_migration_source_coverage(request_options: {}) ⇒ Telnyx::Models::StorageListMigrationSourceCoverageResponse

List Migration Source coverage



32
33
34
35
36
37
38
39
# File 'lib/telnyx/resources/storage.rb', line 32

def list_migration_source_coverage(params = {})
  @client.request(
    method: :get,
    path: "storage/migration_source_coverage",
    model: Telnyx::Models::StorageListMigrationSourceCoverageResponse,
    options: params[:request_options]
  )
end