Class: Telnyx::Resources::TermsOfService::BrandedCalling

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/terms_of_service/branded_calling.rb

Overview

Accept and review the Branded Calling and Phone Number Reputation terms of service.

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ BrandedCalling

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of BrandedCalling.

Parameters:



36
37
38
# File 'lib/telnyx/resources/terms_of_service/branded_calling.rb', line 36

def initialize(client:)
  @client = client
end

Instance Method Details

#agree(request_options: {}) ⇒ Telnyx::Models::TermsOfService::BrandedCallingAgreeResponse

Records the authenticated user’s agreement to the current Branded Calling ToS. No body required. Idempotent - re-calling after agreement is a no-op and returns the existing agreement.

This is a prerequisite for activating Branded Calling on any enterprise (‘POST /enterprises/id/branded_calling`); without an agreement, activation returns `403`.



24
25
26
27
28
29
30
31
# File 'lib/telnyx/resources/terms_of_service/branded_calling.rb', line 24

def agree(params = {})
  @client.request(
    method: :post,
    path: "terms_of_service/branded_calling/agree",
    model: Telnyx::Models::TermsOfService::BrandedCallingAgreeResponse,
    options: params[:request_options]
  )
end