Class: Telnyx::Resources::TermsOfService::NumberReputation

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/terms_of_service/number_reputation.rb

Overview

Accept and review the Branded Calling and Phone Number Reputation terms of service.

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ NumberReputation

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of NumberReputation.

Parameters:



33
34
35
# File 'lib/telnyx/resources/terms_of_service/number_reputation.rb', line 33

def initialize(client:)
  @client = client
end

Instance Method Details

#agree(request_options: {}) ⇒ Telnyx::Models::TermsOfService::NumberReputationAgreeResponse

Records the authenticated user’s agreement to the current Phone Number Reputation ToS. No body required. Idempotent.

Prerequisite for using any of the ‘/v2/…/reputation/*` endpoints.



21
22
23
24
25
26
27
28
# File 'lib/telnyx/resources/terms_of_service/number_reputation.rb', line 21

def agree(params = {})
  @client.request(
    method: :post,
    path: "terms_of_service/number_reputation/agree",
    model: Telnyx::Models::TermsOfService::NumberReputationAgreeResponse,
    options: params[:request_options]
  )
end