Class: Telnyx::Resources::Texml::Accounts

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/texml/accounts.rb,
lib/telnyx/resources/texml/accounts/calls.rb,
lib/telnyx/resources/texml/accounts/queues.rb,
lib/telnyx/resources/texml/accounts/recordings.rb,
lib/telnyx/resources/texml/accounts/conferences.rb,
lib/telnyx/resources/texml/accounts/calls/siprec.rb,
lib/telnyx/resources/texml/accounts/calls/streams.rb,
lib/telnyx/resources/texml/accounts/transcriptions.rb,
lib/telnyx/resources/texml/accounts/recordings/json.rb,
lib/telnyx/resources/texml/accounts/calls/recordings.rb,
lib/telnyx/resources/texml/accounts/transcriptions/json.rb,
lib/telnyx/resources/texml/accounts/calls/recordings_json.rb,
lib/telnyx/resources/texml/accounts/conferences/participants.rb

Overview

TeXML REST Commands

Defined Under Namespace

Classes: Calls, Conferences, Queues, Recordings, Transcriptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Accounts

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Accounts.

Parameters:



88
89
90
91
92
93
94
95
# File 'lib/telnyx/resources/texml/accounts.rb', line 88

def initialize(client:)
  @client = client
  @calls = Telnyx::Resources::Texml::Accounts::Calls.new(client: client)
  @conferences = Telnyx::Resources::Texml::Accounts::Conferences.new(client: client)
  @recordings = Telnyx::Resources::Texml::Accounts::Recordings.new(client: client)
  @transcriptions = Telnyx::Resources::Texml::Accounts::Transcriptions.new(client: client)
  @queues = Telnyx::Resources::Texml::Accounts::Queues.new(client: client)
end

Instance Attribute Details

#callsTelnyx::Resources::Texml::Accounts::Calls (readonly)

TeXML REST Commands



10
11
12
# File 'lib/telnyx/resources/texml/accounts.rb', line 10

def calls
  @calls
end

#conferencesTelnyx::Resources::Texml::Accounts::Conferences (readonly)

TeXML REST Commands



14
15
16
# File 'lib/telnyx/resources/texml/accounts.rb', line 14

def conferences
  @conferences
end

#queuesTelnyx::Resources::Texml::Accounts::Queues (readonly)

TeXML REST Commands



24
25
26
# File 'lib/telnyx/resources/texml/accounts.rb', line 24

def queues
  @queues
end

#recordingsTelnyx::Resources::Texml::Accounts::Recordings (readonly)



17
18
19
# File 'lib/telnyx/resources/texml/accounts.rb', line 17

def recordings
  @recordings
end

#transcriptionsTelnyx::Resources::Texml::Accounts::Transcriptions (readonly)



20
21
22
# File 'lib/telnyx/resources/texml/accounts.rb', line 20

def transcriptions
  @transcriptions
end

Instance Method Details

#retrieve_recordings_json(account_sid, date_created: nil, page: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Models::Texml::AccountRetrieveRecordingsJsonResponse

Some parameter documentations has been truncated, see Models::Texml::AccountRetrieveRecordingsJsonParams for more details.

Returns multiple recording resources for an account.

Parameters:

  • account_sid (String)

    The id of the account the resource belongs to.

  • date_created (Time)

    Filters recording by the creation date. Expected format is ISO8601 date or date-

  • page (Integer)

    The number of the page to be displayed, zero-indexed, should be used in conjucti

  • page_size (Integer)

    The number of records to be displayed on a page

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



46
47
48
49
50
51
52
53
54
55
56
# File 'lib/telnyx/resources/texml/accounts.rb', line 46

def retrieve_recordings_json(, params = {})
  parsed, options = Telnyx::Texml::AccountRetrieveRecordingsJsonParams.dump_request(params)
  query = Telnyx::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["texml/Accounts/%1$s/Recordings.json", ],
    query: query.transform_keys(date_created: "DateCreated", page: "Page", page_size: "PageSize"),
    model: Telnyx::Models::Texml::AccountRetrieveRecordingsJsonResponse,
    options: options
  )
end

#retrieve_transcriptions_json(account_sid, page_size: nil, page_token: nil, request_options: {}) ⇒ Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse

Returns multiple recording transcription resources for an account.

Parameters:

  • account_sid (String)

    The id of the account the resource belongs to.

  • page_size (Integer)

    The number of records to be displayed on a page

  • page_token (String)

    Used to request the next page of results.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



73
74
75
76
77
78
79
80
81
82
83
# File 'lib/telnyx/resources/texml/accounts.rb', line 73

def retrieve_transcriptions_json(, params = {})
  parsed, options = Telnyx::Texml::AccountRetrieveTranscriptionsJsonParams.dump_request(params)
  query = Telnyx::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["texml/Accounts/%1$s/Transcriptions.json", ],
    query: query.transform_keys(page_size: "PageSize", page_token: "PageToken"),
    model: Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse,
    options: options
  )
end