Class: Telnyx::Resources::Texml::Accounts::Conferences
- Inherits:
-
Object
- Object
- Telnyx::Resources::Texml::Accounts::Conferences
- Defined in:
- lib/telnyx/resources/texml/accounts/conferences.rb,
lib/telnyx/resources/texml/accounts/conferences/participants.rb,
sig/telnyx/resources/texml/accounts/conferences.rbs,
sig/telnyx/resources/texml/accounts/conferences/participants.rbs
Overview
TeXML REST Commands
Defined Under Namespace
Classes: Participants
Instance Attribute Summary collapse
-
#participants ⇒ Telnyx::Resources::Texml::Accounts::Conferences::Participants
readonly
TeXML REST Commands.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Conferences
constructor
private
A new instance of Conferences.
-
#retrieve(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceResource
Returns a single conference resource for the account by its ConferenceSid.
-
#retrieve_conferences(account_sid, date_created: nil, date_updated: nil, friendly_name: nil, page: nil, page_size: nil, page_token: nil, status: nil, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse
Some parameter documentations has been truncated, see Models::Texml::Accounts::ConferenceRetrieveConferencesParams for more details.
-
#retrieve_recordings(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse
Returns the list of recordings made for the specified conference.
-
#retrieve_recordings_json(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Calls::TexmlGetCallRecordingsResponseBody
Returns recordings for a conference identified by conference_sid.
-
#update(conference_sid, account_sid:, announce_method: nil, announce_url: nil, status: nil, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceResource
Some parameter documentations has been truncated, see Models::Texml::Accounts::ConferenceUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ Conferences
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Conferences.
186 187 188 189 |
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 186 def initialize(client:) @client = client @participants = Telnyx::Resources::Texml::Accounts::Conferences::Participants.new(client: client) end |
Instance Attribute Details
#participants ⇒ Telnyx::Resources::Texml::Accounts::Conferences::Participants (readonly)
TeXML REST Commands
11 12 13 |
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 11 def participants @participants end |
Instance Method Details
#retrieve(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceResource
Returns a single conference resource for the account by its ConferenceSid.
26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 26 def retrieve(conference_sid, params) parsed, = Telnyx::Texml::Accounts::ConferenceRetrieveParams.dump_request(params) account_sid = parsed.delete(:account_sid) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["texml/Accounts/%1$s/Conferences/%2$s", account_sid, conference_sid], model: Telnyx::Texml::Accounts::ConferenceResource, options: ) end |
#retrieve_conferences(account_sid, date_created: nil, date_updated: nil, friendly_name: nil, page: nil, page_size: nil, page_token: nil, status: nil, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse
Some parameter documentations has been truncated, see Models::Texml::Accounts::ConferenceRetrieveConferencesParams for more details.
Returns a paginated list of conference resources for the account, with support for filtering by friendly name, status, and creation or update dates.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 109 def retrieve_conferences(account_sid, params = {}) parsed, = Telnyx::Texml::Accounts::ConferenceRetrieveConferencesParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["texml/Accounts/%1$s/Conferences", account_sid], query: query.transform_keys( date_created: "DateCreated", date_updated: "DateUpdated", friendly_name: "FriendlyName", page: "Page", page_size: "PageSize", page_token: "PageToken", status: "Status" ), model: Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse, options: ) end |
#retrieve_recordings(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse
Returns the list of recordings made for the specified conference.
142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 142 def retrieve_recordings(conference_sid, params) parsed, = Telnyx::Texml::Accounts::ConferenceRetrieveRecordingsParams.dump_request(params) account_sid = parsed.delete(:account_sid) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["texml/Accounts/%1$s/Conferences/%2$s/Recordings", account_sid, conference_sid], model: Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse, options: ) end |
#retrieve_recordings_json(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Calls::TexmlGetCallRecordingsResponseBody
Returns recordings for a conference identified by conference_sid.
169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 169 def retrieve_recordings_json(conference_sid, params) parsed, = Telnyx::Texml::Accounts::ConferenceRetrieveRecordingsJsonParams.dump_request(params) account_sid = parsed.delete(:account_sid) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["texml/Accounts/%1$s/Conferences/%2$s/Recordings.json", account_sid, conference_sid], model: Telnyx::Texml::Accounts::Calls::TexmlGetCallRecordingsResponseBody, options: ) end |
#update(conference_sid, account_sid:, announce_method: nil, announce_url: nil, status: nil, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceResource
Some parameter documentations has been truncated, see Models::Texml::Accounts::ConferenceUpdateParams for more details.
Updates the specified conference resource, for example to modify its status, and returns the updated conference.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 63 def update(conference_sid, params) parsed, = Telnyx::Texml::Accounts::ConferenceUpdateParams.dump_request(params) account_sid = parsed.delete(:account_sid) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :post, path: ["texml/Accounts/%1$s/Conferences/%2$s", account_sid, conference_sid], headers: {"content-type" => "application/x-www-form-urlencoded"}, body: parsed, model: Telnyx::Texml::Accounts::ConferenceResource, options: ) end |