Class: Telnyx::Resources::Texml::Accounts::Conferences::Participants
- Inherits:
-
Object
- Object
- Telnyx::Resources::Texml::Accounts::Conferences::Participants
- Defined in:
- lib/telnyx/resources/texml/accounts/conferences/participants.rb,
sig/telnyx/resources/texml/accounts/conferences/participants.rbs
Overview
TeXML REST Commands
Instance Method Summary collapse
-
#delete(call_sid_or_participant_label, account_sid:, conference_sid:, request_options: {}) ⇒ nil
Removes the specified participant from the conference, ending their leg of the call.
-
#initialize(client:) ⇒ Participants
constructor
private
A new instance of Participants.
-
#participants(conference_sid, account_sid:, amd_status_callback: nil, amd_status_callback_method: nil, application_sid: nil, beep: nil, caller_id: nil, call_sid_to_coach: nil, cancel_playback_on_detect_message_end: nil, cancel_playback_on_machine_detection: nil, coaching: nil, conference_record: nil, conference_recording_status_callback: nil, conference_recording_status_callback_event: nil, conference_recording_status_callback_method: nil, conference_recording_timeout: nil, conference_status_callback: nil, conference_status_callback_event: nil, conference_status_callback_method: nil, conference_trim: nil, custom_headers: nil, early_media: nil, end_conference_on_exit: nil, from: nil, label: nil, machine_detection: nil, machine_detection_beep_profile: nil, machine_detection_silence_timeout: nil, machine_detection_speech_end_threshold: nil, machine_detection_speech_threshold: nil, machine_detection_timeout: nil, max_participants: nil, muted: nil, preferred_codecs: nil, record: nil, recording_channels: nil, recording_status_callback: nil, recording_status_callback_event: nil, recording_status_callback_method: nil, recording_track: nil, sip_auth_password: nil, sip_auth_username: nil, start_conference_on_enter: nil, status_callback: nil, status_callback_event: nil, status_callback_method: nil, time_limit: nil, timeout_seconds: nil, to: nil, trim: nil, wait_url: nil, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsResponse
Some parameter documentations has been truncated, see Models::Texml::Accounts::Conferences::ParticipantParticipantsParams for more details.
-
#retrieve(call_sid_or_participant_label, account_sid:, conference_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Conferences::ParticipantResource
Returns a single conference participant resource by call SID or participant label.
-
#retrieve_participants(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse
Returns the list of participants currently in the specified conference.
-
#update(call_sid_or_participant_label, account_sid:, conference_sid:, announce_method: nil, announce_url: nil, beep_on_exit: nil, call_sid_to_coach: nil, coaching: nil, end_conference_on_exit: nil, hold: nil, hold_method: nil, hold_url: nil, muted: nil, wait_url: nil, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Conferences::ParticipantResource
Some parameter documentations has been truncated, see Models::Texml::Accounts::Conferences::ParticipantUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ Participants
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Participants.
319 320 321 |
# File 'lib/telnyx/resources/texml/accounts/conferences/participants.rb', line 319 def initialize(client:) @client = client end |
Instance Method Details
#delete(call_sid_or_participant_label, account_sid:, conference_sid:, request_options: {}) ⇒ nil
Removes the specified participant from the conference, ending their leg of the call.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/telnyx/resources/texml/accounts/conferences/participants.rb', line 132 def delete(call_sid_or_participant_label, params) parsed, = Telnyx::Texml::Accounts::Conferences::ParticipantDeleteParams.dump_request(params) account_sid = parsed.delete(:account_sid) do raise ArgumentError.new("missing required path argument #{_1}") end conference_sid = parsed.delete(:conference_sid) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :delete, path: [ "texml/Accounts/%1$s/Conferences/%2$s/Participants/%3$s", account_sid, conference_sid, call_sid_or_participant_label ], model: NilClass, options: ) end |
#participants(conference_sid, account_sid:, amd_status_callback: nil, amd_status_callback_method: nil, application_sid: nil, beep: nil, caller_id: nil, call_sid_to_coach: nil, cancel_playback_on_detect_message_end: nil, cancel_playback_on_machine_detection: nil, coaching: nil, conference_record: nil, conference_recording_status_callback: nil, conference_recording_status_callback_event: nil, conference_recording_status_callback_method: nil, conference_recording_timeout: nil, conference_status_callback: nil, conference_status_callback_event: nil, conference_status_callback_method: nil, conference_trim: nil, custom_headers: nil, early_media: nil, end_conference_on_exit: nil, from: nil, label: nil, machine_detection: nil, machine_detection_beep_profile: nil, machine_detection_silence_timeout: nil, machine_detection_speech_end_threshold: nil, machine_detection_speech_threshold: nil, machine_detection_timeout: nil, max_participants: nil, muted: nil, preferred_codecs: nil, record: nil, recording_channels: nil, recording_status_callback: nil, recording_status_callback_event: nil, recording_status_callback_method: nil, recording_track: nil, sip_auth_password: nil, sip_auth_username: nil, start_conference_on_enter: nil, status_callback: nil, status_callback_event: nil, status_callback_method: nil, time_limit: nil, timeout_seconds: nil, to: nil, trim: nil, wait_url: nil, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsResponse
Some parameter documentations has been truncated, see Models::Texml::Accounts::Conferences::ParticipantParticipantsParams for more details.
Dials a new participant into the specified conference and returns the created participant resource.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/telnyx/resources/texml/accounts/conferences/participants.rb', line 271 def participants(conference_sid, params) parsed, = Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams.dump_request(params) account_sid = parsed.delete(:account_sid) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :post, path: ["texml/Accounts/%1$s/Conferences/%2$s/Participants", account_sid, conference_sid], headers: {"content-type" => "application/x-www-form-urlencoded"}, body: parsed, model: Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsResponse, options: ) end |
#retrieve(call_sid_or_participant_label, account_sid:, conference_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Conferences::ParticipantResource
Returns a single conference participant resource by call SID or participant label.
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/telnyx/resources/texml/accounts/conferences/participants.rb', line 26 def retrieve(call_sid_or_participant_label, params) parsed, = Telnyx::Texml::Accounts::Conferences::ParticipantRetrieveParams.dump_request(params) account_sid = parsed.delete(:account_sid) do raise ArgumentError.new("missing required path argument #{_1}") end conference_sid = parsed.delete(:conference_sid) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: [ "texml/Accounts/%1$s/Conferences/%2$s/Participants/%3$s", account_sid, conference_sid, call_sid_or_participant_label ], model: Telnyx::Texml::Accounts::Conferences::ParticipantResource, options: ) end |
#retrieve_participants(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse
Returns the list of participants currently in the specified conference.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/telnyx/resources/texml/accounts/conferences/participants.rb', line 301 def retrieve_participants(conference_sid, params) parsed, = Telnyx::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsParams.dump_request(params) account_sid = parsed.delete(:account_sid) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["texml/Accounts/%1$s/Conferences/%2$s/Participants", account_sid, conference_sid], model: Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse, options: ) end |
#update(call_sid_or_participant_label, account_sid:, conference_sid:, announce_method: nil, announce_url: nil, beep_on_exit: nil, call_sid_to_coach: nil, coaching: nil, end_conference_on_exit: nil, hold: nil, hold_method: nil, hold_url: nil, muted: nil, wait_url: nil, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Conferences::ParticipantResource
Some parameter documentations has been truncated, see Models::Texml::Accounts::Conferences::ParticipantUpdateParams for more details.
Updates the specified conference participant, for example muting or holding them, and returns the updated participant.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/telnyx/resources/texml/accounts/conferences/participants.rb', line 91 def update(call_sid_or_participant_label, params) parsed, = Telnyx::Texml::Accounts::Conferences::ParticipantUpdateParams.dump_request(params) account_sid = parsed.delete(:account_sid) do raise ArgumentError.new("missing required path argument #{_1}") end conference_sid = parsed.delete(:conference_sid) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :post, path: [ "texml/Accounts/%1$s/Conferences/%2$s/Participants/%3$s", account_sid, conference_sid, call_sid_or_participant_label ], headers: {"content-type" => "application/x-www-form-urlencoded"}, body: parsed, model: Telnyx::Texml::Accounts::Conferences::ParticipantResource, options: ) end |