Class: Telnyx::Resources::Texml::Accounts::Recordings::Json

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/texml/accounts/recordings/json.rb

Overview

TeXML REST Commands

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Json

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Json.

Parameters:



69
70
71
# File 'lib/telnyx/resources/texml/accounts/recordings/json.rb', line 69

def initialize(client:)
  @client = client
end

Instance Method Details

#delete_recording_sid_json(recording_sid, account_sid:, request_options: {}) ⇒ nil

Deletes recording resource identified by recording id.

Parameters:

  • recording_sid (String)

    Uniquely identifies the recording by id.

  • account_sid (String)

    The id of the account the resource belongs to.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

  • (nil)

See Also:



23
24
25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/telnyx/resources/texml/accounts/recordings/json.rb', line 23

def delete_recording_sid_json(recording_sid, params)
  parsed, options =
    Telnyx::Texml::Accounts::Recordings::JsonDeleteRecordingSidJsonParams.dump_request(params)
   =
    parsed.delete(:account_sid) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :delete,
    path: ["texml/Accounts/%1$s/Recordings/%2$s.json", , recording_sid],
    model: NilClass,
    options: options
  )
end

#retrieve_recording_sid_json(recording_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::TexmlGetCallRecordingResponseBody

Returns recording resource identified by recording id.

Parameters:

  • recording_sid (String)

    Uniquely identifies the recording by id.

  • account_sid (String)

    The id of the account the resource belongs to.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/telnyx/resources/texml/accounts/recordings/json.rb', line 51

def retrieve_recording_sid_json(recording_sid, params)
  parsed, options =
    Telnyx::Texml::Accounts::Recordings::JsonRetrieveRecordingSidJsonParams.dump_request(params)
   =
    parsed.delete(:account_sid) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :get,
    path: ["texml/Accounts/%1$s/Recordings/%2$s.json", , recording_sid],
    model: Telnyx::Texml::TexmlGetCallRecordingResponseBody,
    options: options
  )
end