Class: Telnyx::Resources::Texml::Accounts::Transcriptions::Json

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/texml/accounts/transcriptions/json.rb

Overview

TeXML REST Commands

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Json

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Json.

Parameters:



81
82
83
# File 'lib/telnyx/resources/texml/accounts/transcriptions/json.rb', line 81

def initialize(client:)
  @client = client
end

Instance Method Details

#delete_recording_transcription_sid_json(recording_transcription_sid, account_sid:, request_options: {}) ⇒ nil

Permanently deletes a recording transcription.

Parameters:

  • recording_transcription_sid (String)

    Uniquely identifies the recording transcription by id.

  • account_sid (String)

    The id of the account the resource belongs to.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

  • (nil)

See Also:



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/telnyx/resources/texml/accounts/transcriptions/json.rb', line 23

def delete_recording_transcription_sid_json(recording_transcription_sid, params)
  parsed, options =
    Telnyx::Texml::Accounts::Transcriptions::JsonDeleteRecordingTranscriptionSidJsonParams.dump_request(
      params
    )
   =
    parsed.delete(:account_sid) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :delete,
    path: [
      "texml/Accounts/%1$s/Transcriptions/%2$s.json",
      ,
      recording_transcription_sid
    ],
    model: NilClass,
    options: options
  )
end

#retrieve_recording_transcription_sid_json(recording_transcription_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::Transcriptions::JsonRetrieveRecordingTranscriptionSidJsonResponse

Returns the recording transcription resource identified by its ID.

Parameters:

  • recording_transcription_sid (String)

    Uniquely identifies the recording transcription by id.

  • account_sid (String)

    The id of the account the resource belongs to.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/telnyx/resources/texml/accounts/transcriptions/json.rb', line 57

def retrieve_recording_transcription_sid_json(recording_transcription_sid, params)
  parsed, options =
    Telnyx::Texml::Accounts::Transcriptions::JsonRetrieveRecordingTranscriptionSidJsonParams.dump_request(
      params
    )
   =
    parsed.delete(:account_sid) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :get,
    path: [
      "texml/Accounts/%1$s/Transcriptions/%2$s.json",
      ,
      recording_transcription_sid
    ],
    model: Telnyx::Models::Texml::Accounts::Transcriptions::JsonRetrieveRecordingTranscriptionSidJsonResponse,
    options: options
  )
end