Class: Telnyx::Client

Inherits:
Internal::Transport::BaseClient show all
Defined in:
lib/telnyx/client.rb

Constant Summary collapse

DEFAULT_MAX_RETRIES =

Default max number of retries to attempt after a failed retryable request.

2
DEFAULT_TIMEOUT_IN_SECONDS =

Default per-request timeout.

60.0
DEFAULT_INITIAL_RETRY_DELAY =

Default initial retry delay in seconds. Overall delay is calculated using exponential backoff + jitter.

0.5
DEFAULT_MAX_RETRY_DELAY =

Default max retry delay in seconds.

8.0

Constants inherited from Internal::Transport::BaseClient

Internal::Transport::BaseClient::MAX_REDIRECTS, Internal::Transport::BaseClient::PLATFORM_HEADERS

Instance Attribute Summary collapse

Attributes inherited from Internal::Transport::BaseClient

#base_url, #headers, #idempotency_header, #initial_retry_delay, #max_retries, #max_retry_delay, #requester, #timeout

Instance Method Summary collapse

Methods inherited from Internal::Transport::BaseClient

follow_redirect, #inspect, reap_connection!, #request, #send_request, should_retry?, validate!

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_key: ENV["TELNYX_API_KEY"], client_id: ENV["TELNYX_CLIENT_ID"], client_secret: ENV["TELNYX_CLIENT_SECRET"], public_key: ENV["TELNYX_PUBLIC_KEY"], base_url: ENV["TELNYX_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY) ⇒ Client

Creates and returns a new client for interacting with the API.

‘“api.example.com/v2/”`. Defaults to `ENV`

Parameters:

  • api_key (String, nil) (defaults to: ENV["TELNYX_API_KEY"])

    Defaults to ‘ENV`

  • client_id (String, nil) (defaults to: ENV["TELNYX_CLIENT_ID"])

    Defaults to ‘ENV`

  • client_secret (String, nil) (defaults to: ENV["TELNYX_CLIENT_SECRET"])

    Defaults to ‘ENV`

  • public_key (String, nil) (defaults to: ENV["TELNYX_PUBLIC_KEY"])

    Defaults to ‘ENV`

  • base_url (String, nil) (defaults to: ENV["TELNYX_BASE_URL"])

    Override the default base URL for the API, e.g.,

  • max_retries (Integer) (defaults to: self.class::DEFAULT_MAX_RETRIES)

    Max number of retries to attempt after a failed retryable request.

  • timeout (Float) (defaults to: self.class::DEFAULT_TIMEOUT_IN_SECONDS)
  • initial_retry_delay (Float) (defaults to: self.class::DEFAULT_INITIAL_RETRY_DELAY)
  • max_retry_delay (Float) (defaults to: self.class::DEFAULT_MAX_RETRY_DELAY)


555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
# File 'lib/telnyx/client.rb', line 555

def initialize(
  api_key: ENV["TELNYX_API_KEY"],
  client_id: ENV["TELNYX_CLIENT_ID"],
  client_secret: ENV["TELNYX_CLIENT_SECRET"],
  public_key: ENV["TELNYX_PUBLIC_KEY"],
  base_url: ENV["TELNYX_BASE_URL"],
  max_retries: self.class::DEFAULT_MAX_RETRIES,
  timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS,
  initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY,
  max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY
)
  @base_url_overridden = !base_url.nil?

  base_url ||= "https://api.telnyx.com/v2"

  @api_key = api_key&.to_s
  @client_id = client_id&.to_s
  @client_secret = client_secret&.to_s
  @public_key = public_key&.to_s

  super(
    base_url: base_url,
    timeout: timeout,
    max_retries: max_retries,
    initial_retry_delay: initial_retry_delay,
    max_retry_delay: max_retry_delay
  )

  @legacy = Telnyx::Resources::Legacy.new(client: self)
  @oauth = Telnyx::Resources::OAuth.new(client: self)
  @oauth_clients = Telnyx::Resources::OAuthClients.new(client: self)
  @oauth_grants = Telnyx::Resources::OAuthGrants.new(client: self)
  @webhooks = Telnyx::Resources::Webhooks.new(client: self)
  @access_ip_address = Telnyx::Resources::AccessIPAddress.new(client: self)
  @access_ip_ranges = Telnyx::Resources::AccessIPRanges.new(client: self)
  @actions = Telnyx::Resources::Actions.new(client: self)
  @addresses = Telnyx::Resources::Addresses.new(client: self)
  @advanced_orders = Telnyx::Resources::AdvancedOrders.new(client: self)
  @ai = Telnyx::Resources::AI.new(client: self)
  @audit_events = Telnyx::Resources::AuditEvents.new(client: self)
  @authentication_providers = Telnyx::Resources::AuthenticationProviders.new(client: self)
  @available_phone_number_blocks = Telnyx::Resources::AvailablePhoneNumberBlocks.new(client: self)
  @available_phone_numbers = Telnyx::Resources::AvailablePhoneNumbers.new(client: self)
  @balance = Telnyx::Resources::Balance.new(client: self)
  @billing_groups = Telnyx::Resources::BillingGroups.new(client: self)
  @bulk_sim_card_actions = Telnyx::Resources::BulkSimCardActions.new(client: self)
  @bundle_pricing = Telnyx::Resources::BundlePricing.new(client: self)
  @call_control_applications = Telnyx::Resources::CallControlApplications.new(client: self)
  @call_events = Telnyx::Resources::CallEvents.new(client: self)
  @calls = Telnyx::Resources::Calls.new(client: self)
  @channel_zones = Telnyx::Resources::ChannelZones.new(client: self)
  @charges_breakdown = Telnyx::Resources::ChargesBreakdown.new(client: self)
  @charges_summary = Telnyx::Resources::ChargesSummary.new(client: self)
  @comments = Telnyx::Resources::Comments.new(client: self)
  @conferences = Telnyx::Resources::Conferences.new(client: self)
  @connections = Telnyx::Resources::Connections.new(client: self)
  @country_coverage = Telnyx::Resources::CountryCoverage.new(client: self)
  @credential_connections = Telnyx::Resources::CredentialConnections.new(client: self)
  @custom_storage_credentials = Telnyx::Resources::CustomStorageCredentials.new(client: self)
  @customer_service_records = Telnyx::Resources::CustomerServiceRecords.new(client: self)
  @detail_records = Telnyx::Resources::DetailRecords.new(client: self)
  @dialogflow_connections = Telnyx::Resources::DialogflowConnections.new(client: self)
  @document_links = Telnyx::Resources::DocumentLinks.new(client: self)
  @documents = Telnyx::Resources::Documents.new(client: self)
  @dynamic_emergency_addresses = Telnyx::Resources::DynamicEmergencyAddresses.new(client: self)
  @dynamic_emergency_endpoints = Telnyx::Resources::DynamicEmergencyEndpoints.new(client: self)
  @external_connections = Telnyx::Resources::ExternalConnections.new(client: self)
  @fax_applications = Telnyx::Resources::FaxApplications.new(client: self)
  @faxes = Telnyx::Resources::Faxes.new(client: self)
  @fqdn_connections = Telnyx::Resources::FqdnConnections.new(client: self)
  @fqdns = Telnyx::Resources::Fqdns.new(client: self)
  @global_ip_allowed_ports = Telnyx::Resources::GlobalIPAllowedPorts.new(client: self)
  @global_ip_assignment_health = Telnyx::Resources::GlobalIPAssignmentHealth.new(client: self)
  @global_ip_assignments = Telnyx::Resources::GlobalIPAssignments.new(client: self)
  @global_ip_assignments_usage = Telnyx::Resources::GlobalIPAssignmentsUsage.new(client: self)
  @global_ip_health_check_types = Telnyx::Resources::GlobalIPHealthCheckTypes.new(client: self)
  @global_ip_health_checks = Telnyx::Resources::GlobalIPHealthChecks.new(client: self)
  @global_ip_latency = Telnyx::Resources::GlobalIPLatency.new(client: self)
  @global_ip_protocols = Telnyx::Resources::GlobalIPProtocols.new(client: self)
  @global_ip_usage = Telnyx::Resources::GlobalIPUsage.new(client: self)
  @global_ips = Telnyx::Resources::GlobalIPs.new(client: self)
  @inbound_channels = Telnyx::Resources::InboundChannels.new(client: self)
  @integration_secrets = Telnyx::Resources::IntegrationSecrets.new(client: self)
  @inventory_coverage = Telnyx::Resources::InventoryCoverage.new(client: self)
  @invoices = Telnyx::Resources::Invoices.new(client: self)
  @ip_connections = Telnyx::Resources::IPConnections.new(client: self)
  @ips = Telnyx::Resources::IPs.new(client: self)
  @ledger_billing_group_reports = Telnyx::Resources::LedgerBillingGroupReports.new(client: self)
  @list = Telnyx::Resources::List.new(client: self)
  @managed_accounts = Telnyx::Resources::ManagedAccounts.new(client: self)
  @media = Telnyx::Resources::Media.new(client: self)
  @messages = Telnyx::Resources::Messages.new(client: self)
  @messaging = Telnyx::Resources::Messaging.new(client: self)
  @messaging_hosted_number_orders = Telnyx::Resources::MessagingHostedNumberOrders.new(client: self)
  @messaging_hosted_numbers = Telnyx::Resources::MessagingHostedNumbers.new(client: self)
  @messaging_numbers_bulk_updates = Telnyx::Resources::MessagingNumbersBulkUpdates.new(client: self)
  @messaging_optouts = Telnyx::Resources::MessagingOptouts.new(client: self)
  @messaging_profiles = Telnyx::Resources::MessagingProfiles.new(client: self)
  @messaging_tollfree = Telnyx::Resources::MessagingTollfree.new(client: self)
  @messaging_url_domains = Telnyx::Resources::MessagingURLDomains.new(client: self)
  @mobile_network_operators = Telnyx::Resources::MobileNetworkOperators.new(client: self)
  @mobile_push_credentials = Telnyx::Resources::MobilePushCredentials.new(client: self)
  @network_coverage = Telnyx::Resources::NetworkCoverage.new(client: self)
  @networks = Telnyx::Resources::Networks.new(client: self)
  @notification_channels = Telnyx::Resources::NotificationChannels.new(client: self)
  @notification_event_conditions = Telnyx::Resources::NotificationEventConditions.new(client: self)
  @notification_events = Telnyx::Resources::NotificationEvents.new(client: self)
  @notification_profiles = Telnyx::Resources::NotificationProfiles.new(client: self)
  @notification_settings = Telnyx::Resources::NotificationSettings.new(client: self)
  @number_block_orders = Telnyx::Resources::NumberBlockOrders.new(client: self)
  @number_lookup = Telnyx::Resources::NumberLookup.new(client: self)
  @number_order_phone_numbers = Telnyx::Resources::NumberOrderPhoneNumbers.new(client: self)
  @number_orders = Telnyx::Resources::NumberOrders.new(client: self)
  @number_reservations = Telnyx::Resources::NumberReservations.new(client: self)
  @numbers_features = Telnyx::Resources::NumbersFeatures.new(client: self)
  @operator_connect = Telnyx::Resources::OperatorConnect.new(client: self)
  @ota_updates = Telnyx::Resources::OtaUpdates.new(client: self)
  @outbound_voice_profiles = Telnyx::Resources::OutboundVoiceProfiles.new(client: self)
  @payment = Telnyx::Resources::Payment.new(client: self)
  @phone_number_blocks = Telnyx::Resources::PhoneNumberBlocks.new(client: self)
  @phone_numbers = Telnyx::Resources::PhoneNumbers.new(client: self)
  @phone_numbers_regulatory_requirements =
    Telnyx::Resources::PhoneNumbersRegulatoryRequirements.new(client: self)
  @portability_checks = Telnyx::Resources::PortabilityChecks.new(client: self)
  @porting = Telnyx::Resources::Porting.new(client: self)
  @porting_orders = Telnyx::Resources::PortingOrders.new(client: self)
  @porting_phone_numbers = Telnyx::Resources::PortingPhoneNumbers.new(client: self)
  @portouts = Telnyx::Resources::Portouts.new(client: self)
  @private_wireless_gateways = Telnyx::Resources::PrivateWirelessGateways.new(client: self)
  @public_internet_gateways = Telnyx::Resources::PublicInternetGateways.new(client: self)
  @queues = Telnyx::Resources::Queues.new(client: self)
  @rcs_agents = Telnyx::Resources::RcsAgents.new(client: self)
  @recording_transcriptions = Telnyx::Resources::RecordingTranscriptions.new(client: self)
  @recordings = Telnyx::Resources::Recordings.new(client: self)
  @regions = Telnyx::Resources::Regions.new(client: self)
  @regulatory_requirements = Telnyx::Resources::RegulatoryRequirements.new(client: self)
  @reports = Telnyx::Resources::Reports.new(client: self)
  @requirement_groups = Telnyx::Resources::RequirementGroups.new(client: self)
  @requirement_types = Telnyx::Resources::RequirementTypes.new(client: self)
  @requirements = Telnyx::Resources::Requirements.new(client: self)
  @room_compositions = Telnyx::Resources::RoomCompositions.new(client: self)
  @room_participants = Telnyx::Resources::RoomParticipants.new(client: self)
  @room_recordings = Telnyx::Resources::RoomRecordings.new(client: self)
  @rooms = Telnyx::Resources::Rooms.new(client: self)
  @seti = Telnyx::Resources::Seti.new(client: self)
  @short_codes = Telnyx::Resources::ShortCodes.new(client: self)
  @sim_card_data_usage_notifications = Telnyx::Resources::SimCardDataUsageNotifications.new(client: self)
  @sim_card_groups = Telnyx::Resources::SimCardGroups.new(client: self)
  @sim_card_order_preview = Telnyx::Resources::SimCardOrderPreview.new(client: self)
  @sim_card_orders = Telnyx::Resources::SimCardOrders.new(client: self)
  @sim_cards = Telnyx::Resources::SimCards.new(client: self)
  @siprec_connectors = Telnyx::Resources::SiprecConnectors.new(client: self)
  @storage = Telnyx::Resources::Storage.new(client: self)
  @sub_number_orders = Telnyx::Resources::SubNumberOrders.new(client: self)
  @sub_number_orders_report = Telnyx::Resources::SubNumberOrdersReport.new(client: self)
  @telephony_credentials = Telnyx::Resources::TelephonyCredentials.new(client: self)
  @texml = Telnyx::Resources::Texml.new(client: self)
  @texml_applications = Telnyx::Resources::TexmlApplications.new(client: self)
  @text_to_speech = Telnyx::Resources::TextToSpeech.new(client: self)
  @usage_reports = Telnyx::Resources::UsageReports.new(client: self)
  @user_addresses = Telnyx::Resources::UserAddresses.new(client: self)
  @user_tags = Telnyx::Resources::UserTags.new(client: self)
  @verifications = Telnyx::Resources::Verifications.new(client: self)
  @verified_numbers = Telnyx::Resources::VerifiedNumbers.new(client: self)
  @verify_profiles = Telnyx::Resources::VerifyProfiles.new(client: self)
  @virtual_cross_connects = Telnyx::Resources::VirtualCrossConnects.new(client: self)
  @virtual_cross_connects_coverage = Telnyx::Resources::VirtualCrossConnectsCoverage.new(client: self)
  @webhook_deliveries = Telnyx::Resources::WebhookDeliveries.new(client: self)
  @wireguard_interfaces = Telnyx::Resources::WireguardInterfaces.new(client: self)
  @wireguard_peers = Telnyx::Resources::WireguardPeers.new(client: self)
  @wireless = Telnyx::Resources::Wireless.new(client: self)
  @wireless_blocklist_values = Telnyx::Resources::WirelessBlocklistValues.new(client: self)
  @wireless_blocklists = Telnyx::Resources::WirelessBlocklists.new(client: self)
  @well_known = Telnyx::Resources::WellKnown.new(client: self)
  @inexplicit_number_orders = Telnyx::Resources::InexplicitNumberOrders.new(client: self)
  @mobile_phone_numbers = Telnyx::Resources::MobilePhoneNumbers.new(client: self)
  @mobile_voice_connections = Telnyx::Resources::MobileVoiceConnections.new(client: self)
  @messaging_10dlc = Telnyx::Resources::Messaging10dlc.new(client: self)
  @speech_to_text = Telnyx::Resources::SpeechToText.new(client: self)
  @organizations = Telnyx::Resources::Organizations.new(client: self)
end

Instance Attribute Details

#access_ip_addressTelnyx::Resources::AccessIPAddress (readonly)



46
47
48
# File 'lib/telnyx/client.rb', line 46

def access_ip_address
  @access_ip_address
end

#access_ip_rangesTelnyx::Resources::AccessIPRanges (readonly)



49
50
51
# File 'lib/telnyx/client.rb', line 49

def access_ip_ranges
  @access_ip_ranges
end

#actionsTelnyx::Resources::Actions (readonly)



52
53
54
# File 'lib/telnyx/client.rb', line 52

def actions
  @actions
end

#addressesTelnyx::Resources::Addresses (readonly)



55
56
57
# File 'lib/telnyx/client.rb', line 55

def addresses
  @addresses
end

#advanced_ordersTelnyx::Resources::AdvancedOrders (readonly)



58
59
60
# File 'lib/telnyx/client.rb', line 58

def advanced_orders
  @advanced_orders
end

#aiTelnyx::Resources::AI (readonly)



61
62
63
# File 'lib/telnyx/client.rb', line 61

def ai
  @ai
end

#api_keyString? (readonly)

Returns:

  • (String, nil)


19
20
21
# File 'lib/telnyx/client.rb', line 19

def api_key
  @api_key
end

#audit_eventsTelnyx::Resources::AuditEvents (readonly)



64
65
66
# File 'lib/telnyx/client.rb', line 64

def audit_events
  @audit_events
end

#authentication_providersTelnyx::Resources::AuthenticationProviders (readonly)



67
68
69
# File 'lib/telnyx/client.rb', line 67

def authentication_providers
  @authentication_providers
end

#available_phone_number_blocksTelnyx::Resources::AvailablePhoneNumberBlocks (readonly)



70
71
72
# File 'lib/telnyx/client.rb', line 70

def available_phone_number_blocks
  @available_phone_number_blocks
end

#available_phone_numbersTelnyx::Resources::AvailablePhoneNumbers (readonly)



73
74
75
# File 'lib/telnyx/client.rb', line 73

def available_phone_numbers
  @available_phone_numbers
end

#balanceTelnyx::Resources::Balance (readonly)



76
77
78
# File 'lib/telnyx/client.rb', line 76

def balance
  @balance
end

#billing_groupsTelnyx::Resources::BillingGroups (readonly)



79
80
81
# File 'lib/telnyx/client.rb', line 79

def billing_groups
  @billing_groups
end

#bulk_sim_card_actionsTelnyx::Resources::BulkSimCardActions (readonly)



82
83
84
# File 'lib/telnyx/client.rb', line 82

def bulk_sim_card_actions
  @bulk_sim_card_actions
end

#bundle_pricingTelnyx::Resources::BundlePricing (readonly)



85
86
87
# File 'lib/telnyx/client.rb', line 85

def bundle_pricing
  @bundle_pricing
end

#call_control_applicationsTelnyx::Resources::CallControlApplications (readonly)



88
89
90
# File 'lib/telnyx/client.rb', line 88

def call_control_applications
  @call_control_applications
end

#call_eventsTelnyx::Resources::CallEvents (readonly)



91
92
93
# File 'lib/telnyx/client.rb', line 91

def call_events
  @call_events
end

#callsTelnyx::Resources::Calls (readonly)



94
95
96
# File 'lib/telnyx/client.rb', line 94

def calls
  @calls
end

#channel_zonesTelnyx::Resources::ChannelZones (readonly)



97
98
99
# File 'lib/telnyx/client.rb', line 97

def channel_zones
  @channel_zones
end

#charges_breakdownTelnyx::Resources::ChargesBreakdown (readonly)



100
101
102
# File 'lib/telnyx/client.rb', line 100

def charges_breakdown
  @charges_breakdown
end

#charges_summaryTelnyx::Resources::ChargesSummary (readonly)



103
104
105
# File 'lib/telnyx/client.rb', line 103

def charges_summary
  @charges_summary
end

#client_idString? (readonly)

Returns:

  • (String, nil)


25
26
27
# File 'lib/telnyx/client.rb', line 25

def client_id
  @client_id
end

#client_secretString? (readonly)

Returns:

  • (String, nil)


28
29
30
# File 'lib/telnyx/client.rb', line 28

def client_secret
  @client_secret
end

#commentsTelnyx::Resources::Comments (readonly)



106
107
108
# File 'lib/telnyx/client.rb', line 106

def comments
  @comments
end

#conferencesTelnyx::Resources::Conferences (readonly)



109
110
111
# File 'lib/telnyx/client.rb', line 109

def conferences
  @conferences
end

#connectionsTelnyx::Resources::Connections (readonly)



112
113
114
# File 'lib/telnyx/client.rb', line 112

def connections
  @connections
end

#country_coverageTelnyx::Resources::CountryCoverage (readonly)



115
116
117
# File 'lib/telnyx/client.rb', line 115

def country_coverage
  @country_coverage
end

#credential_connectionsTelnyx::Resources::CredentialConnections (readonly)



118
119
120
# File 'lib/telnyx/client.rb', line 118

def credential_connections
  @credential_connections
end

#custom_storage_credentialsTelnyx::Resources::CustomStorageCredentials (readonly)



121
122
123
# File 'lib/telnyx/client.rb', line 121

def custom_storage_credentials
  @custom_storage_credentials
end

#customer_service_recordsTelnyx::Resources::CustomerServiceRecords (readonly)



124
125
126
# File 'lib/telnyx/client.rb', line 124

def customer_service_records
  @customer_service_records
end

#detail_recordsTelnyx::Resources::DetailRecords (readonly)



127
128
129
# File 'lib/telnyx/client.rb', line 127

def detail_records
  @detail_records
end

#dialogflow_connectionsTelnyx::Resources::DialogflowConnections (readonly)



130
131
132
# File 'lib/telnyx/client.rb', line 130

def dialogflow_connections
  @dialogflow_connections
end


133
134
135
# File 'lib/telnyx/client.rb', line 133

def document_links
  @document_links
end

#documentsTelnyx::Resources::Documents (readonly)



136
137
138
# File 'lib/telnyx/client.rb', line 136

def documents
  @documents
end

#dynamic_emergency_addressesTelnyx::Resources::DynamicEmergencyAddresses (readonly)



139
140
141
# File 'lib/telnyx/client.rb', line 139

def dynamic_emergency_addresses
  @dynamic_emergency_addresses
end

#dynamic_emergency_endpointsTelnyx::Resources::DynamicEmergencyEndpoints (readonly)



142
143
144
# File 'lib/telnyx/client.rb', line 142

def dynamic_emergency_endpoints
  @dynamic_emergency_endpoints
end

#external_connectionsTelnyx::Resources::ExternalConnections (readonly)



145
146
147
# File 'lib/telnyx/client.rb', line 145

def external_connections
  @external_connections
end

#fax_applicationsTelnyx::Resources::FaxApplications (readonly)



148
149
150
# File 'lib/telnyx/client.rb', line 148

def fax_applications
  @fax_applications
end

#faxesTelnyx::Resources::Faxes (readonly)



151
152
153
# File 'lib/telnyx/client.rb', line 151

def faxes
  @faxes
end

#fqdn_connectionsTelnyx::Resources::FqdnConnections (readonly)



154
155
156
# File 'lib/telnyx/client.rb', line 154

def fqdn_connections
  @fqdn_connections
end

#fqdnsTelnyx::Resources::Fqdns (readonly)



157
158
159
# File 'lib/telnyx/client.rb', line 157

def fqdns
  @fqdns
end

#global_ip_allowed_portsTelnyx::Resources::GlobalIPAllowedPorts (readonly)



160
161
162
# File 'lib/telnyx/client.rb', line 160

def global_ip_allowed_ports
  @global_ip_allowed_ports
end

#global_ip_assignment_healthTelnyx::Resources::GlobalIPAssignmentHealth (readonly)



163
164
165
# File 'lib/telnyx/client.rb', line 163

def global_ip_assignment_health
  @global_ip_assignment_health
end

#global_ip_assignmentsTelnyx::Resources::GlobalIPAssignments (readonly)



166
167
168
# File 'lib/telnyx/client.rb', line 166

def global_ip_assignments
  @global_ip_assignments
end

#global_ip_assignments_usageTelnyx::Resources::GlobalIPAssignmentsUsage (readonly)



169
170
171
# File 'lib/telnyx/client.rb', line 169

def global_ip_assignments_usage
  @global_ip_assignments_usage
end

#global_ip_health_check_typesTelnyx::Resources::GlobalIPHealthCheckTypes (readonly)



172
173
174
# File 'lib/telnyx/client.rb', line 172

def global_ip_health_check_types
  @global_ip_health_check_types
end

#global_ip_health_checksTelnyx::Resources::GlobalIPHealthChecks (readonly)



175
176
177
# File 'lib/telnyx/client.rb', line 175

def global_ip_health_checks
  @global_ip_health_checks
end

#global_ip_latencyTelnyx::Resources::GlobalIPLatency (readonly)



178
179
180
# File 'lib/telnyx/client.rb', line 178

def global_ip_latency
  @global_ip_latency
end

#global_ip_protocolsTelnyx::Resources::GlobalIPProtocols (readonly)



181
182
183
# File 'lib/telnyx/client.rb', line 181

def global_ip_protocols
  @global_ip_protocols
end

#global_ip_usageTelnyx::Resources::GlobalIPUsage (readonly)



184
185
186
# File 'lib/telnyx/client.rb', line 184

def global_ip_usage
  @global_ip_usage
end

#global_ipsTelnyx::Resources::GlobalIPs (readonly)



187
188
189
# File 'lib/telnyx/client.rb', line 187

def global_ips
  @global_ips
end

#inbound_channelsTelnyx::Resources::InboundChannels (readonly)



190
191
192
# File 'lib/telnyx/client.rb', line 190

def inbound_channels
  @inbound_channels
end

#inexplicit_number_ordersTelnyx::Resources::InexplicitNumberOrders (readonly)



466
467
468
# File 'lib/telnyx/client.rb', line 466

def inexplicit_number_orders
  @inexplicit_number_orders
end

#integration_secretsTelnyx::Resources::IntegrationSecrets (readonly)



193
194
195
# File 'lib/telnyx/client.rb', line 193

def integration_secrets
  @integration_secrets
end

#inventory_coverageTelnyx::Resources::InventoryCoverage (readonly)



196
197
198
# File 'lib/telnyx/client.rb', line 196

def inventory_coverage
  @inventory_coverage
end

#invoicesTelnyx::Resources::Invoices (readonly)



199
200
201
# File 'lib/telnyx/client.rb', line 199

def invoices
  @invoices
end

#ip_connectionsTelnyx::Resources::IPConnections (readonly)



202
203
204
# File 'lib/telnyx/client.rb', line 202

def ip_connections
  @ip_connections
end

#ipsTelnyx::Resources::IPs (readonly)



205
206
207
# File 'lib/telnyx/client.rb', line 205

def ips
  @ips
end

#ledger_billing_group_reportsTelnyx::Resources::LedgerBillingGroupReports (readonly)



208
209
210
# File 'lib/telnyx/client.rb', line 208

def ledger_billing_group_reports
  @ledger_billing_group_reports
end

#legacyTelnyx::Resources::Legacy (readonly)



31
32
33
# File 'lib/telnyx/client.rb', line 31

def legacy
  @legacy
end

#listTelnyx::Resources::List (readonly)



211
212
213
# File 'lib/telnyx/client.rb', line 211

def list
  @list
end

#managed_accountsTelnyx::Resources::ManagedAccounts (readonly)



214
215
216
# File 'lib/telnyx/client.rb', line 214

def managed_accounts
  @managed_accounts
end

#mediaTelnyx::Resources::Media (readonly)



217
218
219
# File 'lib/telnyx/client.rb', line 217

def media
  @media
end

#messagesTelnyx::Resources::Messages (readonly)



220
221
222
# File 'lib/telnyx/client.rb', line 220

def messages
  @messages
end

#messagingTelnyx::Resources::Messaging (readonly)



223
224
225
# File 'lib/telnyx/client.rb', line 223

def messaging
  @messaging
end

#messaging_10dlcTelnyx::Resources::Messaging10dlc (readonly)



475
476
477
# File 'lib/telnyx/client.rb', line 475

def messaging_10dlc
  @messaging_10dlc
end

#messaging_hosted_number_ordersTelnyx::Resources::MessagingHostedNumberOrders (readonly)



226
227
228
# File 'lib/telnyx/client.rb', line 226

def messaging_hosted_number_orders
  @messaging_hosted_number_orders
end

#messaging_hosted_numbersTelnyx::Resources::MessagingHostedNumbers (readonly)



229
230
231
# File 'lib/telnyx/client.rb', line 229

def messaging_hosted_numbers
  @messaging_hosted_numbers
end

#messaging_numbers_bulk_updatesTelnyx::Resources::MessagingNumbersBulkUpdates (readonly)



232
233
234
# File 'lib/telnyx/client.rb', line 232

def messaging_numbers_bulk_updates
  @messaging_numbers_bulk_updates
end

#messaging_optoutsTelnyx::Resources::MessagingOptouts (readonly)



235
236
237
# File 'lib/telnyx/client.rb', line 235

def messaging_optouts
  @messaging_optouts
end

#messaging_profilesTelnyx::Resources::MessagingProfiles (readonly)



238
239
240
# File 'lib/telnyx/client.rb', line 238

def messaging_profiles
  @messaging_profiles
end

#messaging_tollfreeTelnyx::Resources::MessagingTollfree (readonly)



241
242
243
# File 'lib/telnyx/client.rb', line 241

def messaging_tollfree
  @messaging_tollfree
end

#messaging_url_domainsTelnyx::Resources::MessagingURLDomains (readonly)



244
245
246
# File 'lib/telnyx/client.rb', line 244

def messaging_url_domains
  @messaging_url_domains
end

#mobile_network_operatorsTelnyx::Resources::MobileNetworkOperators (readonly)



247
248
249
# File 'lib/telnyx/client.rb', line 247

def mobile_network_operators
  @mobile_network_operators
end

#mobile_phone_numbersTelnyx::Resources::MobilePhoneNumbers (readonly)



469
470
471
# File 'lib/telnyx/client.rb', line 469

def mobile_phone_numbers
  @mobile_phone_numbers
end

#mobile_push_credentialsTelnyx::Resources::MobilePushCredentials (readonly)



250
251
252
# File 'lib/telnyx/client.rb', line 250

def mobile_push_credentials
  @mobile_push_credentials
end

#mobile_voice_connectionsTelnyx::Resources::MobileVoiceConnections (readonly)



472
473
474
# File 'lib/telnyx/client.rb', line 472

def mobile_voice_connections
  @mobile_voice_connections
end

#network_coverageTelnyx::Resources::NetworkCoverage (readonly)



253
254
255
# File 'lib/telnyx/client.rb', line 253

def network_coverage
  @network_coverage
end

#networksTelnyx::Resources::Networks (readonly)



256
257
258
# File 'lib/telnyx/client.rb', line 256

def networks
  @networks
end

#notification_channelsTelnyx::Resources::NotificationChannels (readonly)



259
260
261
# File 'lib/telnyx/client.rb', line 259

def notification_channels
  @notification_channels
end

#notification_event_conditionsTelnyx::Resources::NotificationEventConditions (readonly)



262
263
264
# File 'lib/telnyx/client.rb', line 262

def notification_event_conditions
  @notification_event_conditions
end

#notification_eventsTelnyx::Resources::NotificationEvents (readonly)



265
266
267
# File 'lib/telnyx/client.rb', line 265

def notification_events
  @notification_events
end

#notification_profilesTelnyx::Resources::NotificationProfiles (readonly)



268
269
270
# File 'lib/telnyx/client.rb', line 268

def notification_profiles
  @notification_profiles
end

#notification_settingsTelnyx::Resources::NotificationSettings (readonly)



271
272
273
# File 'lib/telnyx/client.rb', line 271

def notification_settings
  @notification_settings
end

#number_block_ordersTelnyx::Resources::NumberBlockOrders (readonly)



274
275
276
# File 'lib/telnyx/client.rb', line 274

def number_block_orders
  @number_block_orders
end

#number_lookupTelnyx::Resources::NumberLookup (readonly)



277
278
279
# File 'lib/telnyx/client.rb', line 277

def number_lookup
  @number_lookup
end

#number_order_phone_numbersTelnyx::Resources::NumberOrderPhoneNumbers (readonly)



280
281
282
# File 'lib/telnyx/client.rb', line 280

def number_order_phone_numbers
  @number_order_phone_numbers
end

#number_ordersTelnyx::Resources::NumberOrders (readonly)



283
284
285
# File 'lib/telnyx/client.rb', line 283

def number_orders
  @number_orders
end

#number_reservationsTelnyx::Resources::NumberReservations (readonly)



286
287
288
# File 'lib/telnyx/client.rb', line 286

def number_reservations
  @number_reservations
end

#numbers_featuresTelnyx::Resources::NumbersFeatures (readonly)



289
290
291
# File 'lib/telnyx/client.rb', line 289

def numbers_features
  @numbers_features
end

#oauthTelnyx::Resources::OAuth (readonly)



34
35
36
# File 'lib/telnyx/client.rb', line 34

def oauth
  @oauth
end

#oauth_client_auth_stateTelnyx::Internal::OAuth2ClientCredentials (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



501
502
503
# File 'lib/telnyx/client.rb', line 501

def oauth_client_auth_state
  @oauth_client_auth_state
end

#oauth_clientsTelnyx::Resources::OAuthClients (readonly)



37
38
39
# File 'lib/telnyx/client.rb', line 37

def oauth_clients
  @oauth_clients
end

#oauth_grantsTelnyx::Resources::OAuthGrants (readonly)



40
41
42
# File 'lib/telnyx/client.rb', line 40

def oauth_grants
  @oauth_grants
end

#operator_connectTelnyx::Resources::OperatorConnect (readonly)



292
293
294
# File 'lib/telnyx/client.rb', line 292

def operator_connect
  @operator_connect
end

#organizationsTelnyx::Resources::Organizations (readonly)



481
482
483
# File 'lib/telnyx/client.rb', line 481

def organizations
  @organizations
end

#ota_updatesTelnyx::Resources::OtaUpdates (readonly)



295
296
297
# File 'lib/telnyx/client.rb', line 295

def ota_updates
  @ota_updates
end

#outbound_voice_profilesTelnyx::Resources::OutboundVoiceProfiles (readonly)



298
299
300
# File 'lib/telnyx/client.rb', line 298

def outbound_voice_profiles
  @outbound_voice_profiles
end

#paymentTelnyx::Resources::Payment (readonly)



301
302
303
# File 'lib/telnyx/client.rb', line 301

def payment
  @payment
end

#phone_number_blocksTelnyx::Resources::PhoneNumberBlocks (readonly)



304
305
306
# File 'lib/telnyx/client.rb', line 304

def phone_number_blocks
  @phone_number_blocks
end

#phone_numbersTelnyx::Resources::PhoneNumbers (readonly)



307
308
309
# File 'lib/telnyx/client.rb', line 307

def phone_numbers
  @phone_numbers
end

#phone_numbers_regulatory_requirementsTelnyx::Resources::PhoneNumbersRegulatoryRequirements (readonly)



310
311
312
# File 'lib/telnyx/client.rb', line 310

def phone_numbers_regulatory_requirements
  @phone_numbers_regulatory_requirements
end

#portability_checksTelnyx::Resources::PortabilityChecks (readonly)



313
314
315
# File 'lib/telnyx/client.rb', line 313

def portability_checks
  @portability_checks
end

#portingTelnyx::Resources::Porting (readonly)



316
317
318
# File 'lib/telnyx/client.rb', line 316

def porting
  @porting
end

#porting_ordersTelnyx::Resources::PortingOrders (readonly)



319
320
321
# File 'lib/telnyx/client.rb', line 319

def porting_orders
  @porting_orders
end

#porting_phone_numbersTelnyx::Resources::PortingPhoneNumbers (readonly)



322
323
324
# File 'lib/telnyx/client.rb', line 322

def porting_phone_numbers
  @porting_phone_numbers
end

#portoutsTelnyx::Resources::Portouts (readonly)



325
326
327
# File 'lib/telnyx/client.rb', line 325

def portouts
  @portouts
end

#private_wireless_gatewaysTelnyx::Resources::PrivateWirelessGateways (readonly)



328
329
330
# File 'lib/telnyx/client.rb', line 328

def private_wireless_gateways
  @private_wireless_gateways
end

#public_internet_gatewaysTelnyx::Resources::PublicInternetGateways (readonly)



331
332
333
# File 'lib/telnyx/client.rb', line 331

def public_internet_gateways
  @public_internet_gateways
end

#public_keyString? (readonly)

Returns:

  • (String, nil)


22
23
24
# File 'lib/telnyx/client.rb', line 22

def public_key
  @public_key
end

#queuesTelnyx::Resources::Queues (readonly)



334
335
336
# File 'lib/telnyx/client.rb', line 334

def queues
  @queues
end

#rcs_agentsTelnyx::Resources::RcsAgents (readonly)



337
338
339
# File 'lib/telnyx/client.rb', line 337

def rcs_agents
  @rcs_agents
end

#recording_transcriptionsTelnyx::Resources::RecordingTranscriptions (readonly)



340
341
342
# File 'lib/telnyx/client.rb', line 340

def recording_transcriptions
  @recording_transcriptions
end

#recordingsTelnyx::Resources::Recordings (readonly)



343
344
345
# File 'lib/telnyx/client.rb', line 343

def recordings
  @recordings
end

#regionsTelnyx::Resources::Regions (readonly)



346
347
348
# File 'lib/telnyx/client.rb', line 346

def regions
  @regions
end

#regulatory_requirementsTelnyx::Resources::RegulatoryRequirements (readonly)



349
350
351
# File 'lib/telnyx/client.rb', line 349

def regulatory_requirements
  @regulatory_requirements
end

#reportsTelnyx::Resources::Reports (readonly)



352
353
354
# File 'lib/telnyx/client.rb', line 352

def reports
  @reports
end

#requirement_groupsTelnyx::Resources::RequirementGroups (readonly)



355
356
357
# File 'lib/telnyx/client.rb', line 355

def requirement_groups
  @requirement_groups
end

#requirement_typesTelnyx::Resources::RequirementTypes (readonly)



358
359
360
# File 'lib/telnyx/client.rb', line 358

def requirement_types
  @requirement_types
end

#requirementsTelnyx::Resources::Requirements (readonly)



361
362
363
# File 'lib/telnyx/client.rb', line 361

def requirements
  @requirements
end

#room_compositionsTelnyx::Resources::RoomCompositions (readonly)



364
365
366
# File 'lib/telnyx/client.rb', line 364

def room_compositions
  @room_compositions
end

#room_participantsTelnyx::Resources::RoomParticipants (readonly)



367
368
369
# File 'lib/telnyx/client.rb', line 367

def room_participants
  @room_participants
end

#room_recordingsTelnyx::Resources::RoomRecordings (readonly)



370
371
372
# File 'lib/telnyx/client.rb', line 370

def room_recordings
  @room_recordings
end

#roomsTelnyx::Resources::Rooms (readonly)



373
374
375
# File 'lib/telnyx/client.rb', line 373

def rooms
  @rooms
end

#setiTelnyx::Resources::Seti (readonly)



376
377
378
# File 'lib/telnyx/client.rb', line 376

def seti
  @seti
end

#short_codesTelnyx::Resources::ShortCodes (readonly)



379
380
381
# File 'lib/telnyx/client.rb', line 379

def short_codes
  @short_codes
end

#sim_card_data_usage_notificationsTelnyx::Resources::SimCardDataUsageNotifications (readonly)



382
383
384
# File 'lib/telnyx/client.rb', line 382

def sim_card_data_usage_notifications
  @sim_card_data_usage_notifications
end

#sim_card_groupsTelnyx::Resources::SimCardGroups (readonly)



385
386
387
# File 'lib/telnyx/client.rb', line 385

def sim_card_groups
  @sim_card_groups
end

#sim_card_order_previewTelnyx::Resources::SimCardOrderPreview (readonly)



388
389
390
# File 'lib/telnyx/client.rb', line 388

def sim_card_order_preview
  @sim_card_order_preview
end

#sim_card_ordersTelnyx::Resources::SimCardOrders (readonly)



391
392
393
# File 'lib/telnyx/client.rb', line 391

def sim_card_orders
  @sim_card_orders
end

#sim_cardsTelnyx::Resources::SimCards (readonly)



394
395
396
# File 'lib/telnyx/client.rb', line 394

def sim_cards
  @sim_cards
end

#siprec_connectorsTelnyx::Resources::SiprecConnectors (readonly)



397
398
399
# File 'lib/telnyx/client.rb', line 397

def siprec_connectors
  @siprec_connectors
end

#speech_to_textTelnyx::Resources::SpeechToText (readonly)



478
479
480
# File 'lib/telnyx/client.rb', line 478

def speech_to_text
  @speech_to_text
end

#storageTelnyx::Resources::Storage (readonly)



400
401
402
# File 'lib/telnyx/client.rb', line 400

def storage
  @storage
end

#sub_number_ordersTelnyx::Resources::SubNumberOrders (readonly)



403
404
405
# File 'lib/telnyx/client.rb', line 403

def sub_number_orders
  @sub_number_orders
end

#sub_number_orders_reportTelnyx::Resources::SubNumberOrdersReport (readonly)



406
407
408
# File 'lib/telnyx/client.rb', line 406

def sub_number_orders_report
  @sub_number_orders_report
end

#telephony_credentialsTelnyx::Resources::TelephonyCredentials (readonly)



409
410
411
# File 'lib/telnyx/client.rb', line 409

def telephony_credentials
  @telephony_credentials
end

#texmlTelnyx::Resources::Texml (readonly)



412
413
414
# File 'lib/telnyx/client.rb', line 412

def texml
  @texml
end

#texml_applicationsTelnyx::Resources::TexmlApplications (readonly)



415
416
417
# File 'lib/telnyx/client.rb', line 415

def texml_applications
  @texml_applications
end

#text_to_speechTelnyx::Resources::TextToSpeech (readonly)



418
419
420
# File 'lib/telnyx/client.rb', line 418

def text_to_speech
  @text_to_speech
end

#usage_reportsTelnyx::Resources::UsageReports (readonly)



421
422
423
# File 'lib/telnyx/client.rb', line 421

def usage_reports
  @usage_reports
end

#user_addressesTelnyx::Resources::UserAddresses (readonly)



424
425
426
# File 'lib/telnyx/client.rb', line 424

def user_addresses
  @user_addresses
end

#user_tagsTelnyx::Resources::UserTags (readonly)



427
428
429
# File 'lib/telnyx/client.rb', line 427

def user_tags
  @user_tags
end

#verificationsTelnyx::Resources::Verifications (readonly)



430
431
432
# File 'lib/telnyx/client.rb', line 430

def verifications
  @verifications
end

#verified_numbersTelnyx::Resources::VerifiedNumbers (readonly)



433
434
435
# File 'lib/telnyx/client.rb', line 433

def verified_numbers
  @verified_numbers
end

#verify_profilesTelnyx::Resources::VerifyProfiles (readonly)



436
437
438
# File 'lib/telnyx/client.rb', line 436

def verify_profiles
  @verify_profiles
end

#virtual_cross_connectsTelnyx::Resources::VirtualCrossConnects (readonly)



439
440
441
# File 'lib/telnyx/client.rb', line 439

def virtual_cross_connects
  @virtual_cross_connects
end

#virtual_cross_connects_coverageTelnyx::Resources::VirtualCrossConnectsCoverage (readonly)



442
443
444
# File 'lib/telnyx/client.rb', line 442

def virtual_cross_connects_coverage
  @virtual_cross_connects_coverage
end

#webhook_deliveriesTelnyx::Resources::WebhookDeliveries (readonly)



445
446
447
# File 'lib/telnyx/client.rb', line 445

def webhook_deliveries
  @webhook_deliveries
end

#webhooksTelnyx::Resources::Webhooks (readonly)



43
44
45
# File 'lib/telnyx/client.rb', line 43

def webhooks
  @webhooks
end

#well_knownTelnyx::Resources::WellKnown (readonly)



463
464
465
# File 'lib/telnyx/client.rb', line 463

def well_known
  @well_known
end

#wireguard_interfacesTelnyx::Resources::WireguardInterfaces (readonly)



448
449
450
# File 'lib/telnyx/client.rb', line 448

def wireguard_interfaces
  @wireguard_interfaces
end

#wireguard_peersTelnyx::Resources::WireguardPeers (readonly)



451
452
453
# File 'lib/telnyx/client.rb', line 451

def wireguard_peers
  @wireguard_peers
end

#wirelessTelnyx::Resources::Wireless (readonly)



454
455
456
# File 'lib/telnyx/client.rb', line 454

def wireless
  @wireless
end

#wireless_blocklist_valuesTelnyx::Resources::WirelessBlocklistValues (readonly)



457
458
459
# File 'lib/telnyx/client.rb', line 457

def wireless_blocklist_values
  @wireless_blocklist_values
end

#wireless_blocklistsTelnyx::Resources::WirelessBlocklists (readonly)



460
461
462
# File 'lib/telnyx/client.rb', line 460

def wireless_blocklists
  @wireless_blocklists
end

Instance Method Details

#base_url_overridden?Boolean

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (Boolean)


533
# File 'lib/telnyx/client.rb', line 533

def base_url_overridden? = @base_url_overridden