Class: Telnyx::Models::AI::Assistant
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Assistant
- Defined in:
- lib/telnyx/models/ai/assistant.rb
Defined Under Namespace
Modules: Tool
Instance Attribute Summary collapse
-
#instructions ⇒ String?
The system instructions that the voice assistant uses during the gather command.
-
#model ⇒ String?
The model to be used by the voice assistant.
-
#openai_api_key_ref ⇒ String?
This is necessary only if the model selected is from OpenAI.
-
#tools ⇒ Array<Telnyx::Models::BookAppointmentTool, Telnyx::Models::CheckAvailabilityTool, Telnyx::Models::AI::WebhookTool, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::TransferTool, Telnyx::Models::CallControlRetrievalTool>?
The tools that the voice assistant can use.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#instructions ⇒ String?
The system instructions that the voice assistant uses during the gather command
11 |
# File 'lib/telnyx/models/ai/assistant.rb', line 11 optional :instructions, String |
#model ⇒ String?
The model to be used by the voice assistant.
17 |
# File 'lib/telnyx/models/ai/assistant.rb', line 17 optional :model, String |
#openai_api_key_ref ⇒ String?
This is necessary only if the model selected is from OpenAI. You would pass the ‘identifier` for an integration secret [/v2/integration_secrets](developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) that refers to your OpenAI API Key. Warning: Free plans are unlikely to work with this integration.
27 |
# File 'lib/telnyx/models/ai/assistant.rb', line 27 optional :openai_api_key_ref, String |
#tools ⇒ Array<Telnyx::Models::BookAppointmentTool, Telnyx::Models::CheckAvailabilityTool, Telnyx::Models::AI::WebhookTool, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::TransferTool, Telnyx::Models::CallControlRetrievalTool>?
The tools that the voice assistant can use.
33 |
# File 'lib/telnyx/models/ai/assistant.rb', line 33 optional :tools, -> { Telnyx::Internal::Type::ArrayOf[union: Telnyx::AI::Assistant::Tool] } |