Module: Telnyx::Models::AI::Assistant::Tool
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/ai/assistant.rb
Defined Under Namespace
Classes: BookAppointment, CheckAvailability, Retrieval
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(api_key_ref:, event_type_id:) ⇒ Object
Some parameter documentations has been truncated, see CheckAvailability::CheckAvailability for more details.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Telnyx::Models::AI::Assistant::Tool::BookAppointment, Telnyx::Models::AI::Assistant::Tool::CheckAvailability, Telnyx::Models::AI::WebhookTool, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::TransferTool, Telnyx::Models::AI::Assistant::Tool::Retrieval)
|
|
# File 'lib/telnyx/models/ai/assistant.rb', line 209
|
Instance Method Details
#initialize(api_key_ref:, event_type_id:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::Assistant::Tool::CheckAvailability::CheckAvailability for more details.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/telnyx/models/ai/assistant.rb', line 49 module Tool extend Telnyx::Internal::Type::Union discriminator :type variant :book_appointment, -> { Telnyx::AI::Assistant::Tool::BookAppointment } variant :check_availability, -> { Telnyx::AI::Assistant::Tool::CheckAvailability } variant :webhook, -> { Telnyx::AI::WebhookTool } variant :hangup, -> { Telnyx::AI::HangupTool } variant :transfer, -> { Telnyx::AI::TransferTool } variant :retrieval, -> { Telnyx::AI::Assistant::Tool::Retrieval } class BookAppointment < Telnyx::Internal::Type::BaseModel # @!attribute book_appointment # # @return [Telnyx::Models::AI::Assistant::Tool::BookAppointment::BookAppointment] required :book_appointment, -> { Telnyx::AI::Assistant::Tool::BookAppointment::BookAppointment } # @!attribute type # # @return [Symbol, :book_appointment] required :type, const: :book_appointment # @!method initialize(book_appointment:, type: :book_appointment) # @param book_appointment [Telnyx::Models::AI::Assistant::Tool::BookAppointment::BookAppointment] # @param type [Symbol, :book_appointment] # @see Telnyx::Models::AI::Assistant::Tool::BookAppointment#book_appointment class BookAppointment < Telnyx::Internal::Type::BaseModel # @!attribute api_key_ref # Reference to an integration secret that contains your Cal.com API key. You would # pass the `identifier` for an integration secret # [/v2/integration_secrets](https://developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) # that refers to your Cal.com API key. # # @return [String] required :api_key_ref, String # @!attribute event_type_id # Event Type ID for which slots are being fetched. # [cal.com](https://cal.com/docs/api-reference/v2/bookings/create-a-booking#body-event-type-id) # # @return [Integer] required :event_type_id, Integer # @!attribute attendee_name # The name of the attendee # [cal.com](https://cal.com/docs/api-reference/v2/bookings/create-a-booking#body-attendee-name). # If not provided, the assistant will ask for the attendee's name. # # @return [String, nil] optional :attendee_name, String # @!attribute attendee_timezone # The timezone of the attendee # [cal.com](https://cal.com/docs/api-reference/v2/bookings/create-a-booking#body-attendee-timezone). # If not provided, the assistant will ask for the attendee's timezone. # # @return [String, nil] optional :attendee_timezone, String # @!method initialize(api_key_ref:, event_type_id:, attendee_name: nil, attendee_timezone: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::AI::Assistant::Tool::BookAppointment::BookAppointment} for more # details. # # @param api_key_ref [String] Reference to an integration secret that contains your Cal.com API key. You would # # @param event_type_id [Integer] Event Type ID for which slots are being fetched. [cal.com](https://cal.com/docs/ # # @param attendee_name [String] The name of the attendee [cal.com](https://cal.com/docs/api-reference/v2/booking # # @param attendee_timezone [String] The timezone of the attendee [cal.com](https://cal.com/docs/api-reference/v2/boo end end class CheckAvailability < Telnyx::Internal::Type::BaseModel # @!attribute check_availability # # @return [Telnyx::Models::AI::Assistant::Tool::CheckAvailability::CheckAvailability] required :check_availability, -> { Telnyx::AI::Assistant::Tool::CheckAvailability::CheckAvailability } # @!attribute type # # @return [Symbol, :check_availability] required :type, const: :check_availability # @!method initialize(check_availability:, type: :check_availability) # @param check_availability [Telnyx::Models::AI::Assistant::Tool::CheckAvailability::CheckAvailability] # @param type [Symbol, :check_availability] # @see Telnyx::Models::AI::Assistant::Tool::CheckAvailability#check_availability class CheckAvailability < Telnyx::Internal::Type::BaseModel # @!attribute api_key_ref # Reference to an integration secret that contains your Cal.com API key. You would # pass the `identifier` for an integration secret # [/v2/integration_secrets](https://developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) # that refers to your Cal.com API key. # # @return [String] required :api_key_ref, String # @!attribute event_type_id # Event Type ID for which slots are being fetched. # [cal.com](https://cal.com/docs/api-reference/v2/slots/get-available-slots#parameter-event-type-id) # # @return [Integer] required :event_type_id, Integer # @!method initialize(api_key_ref:, event_type_id:) # Some parameter documentations has been truncated, see # {Telnyx::Models::AI::Assistant::Tool::CheckAvailability::CheckAvailability} for # more details. # # @param api_key_ref [String] Reference to an integration secret that contains your Cal.com API key. You would # # @param event_type_id [Integer] Event Type ID for which slots are being fetched. [cal.com](https://cal.com/docs/ end end class Retrieval < Telnyx::Internal::Type::BaseModel # @!attribute retrieval # # @return [Telnyx::Models::AI::Assistant::Tool::Retrieval::Retrieval] required :retrieval, -> { Telnyx::AI::Assistant::Tool::Retrieval::Retrieval } # @!attribute type # # @return [Symbol, :retrieval] required :type, const: :retrieval # @!method initialize(retrieval:, type: :retrieval) # @param retrieval [Telnyx::Models::AI::Assistant::Tool::Retrieval::Retrieval] # @param type [Symbol, :retrieval] # @see Telnyx::Models::AI::Assistant::Tool::Retrieval#retrieval class Retrieval < Telnyx::Internal::Type::BaseModel # @!attribute bucket_ids # # @return [Array<String>] required :bucket_ids, Telnyx::Internal::Type::ArrayOf[String] # @!attribute max_num_results # The maximum number of results to retrieve as context for the language model. # # @return [Integer, nil] optional :max_num_results, Integer # @!method initialize(bucket_ids:, max_num_results: nil) # @param bucket_ids [Array<String>] # # @param max_num_results [Integer] The maximum number of results to retrieve as context for the language model. end end # @!method self.variants # @return [Array(Telnyx::Models::AI::Assistant::Tool::BookAppointment, Telnyx::Models::AI::Assistant::Tool::CheckAvailability, Telnyx::Models::AI::WebhookTool, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::TransferTool, Telnyx::Models::AI::Assistant::Tool::Retrieval)] end |