Class: Telnyx::Models::AI::AssistantCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/ai/assistant_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(instructions:, model:, name:, description: nil, dynamic_variables: nil, dynamic_variables_webhook_url: nil, enabled_features: nil, greeting: nil, insight_settings: nil, llm_api_key_ref: nil, messaging_settings: nil, observability_settings: nil, privacy_settings: nil, telephony_settings: nil, tool_ids: nil, tools: nil, transcription: nil, voice_settings: nil, widget_settings: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantCreateParams for more details.

Parameters:



# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 130

Instance Attribute Details

#descriptionString?

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 34

optional :description, String

#dynamic_variablesHash{Symbol=>Object}?

Map of dynamic variables and their default values

Returns:

  • (Hash{Symbol=>Object}, nil)


40
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 40

optional :dynamic_variables, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#dynamic_variables_webhook_urlString?

If the dynamic_variables_webhook_url is set for the assistant, we will send a request at the start of the conversation. See our [guide](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables) for more information.

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 49

optional :dynamic_variables_webhook_url, String

#enabled_featuresArray<Symbol, Telnyx::Models::AI::EnabledFeatures>?

Returns:



54
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 54

optional :enabled_features, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::AI::EnabledFeatures] }

#greetingString?

Text that the assistant will use to start the conversation. This may be templated with [dynamic variables](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables). Use an empty string to have the assistant wait for the user to speak first. Use the special value ‘<assistant-speaks-first-with-model-generated-message>` to have the assistant generate the greeting based on the system instructions.

Returns:

  • (String, nil)


65
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 65

optional :greeting, String

#insight_settingsTelnyx::Models::AI::InsightSettings?



70
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 70

optional :insight_settings, -> { Telnyx::AI::InsightSettings }

#instructionsString

System instructions for the assistant. These may be templated with [dynamic variables](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables)

Returns:

  • (String)


16
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 16

required :instructions, String

#llm_api_key_refString?

This is only needed when using third-party inference providers. The ‘identifier` for an integration secret [/v2/integration_secrets](developers.telnyx.com/api-reference/integration-secrets/create-a-secret) that refers to your LLM provider’s API key. Warning: Free plans are unlikely to work with this integration.

Returns:

  • (String, nil)


80
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 80

optional :llm_api_key_ref, String

#messaging_settingsTelnyx::Models::AI::MessagingSettings?



85
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 85

optional :messaging_settings, -> { Telnyx::AI::MessagingSettings }

#modelString

ID of the model to use. You can use the [Get models API](developers.telnyx.com/api-reference/chat/get-available-models) to see all of your available models,

Returns:

  • (String)


24
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 24

required :model, String

#nameString

Returns:

  • (String)


29
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 29

required :name, String

#observability_settingsTelnyx::Models::AI::ObservabilityReq?



90
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 90

optional :observability_settings, -> { Telnyx::AI::ObservabilityReq }

#privacy_settingsTelnyx::Models::AI::PrivacySettings?



95
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 95

optional :privacy_settings, -> { Telnyx::AI::PrivacySettings }

#telephony_settingsTelnyx::Models::AI::TelephonySettings?



100
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 100

optional :telephony_settings, -> { Telnyx::AI::TelephonySettings }

#tool_idsArray<String>?

Returns:

  • (Array<String>, nil)


105
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 105

optional :tool_ids, Telnyx::Internal::Type::ArrayOf[String]

#transcriptionTelnyx::Models::AI::TranscriptionSettings?



117
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 117

optional :transcription, -> { Telnyx::AI::TranscriptionSettings }

#voice_settingsTelnyx::Models::AI::VoiceSettings?



122
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 122

optional :voice_settings, -> { Telnyx::AI::VoiceSettings }

#widget_settingsTelnyx::Models::AI::WidgetSettings?

Configuration settings for the assistant’s web widget.



128
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 128

optional :widget_settings, -> { Telnyx::AI::WidgetSettings }