Class: Telnyx::Models::AI::AssistantCreateParams::ExternalLlm
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantCreateParams::ExternalLlm
- Defined in:
- lib/telnyx/models/ai/assistant_create_params.rb
Defined Under Namespace
Modules: AuthenticationMethod
Instance Attribute Summary collapse
-
#authentication_method ⇒ Symbol, ...
Authentication method used when connecting to the external LLM endpoint.
-
#base_url ⇒ String
Base URL for the external LLM endpoint.
-
#certificate_ref ⇒ String?
Integration secret identifier for the client certificate used with certificate authentication.
-
#forward_metadata ⇒ Boolean?
When enabled, Telnyx forwards the assistant’s dynamic variables to the external LLM endpoint.
-
#llm_api_key_ref ⇒ String?
Integration secret identifier for the external LLM API key.
-
#model ⇒ String
Model identifier to use with the external LLM endpoint.
-
#token_retrieval_url ⇒ String?
URL used to retrieve an access token when certificate authentication is enabled.
Instance Method Summary collapse
-
#initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalLlm for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantCreateParams::ExternalLlm for more details.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 201 class ExternalLlm < Telnyx::Internal::Type::BaseModel # @!attribute base_url # Base URL for the external LLM endpoint. # # @return [String] required :base_url, String # @!attribute model # Model identifier to use with the external LLM endpoint. # # @return [String] required :model, String # @!attribute authentication_method # Authentication method used when connecting to the external LLM endpoint. # # @return [Symbol, Telnyx::Models::AI::AssistantCreateParams::ExternalLlm::AuthenticationMethod, nil] optional :authentication_method, enum: -> { Telnyx::AI::AssistantCreateParams::ExternalLlm::AuthenticationMethod } # @!attribute certificate_ref # Integration secret identifier for the client certificate used with certificate # authentication. # # @return [String, nil] optional :certificate_ref, String # @!attribute forward_metadata # When enabled, Telnyx forwards the assistant's dynamic variables to the external # LLM endpoint. Defaults to false. The chat completion request includes a # top-level `extra_metadata` object when dynamic variables are available. For # example: # `{"extra_metadata":{"customer_name":"Jane","account_id":"acct_789","telnyx_agent_target":"+13125550100","telnyx_end_user_target":"+13125550123"}}`. # # @return [Boolean, nil] optional :forward_metadata, Telnyx::Internal::Type::Boolean # @!attribute llm_api_key_ref # Integration secret identifier for the external LLM API key. # # @return [String, nil] optional :llm_api_key_ref, String # @!attribute token_retrieval_url # URL used to retrieve an access token when certificate authentication is enabled. # # @return [String, nil] optional :token_retrieval_url, String # @!method initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::AI::AssistantCreateParams::ExternalLlm} for more details. # # @param base_url [String] Base URL for the external LLM endpoint. # # @param model [String] Model identifier to use with the external LLM endpoint. # # @param authentication_method [Symbol, Telnyx::Models::AI::AssistantCreateParams::ExternalLlm::AuthenticationMethod] Authentication method used when connecting to the external LLM endpoint. # # @param certificate_ref [String] Integration secret identifier for the client certificate used with certificate a # # @param forward_metadata [Boolean] When enabled, Telnyx forwards the assistant's dynamic variables to the external # # @param llm_api_key_ref [String] Integration secret identifier for the external LLM API key. # # @param token_retrieval_url [String] URL used to retrieve an access token when certificate authentication is enabled. # Authentication method used when connecting to the external LLM endpoint. # # @see Telnyx::Models::AI::AssistantCreateParams::ExternalLlm#authentication_method module AuthenticationMethod extend Telnyx::Internal::Type::Enum TOKEN = :token CERTIFICATE = :certificate # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#authentication_method ⇒ Symbol, ...
Authentication method used when connecting to the external LLM endpoint.
218 219 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 218 optional :authentication_method, enum: -> { Telnyx::AI::AssistantCreateParams::ExternalLlm::AuthenticationMethod } |
#base_url ⇒ String
Base URL for the external LLM endpoint.
206 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 206 required :base_url, String |
#certificate_ref ⇒ String?
Integration secret identifier for the client certificate used with certificate authentication.
226 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 226 optional :certificate_ref, String |
#forward_metadata ⇒ Boolean?
When enabled, Telnyx forwards the assistant’s dynamic variables to the external LLM endpoint. Defaults to false. The chat completion request includes a top-level ‘extra_metadata` object when dynamic variables are available. For example: `“extra_metadata”:{“customer_name”:“Jane”,“account_id”:“acct_789”,“telnyx_agent_target”:“+13125550100”,“telnyx_end_user_target”:“+13125550123”}`.
236 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 236 optional :forward_metadata, Telnyx::Internal::Type::Boolean |
#llm_api_key_ref ⇒ String?
Integration secret identifier for the external LLM API key.
242 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 242 optional :llm_api_key_ref, String |
#model ⇒ String
Model identifier to use with the external LLM endpoint.
212 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 212 required :model, String |
#token_retrieval_url ⇒ String?
URL used to retrieve an access token when certificate authentication is enabled.
248 |
# File 'lib/telnyx/models/ai/assistant_create_params.rb', line 248 optional :token_retrieval_url, String |