Class: Telnyx::Models::AI::AssistantIntegration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_integration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(integration_id:, allowed_list: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantIntegration for more details.

Reference to a connected integration attached to an assistant. Discover available integrations with ‘/ai/integrations` and connected integrations with `/ai/integrations/connections`.

Parameters:

  • integration_id (String)

    Catalog integration ID to attach. This is the ‘id` from the integrations catalog

  • allowed_list (Array<String>) (defaults to: nil)

    Optional per-assistant allowlist of integration tool names. When omitted or empt



# File 'lib/telnyx/models/ai/assistant_integration.rb', line 24

Instance Attribute Details

#allowed_listArray<String>?

Optional per-assistant allowlist of integration tool names. When omitted or empty, all tools allowed by the connected integration are available to the assistant.

Returns:

  • (Array<String>, nil)


22
# File 'lib/telnyx/models/ai/assistant_integration.rb', line 22

optional :allowed_list, Telnyx::Internal::Type::ArrayOf[String]

#integration_idString

Catalog integration ID to attach. This is the ‘id` from the integrations catalog at `/ai/integrations` (the same value also appears as `integration_id` on entries returned by `/ai/integrations/connections`). It is not the connection-level `id` from `/ai/integrations/connections`.

Returns:

  • (String)


14
# File 'lib/telnyx/models/ai/assistant_integration.rb', line 14

required :integration_id, String