Module: Telnyx::Models::AI::AssistantTool

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs

Overview

The handoff tool allows the assistant to hand off control of the conversation to another AI assistant. By default, this will happen transparently to the end user.

Defined Under Namespace

Classes: ClientSideTool, Handoff, Invite, Pay, Refer, SendDtmf, SendMessage, SkipTurn, Transfer

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(description: nil) ⇒ Object

Parameters:

  • description (String) (defaults to: nil)

    The description of the function that will be passed to the assistant.



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 978

#self?.variants::Array[Telnyx::Models::AI::assistant_tool]

Returns:

  • (::Array[Telnyx::Models::AI::assistant_tool])


939
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 939

def self?.variants: -> ::Array[Telnyx::Models::AI::assistant_tool]