Module: Telnyx::Models::AI::AssistantTool
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs
Overview
The handoff tool allows the assistant to hand off control of the conversation to another AI assistant. By default, this will happen transparently to the end user.
Defined Under Namespace
Classes: ClientSideTool, Handoff, Invite, Pay, Refer, SendDtmf, SendMessage, SkipTurn, Transfer
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams, Telnyx::Models::AI::AssistantTool::ClientSideTool, Telnyx::Models::AI::RetrievalTool, Telnyx::Models::AI::AssistantTool::Handoff, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::AssistantTool::Transfer, Telnyx::Models::AI::AssistantTool::Invite, Telnyx::Models::AI::AssistantTool::Refer, Telnyx::Models::AI::AssistantTool::SendDtmf, Telnyx::Models::AI::AssistantTool::SendMessage, Telnyx::Models::AI::AssistantTool::SkipTurn, Telnyx::Models::AI::AssistantTool::Pay)
Instance Method Summary collapse
- #initialize(description: nil) ⇒ Object
- #self?.variants ⇒ ::Array[Telnyx::Models::AI::assistant_tool]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 125
|
.variants ⇒ Array(Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams, Telnyx::Models::AI::AssistantTool::ClientSideTool, Telnyx::Models::AI::RetrievalTool, Telnyx::Models::AI::AssistantTool::Handoff, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::AssistantTool::Transfer, Telnyx::Models::AI::AssistantTool::Invite, Telnyx::Models::AI::AssistantTool::Refer, Telnyx::Models::AI::AssistantTool::SendDtmf, Telnyx::Models::AI::AssistantTool::SendMessage, Telnyx::Models::AI::AssistantTool::SkipTurn, Telnyx::Models::AI::AssistantTool::Pay)
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 1072
|
Instance Method Details
#initialize(description: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 978
|
#self?.variants ⇒ ::Array[Telnyx::Models::AI::assistant_tool]
939 |
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 939
def self?.variants: -> ::Array[Telnyx::Models::AI::assistant_tool]
|