Module: Telnyx::Models::AI::AssistantTool

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/ai/assistant_tool.rb

Overview

The handoff tool allows the assistant to hand off control of the conversation to another AI assistant. By default, this will happen transparently to the end user.

Defined Under Namespace

Classes: Handoff, Invite, Refer, SendDtmf, SendMessage, SkipTurn, Transfer

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(message_template: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantTool::SendMessage::SendMessage for more details.

Parameters:

  • message_template (String, nil) (defaults to: nil)

    Optional message template with dynamic variable support using mustache syntax (e



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 787