Module: Telnyx::Models::AI::AssistantTool
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb
Overview
The handoff tool allows the assistant to hand off control of the conversation to another AI assistant. By default, this will happen transparently to the end user.
Defined Under Namespace
Classes: Handoff, Invite, Refer, SendDtmf, SendMessage, SkipTurn, Transfer
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams, Telnyx::Models::AI::RetrievalTool, Telnyx::Models::AI::AssistantTool::Handoff, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::AssistantTool::Transfer, Telnyx::Models::AI::AssistantTool::Invite, Telnyx::Models::AI::AssistantTool::Refer, Telnyx::Models::AI::AssistantTool::SendDtmf, Telnyx::Models::AI::AssistantTool::SendMessage, Telnyx::Models::AI::AssistantTool::SkipTurn)
Instance Method Summary collapse
-
#initialize(message_template: nil) ⇒ Object
Some parameter documentations has been truncated, see SendMessage::SendMessage for more details.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 112
|
.variants ⇒ Array(Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams, Telnyx::Models::AI::RetrievalTool, Telnyx::Models::AI::AssistantTool::Handoff, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::AssistantTool::Transfer, Telnyx::Models::AI::AssistantTool::Invite, Telnyx::Models::AI::AssistantTool::Refer, Telnyx::Models::AI::AssistantTool::SendDtmf, Telnyx::Models::AI::AssistantTool::SendMessage, Telnyx::Models::AI::AssistantTool::SkipTurn)
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 860
|
Instance Method Details
#initialize(message_template: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantTool::SendMessage::SendMessage for more details.
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 787
|