Module: Telnyx::Models::AI::AssistantTool

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/ai/assistant_tool.rb

Overview

The handoff tool allows the assistant to hand off control of the conversation to another AI assistant. By default, this will happen transparently to the end user.

Defined Under Namespace

Classes: Handoff, Refer, SendDtmf, SendMessage, SkipTurn, Transfer

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(send_message:, type: :send_message) ⇒ Object

The send_message tool allows the assistant to send SMS or MMS messages to the end user. The ‘to’ and ‘from’ addresses are automatically determined from the conversation context, and the message text is generated by the assistant.

Parameters:

  • send_message (Hash{Symbol=>Object})
  • type (Symbol, :send_message) (defaults to: :send_message)


# File 'lib/telnyx/models/ai/assistant_tool.rb', line 629