Class: Telnyx::Models::AI::AssistantTool::Handoff::Handoff

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_tool.rb

Overview

See Also:

Defined Under Namespace

Modules: VoiceMode Classes: AIAssistant

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, name:) ⇒ Object

Parameters:

  • id (String)

    The ID of the assistant to hand off to.

  • name (String)

    Helpful name for giving context on when to handoff to the assistant.



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 94

Instance Attribute Details

#ai_assistantsArray<Telnyx::Models::AI::AssistantTool::Handoff::Handoff::AIAssistant>

List of possible assistants that can receive a handoff.



61
62
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 61

required :ai_assistants,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Handoff::Handoff::AIAssistant] }

#voice_modeSymbol, ...

With the unified voice mode all assistants share the same voice, making the handoff transparent to the user. With the distinct voice mode all assistants retain their voice configuration, providing the experience of a conference call with a team of assistants.



71
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 71

optional :voice_mode, enum: -> { Telnyx::AI::AssistantTool::Handoff::Handoff::VoiceMode }