Module: Telnyx::Models::AI::AssistantTool::Handoff::Handoff::VoiceMode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb
Overview
With the unified voice mode all assistants share the same voice, making the handoff transparent to the user. With the distinct voice mode all assistants retain their voice configuration, providing the experience of a conference call with a team of assistants.
Constant Summary collapse
- UNIFIED =
:unified- DISTINCT =
:distinct
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info