Class: Telnyx::Models::AI::AssistantTool::Invite::Invite
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::Invite::Invite
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs
Overview
Defined Under Namespace
Modules: Targets Classes: CustomHeader, VoicemailDetection
Instance Attribute Summary collapse
-
#custom_headers ⇒ Array<Telnyx::Models::AI::AssistantTool::Invite::Invite::CustomHeader>?
Custom headers to be added to the SIP INVITE for the invite command.
-
#from ⇒ String
Number or SIP URI placing the call.
-
#targets ⇒ Array<Telnyx::Models::AI::AssistantTool::Invite::Invite::Targets::TargetsList>, ...
The different possible targets of the invite.
-
#voicemail_detection ⇒ Telnyx::Models::AI::AssistantTool::Invite::Invite::VoicemailDetection?
Configuration for voicemail detection (AMD - Answering Machine Detection) on the invited call.
Instance Method Summary collapse
-
#initialize(name: nil, value: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomHeader for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil, value: nil) ⇒ Object
Some parameter documentations has been truncated, see CustomHeader for more details.
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 690
|
Instance Attribute Details
#custom_headers ⇒ Array<Telnyx::Models::AI::AssistantTool::Invite::Invite::CustomHeader>?
Custom headers to be added to the SIP INVITE for the invite command.
642 643 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 642 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Invite::Invite::CustomHeader] } |
#from ⇒ String
Number or SIP URI placing the call.
636 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 636 required :from, String |
#targets ⇒ Array<Telnyx::Models::AI::AssistantTool::Invite::Invite::Targets::TargetsList>, ...
The different possible targets of the invite. The assistant will be able to
choose one of the targets to invite to the call. This can also be a dynamic
variable string like {{ targets }} where targets is returned by the dynamic
variables webhook and resolves to an array of target objects at runtime. If
omitted or null, the invite tool can still be configured and targets may be
supplied dynamically at runtime.
654 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 654 optional :targets, union: -> { Telnyx::AI::AssistantTool::Invite::Invite::Targets }, nil?: true |
#voicemail_detection ⇒ Telnyx::Models::AI::AssistantTool::Invite::Invite::VoicemailDetection?
Configuration for voicemail detection (AMD - Answering Machine Detection) on the invited call.
661 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 661 optional :voicemail_detection, -> { Telnyx::AI::AssistantTool::Invite::Invite::VoicemailDetection } |
Instance Method Details
#to_hash ⇒ {
577 |
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 577
def to_hash: -> {
|