Class: Telnyx::Models::AI::AssistantTool::Invite::InviteConfig::CustomHeader
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::Invite::InviteConfig::CustomHeader
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb
Instance Attribute Summary collapse
- #name ⇒ String?
-
#value ⇒ String?
The value of the header.
Instance Method Summary collapse
-
#initialize(custom_headers: nil, from: nil, voicemail_detection: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantTool::Invite::InviteConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(custom_headers: nil, from: nil, voicemail_detection: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantTool::Invite::InviteConfig for more details.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 532 class CustomHeader < Telnyx::Internal::Type::BaseModel # @!attribute name # # @return [String, nil] optional :name, String # @!attribute value # The value of the header. Note that we support mustache templating for the value. # For example you can use # `{{#integration_secret}}test-secret{{/integration_secret}}` to pass the value of # the integration secret. # # @return [String, nil] optional :value, String # @!method initialize(name: nil, value: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::AI::AssistantTool::Invite::InviteConfig::CustomHeader} for more # details. # # @param name [String] # # @param value [String] The value of the header. Note that we support mustache templating for the value. end |
Instance Attribute Details
#name ⇒ String?
536 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 536 optional :name, String |
#value ⇒ String?
The value of the header. Note that we support mustache templating for the value. For example you can use ‘Telnyx::Models::AI::AssistantTool::Invite::InviteConfig::CustomHeader.{{#integration_secret}test-secret{/integration_secret}` to pass the value of the integration secret.
545 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 545 optional :value, String |