Class: Telnyx::Models::AI::AssistantTool::Pay
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::Pay
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(pay:, type: :pay) ⇒ Pay
constructor
(BETA) The pay tool allows the assistant to collect card payments from the caller via DTMF during the conversation.
- #to_hash ⇒ { pay: Telnyx::AI::PayToolParams, type: :pay }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(pay:, type: :pay) ⇒ Pay
(BETA) The pay tool allows the assistant to collect card payments from the caller via DTMF during the conversation. Recording is automatically paused while the pay tool is active and resumes when the payment flow completes. The connector_name must reference a pay connector configured in the Telnyx API.
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 1062
|
Instance Attribute Details
#pay ⇒ Telnyx::Models::AI::PayToolParams
1055 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 1055 required :pay, -> { Telnyx::AI::PayToolParams } |
#type ⇒ Symbol, :pay
1060 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 1060 required :type, const: :pay |
Instance Method Details
#to_hash ⇒ { pay: Telnyx::AI::PayToolParams, type: :pay }
936 |
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 936
def to_hash: -> { pay: Telnyx::AI::PayToolParams, type: :pay }
|