Class: Telnyx::Models::AI::AssistantTool::SendMessage::SendMessage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_tool.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#message_templateString?

Optional message template with dynamic variable support using mustache syntax (e.g., {variable_name}). When set, the assistant will use this template for the SMS body instead of generating one. Dynamic variables like {telnyx_end_user_target}, {telnyx_agent_target}, and custom webhook-provided variables will be resolved at runtime.

Returns:

  • (String, nil)


822
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 822

optional :message_template, String, nil?: true