Class: Telnyx::Models::AI::AssistantTool::Transfer::Transfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::Transfer::Transfer
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb
Overview
Defined Under Namespace
Classes: CustomHeader, Target, VoicemailDetection
Instance Attribute Summary collapse
-
#custom_headers ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::CustomHeader>?
Custom headers to be added to the SIP INVITE for the transfer command.
-
#from ⇒ String
Number or SIP URI placing the call.
-
#targets ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::Target>
The different possible targets of the transfer.
-
#voicemail_detection ⇒ Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection?
Configuration for voicemail detection (AMD - Answering Machine Detection) on the transferred call.
-
#warm_message_delay_ms ⇒ Integer?
Optional delay in milliseconds before playing the warm message audio when the transferred call is answered.
-
#warm_transfer_instructions ⇒ String?
Natural language instructions for your agent for how to provide context for the transfer recipient.
Instance Method Summary collapse
-
#initialize(name: nil, value: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomHeader for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil, value: nil) ⇒ Object
Some parameter documentations has been truncated, see CustomHeader for more details.
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 209
|
Instance Attribute Details
#custom_headers ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::CustomHeader>?
Custom headers to be added to the SIP INVITE for the transfer command.
153 154 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 153 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Transfer::Transfer::CustomHeader] } |
#from ⇒ String
Number or SIP URI placing the call.
139 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 139 required :from, String |
#targets ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::Target>
The different possible targets of the transfer. The assistant will be able to choose one of the targets to transfer the call to.
146 147 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 146 required :targets, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Transfer::Transfer::Target] } |
#voicemail_detection ⇒ Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection?
Configuration for voicemail detection (AMD - Answering Machine Detection) on the transferred call. Allows the assistant to detect when a voicemail system answers the transferred call and take appropriate action.
162 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 162 optional :voicemail_detection, -> { Telnyx::AI::AssistantTool::Transfer::Transfer::VoicemailDetection } |
#warm_message_delay_ms ⇒ Integer?
Optional delay in milliseconds before playing the warm message audio when the transferred call is answered. When set, the audio_url is not included in the dial command; instead, playback starts after the specified delay. When not set, existing behavior (audio_url in dial) is preserved.
171 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 171 optional :warm_message_delay_ms, Integer, nil?: true |
#warm_transfer_instructions ⇒ String?
Natural language instructions for your agent for how to provide context for the transfer recipient.
178 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 178 optional :warm_transfer_instructions, String |