Class: Telnyx::Models::AI::AssistantTool::Transfer::Transfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_tool.rb

Overview

See Also:

Defined Under Namespace

Classes: CustomHeader, Target, VoicemailDetection

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil, value: nil) ⇒ Object

Some parameter documentations has been truncated, see CustomHeader for more details.

Parameters:

  • name (String) (defaults to: nil)
  • value (String) (defaults to: nil)

    The value of the header. Note that we support mustache templating for the value.



# File 'lib/telnyx/models/ai/assistant_tool.rb', line 196

Instance Attribute Details

#custom_headersArray<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::CustomHeader>?

Custom headers to be added to the SIP INVITE for the transfer command.



151
152
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 151

optional :custom_headers,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Transfer::Transfer::CustomHeader] }

#fromString

Number or SIP URI placing the call.

Returns:

  • (String)


137
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 137

required :from, String

#targetsArray<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::Target>

The different possible targets of the transfer. The assistant will be able to choose one of the targets to transfer the call to.



144
145
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 144

required :targets,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Transfer::Transfer::Target] }

#voicemail_detectionTelnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection?

Configuration for voicemail detection (AMD - Answering Machine Detection) on the transferred call. Allows the assistant to detect when a voicemail system answers the transferred call and take appropriate action.



160
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 160

optional :voicemail_detection, -> { Telnyx::AI::AssistantTool::Transfer::Transfer::VoicemailDetection }

#warm_transfer_instructionsString?

Natural language instructions for your agent for how to provide context for the transfer recipient.

Returns:

  • (String, nil)


167
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 167

optional :warm_transfer_instructions, String