Class: Telnyx::Models::AI::AssistantTool::Transfer::Transfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::Transfer::Transfer
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb
Overview
Defined Under Namespace
Classes: CustomHeader, Target
Instance Attribute Summary collapse
-
#custom_headers ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::CustomHeader>?
Custom headers to be added to the SIP INVITE for the transfer command.
-
#from ⇒ String
Number or SIP URI placing the call.
-
#targets ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::Target>
The different possible targets of the transfer.
-
#warm_transfer_instructions ⇒ String?
Natural language instructions for your agent for how to provide context for the transfer recipient.
Instance Method Summary collapse
- #initialize(name: nil, to: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil, to: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 184
|
Instance Attribute Details
#custom_headers ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::CustomHeader>?
Custom headers to be added to the SIP INVITE for the transfer command.
149 150 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 149 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Transfer::Transfer::CustomHeader] } |
#from ⇒ String
Number or SIP URI placing the call.
135 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 135 required :from, String |
#targets ⇒ Array<Telnyx::Models::AI::AssistantTool::Transfer::Transfer::Target>
The different possible targets of the transfer. The assistant will be able to choose one of the targets to transfer the call to.
142 143 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 142 required :targets, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantTool::Transfer::Transfer::Target] } |
#warm_transfer_instructions ⇒ String?
Natural language instructions for your agent for how to provide context for the transfer recipient.
157 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 157 optional :warm_transfer_instructions, String |