Class: Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb
Overview
Defined Under Namespace
Modules: DetectionMode Classes: DetectionConfig, OnVoicemailDetected
Instance Attribute Summary collapse
-
#detection_config ⇒ Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionConfig?
Advanced AMD detection configuration parameters.
-
#detection_mode ⇒ Symbol, ...
The AMD detection mode to use.
-
#on_voicemail_detected ⇒ Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::OnVoicemailDetected?
Action to take when voicemail is detected on the transferred call.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(after_greeting_silence_millis: nil, between_words_silence_millis: nil, greeting_duration_millis: nil, greeting_silence_duration_millis: nil, greeting_total_analysis_time_millis: nil, initial_silence_millis: nil, maximum_number_of_words: nil, maximum_word_length_millis: nil, min_word_length_millis: nil, silence_threshold: nil, total_analysis_time_millis: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DetectionConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after_greeting_silence_millis: nil, between_words_silence_millis: nil, greeting_duration_millis: nil, greeting_silence_duration_millis: nil, greeting_total_analysis_time_millis: nil, initial_silence_millis: nil, maximum_number_of_words: nil, maximum_word_length_millis: nil, min_word_length_millis: nil, silence_threshold: nil, total_analysis_time_millis: nil) ⇒ Object
Some parameter documentations has been truncated, see DetectionConfig for more details.
Advanced AMD detection configuration parameters. All values are optional - Telnyx will use defaults if not specified.
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 265
|
Instance Attribute Details
#detection_config ⇒ Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionConfig?
Advanced AMD detection configuration parameters. All values are optional - Telnyx will use defaults if not specified.
247 248 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 247 optional :detection_config, -> { Telnyx::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionConfig } |
#detection_mode ⇒ Symbol, ...
The AMD detection mode to use. ‘premium’ enables premium answering machine detection. ‘disabled’ turns off AMD detection.
255 256 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 255 optional :detection_mode, enum: -> { Telnyx::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionMode } |
#on_voicemail_detected ⇒ Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::OnVoicemailDetected?
Action to take when voicemail is detected on the transferred call.
262 263 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 262 optional :on_voicemail_detected, -> { Telnyx::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::OnVoicemailDetected } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 390
|