Class: Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionConfig
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs
Overview
Instance Attribute Summary collapse
-
#after_greeting_silence_millis ⇒ Integer?
Duration of silence after greeting detection before finalizing the result.
-
#between_words_silence_millis ⇒ Integer?
Maximum silence duration between words during greeting.
-
#greeting_duration_millis ⇒ Integer?
Expected duration of greeting speech.
-
#greeting_silence_duration_millis ⇒ Integer?
Duration of silence after the greeting to wait before considering the greeting complete.
-
#greeting_total_analysis_time_millis ⇒ Integer?
Maximum time to spend analyzing the greeting.
-
#initial_silence_millis ⇒ Integer?
Maximum silence duration at the start of the call before speech.
-
#maximum_number_of_words ⇒ Integer?
Maximum number of words expected in a human greeting.
-
#maximum_word_length_millis ⇒ Integer?
Maximum duration of a single word.
-
#min_word_length_millis ⇒ Integer?
Minimum duration for audio to be considered a word.
-
#silence_threshold ⇒ Integer?
Audio level threshold for silence detection.
-
#total_analysis_time_millis ⇒ Integer?
Total time allowed for AMD analysis.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
406 |
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 406
def initialize: (
|
Instance Attribute Details
#after_greeting_silence_millis ⇒ Integer?
Duration of silence after greeting detection before finalizing the result.
422 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 422 optional :after_greeting_silence_millis, Integer |
#between_words_silence_millis ⇒ Integer?
Maximum silence duration between words during greeting.
428 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 428 optional :between_words_silence_millis, Integer |
#greeting_duration_millis ⇒ Integer?
Expected duration of greeting speech.
434 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 434 optional :greeting_duration_millis, Integer |
#greeting_silence_duration_millis ⇒ Integer?
Duration of silence after the greeting to wait before considering the greeting complete.
441 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 441 optional :greeting_silence_duration_millis, Integer |
#greeting_total_analysis_time_millis ⇒ Integer?
Maximum time to spend analyzing the greeting.
447 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 447 optional :greeting_total_analysis_time_millis, Integer |
#initial_silence_millis ⇒ Integer?
Maximum silence duration at the start of the call before speech.
453 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 453 optional :initial_silence_millis, Integer |
#maximum_number_of_words ⇒ Integer?
Maximum number of words expected in a human greeting.
459 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 459 optional :maximum_number_of_words, Integer |
#maximum_word_length_millis ⇒ Integer?
Maximum duration of a single word.
465 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 465 optional :maximum_word_length_millis, Integer |
#min_word_length_millis ⇒ Integer?
Minimum duration for audio to be considered a word.
471 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 471 optional :min_word_length_millis, Integer |
#silence_threshold ⇒ Integer?
Audio level threshold for silence detection.
477 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 477 optional :silence_threshold, Integer |
#total_analysis_time_millis ⇒ Integer?
Total time allowed for AMD analysis.
483 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 483 optional :total_analysis_time_millis, Integer |
Instance Method Details
#to_hash ⇒ {
420 |
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 420
def to_hash: -> {
|