Class: Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::Transfer::Transfer::VoicemailDetection::DetectionConfig
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb
Overview
Instance Attribute Summary collapse
-
#after_greeting_silence_millis ⇒ Integer?
Duration of silence after greeting detection before finalizing the result.
-
#between_words_silence_millis ⇒ Integer?
Maximum silence duration between words during greeting.
-
#greeting_duration_millis ⇒ Integer?
Expected duration of greeting speech.
-
#greeting_silence_duration_millis ⇒ Integer?
Duration of silence after the greeting to wait before considering the greeting complete.
-
#greeting_total_analysis_time_millis ⇒ Integer?
Maximum time to spend analyzing the greeting.
-
#initial_silence_millis ⇒ Integer?
Maximum silence duration at the start of the call before speech.
-
#maximum_number_of_words ⇒ Integer?
Maximum number of words expected in a human greeting.
-
#maximum_word_length_millis ⇒ Integer?
Maximum duration of a single word.
-
#min_word_length_millis ⇒ Integer?
Minimum duration for audio to be considered a word.
-
#silence_threshold ⇒ Integer?
Audio level threshold for silence detection.
-
#total_analysis_time_millis ⇒ Integer?
Total time allowed for AMD analysis.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#after_greeting_silence_millis ⇒ Integer?
Duration of silence after greeting detection before finalizing the result.
286 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 286 optional :after_greeting_silence_millis, Integer |
#between_words_silence_millis ⇒ Integer?
Maximum silence duration between words during greeting.
292 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 292 optional :between_words_silence_millis, Integer |
#greeting_duration_millis ⇒ Integer?
Expected duration of greeting speech.
298 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 298 optional :greeting_duration_millis, Integer |
#greeting_silence_duration_millis ⇒ Integer?
Duration of silence after the greeting to wait before considering the greeting complete.
305 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 305 optional :greeting_silence_duration_millis, Integer |
#greeting_total_analysis_time_millis ⇒ Integer?
Maximum time to spend analyzing the greeting.
311 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 311 optional :greeting_total_analysis_time_millis, Integer |
#initial_silence_millis ⇒ Integer?
Maximum silence duration at the start of the call before speech.
317 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 317 optional :initial_silence_millis, Integer |
#maximum_number_of_words ⇒ Integer?
Maximum number of words expected in a human greeting.
323 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 323 optional :maximum_number_of_words, Integer |
#maximum_word_length_millis ⇒ Integer?
Maximum duration of a single word.
329 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 329 optional :maximum_word_length_millis, Integer |
#min_word_length_millis ⇒ Integer?
Minimum duration for audio to be considered a word.
335 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 335 optional :min_word_length_millis, Integer |
#silence_threshold ⇒ Integer?
Audio level threshold for silence detection.
341 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 341 optional :silence_threshold, Integer |
#total_analysis_time_millis ⇒ Integer?
Total time allowed for AMD analysis.
347 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 347 optional :total_analysis_time_millis, Integer |