Class: Telnyx::Models::AI::AssistantTool::UpdateDynamicVariables
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantTool::UpdateDynamicVariables
- Defined in:
- lib/telnyx/models/ai/assistant_tool.rb,
sig/telnyx/models/ai/assistant_tool.rbs
Instance Attribute Summary collapse
- #type ⇒ Symbol, :update_dynamic_variables
-
#update_dynamic_variables ⇒ Telnyx::Models::AI::UpdateDynamicVariablesToolParams
Configuration for an update_dynamic_variables tool.
Instance Method Summary collapse
-
#initialize(update_dynamic_variables:, type: :update_dynamic_variables) ⇒ Object
constructor
The update_dynamic_variables tool lets the assistant write values into the conversation's dynamic-variables context during the call.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(update_dynamic_variables:, type: :update_dynamic_variables) ⇒ Object
The update_dynamic_variables tool lets the assistant write values into the
conversation's dynamic-variables context during the call. Updated variables are
available to later {{variable}} interpolation (prompts, speak nodes, message
templates) and to flow edge conditions. Declare each variable the assistant is
allowed to set under updatable_variables.
|
|
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 1087
|
Instance Attribute Details
#type ⇒ Symbol, :update_dynamic_variables
1079 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 1079 required :type, const: :update_dynamic_variables |
#update_dynamic_variables ⇒ Telnyx::Models::AI::UpdateDynamicVariablesToolParams
Configuration for an update_dynamic_variables tool.
1085 |
# File 'lib/telnyx/models/ai/assistant_tool.rb', line 1085 required :update_dynamic_variables, -> { Telnyx::AI::UpdateDynamicVariablesToolParams } |
Instance Method Details
#to_hash ⇒ {
956 |
# File 'sig/telnyx/models/ai/assistant_tool.rbs', line 956
def to_hash: -> {
|