Class: Telnyx::Models::AI::AssistantUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AssistantUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/assistant_update_params.rb
Overview
Defined Under Namespace
Classes: ExternalLlm, FallbackConfig, Integration, InterruptionSettings, McpServer, PostConversationSettings
Instance Attribute Summary collapse
- #assistant_id ⇒ String
- #description ⇒ String?
-
#dynamic_variables ⇒ Hash{Symbol=>Object}?
Map of dynamic variables and their default values.
-
#dynamic_variables_webhook_timeout_ms ⇒ Integer?
Timeout in milliseconds for the dynamic variables webhook.
-
#dynamic_variables_webhook_url ⇒ String?
If ‘dynamic_variables_webhook_url` is set, Telnyx sends a POST request to this URL at the start of the conversation to resolve dynamic variables.
- #enabled_features ⇒ Array<Symbol, Telnyx::Models::AI::EnabledFeatures>?
- #external_llm ⇒ Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm?
- #fallback_config ⇒ Telnyx::Models::AI::AssistantUpdateParams::FallbackConfig?
-
#greeting ⇒ String?
Text that the assistant will use to start the conversation.
- #insight_settings ⇒ Telnyx::Models::AI::InsightSettings?
-
#instructions ⇒ String?
System instructions for the assistant.
-
#integrations ⇒ Array<Telnyx::Models::AI::AssistantUpdateParams::Integration>?
Connected integrations attached to the assistant.
-
#interruption_settings ⇒ Telnyx::Models::AI::AssistantUpdateParams::InterruptionSettings?
Settings for interruptions and how the assistant decides the user has finished speaking.
-
#llm_api_key_ref ⇒ String?
This is only needed when using third-party inference providers selected by ‘model`.
-
#mcp_servers ⇒ Array<Telnyx::Models::AI::AssistantUpdateParams::McpServer>?
MCP servers attached to the assistant.
- #messaging_settings ⇒ Telnyx::Models::AI::MessagingSettings?
-
#model ⇒ String?
ID of the model to use when ‘external_llm` is not set.
- #name ⇒ String?
- #observability_settings ⇒ Telnyx::Models::AI::ObservabilityReq?
-
#post_conversation_settings ⇒ Telnyx::Models::AI::AssistantUpdateParams::PostConversationSettings?
Configuration for post-conversation processing.
- #privacy_settings ⇒ Telnyx::Models::AI::PrivacySettings?
-
#promote_to_main ⇒ Boolean?
Indicates whether the assistant should be promoted to the main version.
-
#tags ⇒ Array<String>?
Tags associated with the assistant.
- #telephony_settings ⇒ Telnyx::Models::AI::TelephonySettings?
-
#tool_ids ⇒ Array<String>?
IDs of shared tools to attach to the assistant.
-
#tools ⇒ Array<Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams, Telnyx::Models::AI::RetrievalTool, Telnyx::Models::AI::AssistantTool::Handoff, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::AssistantTool::Transfer, Telnyx::Models::AI::AssistantTool::Invite, Telnyx::Models::AI::AssistantTool::Refer, Telnyx::Models::AI::AssistantTool::SendDtmf, Telnyx::Models::AI::AssistantTool::SendMessage, Telnyx::Models::AI::AssistantTool::SkipTurn>?
Deprecated for new integrations.
- #transcription ⇒ Telnyx::Models::AI::TranscriptionSettings?
-
#version_name ⇒ String?
Human-readable name for the assistant version.
- #voice_settings ⇒ Telnyx::Models::AI::VoiceSettings?
-
#widget_settings ⇒ Telnyx::Models::AI::WidgetSettings?
Configuration settings for the assistant’s web widget.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, allowed_tools: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see McpServer for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, allowed_tools: nil) ⇒ Object
Some parameter documentations has been truncated, see McpServer for more details.
Reference to an MCP server attached to an assistant. Create and manage MCP servers with the ‘/ai/mcp_servers` endpoints, then attach them to assistants by ID.
|
|
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 506
|
Instance Attribute Details
#assistant_id ⇒ String
14 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 14 required :assistant_id, String |
#description ⇒ String?
19 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 19 optional :description, String |
#dynamic_variables ⇒ Hash{Symbol=>Object}?
Map of dynamic variables and their default values
25 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 25 optional :dynamic_variables, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#dynamic_variables_webhook_timeout_ms ⇒ Integer?
Timeout in milliseconds for the dynamic variables webhook. Must be between 1 and 10000 ms. If the webhook does not respond within this timeout, the call proceeds with default values. See the [dynamic variables guide](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables).
34 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 34 optional :dynamic_variables_webhook_timeout_ms, Integer |
#dynamic_variables_webhook_url ⇒ String?
If ‘dynamic_variables_webhook_url` is set, Telnyx sends a POST request to this URL at the start of the conversation to resolve dynamic variables. Gotcha: the webhook response must wrap variables under a top-level `dynamic_variables` object, e.g. `{“customer_name”: “Jane”}`. Returning a flat object will be ignored and variables will fall back to their defaults. See the [dynamic variables guide](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables) for the full request/response format and timeout behavior.
47 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 47 optional :dynamic_variables_webhook_url, String |
#enabled_features ⇒ Array<Symbol, Telnyx::Models::AI::EnabledFeatures>?
52 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 52 optional :enabled_features, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::AI::EnabledFeatures] } |
#external_llm ⇒ Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm?
57 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 57 optional :external_llm, -> { Telnyx::AI::AssistantUpdateParams::ExternalLlm } |
#fallback_config ⇒ Telnyx::Models::AI::AssistantUpdateParams::FallbackConfig?
62 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 62 optional :fallback_config, -> { Telnyx::AI::AssistantUpdateParams::FallbackConfig } |
#greeting ⇒ String?
Text that the assistant will use to start the conversation. This may be templated with [dynamic variables](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables). Use an empty string to have the assistant wait for the user to speak first. Use the special value ‘<assistant-speaks-first-with-model-generated-message>` to have the assistant generate the greeting based on the system instructions.
73 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 73 optional :greeting, String |
#insight_settings ⇒ Telnyx::Models::AI::InsightSettings?
78 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 78 optional :insight_settings, -> { Telnyx::AI::InsightSettings } |
#instructions ⇒ String?
System instructions for the assistant. These may be templated with [dynamic variables](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables)
85 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 85 optional :instructions, String |
#integrations ⇒ Array<Telnyx::Models::AI::AssistantUpdateParams::Integration>?
Connected integrations attached to the assistant. The catalog of available integrations is at ‘/ai/integrations`; the user’s connected integrations are at ‘/ai/integrations/connections`. Each item references a catalog integration by `integration_id`.
94 95 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 94 optional :integrations, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantUpdateParams::Integration] } |
#interruption_settings ⇒ Telnyx::Models::AI::AssistantUpdateParams::InterruptionSettings?
Settings for interruptions and how the assistant decides the user has finished speaking. These timings are most relevant when using non turn-taking transcription models. For turn-taking models like ‘deepgram/flux`, end-of-turn behavior is controlled by the transcription end-of-turn settings under `transcription.settings` (`eot_threshold`, `eot_timeout_ms`, `eager_eot_threshold`).
106 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 106 optional :interruption_settings, -> { Telnyx::AI::AssistantUpdateParams::InterruptionSettings } |
#llm_api_key_ref ⇒ String?
This is only needed when using third-party inference providers selected by ‘model`. The `identifier` for an integration secret [/v2/integration_secrets](developers.telnyx.com/api-reference/integration-secrets/create-a-secret) that refers to your LLM provider’s API key. For bring-your-own endpoint authentication, use ‘external_llm.llm_api_key_ref` instead. Warning: Free plans are unlikely to work with this integration.
117 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 117 optional :llm_api_key_ref, String |
#mcp_servers ⇒ Array<Telnyx::Models::AI::AssistantUpdateParams::McpServer>?
MCP servers attached to the assistant. Create MCP servers with ‘/ai/mcp_servers`, then reference them by `id` here.
124 125 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 124 optional :mcp_servers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::AssistantUpdateParams::McpServer] } |
#messaging_settings ⇒ Telnyx::Models::AI::MessagingSettings?
130 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 130 optional :messaging_settings, -> { Telnyx::AI::MessagingSettings } |
#model ⇒ String?
ID of the model to use when ‘external_llm` is not set. You can use the [Get models API](developers.telnyx.com/api-reference/chat/get-available-models) to see available models. If `external_llm` is provided, the assistant uses `external_llm` instead of this field. If neither `model` nor `external_llm` is provided, Telnyx applies the default model.
140 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 140 optional :model, String |
#name ⇒ String?
145 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 145 optional :name, String |
#observability_settings ⇒ Telnyx::Models::AI::ObservabilityReq?
150 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 150 optional :observability_settings, -> { Telnyx::AI::ObservabilityReq } |
#post_conversation_settings ⇒ Telnyx::Models::AI::AssistantUpdateParams::PostConversationSettings?
Configuration for post-conversation processing. When enabled, the assistant receives one additional LLM turn after the conversation ends, allowing it to execute tool calls such as logging to a CRM or sending a summary. The assistant can execute multiple parallel or sequential tools during this phase. Telephony-control tools (e.g. hangup, transfer) are unavailable post-conversation. Beta feature.
161 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 161 optional :post_conversation_settings, -> { Telnyx::AI::AssistantUpdateParams::PostConversationSettings } |
#privacy_settings ⇒ Telnyx::Models::AI::PrivacySettings?
166 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 166 optional :privacy_settings, -> { Telnyx::AI::PrivacySettings } |
#promote_to_main ⇒ Boolean?
Indicates whether the assistant should be promoted to the main version. Defaults to true.
173 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 173 optional :promote_to_main, Telnyx::Internal::Type::Boolean |
#tags ⇒ Array<String>?
Tags associated with the assistant. Tags can also be managed with the assistant tag endpoints.
180 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 180 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#telephony_settings ⇒ Telnyx::Models::AI::TelephonySettings?
185 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 185 optional :telephony_settings, -> { Telnyx::AI::TelephonySettings } |
#tool_ids ⇒ Array<String>?
IDs of shared tools to attach to the assistant. New integrations should prefer ‘tool_ids` over inline `tools`.
192 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 192 optional :tool_ids, Telnyx::Internal::Type::ArrayOf[String] |
#tools ⇒ Array<Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams, Telnyx::Models::AI::RetrievalTool, Telnyx::Models::AI::AssistantTool::Handoff, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::AssistantTool::Transfer, Telnyx::Models::AI::AssistantTool::Invite, Telnyx::Models::AI::AssistantTool::Refer, Telnyx::Models::AI::AssistantTool::SendDtmf, Telnyx::Models::AI::AssistantTool::SendMessage, Telnyx::Models::AI::AssistantTool::SkipTurn>?
Deprecated for new integrations. Inline tool definitions available to the assistant. Prefer ‘tool_ids` to attach shared tools created with the AI Tools endpoints.
200 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 200 optional :tools, -> { Telnyx::Internal::Type::ArrayOf[union: Telnyx::AI::AssistantTool] } |
#transcription ⇒ Telnyx::Models::AI::TranscriptionSettings?
205 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 205 optional :transcription, -> { Telnyx::AI::TranscriptionSettings } |
#version_name ⇒ String?
Human-readable name for the assistant version.
211 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 211 optional :version_name, String |
#voice_settings ⇒ Telnyx::Models::AI::VoiceSettings?
216 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 216 optional :voice_settings, -> { Telnyx::AI::VoiceSettings } |
#widget_settings ⇒ Telnyx::Models::AI::WidgetSettings?
Configuration settings for the assistant’s web widget.
222 |
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 222 optional :widget_settings, -> { Telnyx::AI::WidgetSettings } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 368
|