Class: Telnyx::Models::AI::AssistantUpdateParams::ConversationFlow::Edge

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_update_params.rb

Defined Under Namespace

Modules: Condition, Target

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(value:, type: :bool_literal) ⇒ Object

Constant boolean value. Useful for unconditional (‘always’) edges.

Parameters:

  • value (Boolean)

    Literal boolean value.

  • type (Symbol, :bool_literal) (defaults to: :bool_literal)


# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 693

Instance Attribute Details

#conditionTelnyx::Models::AI::AssistantUpdateParams::ConversationFlow::Edge::Condition::Llm, Telnyx::Models::AI::AssistantUpdateParams::ConversationFlow::Edge::Condition::Expression

Condition that gates the transition. Discriminated by ‘type`: `llm`, `expression`.



678
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 678

required :condition, union: -> { Telnyx::AI::AssistantUpdateParams::ConversationFlow::Edge::Condition }

#idString

Caller-supplied unique identifier for this edge within the flow.

Returns:

  • (String)


671
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 671

required :id, String

#start_node_idString

ID of the node this edge transitions away from.

Returns:

  • (String)


684
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 684

required :start_node_id, String

#targetTelnyx::Models::AI::AssistantUpdateParams::ConversationFlow::Edge::Target::Node, Telnyx::Models::AI::AssistantUpdateParams::ConversationFlow::Edge::Target::Assistant

Destination of the transition. Discriminated by ‘type`: `node` (jump to another node in this flow) or `assistant` (hand off to a different assistant).



691
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 691

required :target, union: -> { Telnyx::AI::AssistantUpdateParams::ConversationFlow::Edge::Target }