Class: Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/assistant_update_params.rb

Defined Under Namespace

Modules: AuthenticationMethod

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm for more details.

Parameters:

  • base_url (String)

    Base URL for the external LLM endpoint.

  • model (String)

    Model identifier to use with the external LLM endpoint.

  • authentication_method (Symbol, Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm::AuthenticationMethod) (defaults to: nil)

    Authentication method used when connecting to the external LLM endpoint.

  • certificate_ref (String) (defaults to: nil)

    Integration secret identifier for the client certificate used with certificate a

  • forward_metadata (Boolean) (defaults to: nil)

    When enabled, Telnyx forwards conversation metadata and dynamic variables to the

  • llm_api_key_ref (String) (defaults to: nil)

    Integration secret identifier for the external LLM API key.

  • token_retrieval_url (String) (defaults to: nil)

    URL used to retrieve an access token when certificate authentication is enabled.



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 217

class ExternalLlm < Telnyx::Internal::Type::BaseModel
  # @!attribute base_url
  #   Base URL for the external LLM endpoint.
  #
  #   @return [String]
  required :base_url, String

  # @!attribute model
  #   Model identifier to use with the external LLM endpoint.
  #
  #   @return [String]
  required :model, String

  # @!attribute authentication_method
  #   Authentication method used when connecting to the external LLM endpoint.
  #
  #   @return [Symbol, Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm::AuthenticationMethod, nil]
  optional :authentication_method,
           enum: -> { Telnyx::AI::AssistantUpdateParams::ExternalLlm::AuthenticationMethod }

  # @!attribute certificate_ref
  #   Integration secret identifier for the client certificate used with certificate
  #   authentication.
  #
  #   @return [String, nil]
  optional :certificate_ref, String

  # @!attribute forward_metadata
  #   When enabled, Telnyx forwards conversation metadata and dynamic variables to the
  #   external LLM endpoint. Defaults to false. The external endpoint receives the
  #   standard chat completions payload with top-level `metadata` and
  #   `dynamic_variables` objects when values are available. For example:
  #   `{"metadata":{"conversation_id":"conv_123","assistant_id":"assistant_456","call_control_id":"v3:abc123","telnyx_conversation_channel":"phone_call"},"dynamic_variables":{"customer_name":"Jane","account_id":"acct_789","telnyx_agent_target":"+13125550100","telnyx_end_user_target":"+13125550123"}}`.
  #
  #   @return [Boolean, nil]
  optional :forward_metadata, Telnyx::Internal::Type::Boolean

  # @!attribute llm_api_key_ref
  #   Integration secret identifier for the external LLM API key.
  #
  #   @return [String, nil]
  optional :llm_api_key_ref, String

  # @!attribute token_retrieval_url
  #   URL used to retrieve an access token when certificate authentication is enabled.
  #
  #   @return [String, nil]
  optional :token_retrieval_url, String

  # @!method initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm} for more details.
  #
  #   @param base_url [String] Base URL for the external LLM endpoint.
  #
  #   @param model [String] Model identifier to use with the external LLM endpoint.
  #
  #   @param authentication_method [Symbol, Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm::AuthenticationMethod] Authentication method used when connecting to the external LLM endpoint.
  #
  #   @param certificate_ref [String] Integration secret identifier for the client certificate used with certificate a
  #
  #   @param forward_metadata [Boolean] When enabled, Telnyx forwards conversation metadata and dynamic variables to the
  #
  #   @param llm_api_key_ref [String] Integration secret identifier for the external LLM API key.
  #
  #   @param token_retrieval_url [String] URL used to retrieve an access token when certificate authentication is enabled.

  # Authentication method used when connecting to the external LLM endpoint.
  #
  # @see Telnyx::Models::AI::AssistantUpdateParams::ExternalLlm#authentication_method
  module AuthenticationMethod
    extend Telnyx::Internal::Type::Enum

    TOKEN = :token
    CERTIFICATE = :certificate

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#authentication_methodSymbol, ...

Authentication method used when connecting to the external LLM endpoint.



234
235
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 234

optional :authentication_method,
enum: -> { Telnyx::AI::AssistantUpdateParams::ExternalLlm::AuthenticationMethod }

#base_urlString

Base URL for the external LLM endpoint.

Returns:

  • (String)


222
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 222

required :base_url, String

#certificate_refString?

Integration secret identifier for the client certificate used with certificate authentication.

Returns:

  • (String, nil)


242
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 242

optional :certificate_ref, String

#forward_metadataBoolean?

When enabled, Telnyx forwards conversation metadata and dynamic variables to the external LLM endpoint. Defaults to false. The external endpoint receives the standard chat completions payload with top-level ‘metadata` and `dynamic_variables` objects when values are available. For example: `“metadata”:{“conversation_id”:“conv_123”,“assistant_id”:“assistant_456”,“call_control_id”:“v3:abc123”,“telnyx_conversation_channel”:“phone_call”,“dynamic_variables”:“customer_name”:“Jane”,“account_id”:“acct_789”,“telnyx_agent_target”:“+13125550100”,“telnyx_end_user_target”:“+13125550123”}`.

Returns:

  • (Boolean, nil)


252
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 252

optional :forward_metadata, Telnyx::Internal::Type::Boolean

#llm_api_key_refString?

Integration secret identifier for the external LLM API key.

Returns:

  • (String, nil)


258
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 258

optional :llm_api_key_ref, String

#modelString

Model identifier to use with the external LLM endpoint.

Returns:

  • (String)


228
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 228

required :model, String

#token_retrieval_urlString?

URL used to retrieve an access token when certificate authentication is enabled.

Returns:

  • (String, nil)


264
# File 'lib/telnyx/models/ai/assistant_update_params.rb', line 264

optional :token_retrieval_url, String