Class: Telnyx::Models::AI::Assistants::InstructionEnhanceParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/ai/assistants/instruction_enhance_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(assistant_id:, enhancement_prompt: nil, instructions: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::Assistants::InstructionEnhanceParams for more details.

Parameters:

  • assistant_id (String)
  • enhancement_prompt (String, nil) (defaults to: nil)

    Optional guidance describing how the instructions should be enhanced. When provi

  • instructions (String, nil) (defaults to: nil)

    The instructions to enhance. When omitted, the assistant’s existing instructions

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/ai/assistants/instruction_enhance_params.rb', line 32

Instance Attribute Details

#assistant_idString

Returns:

  • (String)


15
# File 'lib/telnyx/models/ai/assistants/instruction_enhance_params.rb', line 15

required :assistant_id, String

#enhancement_promptString?

Optional guidance describing how the instructions should be enhanced. When provided, the LLM applies these requested changes in addition to fixing any identified issues.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/ai/assistants/instruction_enhance_params.rb', line 23

optional :enhancement_prompt, String, nil?: true

#instructionsString?

The instructions to enhance. When omitted, the assistant’s existing instructions are used.

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/ai/assistants/instruction_enhance_params.rb', line 30

optional :instructions, String, nil?: true