Class: Telnyx::Models::AI::Assistants::ScheduledEventCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Assistants::ScheduledEventCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb
Overview
Defined Under Namespace
Modules: ConversationMetadata
Instance Attribute Summary collapse
- #assistant_id ⇒ String
-
#conversation_metadata ⇒ Hash{Symbol=>String, Integer, Boolean}?
Metadata associated with the conversation.
-
#dynamic_variables ⇒ Hash{Symbol=>String}?
A map of dynamic variable names to values.
-
#scheduled_at_fixed_datetime ⇒ Time
The datetime at which the event should be scheduled.
-
#telnyx_agent_target ⇒ String
The phone number, SIP URI, to schedule the call or text from.
- #telnyx_conversation_channel ⇒ Symbol, Telnyx::Models::AI::Assistants::ConversationChannelType
-
#telnyx_end_user_target ⇒ String
The phone number, SIP URI, to schedule the call or text to.
-
#text ⇒ String?
Required for sms scheduled events.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#assistant_id ⇒ String
15 |
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 15 required :assistant_id, String |
#conversation_metadata ⇒ Hash{Symbol=>String, Integer, Boolean}?
Metadata associated with the conversation. Telnyx provides several pieces of metadata, but customers can also add their own.
45 46 |
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 45 optional :conversation_metadata, -> { Telnyx::Internal::Type::HashOf[union: Telnyx::AI::Assistants::ScheduledEventCreateParams::ConversationMetadata] } |
#dynamic_variables ⇒ Hash{Symbol=>String}?
A map of dynamic variable names to values. These variables can be referenced in the assistant’s instructions and messages using {variable_name} syntax.
53 |
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 53 optional :dynamic_variables, Telnyx::Internal::Type::HashOf[String] |
#scheduled_at_fixed_datetime ⇒ Time
The datetime at which the event should be scheduled. Formatted as ISO 8601.
21 |
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 21 required :scheduled_at_fixed_datetime, Time |
#telnyx_agent_target ⇒ String
The phone number, SIP URI, to schedule the call or text from.
27 |
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 27 required :telnyx_agent_target, String |
#telnyx_conversation_channel ⇒ Symbol, Telnyx::Models::AI::Assistants::ConversationChannelType
32 |
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 32 required :telnyx_conversation_channel, enum: -> { Telnyx::AI::Assistants::ConversationChannelType } |
#telnyx_end_user_target ⇒ String
The phone number, SIP URI, to schedule the call or text to.
38 |
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 38 required :telnyx_end_user_target, String |
#text ⇒ String?
Required for sms scheduled events. The text to be sent to the end user.
59 |
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 59 optional :text, String |