Class: Telnyx::Models::AI::Assistants::ScheduledEventCreateParams::CallSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Assistants::ScheduledEventCreateParams::CallSettings
- Defined in:
- lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb
Defined Under Namespace
Modules: SipRegion
Instance Attribute Summary collapse
-
#sip_region ⇒ Symbol, ...
SIP region passed to Telnyx when initiating an outbound call.
Instance Method Summary collapse
-
#initialize(sip_region: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallSettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(sip_region: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::Assistants::ScheduledEventCreateParams::CallSettings for more details.
Per-call telephony overrides applied when a scheduled phone-call event dispatches. Phone-call events only. New per-call dispatch options should be added here rather than as top-level event fields.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 109 class CallSettings < Telnyx::Internal::Type::BaseModel # @!attribute sip_region # SIP region passed to Telnyx when initiating an outbound call. Values match the # Telnyx TeXML `SipRegion` parameter exactly. Telnyx defaults to `US` when # omitted. # # @return [Symbol, Telnyx::Models::AI::Assistants::ScheduledEventCreateParams::CallSettings::SipRegion, nil] optional :sip_region, enum: -> { Telnyx::AI::Assistants::ScheduledEventCreateParams::CallSettings::SipRegion } # @!method initialize(sip_region: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::AI::Assistants::ScheduledEventCreateParams::CallSettings} for # more details. # # Per-call telephony overrides applied when a scheduled phone-call event # dispatches. Phone-call events only. New per-call dispatch options should be # added here rather than as top-level event fields. # # @param sip_region [Symbol, Telnyx::Models::AI::Assistants::ScheduledEventCreateParams::CallSettings::SipRegion] SIP region passed to Telnyx when initiating an outbound call. Values # SIP region passed to Telnyx when initiating an outbound call. Values match the # Telnyx TeXML `SipRegion` parameter exactly. Telnyx defaults to `US` when # omitted. # # @see Telnyx::Models::AI::Assistants::ScheduledEventCreateParams::CallSettings#sip_region module SipRegion extend Telnyx::Internal::Type::Enum US = :US EUROPE = :Europe CANADA = :Canada AUSTRALIA = :Australia MIDDLE_EAST = :"Middle East" # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#sip_region ⇒ Symbol, ...
SIP region passed to Telnyx when initiating an outbound call. Values match the Telnyx TeXML ‘SipRegion` parameter exactly. Telnyx defaults to `US` when omitted.
116 117 |
# File 'lib/telnyx/models/ai/assistants/scheduled_event_create_params.rb', line 116 optional :sip_region, enum: -> { Telnyx::AI::Assistants::ScheduledEventCreateParams::CallSettings::SipRegion } |