Class: Telnyx::Models::AI::Assistants::Tests::TestRunResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Assistants::Tests::TestRunResponse
- Defined in:
- lib/telnyx/models/ai/assistants/tests/test_run_response.rb
Overview
Instance Attribute Summary collapse
-
#completed_at ⇒ Time?
Timestamp when the test run finished execution.
-
#conversation_id ⇒ String?
Identifier of the conversation created during test execution.
-
#conversation_insights_id ⇒ String?
Identifier for conversation analysis and insights data.
-
#created_at ⇒ Time
Timestamp when the test run was created and queued.
-
#detail_status ⇒ Array<Telnyx::Models::AI::Assistants::Tests::TestRunDetailResult>?
Detailed evaluation results for each rubric criteria.
-
#logs ⇒ String?
Detailed execution logs and debug information.
-
#run_id ⇒ String
Unique identifier for this specific test run execution.
-
#status ⇒ Symbol, Telnyx::Models::AI::Assistants::Tests::TestStatus
Represents the lifecycle of a test:.
-
#test_id ⇒ String
Identifier of the assistant test that was executed.
-
#test_suite_run_id ⇒ String?
Identifier linking this run to a test suite execution batch.
-
#triggered_by ⇒ String
How this test run was initiated (manual, scheduled, or API).
-
#updated_at ⇒ Time?
Timestamp of the last update to this test run.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#completed_at ⇒ Time?
Timestamp when the test run finished execution.
51 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 51 optional :completed_at, Time |
#conversation_id ⇒ String?
Identifier of the conversation created during test execution.
57 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 57 optional :conversation_id, String |
#conversation_insights_id ⇒ String?
Identifier for conversation analysis and insights data.
63 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 63 optional :conversation_insights_id, String |
#created_at ⇒ Time
Timestamp when the test run was created and queued.
14 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 14 required :created_at, Time |
#detail_status ⇒ Array<Telnyx::Models::AI::Assistants::Tests::TestRunDetailResult>?
Detailed evaluation results for each rubric criteria. Name is name of the criteria from the rubric and status is the result of the evaluation. This list will have a result for every criteria in the rubric section.
71 72 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 71 optional :detail_status, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::Assistants::Tests::TestRunDetailResult] } |
#logs ⇒ String?
Detailed execution logs and debug information.
78 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 78 optional :logs, String |
#run_id ⇒ String
Unique identifier for this specific test run execution.
20 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 20 required :run_id, String |
#status ⇒ Symbol, Telnyx::Models::AI::Assistants::Tests::TestStatus
Represents the lifecycle of a test:
-
‘pending’: Test is waiting to be executed.
-
‘starting’: Test execution is initializing.
-
‘running’: Test is currently executing.
-
‘passed’: Test completed successfully.
-
‘failed’: Test executed but did not pass.
-
‘error’: An error occurred during test execution.
33 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 33 required :status, enum: -> { Telnyx::AI::Assistants::Tests::TestStatus } |
#test_id ⇒ String
Identifier of the assistant test that was executed.
39 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 39 required :test_id, String |
#test_suite_run_id ⇒ String?
Identifier linking this run to a test suite execution batch.
84 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 84 optional :test_suite_run_id, String |
#triggered_by ⇒ String
How this test run was initiated (manual, scheduled, or API).
45 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 45 required :triggered_by, String |
#updated_at ⇒ Time?
Timestamp of the last update to this test run.
90 |
# File 'lib/telnyx/models/ai/assistants/tests/test_run_response.rb', line 90 optional :updated_at, Time |