Class: Telnyx::Models::AI::Assistants::UpdateAssistant
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Assistants::UpdateAssistant
- Defined in:
- lib/telnyx/models/ai/assistants/update_assistant.rb
Direct Known Subclasses
Instance Attribute Summary collapse
- #description ⇒ String?
-
#dynamic_variables ⇒ Hash{Symbol=>Object}?
Map of dynamic variables and their default values.
-
#dynamic_variables_webhook_url ⇒ String?
If the dynamic_variables_webhook_url is set for the assistant, we will send a request at the start of the conversation.
- #enabled_features ⇒ Array<Symbol, Telnyx::Models::AI::EnabledFeatures>?
-
#greeting ⇒ String?
Text that the assistant will use to start the conversation.
- #insight_settings ⇒ Telnyx::Models::AI::InsightSettings?
-
#instructions ⇒ String?
System instructions for the assistant.
-
#llm_api_key_ref ⇒ String?
This is only needed when using third-party inference providers.
- #messaging_settings ⇒ Telnyx::Models::AI::MessagingSettings?
-
#model ⇒ String?
ID of the model to use.
- #name ⇒ String?
- #observability_settings ⇒ Telnyx::Models::AI::ObservabilityReq?
- #privacy_settings ⇒ Telnyx::Models::AI::PrivacySettings?
- #telephony_settings ⇒ Telnyx::Models::AI::TelephonySettings?
- #tool_ids ⇒ Array<String>?
-
#tools ⇒ Array<Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams, Telnyx::Models::AI::RetrievalTool, Telnyx::Models::AI::AssistantTool::Handoff, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::AssistantTool::Transfer, Telnyx::Models::AI::AssistantTool::Invite, Telnyx::Models::AI::AssistantTool::Refer, Telnyx::Models::AI::AssistantTool::SendDtmf, Telnyx::Models::AI::AssistantTool::SendMessage, Telnyx::Models::AI::AssistantTool::SkipTurn>?
The tools that the assistant can use.
- #transcription ⇒ Telnyx::Models::AI::TranscriptionSettings?
- #voice_settings ⇒ Telnyx::Models::AI::VoiceSettings?
-
#widget_settings ⇒ Telnyx::Models::AI::WidgetSettings?
Configuration settings for the assistant’s web widget.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#description ⇒ String?
11 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 11 optional :description, String |
#dynamic_variables ⇒ Hash{Symbol=>Object}?
Map of dynamic variables and their default values
17 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 17 optional :dynamic_variables, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#dynamic_variables_webhook_url ⇒ String?
If the dynamic_variables_webhook_url is set for the assistant, we will send a request at the start of the conversation. See our [guide](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables) for more information.
26 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 26 optional :dynamic_variables_webhook_url, String |
#enabled_features ⇒ Array<Symbol, Telnyx::Models::AI::EnabledFeatures>?
31 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 31 optional :enabled_features, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::AI::EnabledFeatures] } |
#greeting ⇒ String?
Text that the assistant will use to start the conversation. This may be templated with [dynamic variables](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables). Use an empty string to have the assistant wait for the user to speak first. Use the special value ‘<assistant-speaks-first-with-model-generated-message>` to have the assistant generate the greeting based on the system instructions.
42 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 42 optional :greeting, String |
#insight_settings ⇒ Telnyx::Models::AI::InsightSettings?
47 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 47 optional :insight_settings, -> { Telnyx::AI::InsightSettings } |
#instructions ⇒ String?
System instructions for the assistant. These may be templated with [dynamic variables](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables)
54 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 54 optional :instructions, String |
#llm_api_key_ref ⇒ String?
This is only needed when using third-party inference providers. The ‘identifier` for an integration secret [/v2/integration_secrets](developers.telnyx.com/api-reference/integration-secrets/create-a-secret) that refers to your LLM provider’s API key. Warning: Free plans are unlikely to work with this integration.
64 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 64 optional :llm_api_key_ref, String |
#messaging_settings ⇒ Telnyx::Models::AI::MessagingSettings?
69 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 69 optional :messaging_settings, -> { Telnyx::AI::MessagingSettings } |
#model ⇒ String?
ID of the model to use. You can use the [Get models API](developers.telnyx.com/api-reference/chat/get-available-models) to see all of your available models,
77 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 77 optional :model, String |
#name ⇒ String?
82 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 82 optional :name, String |
#observability_settings ⇒ Telnyx::Models::AI::ObservabilityReq?
87 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 87 optional :observability_settings, -> { Telnyx::AI::ObservabilityReq } |
#privacy_settings ⇒ Telnyx::Models::AI::PrivacySettings?
92 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 92 optional :privacy_settings, -> { Telnyx::AI::PrivacySettings } |
#telephony_settings ⇒ Telnyx::Models::AI::TelephonySettings?
97 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 97 optional :telephony_settings, -> { Telnyx::AI::TelephonySettings } |
#tool_ids ⇒ Array<String>?
102 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 102 optional :tool_ids, Telnyx::Internal::Type::ArrayOf[String] |
#tools ⇒ Array<Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams, Telnyx::Models::AI::RetrievalTool, Telnyx::Models::AI::AssistantTool::Handoff, Telnyx::Models::AI::HangupTool, Telnyx::Models::AI::AssistantTool::Transfer, Telnyx::Models::AI::AssistantTool::Invite, Telnyx::Models::AI::AssistantTool::Refer, Telnyx::Models::AI::AssistantTool::SendDtmf, Telnyx::Models::AI::AssistantTool::SendMessage, Telnyx::Models::AI::AssistantTool::SkipTurn>?
The tools that the assistant can use. These may be templated with [dynamic variables](developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables)
109 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 109 optional :tools, -> { Telnyx::Internal::Type::ArrayOf[union: Telnyx::AI::AssistantTool] } |
#transcription ⇒ Telnyx::Models::AI::TranscriptionSettings?
114 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 114 optional :transcription, -> { Telnyx::AI::TranscriptionSettings } |
#voice_settings ⇒ Telnyx::Models::AI::VoiceSettings?
119 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 119 optional :voice_settings, -> { Telnyx::AI::VoiceSettings } |
#widget_settings ⇒ Telnyx::Models::AI::WidgetSettings?
Configuration settings for the assistant’s web widget.
125 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 125 optional :widget_settings, -> { Telnyx::AI::WidgetSettings } |