Class: Telnyx::Models::AI::Assistants::UpdateAssistant::InterruptionSettings::StartSpeakingPlan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Assistants::UpdateAssistant::InterruptionSettings::StartSpeakingPlan
- Defined in:
- lib/telnyx/models/ai/assistants/update_assistant.rb
Overview
Defined Under Namespace
Classes: TranscriptionEndpointingPlan
Instance Attribute Summary collapse
-
#transcription_endpointing_plan ⇒ Telnyx::Models::AI::Assistants::UpdateAssistant::InterruptionSettings::StartSpeakingPlan::TranscriptionEndpointingPlan?
Endpointing thresholds used to decide when the user has finished speaking.
-
#wait_seconds ⇒ Float?
Minimum seconds to wait before the assistant starts speaking.
Instance Method Summary collapse
-
#initialize(transcription_endpointing_plan: nil, wait_seconds: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see StartSpeakingPlan for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transcription_endpointing_plan: nil, wait_seconds: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::Assistants::UpdateAssistant::InterruptionSettings::StartSpeakingPlan for more details.
Controls when the assistant starts speaking after the user stops. These thresholds primarily apply to non turn-taking transcription models. For turn-taking models like ‘deepgram/flux`, end-of-turn detection is driven by the transcription end-of-turn settings under `transcription.settings` instead.
|
|
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 554
|
Instance Attribute Details
#transcription_endpointing_plan ⇒ Telnyx::Models::AI::Assistants::UpdateAssistant::InterruptionSettings::StartSpeakingPlan::TranscriptionEndpointingPlan?
Endpointing thresholds used to decide when the user has finished speaking. Applies to non turn-taking transcription models. For ‘deepgram/flux`, use `transcription.settings.eot_threshold` / `eot_timeout_ms` / `eager_eot_threshold`.
545 546 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 545 optional :transcription_endpointing_plan, -> { Telnyx::AI::Assistants::UpdateAssistant::InterruptionSettings::StartSpeakingPlan::TranscriptionEndpointingPlan } |
#wait_seconds ⇒ Float?
Minimum seconds to wait before the assistant starts speaking.
552 |
# File 'lib/telnyx/models/ai/assistants/update_assistant.rb', line 552 optional :wait_seconds, Float |