Class: Telnyx::Models::AI::AudioTranscribeResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::AudioTranscribeResponse
- Defined in:
- lib/telnyx/models/ai/audio_transcribe_response.rb
Overview
Defined Under Namespace
Classes: Segment
Instance Attribute Summary collapse
-
#duration ⇒ Float?
The duration of the audio file in seconds.
-
#segments ⇒ Array<Telnyx::Models::AI::AudioTranscribeResponse::Segment>?
Segments of the transcribed text and their corresponding details.
-
#text ⇒ String
The transcribed text for the audio file.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#duration ⇒ Float?
The duration of the audio file in seconds. This is only included if ‘response_format` is set to `verbose_json`.
19 |
# File 'lib/telnyx/models/ai/audio_transcribe_response.rb', line 19 optional :duration, Float |
#segments ⇒ Array<Telnyx::Models::AI::AudioTranscribeResponse::Segment>?
Segments of the transcribed text and their corresponding details. This is only included if ‘response_format` is set to `verbose_json`.
26 27 |
# File 'lib/telnyx/models/ai/audio_transcribe_response.rb', line 26 optional :segments, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AI::AudioTranscribeResponse::Segment] } |
#text ⇒ String
The transcribed text for the audio file.
12 |
# File 'lib/telnyx/models/ai/audio_transcribe_response.rb', line 12 required :text, String |