Class: Telnyx::Models::AI::ChatCreateCompletionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::ChatCreateCompletionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/chat_create_completion_params.rb
Overview
Defined Under Namespace
Modules: Tool, ToolChoice Classes: Message, ResponseFormat
Instance Attribute Summary collapse
-
#api_key_ref ⇒ String?
If you are using an external inference provider like xAI or OpenAI, this field allows you to pass along a reference to your API key.
-
#best_of ⇒ Integer?
This is used with ‘use_beam_search` to determine how many candidate beams to explore.
-
#early_stopping ⇒ Boolean?
This is used with ‘use_beam_search`.
-
#enable_thinking ⇒ Boolean?
Whether to enable the thinking/reasoning phase for models that support it (e.g., QwQ, Qwen3).
-
#frequency_penalty ⇒ Float?
Higher values will penalize the model from repeating the same output tokens.
-
#guided_choice ⇒ Array<String>?
If specified, the output will be exactly one of the choices.
-
#guided_json ⇒ Hash{Symbol=>Object}?
Must be a valid JSON schema.
-
#guided_regex ⇒ String?
If specified, the output will follow the regex pattern.
-
#length_penalty ⇒ Float?
This is used with ‘use_beam_search` to prefer shorter or longer completions.
-
#logprobs ⇒ Boolean?
Whether to return log probabilities of the output tokens or not.
-
#max_tokens ⇒ Integer?
Maximum number of completion tokens the model should generate.
-
#messages ⇒ Array<Telnyx::Models::AI::ChatCreateCompletionParams::Message>
A list of the previous chat messages for context.
-
#min_p ⇒ Float?
This is an alternative to ‘top_p` that [many prefer](github.com/huggingface/transformers/issues/27670).
-
#model ⇒ String?
The language model to chat with.
-
#n ⇒ Float?
This will return multiple choices for you instead of a single chat completion.
-
#presence_penalty ⇒ Float?
Higher values will penalize the model from repeating the same output tokens.
-
#response_format ⇒ Telnyx::Models::AI::ChatCreateCompletionParams::ResponseFormat?
Use this is you want to guarantee a JSON output without defining a schema.
-
#stream ⇒ Boolean?
Whether or not to stream data-only server-sent events as they become available.
-
#temperature ⇒ Float?
Adjusts the “creativity” of the model.
- #tool_choice ⇒ Symbol, ...
-
#tools ⇒ Array<Telnyx::Models::AI::ChatCreateCompletionParams::Tool::Function, Telnyx::Models::AI::ChatCreateCompletionParams::Tool::Retrieval>?
The ‘function` tool type follows the same schema as the [OpenAI Chat Completions API](platform.openai.com/docs/api-reference/chat).
-
#top_logprobs ⇒ Integer?
This is used with ‘logprobs`.
-
#top_p ⇒ Float?
An alternative or complement to ‘temperature`.
-
#use_beam_search ⇒ Boolean?
Setting this to ‘true` will allow the model to [explore more completion options](huggingface.co/blog/how-to-generate#beam-search).
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#api_key_ref ⇒ String?
If you are using an external inference provider like xAI or OpenAI, this field allows you to pass along a reference to your API key. After creating an [integration secret](developers.telnyx.com/api-reference/integration-secrets/create-a-secret) for you API key, pass the secret’s ‘identifier` in this field.
25 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 25 optional :api_key_ref, String |
#best_of ⇒ Integer?
This is used with ‘use_beam_search` to determine how many candidate beams to explore.
32 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 32 optional :best_of, Integer |
#early_stopping ⇒ Boolean?
This is used with ‘use_beam_search`. If `true`, generation stops as soon as there are `best_of` complete candidates; if `false`, a heuristic is applied and the generation stops when is it very unlikely to find better candidates.
40 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 40 optional :early_stopping, Telnyx::Internal::Type::Boolean |
#enable_thinking ⇒ Boolean?
Whether to enable the thinking/reasoning phase for models that support it (e.g., QwQ, Qwen3). When set to false, the model will skip the internal reasoning step and respond directly, which can reduce latency. Defaults to true.
48 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 48 optional :enable_thinking, Telnyx::Internal::Type::Boolean |
#frequency_penalty ⇒ Float?
Higher values will penalize the model from repeating the same output tokens.
54 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 54 optional :frequency_penalty, Float |
#guided_choice ⇒ Array<String>?
If specified, the output will be exactly one of the choices.
60 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 60 optional :guided_choice, Telnyx::Internal::Type::ArrayOf[String] |
#guided_json ⇒ Hash{Symbol=>Object}?
Must be a valid JSON schema. If specified, the output will follow the JSON schema.
67 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 67 optional :guided_json, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#guided_regex ⇒ String?
If specified, the output will follow the regex pattern.
73 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 73 optional :guided_regex, String |
#length_penalty ⇒ Float?
This is used with ‘use_beam_search` to prefer shorter or longer completions.
79 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 79 optional :length_penalty, Float |
#logprobs ⇒ Boolean?
Whether to return log probabilities of the output tokens or not. If true, returns the log probabilities of each output token returned in the ‘content` of `message`.
87 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 87 optional :logprobs, Telnyx::Internal::Type::Boolean |
#max_tokens ⇒ Integer?
Maximum number of completion tokens the model should generate.
93 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 93 optional :max_tokens, Integer |
#messages ⇒ Array<Telnyx::Models::AI::ChatCreateCompletionParams::Message>
A list of the previous chat messages for context.
15 16 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 15 required :messages, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::ChatCreateCompletionParams::Message] } |
#min_p ⇒ Float?
This is an alternative to ‘top_p` that [many prefer](github.com/huggingface/transformers/issues/27670). Must be in [0, 1].
101 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 101 optional :min_p, Float |
#model ⇒ String?
The language model to chat with.
107 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 107 optional :model, String |
#n ⇒ Float?
This will return multiple choices for you instead of a single chat completion.
113 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 113 optional :n, Float |
#presence_penalty ⇒ Float?
Higher values will penalize the model from repeating the same output tokens.
119 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 119 optional :presence_penalty, Float |
#response_format ⇒ Telnyx::Models::AI::ChatCreateCompletionParams::ResponseFormat?
Use this is you want to guarantee a JSON output without defining a schema. For control over the schema, use ‘guided_json`.
126 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 126 optional :response_format, -> { Telnyx::AI::ChatCreateCompletionParams::ResponseFormat } |
#stream ⇒ Boolean?
Whether or not to stream data-only server-sent events as they become available.
132 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 132 optional :stream, Telnyx::Internal::Type::Boolean |
#temperature ⇒ Float?
Adjusts the “creativity” of the model. Lower values make the model more deterministic and repetitive, while higher values make the model more random and creative.
140 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 140 optional :temperature, Float |
#tool_choice ⇒ Symbol, ...
145 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 145 optional :tool_choice, enum: -> { Telnyx::AI::ChatCreateCompletionParams::ToolChoice } |
#tools ⇒ Array<Telnyx::Models::AI::ChatCreateCompletionParams::Tool::Function, Telnyx::Models::AI::ChatCreateCompletionParams::Tool::Retrieval>?
The ‘function` tool type follows the same schema as the [OpenAI Chat Completions API](platform.openai.com/docs/api-reference/chat). The `retrieval` tool type is unique to Telnyx. You may pass a list of [embedded storage buckets](developers.telnyx.com/api-reference/embeddings/embed-documents) for retrieval-augmented generation.
155 156 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 155 optional :tools, -> { Telnyx::Internal::Type::ArrayOf[union: Telnyx::AI::ChatCreateCompletionParams::Tool] } |
#top_logprobs ⇒ Integer?
This is used with ‘logprobs`. An integer between 0 and 20 specifying the number of most likely tokens to return at each token position, each with an associated log probability.
164 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 164 optional :top_logprobs, Integer |
#top_p ⇒ Float?
An alternative or complement to ‘temperature`. This adjusts how many of the top possibilities to consider.
171 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 171 optional :top_p, Float |
#use_beam_search ⇒ Boolean?
Setting this to ‘true` will allow the model to [explore more completion options](huggingface.co/blog/how-to-generate#beam-search). This is not supported by OpenAI.
179 |
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 179 optional :use_beam_search, Telnyx::Internal::Type::Boolean |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 311
|