Class: Telnyx::Models::AI::ChatCreateCompletionParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/ai/chat_create_completion_params.rb

Overview

Defined Under Namespace

Modules: Tool, ToolChoice Classes: Message, ResponseFormat

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#api_key_refString?

If you are using an external inference provider like xAI or OpenAI, this field allows you to pass along a reference to your API key. After creating an [integration secret](developers.telnyx.com/api-reference/integration-secrets/create-a-secret) for you API key, pass the secret’s ‘identifier` in this field.

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 25

optional :api_key_ref, String

#best_ofInteger?

This is used with ‘use_beam_search` to determine how many candidate beams to explore.

Returns:

  • (Integer, nil)


32
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 32

optional :best_of, Integer

#early_stoppingBoolean?

This is used with ‘use_beam_search`. If `true`, generation stops as soon as there are `best_of` complete candidates; if `false`, a heuristic is applied and the generation stops when is it very unlikely to find better candidates.

Returns:

  • (Boolean, nil)


40
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 40

optional :early_stopping, Telnyx::Internal::Type::Boolean

#frequency_penaltyFloat?

Higher values will penalize the model from repeating the same output tokens.

Returns:

  • (Float, nil)


46
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 46

optional :frequency_penalty, Float

#guided_choiceArray<String>?

If specified, the output will be exactly one of the choices.

Returns:

  • (Array<String>, nil)


52
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 52

optional :guided_choice, Telnyx::Internal::Type::ArrayOf[String]

#guided_jsonHash{Symbol=>Object}?

Must be a valid JSON schema. If specified, the output will follow the JSON schema.

Returns:

  • (Hash{Symbol=>Object}, nil)


59
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 59

optional :guided_json, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown]

#guided_regexString?

If specified, the output will follow the regex pattern.

Returns:

  • (String, nil)


65
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 65

optional :guided_regex, String

#length_penaltyFloat?

This is used with ‘use_beam_search` to prefer shorter or longer completions.

Returns:

  • (Float, nil)


71
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 71

optional :length_penalty, Float

#logprobsBoolean?

Whether to return log probabilities of the output tokens or not. If true, returns the log probabilities of each output token returned in the ‘content` of `message`.

Returns:

  • (Boolean, nil)


79
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 79

optional :logprobs, Telnyx::Internal::Type::Boolean

#max_tokensInteger?

Maximum number of completion tokens the model should generate.

Returns:

  • (Integer, nil)


85
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 85

optional :max_tokens, Integer

#messagesArray<Telnyx::Models::AI::ChatCreateCompletionParams::Message>

A list of the previous chat messages for context.



15
16
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 15

required :messages,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::ChatCreateCompletionParams::Message] }

#min_pFloat?

This is an alternative to ‘top_p` that [many prefer](github.com/huggingface/transformers/issues/27670). Must be in [0, 1].

Returns:

  • (Float, nil)


93
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 93

optional :min_p, Float

#modelString?

The language model to chat with.

Returns:

  • (String, nil)


99
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 99

optional :model, String

#nFloat?

This will return multiple choices for you instead of a single chat completion.

Returns:

  • (Float, nil)


105
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 105

optional :n, Float

#presence_penaltyFloat?

Higher values will penalize the model from repeating the same output tokens.

Returns:

  • (Float, nil)


111
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 111

optional :presence_penalty, Float

#response_formatTelnyx::Models::AI::ChatCreateCompletionParams::ResponseFormat?

Use this is you want to guarantee a JSON output without defining a schema. For control over the schema, use ‘guided_json`.



118
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 118

optional :response_format, -> { Telnyx::AI::ChatCreateCompletionParams::ResponseFormat }

#streamBoolean?

Whether or not to stream data-only server-sent events as they become available.

Returns:

  • (Boolean, nil)


124
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 124

optional :stream, Telnyx::Internal::Type::Boolean

#temperatureFloat?

Adjusts the “creativity” of the model. Lower values make the model more deterministic and repetitive, while higher values make the model more random and creative.

Returns:

  • (Float, nil)


132
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 132

optional :temperature, Float

#tool_choiceSymbol, ...



137
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 137

optional :tool_choice, enum: -> { Telnyx::AI::ChatCreateCompletionParams::ToolChoice }

#toolsArray<Telnyx::Models::AI::ChatCreateCompletionParams::Tool::Function, Telnyx::Models::AI::ChatCreateCompletionParams::Tool::Retrieval>?

The ‘function` tool type follows the same schema as the [OpenAI Chat Completions API](platform.openai.com/docs/api-reference/chat). The `retrieval` tool type is unique to Telnyx. You may pass a list of [embedded storage buckets](developers.telnyx.com/api-reference/embeddings/embed-documents) for retrieval-augmented generation.



147
148
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 147

optional :tools,
-> { Telnyx::Internal::Type::ArrayOf[union: Telnyx::AI::ChatCreateCompletionParams::Tool] }

#top_logprobsInteger?

This is used with ‘logprobs`. An integer between 0 and 20 specifying the number of most likely tokens to return at each token position, each with an associated log probability.

Returns:

  • (Integer, nil)


156
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 156

optional :top_logprobs, Integer

#top_pFloat?

An alternative or complement to ‘temperature`. This adjusts how many of the top possibilities to consider.

Returns:

  • (Float, nil)


163
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 163

optional :top_p, Float

#use_beam_searchBoolean?

Setting this to ‘true` will allow the model to [explore more completion options](huggingface.co/blog/how-to-generate#beam-search). This is not supported by OpenAI.

Returns:

  • (Boolean, nil)


171
# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 171

optional :use_beam_search, Telnyx::Internal::Type::Boolean

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ai/chat_create_completion_params.rb', line 301