Class: Telnyx::Models::AI::ClusterComputeParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::ClusterComputeParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/cluster_compute_params.rb
Overview
Instance Attribute Summary collapse
-
#bucket ⇒ String
The embedded storage bucket to compute the clusters from.
-
#files ⇒ Array<String>?
Array of files to filter which are included.
-
#min_cluster_size ⇒ Integer?
Smallest number of related text chunks to qualify as a cluster.
-
#min_subcluster_size ⇒ Integer?
Smallest number of related text chunks to qualify as a sub-cluster.
-
#prefix ⇒ String?
Prefix to filter whcih files in the buckets are included.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(bucket:, files: nil, min_cluster_size: nil, min_subcluster_size: nil, prefix: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ClusterComputeParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bucket:, files: nil, min_cluster_size: nil, min_subcluster_size: nil, prefix: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::ClusterComputeParams for more details.
|
|
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 45
|
Instance Attribute Details
#bucket ⇒ String
The embedded storage bucket to compute the clusters from. The bucket must already be [embedded](developers.telnyx.com/api-reference/embeddings/embed-documents).
17 |
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 17 required :bucket, String |
#files ⇒ Array<String>?
Array of files to filter which are included.
23 |
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 23 optional :files, Telnyx::Internal::Type::ArrayOf[String] |
#min_cluster_size ⇒ Integer?
Smallest number of related text chunks to qualify as a cluster. Top-level clusters should be thought of as identifying broad themes in your data.
30 |
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 30 optional :min_cluster_size, Integer |
#min_subcluster_size ⇒ Integer?
Smallest number of related text chunks to qualify as a sub-cluster. Sub-clusters should be thought of as identifying more specific topics within a broader theme.
37 |
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 37 optional :min_subcluster_size, Integer |
#prefix ⇒ String?
Prefix to filter whcih files in the buckets are included.
43 |
# File 'lib/telnyx/models/ai/cluster_compute_params.rb', line 43 optional :prefix, String |