Class: Telnyx::Models::AI::Collections::Source
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Collections::Source
- Defined in:
- lib/telnyx/models/ai/collections/source.rb,
sig/telnyx/models/ai/collections/source.rbs
Instance Attribute Summary collapse
-
#bucket_id ⇒ String?
The Telnyx Storage bucket name.
- #collection_id ⇒ String?
- #id ⇒ String?
-
#record_type ⇒ String?
Identifies the record type.
-
#source_type ⇒ Symbol, ...
The type of Telnyx data attached as a source.
- #status ⇒ String?
Instance Method Summary collapse
-
#initialize(id: nil, bucket_id: nil, collection_id: nil, record_type: nil, source_type: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Source for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, bucket_id: nil, collection_id: nil, record_type: nil, source_type: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::Collections::Source for more details.
|
|
# File 'lib/telnyx/models/ai/collections/source.rb', line 43
|
Instance Attribute Details
#bucket_id ⇒ String?
The Telnyx Storage bucket name. Present only for bucket sources.
17 |
# File 'lib/telnyx/models/ai/collections/source.rb', line 17 optional :bucket_id, String |
#collection_id ⇒ String?
22 |
# File 'lib/telnyx/models/ai/collections/source.rb', line 22 optional :collection_id, String |
#id ⇒ String?
11 |
# File 'lib/telnyx/models/ai/collections/source.rb', line 11 optional :id, String |
#record_type ⇒ String?
Identifies the record type. Always ai_collection_source.
28 |
# File 'lib/telnyx/models/ai/collections/source.rb', line 28 optional :record_type, String |
#source_type ⇒ Symbol, ...
The type of Telnyx data attached as a source. bucket requires an additional
bucket_id. Only voice is searchable today; meeting_bot, message, and
bucket attach but are not yet searchable (Coming soon).
36 |
# File 'lib/telnyx/models/ai/collections/source.rb', line 36 optional :source_type, enum: -> { Telnyx::AI::Collections::SourceType } |
#status ⇒ String?
41 |
# File 'lib/telnyx/models/ai/collections/source.rb', line 41 optional :status, String |
Instance Method Details
#to_hash ⇒ {
51 |
# File 'sig/telnyx/models/ai/collections/source.rbs', line 51
def to_hash: -> {
|