Class: Telnyx::Models::AI::Collections::SourceRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Collections::SourceRequest
- Defined in:
- lib/telnyx/models/ai/collections/source_request.rb,
sig/telnyx/models/ai/collections/source_request.rbs
Direct Known Subclasses
Instance Attribute Summary collapse
-
#bucket_id ⇒ String?
The Telnyx Storage bucket name.
-
#source_type ⇒ Symbol, Telnyx::Models::AI::Collections::SourceType
The type of Telnyx data attached as a source.
Instance Method Summary collapse
-
#initialize(source_type:, bucket_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SourceRequest for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(source_type:, bucket_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::Collections::SourceRequest for more details.
|
|
# File 'lib/telnyx/models/ai/collections/source_request.rb', line 23
|
Instance Attribute Details
#bucket_id ⇒ String?
The Telnyx Storage bucket name. Required when source_type is bucket; ignored
otherwise.
21 |
# File 'lib/telnyx/models/ai/collections/source_request.rb', line 21 optional :bucket_id, String |
#source_type ⇒ Symbol, Telnyx::Models::AI::Collections::SourceType
The type of Telnyx data attached as a source. bucket requires an additional
bucket_id. Only voice is searchable today; meeting_bot, message, and
bucket attach but are not yet searchable (Coming soon).
14 |
# File 'lib/telnyx/models/ai/collections/source_request.rb', line 14 required :source_type, enum: -> { Telnyx::AI::Collections::SourceType } |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/telnyx/models/ai/collections/source_request.rbs', line 23
def to_hash: -> {
|