Class: Telnyx::Models::AI::ConversationListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/ai/conversation_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, last_message_at: nil, limit: nil, metadata_assistant_id: nil, metadata_call_control_id: nil, metadata_telnyx_agent_target: nil, metadata_telnyx_conversation_channel: nil, metadata_telnyx_end_user_target: nil, name: nil, or_: nil, order: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::ConversationListParams for more details.

Parameters:

  • id (String) (defaults to: nil)

    Filter by conversation ID (e.g. id=eq.123)

  • created_at (String) (defaults to: nil)

    Filter by creation datetime (e.g., ‘created_at=gte.2025-01-01`)

  • last_message_at (String) (defaults to: nil)

    Filter by last message datetime (e.g., ‘last_message_at=lte.2025-06-01`)

  • limit (Integer) (defaults to: nil)

    Limit the number of returned conversations (e.g., ‘limit=10`)

  • metadata_assistant_id (String) (defaults to: nil)

    Filter by assistant ID (e.g., ‘metadata->assistant_id=eq.assistant-123`)

  • metadata_call_control_id (String) (defaults to: nil)

    Filter by call control ID (e.g., ‘metadata->call_control_id=eq.v3:123`)

  • metadata_telnyx_agent_target (String) (defaults to: nil)

    Filter by the phone number, SIP URI, or other identifier for the agent (e.g., ‘m

  • metadata_telnyx_conversation_channel (String) (defaults to: nil)

    Filter by conversation channel (e.g., ‘metadata->telnyx_conversation_channel=eq.

  • metadata_telnyx_end_user_target (String) (defaults to: nil)

    Filter by the phone number, SIP URI, or other identifier for the end user (e.g.,

  • name (String) (defaults to: nil)

    Filter by conversation Name (e.g. ‘name=like.Voice%`)

  • or_ (String) (defaults to: nil)

    Apply OR conditions using PostgREST syntax (e.g., ‘or=(created_at.gte.2025-04-01

  • order (String) (defaults to: nil)

    Order the results by specific fields (e.g., ‘order=created_at.desc` or `order=la

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 88

Instance Attribute Details

#created_atString?

Filter by creation datetime (e.g., ‘created_at=gte.2025-01-01`)

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 21

optional :created_at, String

#idString?

Filter by conversation ID (e.g. id=eq.123)

Returns:

  • (String, nil)


15
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 15

optional :id, String

#last_message_atString?

Filter by last message datetime (e.g., ‘last_message_at=lte.2025-06-01`)

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 27

optional :last_message_at, String

#limitInteger?

Limit the number of returned conversations (e.g., ‘limit=10`)

Returns:

  • (Integer, nil)


33
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 33

optional :limit, Integer

#metadata_assistant_idString?

Filter by assistant ID (e.g., ‘metadata->assistant_id=eq.assistant-123`)

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 39

optional :metadata_assistant_id, String

#metadata_call_control_idString?

Filter by call control ID (e.g., ‘metadata->call_control_id=eq.v3:123`)

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 45

optional :metadata_call_control_id, String

#metadata_telnyx_agent_targetString?

Filter by the phone number, SIP URI, or other identifier for the agent (e.g., ‘metadata->telnyx_agent_target=eq.+13128675309`)

Returns:

  • (String, nil)


52
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 52

optional :metadata_telnyx_agent_target, String

#metadata_telnyx_conversation_channelString?

Filter by conversation channel (e.g., ‘metadata->telnyx_conversation_channel=eq.phone_call`)

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 59

optional :metadata_telnyx_conversation_channel, String

#metadata_telnyx_end_user_targetString?

Filter by the phone number, SIP URI, or other identifier for the end user (e.g., ‘metadata->telnyx_end_user_target=eq.+13128675309`)

Returns:

  • (String, nil)


66
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 66

optional :metadata_telnyx_end_user_target, String

#nameString?

Filter by conversation Name (e.g. ‘name=like.Voice%`)

Returns:

  • (String, nil)


72
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 72

optional :name, String

#or_String?

Apply OR conditions using PostgREST syntax (e.g., ‘or=(created_at.gte.2025-04-01,last_message_at.gte.2025-04-01)`)

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 79

optional :or_, String

#orderString?

Order the results by specific fields (e.g., ‘order=created_at.desc` or `order=last_message_at.asc`)

Returns:

  • (String, nil)


86
# File 'lib/telnyx/models/ai/conversation_list_params.rb', line 86

optional :order, String