Class: Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rb,
sig/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rbs
Overview
Defined Under Namespace
Classes: Metadata
Instance Attribute Summary collapse
-
#created_at ⇒ String?
Filter by creation datetime to scope the aggregation window.
-
#group_by ⇒ Array<String>?
Fields to group by (can be comma-separated or multiple parameters).
-
#insight_id ⇒ String?
Optional insight ID to filter conversation insights.
- #metadata ⇒ Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesParams::Metadata?
-
#show ⇒ Array<String>?
Fields to include in the result (can be comma-separated or multiple parameters).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
41 |
# File 'sig/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rbs', line 41
def initialize: (
|
Instance Attribute Details
#created_at ⇒ String?
Filter by creation datetime to scope the aggregation window. Supports range
operators (e.g., created_at=gte.2025-01-01T00:00:00Z for the start of the
range, created_at=lt.2025-01-02T00:00:00Z for the end). To build per-day time
series (as the portal does for the 'Insights Over Time' chart), issue one
request per day bounded by created_at=gte.<day_start> and
created_at=lt.<next_day_start>.
21 |
# File 'lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rb', line 21 optional :created_at, String |
#group_by ⇒ Array<String>?
Fields to group by (can be comma-separated or multiple parameters). Prefix a field with 'metadata.' (e.g. 'metadata.assistant_id') to group by the conversation's metadata instead of the insight result.
Common fields used for over-time charts:
score— Group by the insight's score value (e.g. for Agent Instruction Following, User Satisfaction).metadata.assistant_id— Group by the assistant that handled the conversation.metadata.assistant_version_id— Group by the assistant version, useful for comparing performance across versions in the portal's 'Insights Over Time' chart.metadata.telnyx_conversation_channel— Group by conversation channel (phone_call, web_chat, etc.).
41 |
# File 'lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rb', line 41 optional :group_by, Telnyx::Internal::Type::ArrayOf[String] |
#insight_id ⇒ String?
Optional insight ID to filter conversation insights. Only insights matching this ID will be included in the aggregation.
48 |
# File 'lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rb', line 48 optional :insight_id, String |
#metadata ⇒ Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesParams::Metadata?
53 54 |
# File 'lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rb', line 53 optional :metadata, -> { Telnyx::AI::Conversations::ConversationInsightRetrieveAggregatesParams::Metadata } |
#show ⇒ Array<String>?
Fields to include in the result (can be comma-separated or multiple parameters).
Supports the same 'metadata.record_count indicating how many
conversation insights match that combination.
63 |
# File 'lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rb', line 63 optional :show, Telnyx::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
50 |
# File 'sig/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rbs', line 50
def to_hash: -> {
|