Class: Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesParams::Metadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesParams::Metadata
- Defined in:
- lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rb,
sig/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rbs
Instance Attribute Summary collapse
-
#assistant_id ⇒ String?
Filter by assistant ID (e.g.,
metadata.assistant_id=eq.<assistant_id>).
Instance Method Summary collapse
-
#initialize(assistant_id: nil) ⇒ Metadata
constructor
Some parameter documentations has been truncated, see Metadata for more details.
- #to_hash ⇒ { assistant_id: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assistant_id: nil) ⇒ Metadata
Some parameter documentations has been truncated, see Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesParams::Metadata for more details.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rb', line 82 class Metadata < Telnyx::Internal::Type::BaseModel # @!attribute assistant_id # Filter by assistant ID (e.g., `metadata.assistant_id=eq.<assistant_id>`). When # provided, only conversation insights for the specified assistant are aggregated. # Used by the portal to scope the 'Insights Over Time' chart to a single # assistant. # # @return [String, nil] optional :assistant_id, String # @!method initialize(assistant_id: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesParams::Metadata} # for more details. # # @param assistant_id [String] Filter by assistant ID (e.g., `metadata.assistant_id=eq.<assistant_id>`). When p end |
Instance Attribute Details
#assistant_id ⇒ String?
Filter by assistant ID (e.g., metadata.assistant_id=eq.<assistant_id>). When
provided, only conversation insights for the specified assistant are aggregated.
Used by the portal to scope the 'Insights Over Time' chart to a single
assistant.
90 |
# File 'lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rb', line 90 optional :assistant_id, String |
Instance Method Details
#to_hash ⇒ { assistant_id: String }
68 |
# File 'sig/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_params.rbs', line 68
def to_hash: -> { assistant_id: String }
|