Class: Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesResponse::Data
- Defined in:
- lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_response.rb,
sig/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_response.rbs
Instance Attribute Summary collapse
-
#record_count ⇒ Integer
Number of conversation insights that match this combination of grouped field values.
Instance Method Summary collapse
-
#initialize(record_count:) ⇒ Data
constructor
Some parameter documentations has been truncated, see Data for more details.
- #to_hash ⇒ { record_count: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(record_count:) ⇒ Data
Some parameter documentations has been truncated, see Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesResponse::Data for more details.
An aggregation row. Contains the grouped field values (keyed by the group_by
field names) and a record_count integer. For example, when grouping by
score, each row has a score value and a record_count of conversations with
that score. When also splitting by metadata.assistant_version_id, each row
includes both score and metadata.assistant_version_id plus their combined
record_count.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_response.rb', line 28 class Data < Telnyx::Internal::Type::BaseModel # @!attribute record_count # Number of conversation insights that match this combination of grouped field # values. # # @return [Integer] required :record_count, Integer # @!method initialize(record_count:) # Some parameter documentations has been truncated, see # {Telnyx::Models::AI::Conversations::ConversationInsightRetrieveAggregatesResponse::Data} # for more details. # # An aggregation row. Contains the grouped field values (keyed by the group_by # field names) and a `record_count` integer. For example, when grouping by # `score`, each row has a `score` value and a `record_count` of conversations with # that score. When also splitting by `metadata.assistant_version_id`, each row # includes both `score` and `metadata.assistant_version_id` plus their combined # `record_count`. # # @param record_count [Integer] Number of conversation insights that match this combination of grouped field val end |
Instance Attribute Details
#record_count ⇒ Integer
Number of conversation insights that match this combination of grouped field values.
34 |
# File 'lib/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_response.rb', line 34 required :record_count, Integer |
Instance Method Details
#to_hash ⇒ { record_count: Integer }
28 |
# File 'sig/telnyx/models/ai/conversations/conversation_insight_retrieve_aggregates_response.rbs', line 28
def to_hash: -> { record_count: Integer }
|