Class: Telnyx::Models::AI::Conversations::MessageListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/conversations/message_list_response.rb

Overview

Defined Under Namespace

Modules: Role Classes: ToolCall

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(role:, text:, created_at: nil, sent_at: nil, tool_calls: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::Conversations::MessageListResponse for more details.

Parameters:



# File 'lib/telnyx/models/ai/conversations/message_list_response.rb', line 42

Instance Attribute Details

#created_atTime?

The datetime the message was created on the conversation. This does not necesarily correspond to the time the message was sent. The best field to use to determine the time the end user experienced the message is ‘sent_at`.

Returns:

  • (Time, nil)


27
# File 'lib/telnyx/models/ai/conversations/message_list_response.rb', line 27

optional :created_at, Time

#roleSymbol, Telnyx::Models::AI::Conversations::MessageListResponse::Role

The role of the message sender.



13
# File 'lib/telnyx/models/ai/conversations/message_list_response.rb', line 13

required :role, enum: -> { Telnyx::Models::AI::Conversations::MessageListResponse::Role }

#sent_atTime?

The datetime the message was sent to the end user.

Returns:

  • (Time, nil)


33
# File 'lib/telnyx/models/ai/conversations/message_list_response.rb', line 33

optional :sent_at, Time

#textString

The message content. Can be null for tool calls.

Returns:

  • (String)


19
# File 'lib/telnyx/models/ai/conversations/message_list_response.rb', line 19

required :text, String

#tool_callsArray<Telnyx::Models::AI::Conversations::MessageListResponse::ToolCall>?

Optional tool calls made by the assistant.



39
40
# File 'lib/telnyx/models/ai/conversations/message_list_response.rb', line 39

optional :tool_calls,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AI::Conversations::MessageListResponse::ToolCall] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ai/conversations/message_list_response.rb', line 66