Module: Telnyx::Models::AI::EnabledFeatures
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/ai/enabled_features.rb
Overview
If ‘telephony` is enabled, the assistant will be able to make and receive calls. If `messaging` is enabled, the assistant will be able to send and receive messages.
Constant Summary collapse
- TELEPHONY =
:telephony- MESSAGING =
:messaging
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/enabled_features.rb', line 15
|