Class: Telnyx::Models::AI::FineTuning::FineTuningJob
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::FineTuning::FineTuningJob
- Defined in:
- lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb
Overview
Defined Under Namespace
Modules: Status Classes: Hyperparameters
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
The Unix timestamp (in seconds) for when the fine-tuning job was created.
-
#finished_at ⇒ Integer?
The Unix timestamp (in seconds) for when the fine-tuning job was finished.
-
#hyperparameters ⇒ Telnyx::Models::AI::FineTuning::FineTuningJob::Hyperparameters
The hyperparameters used for the fine-tuning job.
-
#id ⇒ String
The name of the fine-tuned model that is being created.
-
#model ⇒ String
The base model that is being fine-tuned.
-
#organization_id ⇒ String
The organization that owns the fine-tuning job.
-
#status ⇒ Symbol, Telnyx::Models::AI::FineTuning::FineTuningJob::Status
The current status of the fine-tuning job.
-
#trained_tokens ⇒ Integer?
The total number of billable tokens processed by this fine-tuning job.
-
#training_file ⇒ String
The storage bucket or object used for training.
Instance Method Summary collapse
-
#initialize(n_epochs:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Hyperparameters for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(n_epochs:) ⇒ Object
Some parameter documentations has been truncated, see Hyperparameters for more details.
The hyperparameters used for the fine-tuning job.
|
|
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 65
|
Instance Attribute Details
#created_at ⇒ Integer
The Unix timestamp (in seconds) for when the fine-tuning job was created.
19 |
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 19 required :created_at, Integer |
#finished_at ⇒ Integer?
The Unix timestamp (in seconds) for when the fine-tuning job was finished. The value will be null if the fine-tuning job is still running.
26 |
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 26 required :finished_at, Integer, nil?: true |
#hyperparameters ⇒ Telnyx::Models::AI::FineTuning::FineTuningJob::Hyperparameters
The hyperparameters used for the fine-tuning job.
32 |
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 32 required :hyperparameters, -> { Telnyx::AI::FineTuning::FineTuningJob::Hyperparameters } |
#id ⇒ String
The name of the fine-tuned model that is being created.
13 |
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 13 required :id, String |
#model ⇒ String
The base model that is being fine-tuned.
38 |
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 38 required :model, String |
#organization_id ⇒ String
The organization that owns the fine-tuning job.
44 |
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 44 required :organization_id, String |
#status ⇒ Symbol, Telnyx::Models::AI::FineTuning::FineTuningJob::Status
The current status of the fine-tuning job.
50 |
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 50 required :status, enum: -> { Telnyx::AI::FineTuning::FineTuningJob::Status } |
#trained_tokens ⇒ Integer?
The total number of billable tokens processed by this fine-tuning job. The value will be null if the fine-tuning job is still running.
57 |
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 57 required :trained_tokens, Integer, nil?: true |
#training_file ⇒ String
The storage bucket or object used for training.
63 |
# File 'lib/telnyx/models/ai/fine_tuning/fine_tuning_job.rb', line 63 required :training_file, String |