Module: Telnyx::Models::AI::FlowEdge::Condition
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/ai/flow_edge.rb,
sig/telnyx/models/ai/flow_edge.rbs
Overview
Condition that gates the transition. Discriminated by type: llm,
expression.
Defined Under Namespace
Classes: Default, Expression, Llm
Instance Method Summary collapse
-
#initialize(expression:, type: :expression) ⇒ Object
Some parameter documentations has been truncated, see Expression for more details.
- #self?.variants ⇒ ::Array[Telnyx::Models::AI::FlowEdge::condition]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(expression:, type: :expression) ⇒ Object
Some parameter documentations has been truncated, see Expression for more details.
Edge condition evaluated as a deterministic expression AST.
The expression is computed against runtime dynamic variables and must evaluate
to a boolean. Prefer this over LLMCondition when the rule is a clean function
of known variables — it's cheaper and predictable.
|
|
# File 'lib/telnyx/models/ai/flow_edge.rb', line 98
|
#self?.variants ⇒ ::Array[Telnyx::Models::AI::FlowEdge::condition]
77 |
# File 'sig/telnyx/models/ai/flow_edge.rbs', line 77
def self?.variants: -> ::Array[Telnyx::Models::AI::FlowEdge::condition]
|