Module: Telnyx::Models::AI::FlowEdge::Condition

Extended by:
Internal::Type::Union
Defined in:
lib/telnyx/models/ai/flow_edge.rb

Overview

Condition that gates the transition. Discriminated by ‘type`: `llm`, `expression`.

See Also:

Defined Under Namespace

Classes: Default, Expression, Llm

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(expression:, type: :expression) ⇒ Object

Some parameter documentations has been truncated, see Expression for more details.

Edge condition evaluated as a deterministic expression AST.

The expression is computed against runtime dynamic variables and must evaluate to a boolean. Prefer this over ‘LLMCondition` when the rule is a clean function of known variables — it’s cheaper and predictable.

Parameters:

  • expression (Object)

    Root of the expression AST; evaluates to a boolean. Typed as free-form JSON to a

  • type (Symbol, :expression) (defaults to: :expression)


# File 'lib/telnyx/models/ai/flow_edge.rb', line 98