Class: Telnyx::Models::AI::InferenceEmbedding::FallbackConfig::ExternalLlm

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/inference_embedding.rb

Overview

See Also:

Defined Under Namespace

Modules: AuthenticationMethod

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::InferenceEmbedding::FallbackConfig::ExternalLlm for more details.

Parameters:

  • base_url (String)

    Base URL for the external LLM endpoint.

  • model (String)

    Model identifier to use with the external LLM endpoint.

  • authentication_method (Symbol, Telnyx::Models::AI::InferenceEmbedding::FallbackConfig::ExternalLlm::AuthenticationMethod) (defaults to: nil)

    Authentication method used when connecting to the external LLM endpoint.

  • certificate_ref (String) (defaults to: nil)

    Integration secret identifier for the client certificate used with certificate a

  • forward_metadata (Boolean) (defaults to: nil)

    When enabled, Telnyx forwards conversation metadata and dynamic variables to the

  • llm_api_key_ref (String) (defaults to: nil)

    Integration secret identifier for the external LLM API key.

  • token_retrieval_url (String) (defaults to: nil)

    URL used to retrieve an access token when certificate authentication is enabled.



# File 'lib/telnyx/models/ai/inference_embedding.rb', line 372

Instance Attribute Details

#authentication_methodSymbol, ...

Authentication method used when connecting to the external LLM endpoint.



340
341
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 340

optional :authentication_method,
enum: -> { Telnyx::AI::InferenceEmbedding::FallbackConfig::ExternalLlm::AuthenticationMethod }

#base_urlString

Base URL for the external LLM endpoint.

Returns:

  • (String)


328
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 328

required :base_url, String

#certificate_refString?

Integration secret identifier for the client certificate used with certificate authentication.

Returns:

  • (String, nil)


348
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 348

optional :certificate_ref, String

#forward_metadataBoolean?

When enabled, Telnyx forwards conversation metadata and dynamic variables to the external LLM endpoint. Defaults to false. The external endpoint receives the standard chat completions payload with top-level ‘metadata` and `dynamic_variables` objects when values are available. For example: `“metadata”:{“conversation_id”:“conv_123”,“assistant_id”:“assistant_456”,“call_control_id”:“v3:abc123”,“telnyx_conversation_channel”:“phone_call”,“dynamic_variables”:“customer_name”:“Jane”,“account_id”:“acct_789”,“telnyx_agent_target”:“+13125550100”,“telnyx_end_user_target”:“+13125550123”}`.

Returns:

  • (Boolean, nil)


358
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 358

optional :forward_metadata, Telnyx::Internal::Type::Boolean

#llm_api_key_refString?

Integration secret identifier for the external LLM API key.

Returns:

  • (String, nil)


364
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 364

optional :llm_api_key_ref, String

#modelString

Model identifier to use with the external LLM endpoint.

Returns:

  • (String)


334
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 334

required :model, String

#token_retrieval_urlString?

URL used to retrieve an access token when certificate authentication is enabled.

Returns:

  • (String, nil)


370
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 370

optional :token_retrieval_url, String