Class: Telnyx::Models::AI::InferenceEmbedding::FallbackConfig::ExternalLlm
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::InferenceEmbedding::FallbackConfig::ExternalLlm
- Defined in:
- lib/telnyx/models/ai/inference_embedding.rb
Overview
Defined Under Namespace
Modules: AuthenticationMethod
Instance Attribute Summary collapse
-
#authentication_method ⇒ Symbol, ...
Authentication method used when connecting to the external LLM endpoint.
-
#base_url ⇒ String
Base URL for the external LLM endpoint.
-
#certificate_ref ⇒ String?
Integration secret identifier for the client certificate used with certificate authentication.
-
#forward_metadata ⇒ Boolean?
When enabled, Telnyx forwards conversation metadata and dynamic variables to the external LLM endpoint.
-
#llm_api_key_ref ⇒ String?
Integration secret identifier for the external LLM API key.
-
#model ⇒ String
Model identifier to use with the external LLM endpoint.
-
#token_retrieval_url ⇒ String?
URL used to retrieve an access token when certificate authentication is enabled.
Instance Method Summary collapse
-
#initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalLlm for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(base_url:, model:, authentication_method: nil, certificate_ref: nil, forward_metadata: nil, llm_api_key_ref: nil, token_retrieval_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::InferenceEmbedding::FallbackConfig::ExternalLlm for more details.
|
|
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 372
|
Instance Attribute Details
#authentication_method ⇒ Symbol, ...
Authentication method used when connecting to the external LLM endpoint.
340 341 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 340 optional :authentication_method, enum: -> { Telnyx::AI::InferenceEmbedding::FallbackConfig::ExternalLlm::AuthenticationMethod } |
#base_url ⇒ String
Base URL for the external LLM endpoint.
328 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 328 required :base_url, String |
#certificate_ref ⇒ String?
Integration secret identifier for the client certificate used with certificate authentication.
348 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 348 optional :certificate_ref, String |
#forward_metadata ⇒ Boolean?
When enabled, Telnyx forwards conversation metadata and dynamic variables to the external LLM endpoint. Defaults to false. The external endpoint receives the standard chat completions payload with top-level ‘metadata` and `dynamic_variables` objects when values are available. For example: `“metadata”:{“conversation_id”:“conv_123”,“assistant_id”:“assistant_456”,“call_control_id”:“v3:abc123”,“telnyx_conversation_channel”:“phone_call”,“dynamic_variables”:“customer_name”:“Jane”,“account_id”:“acct_789”,“telnyx_agent_target”:“+13125550100”,“telnyx_end_user_target”:“+13125550123”}`.
358 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 358 optional :forward_metadata, Telnyx::Internal::Type::Boolean |
#llm_api_key_ref ⇒ String?
Integration secret identifier for the external LLM API key.
364 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 364 optional :llm_api_key_ref, String |
#model ⇒ String
Model identifier to use with the external LLM endpoint.
334 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 334 required :model, String |
#token_retrieval_url ⇒ String?
URL used to retrieve an access token when certificate authentication is enabled.
370 |
# File 'lib/telnyx/models/ai/inference_embedding.rb', line 370 optional :token_retrieval_url, String |