Class: Telnyx::Models::AI::InferenceEmbeddingInterruptionSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/inference_embedding_interruption_settings.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enable: nil, start_speaking_plan: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::InferenceEmbeddingInterruptionSettings for more details.

Settings for interruptions and how the assistant decides the user has finished speaking. These timings are most relevant when using non turn-taking transcription models. For turn-taking models like ‘deepgram/flux`, end-of-turn behavior is controlled by the transcription end-of-turn settings under `transcription.settings` (`eot_threshold`, `eot_timeout_ms`, `eager_eot_threshold`).

Parameters:

  • enable (Boolean) (defaults to: nil)

    Whether users can interrupt the assistant while it is speaking.

  • start_speaking_plan (Telnyx::Models::AI::StartSpeakingPlan) (defaults to: nil)

    Controls when the assistant starts speaking after the user stops. These threshol



# File 'lib/telnyx/models/ai/inference_embedding_interruption_settings.rb', line 22

Instance Attribute Details

#enableBoolean?

Whether users can interrupt the assistant while it is speaking.

Returns:

  • (Boolean, nil)


11
# File 'lib/telnyx/models/ai/inference_embedding_interruption_settings.rb', line 11

optional :enable, Telnyx::Internal::Type::Boolean

#start_speaking_planTelnyx::Models::AI::StartSpeakingPlan?

Controls when the assistant starts speaking after the user stops. These thresholds primarily apply to non turn-taking transcription models. For turn-taking models like ‘deepgram/flux`, end-of-turn detection is driven by the transcription end-of-turn settings under `transcription.settings` instead.



20
# File 'lib/telnyx/models/ai/inference_embedding_interruption_settings.rb', line 20

optional :start_speaking_plan, -> { Telnyx::AI::StartSpeakingPlan }