Class: Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook
- Defined in:
- lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb
Overview
Defined Under Namespace
Modules: Method Classes: BodyParameters, Header, PathParameters, QueryParameters, StoreFieldsAsVariable
Instance Attribute Summary collapse
-
#async ⇒ Boolean?
If async, the assistant will move forward without waiting for your server to respond.
-
#body_parameters ⇒ Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::BodyParameters?
The body parameters the webhook tool accepts, described as a JSON Schema object.
-
#description ⇒ String
The description of the tool.
-
#headers ⇒ Array<Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::Header>?
The headers to be sent to the external tool.
-
#http_method ⇒ Symbol, ...
The HTTP method to be used when calling the external tool.
-
#name ⇒ String
The name of the tool.
-
#path_parameters ⇒ Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::PathParameters?
The path parameters the webhook tool accepts, described as a JSON Schema object.
-
#query_parameters ⇒ Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::QueryParameters?
The query parameters the webhook tool accepts, described as a JSON Schema object.
-
#store_fields_as_variables ⇒ Array<Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::StoreFieldsAsVariable>?
A list of mappings that extract values from the webhook response and store them as dynamic variables.
-
#timeout_ms ⇒ Integer?
The maximum number of milliseconds to wait for the webhook to respond.
-
#url ⇒ String
The URL of the external tool to be called.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil, value: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Header for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil, value: nil) ⇒ Object
Some parameter documentations has been truncated, see Header for more details.
|
|
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 122
|
Instance Attribute Details
#async ⇒ Boolean?
If async, the assistant will move forward without waiting for your server to respond.
59 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 59 optional :async, Telnyx::Internal::Type::Boolean |
#body_parameters ⇒ Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::BodyParameters?
The body parameters the webhook tool accepts, described as a JSON Schema object. These parameters will be passed to the webhook as the body of the request. See the [JSON Schema reference](json-schema.org/understanding-json-schema) for documentation about the format
68 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 68 optional :body_parameters, -> { Telnyx::AI::InferenceEmbeddingWebhookToolParams::Webhook::BodyParameters } |
#description ⇒ String
The description of the tool.
37 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 37 required :description, String |
#headers ⇒ Array<Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::Header>?
The headers to be sent to the external tool.
74 75 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 74 optional :headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::InferenceEmbeddingWebhookToolParams::Webhook::Header] } |
#http_method ⇒ Symbol, ...
The HTTP method to be used when calling the external tool.
81 82 83 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 81 optional :http_method, enum: -> { Telnyx::AI::InferenceEmbeddingWebhookToolParams::Webhook::Method }, api_name: :method |
#name ⇒ String
The name of the tool.
43 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 43 required :name, String |
#path_parameters ⇒ Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::PathParameters?
The path parameters the webhook tool accepts, described as a JSON Schema object. These parameters will be passed to the webhook as the path of the request if the URL contains a placeholder for a value. See the [JSON Schema reference](json-schema.org/understanding-json-schema) for documentation about the format
93 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 93 optional :path_parameters, -> { Telnyx::AI::InferenceEmbeddingWebhookToolParams::Webhook::PathParameters } |
#query_parameters ⇒ Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::QueryParameters?
The query parameters the webhook tool accepts, described as a JSON Schema object. These parameters will be passed to the webhook as the query of the request. See the [JSON Schema reference](json-schema.org/understanding-json-schema) for documentation about the format
103 104 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 103 optional :query_parameters, -> { Telnyx::AI::InferenceEmbeddingWebhookToolParams::Webhook::QueryParameters } |
#store_fields_as_variables ⇒ Array<Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::StoreFieldsAsVariable>?
A list of mappings that extract values from the webhook response and store them as dynamic variables. Each mapping specifies a dynamic variable name and a dot-notation path to the value in the response body.
112 113 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 112 optional :store_fields_as_variables, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::AI::InferenceEmbeddingWebhookToolParams::Webhook::StoreFieldsAsVariable] } |
#timeout_ms ⇒ Integer?
The maximum number of milliseconds to wait for the webhook to respond. Only applicable when async is false.
120 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 120 optional :timeout_ms, Integer |
#url ⇒ String
The URL of the external tool to be called. This URL is going to be used by the assistant. The URL can be templated like: ‘example.com/api/v1/id`, where `id` is a placeholder for a value that will be provided by the assistant if `path_parameters` are provided with the `id` attribute.
52 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 52 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 187
|