Class: Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::Header

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#nameString?

Returns:

  • (String, nil)


196
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 196

optional :name, String

#valueString?

The value of the header. Note that we support mustache templating for the value. For example you can use ‘Bearer Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::Header.{{#integration_secret}test-secret{/integration_secret}` to pass the value of the integration secret as the bearer token. [Telnyx signature headers](developers.telnyx.com/docs/voice/programmable-voice/voice-api-webhooks) will be automatically added to the request.

Returns:

  • (String, nil)


207
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 207

optional :value, String