Class: Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::Message::WebhookToolRequestResponseDelayedMessage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::Message::WebhookToolRequestResponseDelayedMessage
- Defined in:
- lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb,
sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs
Instance Attribute Summary collapse
-
#content ⇒ String
The text the assistant speaks.
-
#timing_ms ⇒ Integer
The delay in milliseconds from the start of the webhook request.
-
#type ⇒ Symbol, :request_response_delayed
Speak the filler message after the configured delay if the webhook response is still pending.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
252 |
# File 'sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs', line 252
def initialize: (
|
Instance Attribute Details
#content ⇒ String
The text the assistant speaks.
281 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 281 required :content, String |
#timing_ms ⇒ Integer
The delay in milliseconds from the start of the webhook request.
287 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 287 required :timing_ms, Integer |
#type ⇒ Symbol, :request_response_delayed
Speak the filler message after the configured delay if the webhook response is still pending.
294 |
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 294 required :type, const: :request_response_delayed |
Instance Method Details
#to_hash ⇒ {
258 |
# File 'sig/telnyx/models/ai/inference_embedding_webhook_tool_params.rbs', line 258
def to_hash: -> {
|