Class: Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::StoreFieldsAsVariable

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value_path:) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::InferenceEmbeddingWebhookToolParams::Webhook::StoreFieldsAsVariable for more details.

Parameters:

  • name (String)

    The name of the dynamic variable to store the extracted value in.

  • value_path (String)

    A dot-notation path to the value in the webhook response body (e.g. ‘customer.na



# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 337

Instance Attribute Details

#nameString

The name of the dynamic variable to store the extracted value in.

Returns:

  • (String)


328
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 328

required :name, String

#value_pathString

A dot-notation path to the value in the webhook response body (e.g. ‘customer.name’ or ‘id’).

Returns:

  • (String)


335
# File 'lib/telnyx/models/ai/inference_embedding_webhook_tool_params.rb', line 335

required :value_path, String