Class: Telnyx::Models::AI::RecursiveCluster::Node
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::RecursiveCluster::Node
- Defined in:
- lib/telnyx/models/ai/recursive_cluster.rb
Instance Attribute Summary collapse
-
#filename ⇒ String
The corresponding source file of your embedded storage bucket that the node is from.
-
#text ⇒ String
The text of the node.
Instance Method Summary collapse
-
#initialize(filename:, text:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Node for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filename:, text:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::RecursiveCluster::Node for more details.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/telnyx/models/ai/recursive_cluster.rb', line 45 class Node < Telnyx::Internal::Type::BaseModel # @!attribute filename # The corresponding source file of your embedded storage bucket that the node is # from. # # @return [String] required :filename, String # @!attribute text # The text of the node. # # @return [String] required :text, String # @!method initialize(filename:, text:) # Some parameter documentations has been truncated, see # {Telnyx::Models::AI::RecursiveCluster::Node} for more details. # # @param filename [String] The corresponding source file of your embedded storage bucket that the node is f # # @param text [String] The text of the node. end |
Instance Attribute Details
#filename ⇒ String
The corresponding source file of your embedded storage bucket that the node is from.
51 |
# File 'lib/telnyx/models/ai/recursive_cluster.rb', line 51 required :filename, String |
#text ⇒ String
The text of the node.
57 |
# File 'lib/telnyx/models/ai/recursive_cluster.rb', line 57 required :text, String |