Class: Telnyx::Models::AI::TelephonySettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::TelephonySettings
- Defined in:
- lib/telnyx/models/ai/telephony_settings.rb
Defined Under Namespace
Modules: NoiseSuppression Classes: NoiseSuppressionConfig, RecordingSettings, VoicemailDetection
Instance Attribute Summary collapse
-
#default_texml_app_id ⇒ String?
Default Texml App used for voice calls with your assistant.
-
#noise_suppression ⇒ Symbol, ...
The noise suppression engine to use.
-
#noise_suppression_config ⇒ Telnyx::Models::AI::TelephonySettings::NoiseSuppressionConfig?
Configuration for noise suppression.
-
#recording_settings ⇒ Telnyx::Models::AI::TelephonySettings::RecordingSettings?
Configuration for call recording format and channel settings.
-
#supports_unauthenticated_web_calls ⇒ Boolean?
When enabled, allows users to interact with your AI assistant directly from your website without requiring authentication.
-
#time_limit_secs ⇒ Integer?
Maximum duration in seconds for the AI assistant to participate on the call.
-
#user_idle_timeout_secs ⇒ Integer?
Maximum duration in seconds of end user silence on the call.
-
#voicemail_detection ⇒ Telnyx::Models::AI::TelephonySettings::VoicemailDetection?
Configuration for voicemail detection (AMD - Answering Machine Detection) on outgoing calls.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(default_texml_app_id: nil, noise_suppression: nil, noise_suppression_config: nil, recording_settings: nil, supports_unauthenticated_web_calls: nil, time_limit_secs: nil, user_idle_timeout_secs: nil, voicemail_detection: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TelephonySettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(default_texml_app_id: nil, noise_suppression: nil, noise_suppression_config: nil, recording_settings: nil, supports_unauthenticated_web_calls: nil, time_limit_secs: nil, user_idle_timeout_secs: nil, voicemail_detection: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::TelephonySettings for more details.
|
|
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 71
|
Instance Attribute Details
#default_texml_app_id ⇒ String?
Default Texml App used for voice calls with your assistant. This will be created automatically on assistant creation.
12 |
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 12 optional :default_texml_app_id, String |
#noise_suppression ⇒ Symbol, ...
The noise suppression engine to use. Use ‘disabled’ to turn off noise suppression.
19 |
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 19 optional :noise_suppression, enum: -> { Telnyx::AI::TelephonySettings::NoiseSuppression } |
#noise_suppression_config ⇒ Telnyx::Models::AI::TelephonySettings::NoiseSuppressionConfig?
Configuration for noise suppression. Only applicable when noise_suppression is ‘deepfilternet’.
26 |
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 26 optional :noise_suppression_config, -> { Telnyx::AI::TelephonySettings::NoiseSuppressionConfig } |
#recording_settings ⇒ Telnyx::Models::AI::TelephonySettings::RecordingSettings?
Configuration for call recording format and channel settings.
32 |
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 32 optional :recording_settings, -> { Telnyx::AI::TelephonySettings::RecordingSettings } |
#supports_unauthenticated_web_calls ⇒ Boolean?
When enabled, allows users to interact with your AI assistant directly from your website without requiring authentication. This is required for FE widgets that work with assistants that have telephony enabled.
40 |
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 40 optional :supports_unauthenticated_web_calls, Telnyx::Internal::Type::Boolean |
#time_limit_secs ⇒ Integer?
Maximum duration in seconds for the AI assistant to participate on the call. When this limit is reached the assistant will be stopped. This limit does not apply to portions of a call without an active assistant (for instance, a call transferred to a human representative).
49 |
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 49 optional :time_limit_secs, Integer |
#user_idle_timeout_secs ⇒ Integer?
Maximum duration in seconds of end user silence on the call. When this limit is reached the assistant will be stopped. This limit does not apply to portions of a call without an active assistant (for instance, a call transferred to a human representative).
58 |
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 58 optional :user_idle_timeout_secs, Integer |
#voicemail_detection ⇒ Telnyx::Models::AI::TelephonySettings::VoicemailDetection?
Configuration for voicemail detection (AMD - Answering Machine Detection) on outgoing calls. These settings only apply if AMD is enabled on the Dial command. See [TeXML Dial documentation](developers.telnyx.com/api-reference/texml-rest-commands/initiate-an-outbound-call) for enabling AMD. Recommended settings: MachineDetection=Enable, AsyncAmd=true, DetectionMode=Premium.
69 |
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 69 optional :voicemail_detection, -> { Telnyx::AI::TelephonySettings::VoicemailDetection } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/telephony_settings.rb', line 102
|