Class: Telnyx::Models::AI::TranscriptionSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::TranscriptionSettings
- Defined in:
- lib/telnyx/models/ai/transcription_settings.rb,
sig/telnyx/models/ai/transcription_settings.rbs
Defined Under Namespace
Modules: Model
Instance Attribute Summary collapse
-
#api_key_ref ⇒ String?
Integration secret identifier for the transcription provider API key.
-
#language ⇒ String?
The language of the audio to be transcribed.
-
#model ⇒ Symbol, ...
The speech to text model to be used by the voice assistant.
-
#region ⇒ String?
Region on third party cloud providers (currently Azure) if using one of their models.
- #settings ⇒ Telnyx::Models::AI::TranscriptionSettingsConfig?
Instance Method Summary collapse
-
#initialize(api_key_ref: nil, language: nil, model: nil, region: nil, settings: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TranscriptionSettings for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(api_key_ref: nil, language: nil, model: nil, region: nil, settings: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::TranscriptionSettings for more details.
|
|
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 57
|
Instance Attribute Details
#api_key_ref ⇒ String?
Integration secret identifier for the transcription provider API key. Currently used for Azure transcription regions that require a customer-provided API key.
12 |
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 12 optional :api_key_ref, String |
#language ⇒ String?
The language of the audio to be transcribed. If not set, or if set to auto,
supported models will automatically detect the language. For deepgram/flux,
supported values are: auto (Telnyx language detection controls the language
hint), multi (no language hint), and language-specific hints en, es, fr,
de, hi, ru, pt, ja, it, and nl. For soniox/stt-rt-v4, auto
omits the language hint and lets Soniox auto-detect; ISO 639-1 codes (e.g. en,
es) bias detection toward that language.
24 |
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 24 optional :language, String |
#model ⇒ Symbol, ...
The speech to text model to be used by the voice assistant. All Deepgram models are run on-premise.
deepgram/fluxis optimized for turn-taking with multilingual language hints.deepgram/nova-3is multilingual with automatic language detection.deepgram/nova-2is Deepgram's previous-generation multilingual model.azure/fastis a multilingual Azure transcription model.assemblyai/universal-streamingis a multilingual streaming model with configurable turn detection.xai/grok-sttis a multilingual Grok STT model.soniox/stt-rt-v4is a multilingual streaming model with automatic language detection and configurable endpointing.parakeet/tdt-0.6b-v3is a multilingual transcription model with automatic language detection.
43 |
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 43 optional :model, enum: -> { Telnyx::AI::TranscriptionSettings::Model } |
#region ⇒ String?
Region on third party cloud providers (currently Azure) if using one of their
models. Some regions require api_key_ref.
50 |
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 50 optional :region, String |
#settings ⇒ Telnyx::Models::AI::TranscriptionSettingsConfig?
55 |
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 55 optional :settings, -> { Telnyx::AI::TranscriptionSettingsConfig } |
Instance Method Details
#to_hash ⇒ {
46 |
# File 'sig/telnyx/models/ai/transcription_settings.rbs', line 46
def to_hash: -> {
|