Class: Telnyx::Models::AI::TranscriptionSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/transcription_settings.rb

Defined Under Namespace

Modules: Model

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_key_ref: nil, language: nil, model: nil, region: nil, settings: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::TranscriptionSettings for more details.

Parameters:

  • api_key_ref (String) (defaults to: nil)

    Integration secret identifier for the transcription provider API key. Currently

  • language (String) (defaults to: nil)

    The language of the audio to be transcribed. If not set, or if set to ‘auto`, su

  • model (Symbol, Telnyx::Models::AI::TranscriptionSettings::Model) (defaults to: nil)

    The speech to text model to be used by the voice assistant. All Deepgram models

  • region (String) (defaults to: nil)

    Region on third party cloud providers (currently Azure) if using one of their mo

  • settings (Telnyx::Models::AI::TranscriptionSettingsConfig) (defaults to: nil)


# File 'lib/telnyx/models/ai/transcription_settings.rb', line 51

Instance Attribute Details

#api_key_refString?

Integration secret identifier for the transcription provider API key. Currently used for Azure transcription regions that require a customer-provided API key.

Returns:

  • (String, nil)


12
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 12

optional :api_key_ref, String

#languageString?

The language of the audio to be transcribed. If not set, or if set to ‘auto`, supported models will automatically detect the language. For `deepgram/flux`, supported values are: `auto` (Telnyx language detection controls the language hint), `multi` (no language hint), and language-specific hints `en`, `es`, `fr`, `de`, `hi`, `ru`, `pt`, `ja`, `it`, and `nl`.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 22

optional :language, String

#modelSymbol, ...

The speech to text model to be used by the voice assistant. All Deepgram models are run on-premise.

  • ‘deepgram/flux` is optimized for turn-taking with multilingual language hints.

  • ‘deepgram/nova-3` is multilingual with automatic language detection.

  • ‘deepgram/nova-2` is Deepgram’s previous-generation multilingual model.

  • ‘azure/fast` is a multilingual Azure transcription model.

  • ‘assemblyai/universal-streaming` is a multilingual streaming model with configurable turn detection.

  • ‘xai/grok-stt` is a multilingual Grok STT model.



37
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 37

optional :model, enum: -> { Telnyx::AI::TranscriptionSettings::Model }

#regionString?

Region on third party cloud providers (currently Azure) if using one of their models. Some regions require ‘api_key_ref`.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 44

optional :region, String

#settingsTelnyx::Models::AI::TranscriptionSettingsConfig?



49
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 49

optional :settings, -> { Telnyx::AI::TranscriptionSettingsConfig }