Class: Telnyx::Models::AI::TranscriptionSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::TranscriptionSettings
- Defined in:
- lib/telnyx/models/ai/transcription_settings.rb
Defined Under Namespace
Modules: Model
Instance Attribute Summary collapse
-
#language ⇒ String?
The language of the audio to be transcribed.
-
#model ⇒ Symbol, ...
The speech to text model to be used by the voice assistant.
-
#region ⇒ String?
Region on third party cloud providers (currently Azure) if using one of their models.
- #settings ⇒ Telnyx::Models::AI::TranscriptionSettingsConfig?
Instance Method Summary collapse
-
#initialize(language: nil, model: nil, region: nil, settings: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TranscriptionSettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(language: nil, model: nil, region: nil, settings: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AI::TranscriptionSettings for more details.
|
|
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 37
|
Instance Attribute Details
#language ⇒ String?
The language of the audio to be transcribed. If not set, of if set to ‘auto`, the model will automatically detect the language.
12 |
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 12 optional :language, String |
#model ⇒ Symbol, ...
The speech to text model to be used by the voice assistant. All the deepgram models are run on-premise.
-
‘deepgram/flux` is optimized for turn-taking but is English-only.
-
‘deepgram/nova-3` is multi-lingual with automatic language detection but slightly higher latency.
23 |
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 23 optional :model, enum: -> { Telnyx::AI::TranscriptionSettings::Model } |
#region ⇒ String?
Region on third party cloud providers (currently Azure) if using one of their models
30 |
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 30 optional :region, String |
#settings ⇒ Telnyx::Models::AI::TranscriptionSettingsConfig?
35 |
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 35 optional :settings, -> { Telnyx::AI::TranscriptionSettingsConfig } |