Module: Telnyx::Models::AI::TranscriptionSettings::Model

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/ai/transcription_settings.rb,
sig/telnyx/models/ai/transcription_settings.rbs

Overview

The speech to text model to be used by the voice assistant. All Deepgram models are run on-premise.

  • deepgram/flux is optimized for turn-taking with multilingual language hints.
  • deepgram/nova-3 is multilingual with automatic language detection.
  • deepgram/nova-2 is Deepgram's previous-generation multilingual model.
  • azure/fast is a multilingual Azure transcription model.
  • assemblyai/universal-streaming is a multilingual streaming model with configurable turn detection.
  • xai/grok-stt is a multilingual Grok STT model.
  • soniox/stt-rt-v4 is a multilingual streaming model with automatic language detection and configurable endpointing.
  • parakeet/tdt-0.6b-v3 is a multilingual transcription model with automatic language detection.

See Also:

  • Telnyx::Models::AI::TranscriptionSettings#model

Constant Summary collapse

DEEPGRAM_FLUX =

Returns:

  • (:"deepgram/flux")
:"deepgram/flux"
DEEPGRAM_NOVA_3 =

Returns:

  • (:"deepgram/nova-3")
:"deepgram/nova-3"
DEEPGRAM_NOVA_2 =

Returns:

  • (:"deepgram/nova-2")
:"deepgram/nova-2"
AZURE_FAST =

Returns:

  • (:"azure/fast")
:"azure/fast"
ASSEMBLYAI_UNIVERSAL_STREAMING =

Returns:

  • (:"assemblyai/universal-streaming")
:"assemblyai/universal-streaming"
XAI_GROK_STT =

Returns:

  • (:"xai/grok-stt")
:"xai/grok-stt"
SONIOX_STT_RT_V4 =

Returns:

  • (:"soniox/stt-rt-v4")
:"soniox/stt-rt-v4"
PARAKEET_TDT_0_6B_V3 =

Returns:

  • (:"parakeet/tdt-0.6b-v3")
:"parakeet/tdt-0.6b-v3"
DISTIL_WHISPER_DISTIL_LARGE_V2 =

Returns:

  • (:"distil-whisper/distil-large-v2")
:"distil-whisper/distil-large-v2"
OPENAI_WHISPER_LARGE_V3_TURBO =

Returns:

  • (:"openai/whisper-large-v3-turbo")
:"openai/whisper-large-v3-turbo"

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ai/transcription_settings.rb', line 101

Instance Method Details

#self?.values::Array[Telnyx::Models::AI::TranscriptionSettings::model]

Returns:

  • (::Array[Telnyx::Models::AI::TranscriptionSettings::model])


80
# File 'sig/telnyx/models/ai/transcription_settings.rbs', line 80

def self?.values: -> ::Array[Telnyx::Models::AI::TranscriptionSettings::model]