Module: Telnyx::Models::AI::TranscriptionSettings::Model
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/ai/transcription_settings.rb,
sig/telnyx/models/ai/transcription_settings.rbs
Overview
The speech to text model to be used by the voice assistant. All Deepgram models are run on-premise.
deepgram/fluxis optimized for turn-taking with multilingual language hints.deepgram/nova-3is multilingual with automatic language detection.deepgram/nova-2is Deepgram's previous-generation multilingual model.azure/fastis a multilingual Azure transcription model.assemblyai/universal-streamingis a multilingual streaming model with configurable turn detection.xai/grok-sttis a multilingual Grok STT model.soniox/stt-rt-v4is a multilingual streaming model with automatic language detection and configurable endpointing.parakeet/tdt-0.6b-v3is a multilingual transcription model with automatic language detection.
Constant Summary collapse
- DEEPGRAM_FLUX =
:"deepgram/flux"- DEEPGRAM_NOVA_3 =
:"deepgram/nova-3"- DEEPGRAM_NOVA_2 =
:"deepgram/nova-2"- AZURE_FAST =
:"azure/fast"- ASSEMBLYAI_UNIVERSAL_STREAMING =
:"assemblyai/universal-streaming"- XAI_GROK_STT =
:"xai/grok-stt"- SONIOX_STT_RT_V4 =
:"soniox/stt-rt-v4"- PARAKEET_TDT_0_6B_V3 =
:"parakeet/tdt-0.6b-v3"- DISTIL_WHISPER_DISTIL_LARGE_V2 =
:"distil-whisper/distil-large-v2"- OPENAI_WHISPER_LARGE_V3_TURBO =
:"openai/whisper-large-v3-turbo"
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 101
|
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::AI::TranscriptionSettings::model]
80 |
# File 'sig/telnyx/models/ai/transcription_settings.rbs', line 80
def self?.values: -> ::Array[Telnyx::Models::AI::TranscriptionSettings::model]
|