Module: Telnyx::Models::AI::TranscriptionSettings::Model
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/ai/transcription_settings.rb
Overview
The speech to text model to be used by the voice assistant. All the deepgram models are run on-premise.
-
‘deepgram/flux` is optimized for turn-taking but is English-only.
-
‘deepgram/nova-3` is multi-lingual with automatic language detection but slightly higher latency.
Constant Summary collapse
- DEEPGRAM_FLUX =
:"deepgram/flux"- DEEPGRAM_NOVA_3 =
:"deepgram/nova-3"- DEEPGRAM_NOVA_2 =
:"deepgram/nova-2"- AZURE_FAST =
:"azure/fast"- DISTIL_WHISPER_DISTIL_LARGE_V2 =
:"distil-whisper/distil-large-v2"- OPENAI_WHISPER_LARGE_V3_TURBO =
:"openai/whisper-large-v3-turbo"
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/transcription_settings.rb', line 67
|