Class: Telnyx::Models::AI::TranscriptionSettingsConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/transcription_settings_config.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(eager_eot_threshold: nil, end_of_turn_confidence_threshold: nil, eot_threshold: nil, eot_timeout_ms: nil, keyterm: nil, max_turn_silence: nil, min_turn_silence: nil, numerals: nil, smart_format: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::TranscriptionSettingsConfig for more details.

Parameters:

  • eager_eot_threshold (Float) (defaults to: nil)

    Available only for deepgram/flux. Confidence threshold for eager end of turn det

  • end_of_turn_confidence_threshold (Float) (defaults to: nil)

    Available only for assemblyai/universal-streaming. Confidence level required to

  • eot_threshold (Float) (defaults to: nil)

    Available only for deepgram/flux. Confidence required to trigger an end of turn.

  • eot_timeout_ms (Integer) (defaults to: nil)

    Available only for deepgram/flux. Maximum milliseconds of silence before forcing

  • keyterm (String) (defaults to: nil)

    Available only for deepgram/nova-3 and deepgram/flux. A comma-separated list of

  • max_turn_silence (Integer) (defaults to: nil)

    Available only for assemblyai/universal-streaming. Maximum duration of silence i

  • min_turn_silence (Integer) (defaults to: nil)

    Available only for assemblyai/universal-streaming. Minimum duration of silence i

  • numerals (Boolean) (defaults to: nil)
  • smart_format (Boolean) (defaults to: nil)


# File 'lib/telnyx/models/ai/transcription_settings_config.rb', line 70

Instance Attribute Details

#eager_eot_thresholdFloat?

Available only for deepgram/flux. Confidence threshold for eager end of turn detection. Must be lower than or equal to eot_threshold. Setting this equal to eot_threshold effectively disables eager end of turn.

Returns:

  • (Float, nil)


13
# File 'lib/telnyx/models/ai/transcription_settings_config.rb', line 13

optional :eager_eot_threshold, Float

#end_of_turn_confidence_thresholdFloat?

Available only for assemblyai/universal-streaming. Confidence level required to trigger an end of turn. Higher values require more certainty before ending a turn.

Returns:

  • (Float, nil)


21
# File 'lib/telnyx/models/ai/transcription_settings_config.rb', line 21

optional :end_of_turn_confidence_threshold, Float

#eot_thresholdFloat?

Available only for deepgram/flux. Confidence required to trigger an end of turn. Higher values = more reliable turn detection but slightly increased latency.

Returns:

  • (Float, nil)


28
# File 'lib/telnyx/models/ai/transcription_settings_config.rb', line 28

optional :eot_threshold, Float

#eot_timeout_msInteger?

Available only for deepgram/flux. Maximum milliseconds of silence before forcing an end of turn, regardless of confidence.

Returns:

  • (Integer, nil)


35
# File 'lib/telnyx/models/ai/transcription_settings_config.rb', line 35

optional :eot_timeout_ms, Integer

#keytermString?

Available only for deepgram/nova-3 and deepgram/flux. A comma-separated list of key terms to boost for recognition during transcription. Helps improve accuracy for domain-specific terminology, proper nouns, or uncommon words.

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/ai/transcription_settings_config.rb', line 43

optional :keyterm, String

#max_turn_silenceInteger?

Available only for assemblyai/universal-streaming. Maximum duration of silence in milliseconds before forcing an end of turn.

Returns:

  • (Integer, nil)


50
# File 'lib/telnyx/models/ai/transcription_settings_config.rb', line 50

optional :max_turn_silence, Integer

#min_turn_silenceInteger?

Available only for assemblyai/universal-streaming. Minimum duration of silence in milliseconds before a turn can end. Must be less than or equal to max_turn_silence.

Returns:

  • (Integer, nil)


58
# File 'lib/telnyx/models/ai/transcription_settings_config.rb', line 58

optional :min_turn_silence, Integer

#numeralsBoolean?

Returns:

  • (Boolean, nil)


63
# File 'lib/telnyx/models/ai/transcription_settings_config.rb', line 63

optional :numerals, Telnyx::Internal::Type::Boolean

#smart_formatBoolean?

Returns:

  • (Boolean, nil)


68
# File 'lib/telnyx/models/ai/transcription_settings_config.rb', line 68

optional :smart_format, Telnyx::Internal::Type::Boolean