Module: Telnyx::Models::AI::TransferTool::Transfer::Targets
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/ai/transfer_tool.rb
Overview
The different possible targets of the transfer. The assistant will be able to choose one of the targets to transfer the call to. This can also be a dynamic variable string like ‘targets }` where `targets` is returned by the dynamic variables webhook and resolves to an array of target objects at runtime.
Defined Under Namespace
Classes: UnionMember0
Constant Summary collapse
- UnionMember0Array =
Telnyx::Internal::Type::ArrayOf[-> { Telnyx::AI::TransferTool::Transfer::Targets::UnionMember0 }]
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Array<Telnyx::Models::AI::TransferTool::Transfer::Targets::UnionMember0>, String)
|
|
# File 'lib/telnyx/models/ai/transfer_tool.rb', line 79
|
Instance Method Details
#initialize(to:, name: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/ai/transfer_tool.rb', line 73
|