Module: Telnyx::Models::AI::VoiceSettings::BackgroundAudio
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/ai/voice_settings.rb
Overview
Optional background audio to play on the call. Use a predefined media bed, or supply a looped MP3 URL. If a media URL is chosen in the portal, customers can preview it before saving.
Defined Under Namespace
Classes: MediaName, MediaURL, PredefinedMedia
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ai/voice_settings.rb', line 166
|
Instance Method Details
#initialize(value:, type: :media_url) ⇒ Object
|
|
# File 'lib/telnyx/models/ai/voice_settings.rb', line 184
|