Class: Telnyx::Models::AI::VoiceSettings::BackgroundAudio::MediaName
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::VoiceSettings::BackgroundAudio::MediaName
- Defined in:
- lib/telnyx/models/ai/voice_settings.rb
Instance Attribute Summary collapse
-
#type ⇒ Symbol, :media_name
Reference a previously uploaded media by its name from Telnyx Media Storage.
-
#value ⇒ String
The ‘name` of a media asset created via [Media Storage API](developers.telnyx.com/api/media-storage/create-media-storage).
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#type ⇒ Symbol, :media_name
Reference a previously uploaded media by its name from Telnyx Media Storage.
195 |
# File 'lib/telnyx/models/ai/voice_settings.rb', line 195 required :type, const: :media_name |
#value ⇒ String
The ‘name` of a media asset created via [Media Storage API](developers.telnyx.com/api/media-storage/create-media-storage). The audio will loop during the call.
203 |
# File 'lib/telnyx/models/ai/voice_settings.rb', line 203 required :value, String |