Class: Telnyx::Models::AI::VoiceSettings::BackgroundAudio::MediaName

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ai/voice_settings.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(value:, type: :media_name) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::AI::VoiceSettings::BackgroundAudio::MediaName for more details.

Parameters:

  • value (String)

    The ‘name` of a media asset created via [Media Storage API](developers.t

  • type (Symbol, :media_name) (defaults to: :media_name)

    Reference a previously uploaded media by its name from Telnyx Media Storage.



# File 'lib/telnyx/models/ai/voice_settings.rb', line 185

Instance Attribute Details

#typeSymbol, :media_name

Reference a previously uploaded media by its name from Telnyx Media Storage.

Returns:

  • (Symbol, :media_name)


175
# File 'lib/telnyx/models/ai/voice_settings.rb', line 175

required :type, const: :media_name

#valueString

The ‘name` of a media asset created via [Media Storage API](developers.telnyx.com/api/media-storage/create-media-storage). The audio will loop during the call.

Returns:

  • (String)


183
# File 'lib/telnyx/models/ai/voice_settings.rb', line 183

required :value, String