Class: Telnyx::Models::AI::WebhookTool::Webhook::PathParameters
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AI::WebhookTool::Webhook::PathParameters
- Defined in:
- lib/telnyx/models/ai/webhook_tool.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#properties ⇒ Hash{Symbol=>Object}?
The properties of the path parameters.
-
#required ⇒ Array<String>?
The required properties of the path parameters.
- #type ⇒ Symbol, ...
Instance Method Summary collapse
-
#initialize(properties: nil, required: nil, type: nil) ⇒ Object
constructor
The path parameters the webhook tool accepts, described as a JSON Schema object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(properties: nil, required: nil, type: nil) ⇒ Object
The path parameters the webhook tool accepts, described as a JSON Schema object. These parameters will be passed to the webhook as the path of the request if the URL contains a placeholder for a value. See the [JSON Schema reference](json-schema.org/understanding-json-schema) for documentation about the format
|
|
# File 'lib/telnyx/models/ai/webhook_tool.rb', line 216
|
Instance Attribute Details
#properties ⇒ Hash{Symbol=>Object}?
The properties of the path parameters.
203 |
# File 'lib/telnyx/models/ai/webhook_tool.rb', line 203 optional :properties, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |