Class: Telnyx::Models::Actions::PurchaseCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Actions::PurchaseCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/actions/purchase_create_params.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount of eSIMs to be purchased.
-
#product ⇒ String?
Type of product to be purchased, specify “whitelabel” to use a custom SPN.
-
#sim_card_group_id ⇒ String?
The group SIMCardGroup identification.
-
#status ⇒ Symbol, ...
Status on which the SIM cards will be set after being successfully registered.
-
#tags ⇒ Array<String>?
Searchable tags associated with the SIM cards.
-
#whitelabel_name ⇒ String?
Service Provider Name (SPN) for the Whitelabel eSIM product.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(amount:, product: nil, sim_card_group_id: nil, status: nil, tags: nil, whitelabel_name: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PurchaseCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, product: nil, sim_card_group_id: nil, status: nil, tags: nil, whitelabel_name: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Actions::PurchaseCreateParams for more details.
|
|
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 50
|
Instance Attribute Details
#amount ⇒ Integer
The amount of eSIMs to be purchased.
15 |
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 15 required :amount, Integer |
#product ⇒ String?
Type of product to be purchased, specify “whitelabel” to use a custom SPN
21 |
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 21 optional :product, String |
#sim_card_group_id ⇒ String?
The group SIMCardGroup identification. This attribute can be null when it’s present in an associated resource.
28 |
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 28 optional :sim_card_group_id, String |
#status ⇒ Symbol, ...
Status on which the SIM cards will be set after being successfully registered.
34 |
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 34 optional :status, enum: -> { Telnyx::Actions::PurchaseCreateParams::Status } |
#tags ⇒ Array<String>?
Searchable tags associated with the SIM cards
40 |
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 40 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#whitelabel_name ⇒ String?
Service Provider Name (SPN) for the Whitelabel eSIM product. It will be displayed as the mobile service name by operating systems of smartphones. This parameter must only contain letters, numbers and whitespaces.
48 |
# File 'lib/telnyx/models/actions/purchase_create_params.rb', line 48 optional :whitelabel_name, String |