Class: Telnyx::Models::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Address
- Defined in:
- lib/telnyx/models/address.rb
Overview
Instance Attribute Summary collapse
-
#address_book ⇒ Boolean?
Indicates whether or not the address should be considered part of your list of addresses that appear for regular use.
-
#administrative_area ⇒ String?
The locality of the address.
-
#borough ⇒ String?
The borough of the address.
-
#business_name ⇒ String?
The business name associated with the address.
-
#country_code ⇒ String?
The two-character (ISO 3166-1 alpha-2) country code of the address.
-
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#extended_address ⇒ String?
Additional street address information about the address such as, but not limited to, unit number or apartment number.
-
#first_name ⇒ String?
The first name associated with the address.
-
#id ⇒ String?
Uniquely identifies the address.
-
#last_name ⇒ String?
The last name associated with the address.
-
#locality ⇒ String?
The locality of the address.
-
#neighborhood ⇒ String?
The neighborhood of the address.
-
#phone_number ⇒ String?
The phone number associated with the address.
-
#postal_code ⇒ String?
The postal code of the address.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#street_address ⇒ String?
The primary street address information about the address.
-
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
-
#validate_address ⇒ Boolean?
Indicates whether or not the address should be validated for emergency use upon creation or not.
Instance Method Summary collapse
-
#initialize(id: nil, address_book: nil, administrative_area: nil, borough: nil, business_name: nil, country_code: nil, created_at: nil, customer_reference: nil, extended_address: nil, first_name: nil, last_name: nil, locality: nil, neighborhood: nil, phone_number: nil, postal_code: nil, record_type: nil, street_address: nil, updated_at: nil, validate_address: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, address_book: nil, administrative_area: nil, borough: nil, business_name: nil, country_code: nil, created_at: nil, customer_reference: nil, extended_address: nil, first_name: nil, last_name: nil, locality: nil, neighborhood: nil, phone_number: nil, postal_code: nil, record_type: nil, street_address: nil, updated_at: nil, validate_address: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Address for more details.
|
|
# File 'lib/telnyx/models/address.rb', line 135
|
Instance Attribute Details
#address_book ⇒ Boolean?
Indicates whether or not the address should be considered part of your list of addresses that appear for regular use.
18 |
# File 'lib/telnyx/models/address.rb', line 18 optional :address_book, Telnyx::Internal::Type::Boolean |
#administrative_area ⇒ String?
The locality of the address. For US addresses, this corresponds to the state of the address.
25 |
# File 'lib/telnyx/models/address.rb', line 25 optional :administrative_area, String |
#borough ⇒ String?
The borough of the address. This field is not used for addresses in the US but is used for some international addresses.
32 |
# File 'lib/telnyx/models/address.rb', line 32 optional :borough, String |
#business_name ⇒ String?
The business name associated with the address. An address must have either a first last name or a business name.
39 |
# File 'lib/telnyx/models/address.rb', line 39 optional :business_name, String |
#country_code ⇒ String?
The two-character (ISO 3166-1 alpha-2) country code of the address.
45 |
# File 'lib/telnyx/models/address.rb', line 45 optional :country_code, String |
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
51 |
# File 'lib/telnyx/models/address.rb', line 51 optional :created_at, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
57 |
# File 'lib/telnyx/models/address.rb', line 57 optional :customer_reference, String |
#extended_address ⇒ String?
Additional street address information about the address such as, but not limited to, unit number or apartment number.
64 |
# File 'lib/telnyx/models/address.rb', line 64 optional :extended_address, String |
#first_name ⇒ String?
The first name associated with the address. An address must have either a first last name or a business name.
71 |
# File 'lib/telnyx/models/address.rb', line 71 optional :first_name, String |
#id ⇒ String?
Uniquely identifies the address.
11 |
# File 'lib/telnyx/models/address.rb', line 11 optional :id, String |
#last_name ⇒ String?
The last name associated with the address. An address must have either a first last name or a business name.
78 |
# File 'lib/telnyx/models/address.rb', line 78 optional :last_name, String |
#locality ⇒ String?
The locality of the address. For US addresses, this corresponds to the city of the address.
85 |
# File 'lib/telnyx/models/address.rb', line 85 optional :locality, String |
#neighborhood ⇒ String?
The neighborhood of the address. This field is not used for addresses in the US but is used for some international addresses.
92 |
# File 'lib/telnyx/models/address.rb', line 92 optional :neighborhood, String |
#phone_number ⇒ String?
The phone number associated with the address.
98 |
# File 'lib/telnyx/models/address.rb', line 98 optional :phone_number, String |
#postal_code ⇒ String?
The postal code of the address.
104 |
# File 'lib/telnyx/models/address.rb', line 104 optional :postal_code, String |
#record_type ⇒ String?
Identifies the type of the resource.
110 |
# File 'lib/telnyx/models/address.rb', line 110 optional :record_type, String |
#street_address ⇒ String?
The primary street address information about the address.
116 |
# File 'lib/telnyx/models/address.rb', line 116 optional :street_address, String |
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
122 |
# File 'lib/telnyx/models/address.rb', line 122 optional :updated_at, String |
#validate_address ⇒ Boolean?
Indicates whether or not the address should be validated for emergency use upon creation or not. This should be left with the default value of ‘true` unless you have used the `/addresses/actions/validate` endpoint to validate the address separately prior to creation. If an address is not validated for emergency use upon creation and it is not valid, it will not be able to be used for emergency services.
133 |
# File 'lib/telnyx/models/address.rb', line 133 optional :validate_address, Telnyx::Internal::Type::Boolean |