Class: Telnyx::Models::AddressCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AddressCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/address_create_params.rb
Overview
Instance Attribute Summary collapse
-
#address_book ⇒ Boolean?
Indicates whether or not the address should be considered part of your list of addresses that appear for regular use.
-
#administrative_area ⇒ String?
The locality of the address.
-
#borough ⇒ String?
The borough of the address.
-
#business_name ⇒ String
The business name associated with the address.
-
#country_code ⇒ String
The two-character (ISO 3166-1 alpha-2) country code of the address.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#extended_address ⇒ String?
Additional street address information about the address such as, but not limited to, unit number or apartment number.
-
#first_name ⇒ String
The first name associated with the address.
-
#last_name ⇒ String
The last name associated with the address.
-
#locality ⇒ String
The locality of the address.
-
#neighborhood ⇒ String?
The neighborhood of the address.
-
#phone_number ⇒ String?
The phone number associated with the address.
-
#postal_code ⇒ String?
The postal code of the address.
-
#street_address ⇒ String
The primary street address information about the address.
-
#validate_address ⇒ Boolean?
Indicates whether or not the address should be validated for emergency use upon creation or not.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(business_name:, country_code:, first_name:, last_name:, locality:, street_address:, address_book: nil, administrative_area: nil, borough: nil, customer_reference: nil, extended_address: nil, neighborhood: nil, phone_number: nil, postal_code: nil, validate_address: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AddressCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(business_name:, country_code:, first_name:, last_name:, locality:, street_address:, address_book: nil, administrative_area: nil, borough: nil, customer_reference: nil, extended_address: nil, neighborhood: nil, phone_number: nil, postal_code: nil, validate_address: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AddressCreateParams for more details.
|
|
# File 'lib/telnyx/models/address_create_params.rb', line 114
|
Instance Attribute Details
#address_book ⇒ Boolean?
Indicates whether or not the address should be considered part of your list of addresses that appear for regular use.
55 |
# File 'lib/telnyx/models/address_create_params.rb', line 55 optional :address_book, Telnyx::Internal::Type::Boolean |
#administrative_area ⇒ String?
The locality of the address. For US addresses, this corresponds to the state of the address.
62 |
# File 'lib/telnyx/models/address_create_params.rb', line 62 optional :administrative_area, String |
#borough ⇒ String?
The borough of the address. This field is not used for addresses in the US but is used for some international addresses.
69 |
# File 'lib/telnyx/models/address_create_params.rb', line 69 optional :borough, String |
#business_name ⇒ String
The business name associated with the address. An address must have either a first last name or a business name.
15 |
# File 'lib/telnyx/models/address_create_params.rb', line 15 required :business_name, String |
#country_code ⇒ String
The two-character (ISO 3166-1 alpha-2) country code of the address.
21 |
# File 'lib/telnyx/models/address_create_params.rb', line 21 required :country_code, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
75 |
# File 'lib/telnyx/models/address_create_params.rb', line 75 optional :customer_reference, String |
#extended_address ⇒ String?
Additional street address information about the address such as, but not limited to, unit number or apartment number.
82 |
# File 'lib/telnyx/models/address_create_params.rb', line 82 optional :extended_address, String |
#first_name ⇒ String
The first name associated with the address. An address must have either a first last name or a business name.
28 |
# File 'lib/telnyx/models/address_create_params.rb', line 28 required :first_name, String |
#last_name ⇒ String
The last name associated with the address. An address must have either a first last name or a business name.
35 |
# File 'lib/telnyx/models/address_create_params.rb', line 35 required :last_name, String |
#locality ⇒ String
The locality of the address. For US addresses, this corresponds to the city of the address.
42 |
# File 'lib/telnyx/models/address_create_params.rb', line 42 required :locality, String |
#neighborhood ⇒ String?
The neighborhood of the address. This field is not used for addresses in the US but is used for some international addresses.
89 |
# File 'lib/telnyx/models/address_create_params.rb', line 89 optional :neighborhood, String |
#phone_number ⇒ String?
The phone number associated with the address.
95 |
# File 'lib/telnyx/models/address_create_params.rb', line 95 optional :phone_number, String |
#postal_code ⇒ String?
The postal code of the address.
101 |
# File 'lib/telnyx/models/address_create_params.rb', line 101 optional :postal_code, String |
#street_address ⇒ String
The primary street address information about the address.
48 |
# File 'lib/telnyx/models/address_create_params.rb', line 48 required :street_address, String |
#validate_address ⇒ Boolean?
Indicates whether or not the address should be validated for emergency use upon creation or not. This should be left with the default value of ‘true` unless you have used the `/addresses/actions/validate` endpoint to validate the address separately prior to creation. If an address is not validated for emergency use upon creation and it is not valid, it will not be able to be used for emergency services.
112 |
# File 'lib/telnyx/models/address_create_params.rb', line 112 optional :validate_address, Telnyx::Internal::Type::Boolean |