Class: Telnyx::Models::Addresses::ActionValidateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Addresses::ActionValidateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/addresses/action_validate_params.rb
Overview
Instance Attribute Summary collapse
-
#administrative_area ⇒ String?
The locality of the address.
-
#country_code ⇒ String
The two-character (ISO 3166-1 alpha-2) country code of the address.
-
#extended_address ⇒ String?
Additional street address information about the address such as, but not limited to, unit number or apartment number.
-
#locality ⇒ String?
The locality of the address.
-
#postal_code ⇒ String
The postal code of the address.
-
#street_address ⇒ String
The primary street address information about the address.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(country_code:, postal_code:, street_address:, administrative_area: nil, extended_address: nil, locality: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionValidateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country_code:, postal_code:, street_address:, administrative_area: nil, extended_address: nil, locality: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Addresses::ActionValidateParams for more details.
|
|
# File 'lib/telnyx/models/addresses/action_validate_params.rb', line 50
|
Instance Attribute Details
#administrative_area ⇒ String?
The locality of the address. For US addresses, this corresponds to the state of the address.
34 |
# File 'lib/telnyx/models/addresses/action_validate_params.rb', line 34 optional :administrative_area, String |
#country_code ⇒ String
The two-character (ISO 3166-1 alpha-2) country code of the address.
15 |
# File 'lib/telnyx/models/addresses/action_validate_params.rb', line 15 required :country_code, String |
#extended_address ⇒ String?
Additional street address information about the address such as, but not limited to, unit number or apartment number.
41 |
# File 'lib/telnyx/models/addresses/action_validate_params.rb', line 41 optional :extended_address, String |
#locality ⇒ String?
The locality of the address. For US addresses, this corresponds to the city of the address.
48 |
# File 'lib/telnyx/models/addresses/action_validate_params.rb', line 48 optional :locality, String |
#postal_code ⇒ String
The postal code of the address.
21 |
# File 'lib/telnyx/models/addresses/action_validate_params.rb', line 21 required :postal_code, String |
#street_address ⇒ String
The primary street address information about the address.
27 |
# File 'lib/telnyx/models/addresses/action_validate_params.rb', line 27 required :street_address, String |