Class: Telnyx::Models::Addresses::ActionValidateResponse::Data::Suggested
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Addresses::ActionValidateResponse::Data::Suggested
- Defined in:
- lib/telnyx/models/addresses/action_validate_response.rb
Overview
Instance Attribute Summary collapse
-
#administrative_area ⇒ String?
The locality of the address.
-
#country_code ⇒ String?
The two-character (ISO 3166-1 alpha-2) country code of the address.
-
#extended_address ⇒ String?
Additional street address information about the address such as, but not limited to, unit number or apartment number.
-
#locality ⇒ String?
The locality of the address.
-
#postal_code ⇒ String?
The postal code of the address.
-
#street_address ⇒ String?
The primary street address information about the address.
Instance Method Summary collapse
-
#initialize(administrative_area: nil, country_code: nil, extended_address: nil, locality: nil, postal_code: nil, street_address: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Suggested for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(administrative_area: nil, country_code: nil, extended_address: nil, locality: nil, postal_code: nil, street_address: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Addresses::ActionValidateResponse::Data::Suggested for more details.
Provides normalized address when available.
|
|
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 104
|
Instance Attribute Details
#administrative_area ⇒ String?
The locality of the address. For US addresses, this corresponds to the state of the address.
70 |
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 70 optional :administrative_area, String |
#country_code ⇒ String?
The two-character (ISO 3166-1 alpha-2) country code of the address.
76 |
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 76 optional :country_code, String |
#extended_address ⇒ String?
Additional street address information about the address such as, but not limited to, unit number or apartment number.
83 |
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 83 optional :extended_address, String |
#locality ⇒ String?
The locality of the address. For US addresses, this corresponds to the city of the address.
90 |
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 90 optional :locality, String |
#postal_code ⇒ String?
The postal code of the address.
96 |
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 96 optional :postal_code, String |
#street_address ⇒ String?
The primary street address information about the address.
102 |
# File 'lib/telnyx/models/addresses/action_validate_response.rb', line 102 optional :street_address, String |