Class: Telnyx::Models::AdvancedOrderListResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AdvancedOrderListResponse::Data
- Defined in:
- lib/telnyx/models/advanced_order_list_response.rb
Defined Under Namespace
Modules: Feature, PhoneNumberType, Status
Instance Attribute Summary collapse
- #area_code ⇒ String?
- #comments ⇒ String?
- #country_code ⇒ String?
- #customer_reference ⇒ String?
- #features ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::Feature>?
- #id ⇒ String?
- #orders ⇒ Array<String>?
- #phone_number_type ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::PhoneNumberType>?
- #quantity ⇒ Integer?
-
#requirement_group_id ⇒ String?
The ID of the requirement group associated with this advanced order.
- #status ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::Status>?
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(data: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data: nil) ⇒ Object
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 15 class Data < Telnyx::Internal::Type::BaseModel # @!attribute id # # @return [String, nil] optional :id, String # @!attribute area_code # # @return [String, nil] optional :area_code, String # @!attribute comments # # @return [String, nil] optional :comments, String # @!attribute country_code # # @return [String, nil] optional :country_code, String # @!attribute customer_reference # # @return [String, nil] optional :customer_reference, String # @!attribute features # # @return [Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::Feature>, nil] optional :features, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::AdvancedOrderListResponse::Data::Feature] } # @!attribute orders # # @return [Array<String>, nil] optional :orders, Telnyx::Internal::Type::ArrayOf[String] # @!attribute phone_number_type # # @return [Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::PhoneNumberType>, nil] optional :phone_number_type, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::AdvancedOrderListResponse::Data::PhoneNumberType] } # @!attribute quantity # # @return [Integer, nil] optional :quantity, Integer # @!attribute requirement_group_id # The ID of the requirement group associated with this advanced order # # @return [String, nil] optional :requirement_group_id, String # @!attribute status # # @return [Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::Status>, nil] optional :status, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::AdvancedOrderListResponse::Data::Status] } # @!method initialize(id: nil, area_code: nil, comments: nil, country_code: nil, customer_reference: nil, features: nil, orders: nil, phone_number_type: nil, quantity: nil, requirement_group_id: nil, status: nil) # @param id [String] # # @param area_code [String] # # @param comments [String] # # @param country_code [String] # # @param customer_reference [String] # # @param features [Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::Feature>] # # @param orders [Array<String>] # # @param phone_number_type [Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::PhoneNumberType>] # # @param quantity [Integer] # # @param requirement_group_id [String] The ID of the requirement group associated with this advanced order # # @param status [Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::Status>] module Feature extend Telnyx::Internal::Type::Enum SMS = :sms MMS = :mms VOICE = :voice FAX = :fax EMERGENCY = :emergency # @!method self.values # @return [Array<Symbol>] end module PhoneNumberType extend Telnyx::Internal::Type::Enum LOCAL = :local MOBILE = :mobile TOLL_FREE = :toll_free SHARED_COST = :shared_cost NATIONAL = :national LANDLINE = :landline # @!method self.values # @return [Array<Symbol>] end module Status extend Telnyx::Internal::Type::Enum PENDING = :pending PROCESSING = :processing ORDERED = :ordered # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#area_code ⇒ String?
24 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 24 optional :area_code, String |
#comments ⇒ String?
29 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 29 optional :comments, String |
#country_code ⇒ String?
34 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 34 optional :country_code, String |
#customer_reference ⇒ String?
39 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 39 optional :customer_reference, String |
#features ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::Feature>?
44 45 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 44 optional :features, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::AdvancedOrderListResponse::Data::Feature] } |
#id ⇒ String?
19 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 19 optional :id, String |
#orders ⇒ Array<String>?
50 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 50 optional :orders, Telnyx::Internal::Type::ArrayOf[String] |
#phone_number_type ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::PhoneNumberType>?
55 56 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 55 optional :phone_number_type, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::AdvancedOrderListResponse::Data::PhoneNumberType] } |
#quantity ⇒ Integer?
61 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 61 optional :quantity, Integer |
#requirement_group_id ⇒ String?
The ID of the requirement group associated with this advanced order
67 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 67 optional :requirement_group_id, String |
#status ⇒ Array<Symbol, Telnyx::Models::AdvancedOrderListResponse::Data::Status>?
72 73 |
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 72 optional :status, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::AdvancedOrderListResponse::Data::Status] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/advanced_order_list_response.rb', line 107
|