Module: Telnyx::Models::AnchorsiteOverride
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/anchorsite_override.rb,
sig/telnyx/models/anchorsite_override.rbs
Overview
Latency directs Telnyx to route media through the site with the lowest
round-trip time to the user's connection. Telnyx calculates this time using ICMP
ping messages. This can be disabled by specifying a site to handle all media.
Constant Summary collapse
- LATENCY =
:Latency- CHICAGO_IL =
:"Chicago, IL"- ASHBURN_VA =
:"Ashburn, VA"- SAN_JOSE_CA =
:"San Jose, CA"- SYDNEY_AUSTRALIA =
:"Sydney, Australia"- AMSTERDAM_NETHERLANDS =
:"Amsterdam, Netherlands"- LONDON_UK =
:"London, UK"- TORONTO_CANADA =
:"Toronto, Canada"- VANCOUVER_CANADA =
:"Vancouver, Canada"- FRANKFURT_GERMANY =
:"Frankfurt, Germany"
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/anchorsite_override.rb', line 22
|
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::anchorsite_override]
29 |
# File 'sig/telnyx/models/anchorsite_override.rbs', line 29
def self?.values: -> ::Array[Telnyx::Models::anchorsite_override]
|