Class: Telnyx::Models::AuditEventListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AuditEventListResponse
- Defined in:
- lib/telnyx/models/audit_event_list_response.rb
Overview
Defined Under Namespace
Modules: ChangeMadeBy Classes: Change
Instance Attribute Summary collapse
-
#alternate_resource_id ⇒ String?
An alternate identifier for a resource which may be considered unique enough to identify the resource but is not the primary identifier for the resource.
-
#change_made_by ⇒ Symbol, ...
Indicates if the change was made by Telnyx on your behalf, the organization owner, a member of your organization, or in the case of managed accounts, the account manager.
-
#change_type ⇒ String?
The type of change that occurred.
-
#changes ⇒ Array<Telnyx::Models::AuditEventListResponse::Change>?
Details of the changes made to the resource.
-
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the change occurred.
-
#id ⇒ String?
Unique identifier for the audit log entry.
-
#organization_id ⇒ String?
Unique identifier for the organization that owns the resource.
-
#record_type ⇒ String?
The type of the resource being audited.
-
#resource_id ⇒ String?
Unique identifier for the resource that was changed.
-
#user_id ⇒ String?
Unique identifier for the user who made the change.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, alternate_resource_id: nil, change_made_by: nil, change_type: nil, changes: nil, created_at: nil, organization_id: nil, record_type: nil, resource_id: nil, user_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AuditEventListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, alternate_resource_id: nil, change_made_by: nil, change_type: nil, changes: nil, created_at: nil, organization_id: nil, record_type: nil, resource_id: nil, user_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AuditEventListResponse for more details.
|
|
# File 'lib/telnyx/models/audit_event_list_response.rb', line 74
|
Instance Attribute Details
#alternate_resource_id ⇒ String?
An alternate identifier for a resource which may be considered unique enough to identify the resource but is not the primary identifier for the resource. For example, this field could be used to store the phone number value for a phone number when the primary database identifier is a separate distinct value.
20 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 20 optional :alternate_resource_id, String, nil?: true |
#change_made_by ⇒ Symbol, ...
Indicates if the change was made by Telnyx on your behalf, the organization owner, a member of your organization, or in the case of managed accounts, the account manager.
28 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 28 optional :change_made_by, enum: -> { Telnyx::Models::AuditEventListResponse::ChangeMadeBy } |
#change_type ⇒ String?
The type of change that occurred.
34 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 34 optional :change_type, String |
#changes ⇒ Array<Telnyx::Models::AuditEventListResponse::Change>?
Details of the changes made to the resource.
40 41 42 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 40 optional :changes, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AuditEventListResponse::Change] }, nil?: true |
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the change occurred.
48 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 48 optional :created_at, Time |
#id ⇒ String?
Unique identifier for the audit log entry.
11 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 11 optional :id, String |
#organization_id ⇒ String?
Unique identifier for the organization that owns the resource.
54 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 54 optional :organization_id, String |
#record_type ⇒ String?
The type of the resource being audited.
60 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 60 optional :record_type, String |
#resource_id ⇒ String?
Unique identifier for the resource that was changed.
66 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 66 optional :resource_id, String |
#user_id ⇒ String?
Unique identifier for the user who made the change.
72 |
# File 'lib/telnyx/models/audit_event_list_response.rb', line 72 optional :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/audit_event_list_response.rb', line 111
|