Module: Telnyx::Models::AuditEventListResponse::ChangeMadeBy
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/audit_event_list_response.rb,
sig/telnyx/models/audit_event_list_response.rbs
Overview
Indicates if the change was made by Telnyx on your behalf, the organization owner, a member of your organization, or in the case of managed accounts, the account manager.
Constant Summary collapse
- TELNYX =
:telnyx- ACCOUNT_MANAGER =
:account_manager- ACCOUNT_OWNER =
:account_owner- ORGANIZATION_MEMBER =
:organization_member
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::AuditEventListResponse::change_made_by]
93 |
# File 'sig/telnyx/models/audit_event_list_response.rbs', line 93
def self?.values: -> ::Array[Telnyx::Models::AuditEventListResponse::change_made_by]
|