Class: Telnyx::Models::AuthenticationProviderCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AuthenticationProviderCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/authentication_provider_create_params.rb
Overview
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
The active status of the authentication provider.
-
#name ⇒ String
The name associated with the authentication provider.
-
#settings ⇒ Telnyx::Models::Settings
The settings associated with the authentication provider.
-
#settings_url ⇒ String?
The URL for the identity provider metadata file to populate the settings automatically.
-
#short_name ⇒ String
The short name associated with the authentication provider.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(name:, settings:, short_name:, active: nil, settings_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AuthenticationProviderCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, settings:, short_name:, active: nil, settings_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AuthenticationProviderCreateParams for more details.
|
|
# File 'lib/telnyx/models/authentication_provider_create_params.rb', line 42
|
Instance Attribute Details
#active ⇒ Boolean?
The active status of the authentication provider
33 |
# File 'lib/telnyx/models/authentication_provider_create_params.rb', line 33 optional :active, Telnyx::Internal::Type::Boolean |
#name ⇒ String
The name associated with the authentication provider.
14 |
# File 'lib/telnyx/models/authentication_provider_create_params.rb', line 14 required :name, String |
#settings ⇒ Telnyx::Models::Settings
The settings associated with the authentication provider.
20 |
# File 'lib/telnyx/models/authentication_provider_create_params.rb', line 20 required :settings, -> { Telnyx::Settings } |
#settings_url ⇒ String?
The URL for the identity provider metadata file to populate the settings automatically. If the settings attribute is provided, that will be used instead.
40 |
# File 'lib/telnyx/models/authentication_provider_create_params.rb', line 40 optional :settings_url, String |
#short_name ⇒ String
The short name associated with the authentication provider. This must be unique and URL-friendly, as it’s going to be part of the login URL.
27 |
# File 'lib/telnyx/models/authentication_provider_create_params.rb', line 27 required :short_name, String |