Class: Telnyx::Models::AvailablePhoneNumberListResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AvailablePhoneNumberListResponse::Data
- Defined in:
- lib/telnyx/models/available_phone_number_list_response.rb
Defined Under Namespace
Modules: RecordType
Instance Attribute Summary collapse
-
#best_effort ⇒ Boolean?
Specifies whether the phone number is an exact match based on the search criteria or not.
- #cost_information ⇒ Telnyx::Models::CostInformation?
- #features ⇒ Array<Telnyx::Models::Feature>?
- #phone_number ⇒ String?
-
#quickship ⇒ Boolean?
Specifies whether the phone number can receive calls immediately after purchase or not.
- #record_type ⇒ Symbol, ...
- #region_information ⇒ Array<Telnyx::Models::RegionInformation>?
-
#reservable ⇒ Boolean?
Specifies whether the phone number can be reserved before purchase or not.
- #vanity_format ⇒ String?
Instance Method Summary collapse
-
#initialize(best_effort: nil, cost_information: nil, features: nil, phone_number: nil, quickship: nil, record_type: nil, region_information: nil, reservable: nil, vanity_format: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(best_effort: nil, cost_information: nil, features: nil, phone_number: nil, quickship: nil, record_type: nil, region_information: nil, reservable: nil, vanity_format: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AvailablePhoneNumberListResponse::Data for more details.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 28 class Data < Telnyx::Internal::Type::BaseModel # @!attribute best_effort # Specifies whether the phone number is an exact match based on the search # criteria or not. # # @return [Boolean, nil] optional :best_effort, Telnyx::Internal::Type::Boolean # @!attribute cost_information # # @return [Telnyx::Models::CostInformation, nil] optional :cost_information, -> { Telnyx::CostInformation } # @!attribute features # # @return [Array<Telnyx::Models::Feature>, nil] optional :features, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Feature] } # @!attribute phone_number # # @return [String, nil] optional :phone_number, String # @!attribute quickship # Specifies whether the phone number can receive calls immediately after purchase # or not. # # @return [Boolean, nil] optional :quickship, Telnyx::Internal::Type::Boolean # @!attribute record_type # # @return [Symbol, Telnyx::Models::AvailablePhoneNumberListResponse::Data::RecordType, nil] optional :record_type, enum: -> { Telnyx::Models::AvailablePhoneNumberListResponse::Data::RecordType } # @!attribute region_information # # @return [Array<Telnyx::Models::RegionInformation>, nil] optional :region_information, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::RegionInformation] } # @!attribute reservable # Specifies whether the phone number can be reserved before purchase or not. # # @return [Boolean, nil] optional :reservable, Telnyx::Internal::Type::Boolean # @!attribute vanity_format # # @return [String, nil] optional :vanity_format, String # @!method initialize(best_effort: nil, cost_information: nil, features: nil, phone_number: nil, quickship: nil, record_type: nil, region_information: nil, reservable: nil, vanity_format: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::AvailablePhoneNumberListResponse::Data} for more details. # # @param best_effort [Boolean] Specifies whether the phone number is an exact match based on the search criteri # # @param cost_information [Telnyx::Models::CostInformation] # # @param features [Array<Telnyx::Models::Feature>] # # @param phone_number [String] # # @param quickship [Boolean] Specifies whether the phone number can receive calls immediately after purchase # # @param record_type [Symbol, Telnyx::Models::AvailablePhoneNumberListResponse::Data::RecordType] # # @param region_information [Array<Telnyx::Models::RegionInformation>] # # @param reservable [Boolean] Specifies whether the phone number can be reserved before purchase or not. # # @param vanity_format [String] # @see Telnyx::Models::AvailablePhoneNumberListResponse::Data#record_type module RecordType extend Telnyx::Internal::Type::Enum AVAILABLE_PHONE_NUMBER = :available_phone_number # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#best_effort ⇒ Boolean?
Specifies whether the phone number is an exact match based on the search criteria or not.
34 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 34 optional :best_effort, Telnyx::Internal::Type::Boolean |
#cost_information ⇒ Telnyx::Models::CostInformation?
39 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 39 optional :cost_information, -> { Telnyx::CostInformation } |
#features ⇒ Array<Telnyx::Models::Feature>?
44 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 44 optional :features, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Feature] } |
#phone_number ⇒ String?
49 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 49 optional :phone_number, String |
#quickship ⇒ Boolean?
Specifies whether the phone number can receive calls immediately after purchase or not.
56 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 56 optional :quickship, Telnyx::Internal::Type::Boolean |
#record_type ⇒ Symbol, ...
61 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 61 optional :record_type, enum: -> { Telnyx::Models::AvailablePhoneNumberListResponse::Data::RecordType } |
#region_information ⇒ Array<Telnyx::Models::RegionInformation>?
66 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 66 optional :region_information, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::RegionInformation] } |
#reservable ⇒ Boolean?
Specifies whether the phone number can be reserved before purchase or not.
72 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 72 optional :reservable, Telnyx::Internal::Type::Boolean |
#vanity_format ⇒ String?
77 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 77 optional :vanity_format, String |