Class: Telnyx::Models::AvailablePhoneNumberListResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AvailablePhoneNumberListResponse::Data
- Defined in:
- lib/telnyx/models/available_phone_number_list_response.rb
Defined Under Namespace
Modules: RecordType Classes: CostInformation, Feature, RegionInformation
Instance Attribute Summary collapse
-
#best_effort ⇒ Boolean?
Specifies whether the phone number is an exact match based on the search criteria or not.
- #cost_information ⇒ Telnyx::Models::AvailablePhoneNumberListResponse::Data::CostInformation?
- #features ⇒ Array<Telnyx::Models::AvailablePhoneNumberListResponse::Data::Feature>?
- #phone_number ⇒ String?
-
#quickship ⇒ Boolean?
Specifies whether the phone number can receive calls immediately after purchase or not.
- #record_type ⇒ Symbol, ...
- #region_information ⇒ Array<Telnyx::Models::AvailablePhoneNumberListResponse::Data::RegionInformation>?
-
#reservable ⇒ Boolean?
Specifies whether the phone number can be reserved before purchase or not.
- #vanity_format ⇒ String?
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(name: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil) ⇒ Object
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 28 class Data < Telnyx::Internal::Type::BaseModel # @!attribute best_effort # Specifies whether the phone number is an exact match based on the search # criteria or not. # # @return [Boolean, nil] optional :best_effort, Telnyx::Internal::Type::Boolean # @!attribute cost_information # # @return [Telnyx::Models::AvailablePhoneNumberListResponse::Data::CostInformation, nil] optional :cost_information, -> { Telnyx::Models::AvailablePhoneNumberListResponse::Data::CostInformation } # @!attribute features # # @return [Array<Telnyx::Models::AvailablePhoneNumberListResponse::Data::Feature>, nil] optional :features, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AvailablePhoneNumberListResponse::Data::Feature] } # @!attribute phone_number # # @return [String, nil] optional :phone_number, String # @!attribute quickship # Specifies whether the phone number can receive calls immediately after purchase # or not. # # @return [Boolean, nil] optional :quickship, Telnyx::Internal::Type::Boolean # @!attribute record_type # # @return [Symbol, Telnyx::Models::AvailablePhoneNumberListResponse::Data::RecordType, nil] optional :record_type, enum: -> { Telnyx::Models::AvailablePhoneNumberListResponse::Data::RecordType } # @!attribute region_information # # @return [Array<Telnyx::Models::AvailablePhoneNumberListResponse::Data::RegionInformation>, nil] optional :region_information, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AvailablePhoneNumberListResponse::Data::RegionInformation] } # @!attribute reservable # Specifies whether the phone number can be reserved before purchase or not. # # @return [Boolean, nil] optional :reservable, Telnyx::Internal::Type::Boolean # @!attribute vanity_format # # @return [String, nil] optional :vanity_format, String # @!method initialize(best_effort: nil, cost_information: nil, features: nil, phone_number: nil, quickship: nil, record_type: nil, region_information: nil, reservable: nil, vanity_format: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::AvailablePhoneNumberListResponse::Data} for more details. # # @param best_effort [Boolean] Specifies whether the phone number is an exact match based on the search criteri # # @param cost_information [Telnyx::Models::AvailablePhoneNumberListResponse::Data::CostInformation] # # @param features [Array<Telnyx::Models::AvailablePhoneNumberListResponse::Data::Feature>] # # @param phone_number [String] # # @param quickship [Boolean] Specifies whether the phone number can receive calls immediately after purchase # # @param record_type [Symbol, Telnyx::Models::AvailablePhoneNumberListResponse::Data::RecordType] # # @param region_information [Array<Telnyx::Models::AvailablePhoneNumberListResponse::Data::RegionInformation>] # # @param reservable [Boolean] Specifies whether the phone number can be reserved before purchase or not. # # @param vanity_format [String] # @see Telnyx::Models::AvailablePhoneNumberListResponse::Data#cost_information class CostInformation < Telnyx::Internal::Type::BaseModel # @!attribute currency # The ISO 4217 code for the currency. # # @return [String, nil] optional :currency, String # @!attribute monthly_cost # # @return [String, nil] optional :monthly_cost, String # @!attribute upfront_cost # # @return [String, nil] optional :upfront_cost, String # @!method initialize(currency: nil, monthly_cost: nil, upfront_cost: nil) # @param currency [String] The ISO 4217 code for the currency. # # @param monthly_cost [String] # # @param upfront_cost [String] end class Feature < Telnyx::Internal::Type::BaseModel # @!attribute name # # @return [String, nil] optional :name, String # @!method initialize(name: nil) # @param name [String] end # @see Telnyx::Models::AvailablePhoneNumberListResponse::Data#record_type module RecordType extend Telnyx::Internal::Type::Enum AVAILABLE_PHONE_NUMBER = :available_phone_number # @!method self.values # @return [Array<Symbol>] end class RegionInformation < Telnyx::Internal::Type::BaseModel # @!attribute region_name # # @return [String, nil] optional :region_name, String # @!attribute region_type # # @return [Symbol, Telnyx::Models::AvailablePhoneNumberListResponse::Data::RegionInformation::RegionType, nil] optional :region_type, enum: -> { Telnyx::Models::AvailablePhoneNumberListResponse::Data::RegionInformation::RegionType } # @!method initialize(region_name: nil, region_type: nil) # @param region_name [String] # @param region_type [Symbol, Telnyx::Models::AvailablePhoneNumberListResponse::Data::RegionInformation::RegionType] # @see Telnyx::Models::AvailablePhoneNumberListResponse::Data::RegionInformation#region_type module RegionType extend Telnyx::Internal::Type::Enum COUNTRY_CODE = :country_code RATE_CENTER = :rate_center STATE = :state LOCATION = :location # @!method self.values # @return [Array<Symbol>] end end end |
Instance Attribute Details
#best_effort ⇒ Boolean?
Specifies whether the phone number is an exact match based on the search criteria or not.
34 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 34 optional :best_effort, Telnyx::Internal::Type::Boolean |
#cost_information ⇒ Telnyx::Models::AvailablePhoneNumberListResponse::Data::CostInformation?
39 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 39 optional :cost_information, -> { Telnyx::Models::AvailablePhoneNumberListResponse::Data::CostInformation } |
#features ⇒ Array<Telnyx::Models::AvailablePhoneNumberListResponse::Data::Feature>?
44 45 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 44 optional :features, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AvailablePhoneNumberListResponse::Data::Feature] } |
#phone_number ⇒ String?
50 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 50 optional :phone_number, String |
#quickship ⇒ Boolean?
Specifies whether the phone number can receive calls immediately after purchase or not.
57 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 57 optional :quickship, Telnyx::Internal::Type::Boolean |
#record_type ⇒ Symbol, ...
62 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 62 optional :record_type, enum: -> { Telnyx::Models::AvailablePhoneNumberListResponse::Data::RecordType } |
#region_information ⇒ Array<Telnyx::Models::AvailablePhoneNumberListResponse::Data::RegionInformation>?
67 68 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 67 optional :region_information, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::AvailablePhoneNumberListResponse::Data::RegionInformation] } |
#reservable ⇒ Boolean?
Specifies whether the phone number can be reserved before purchase or not.
74 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 74 optional :reservable, Telnyx::Internal::Type::Boolean |
#vanity_format ⇒ String?
79 |
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 79 optional :vanity_format, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/available_phone_number_list_response.rb', line 145
|