Class: Telnyx::Models::AzureVoiceSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::AzureVoiceSettings
- Defined in:
- lib/telnyx/models/azure_voice_settings.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#api_key_ref ⇒ String?
The ‘identifier` for an integration secret that refers to your Azure Speech API key.
-
#deployment_id ⇒ String?
The deployment ID for a custom Azure neural voice.
-
#effect ⇒ Symbol, ...
Audio effect to apply.
-
#gender ⇒ Symbol, ...
Voice gender filter.
-
#region ⇒ String?
The Azure region for the Speech service (e.g., ‘eastus`, `westeurope`).
-
#type ⇒ Symbol, Telnyx::Models::AzureVoiceSettings::Type
Voice settings provider type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type:, api_key_ref: nil, deployment_id: nil, effect: nil, gender: nil, region: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AzureVoiceSettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, api_key_ref: nil, deployment_id: nil, effect: nil, gender: nil, region: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::AzureVoiceSettings for more details.
|
|
# File 'lib/telnyx/models/azure_voice_settings.rb', line 44
|
Instance Attribute Details
#api_key_ref ⇒ String?
The ‘identifier` for an integration secret that refers to your Azure Speech API key.
17 |
# File 'lib/telnyx/models/azure_voice_settings.rb', line 17 optional :api_key_ref, String |
#deployment_id ⇒ String?
The deployment ID for a custom Azure neural voice.
23 |
# File 'lib/telnyx/models/azure_voice_settings.rb', line 23 optional :deployment_id, String |
#effect ⇒ Symbol, ...
Audio effect to apply.
29 |
# File 'lib/telnyx/models/azure_voice_settings.rb', line 29 optional :effect, enum: -> { Telnyx::AzureVoiceSettings::Effect } |
#gender ⇒ Symbol, ...
Voice gender filter.
35 |
# File 'lib/telnyx/models/azure_voice_settings.rb', line 35 optional :gender, enum: -> { Telnyx::AzureVoiceSettings::Gender } |
#region ⇒ String?
The Azure region for the Speech service (e.g., ‘eastus`, `westeurope`). Required when using a custom API key.
42 |
# File 'lib/telnyx/models/azure_voice_settings.rb', line 42 optional :region, String |
#type ⇒ Symbol, Telnyx::Models::AzureVoiceSettings::Type
Voice settings provider type
10 |
# File 'lib/telnyx/models/azure_voice_settings.rb', line 10 required :type, enum: -> { Telnyx::AzureVoiceSettings::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/azure_voice_settings.rb', line 68
|