Class: Telnyx::Models::BookAppointmentToolParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/book_appointment_tool_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_key_ref:, event_type_id:, attendee_name: nil, attendee_timezone: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::BookAppointmentToolParams for more details.

Parameters:

  • api_key_ref (String)

    Reference to an integration secret that contains your Cal.com API key. You would

  • event_type_id (Integer)

    Event Type ID for which slots are being fetched. [cal.com](cal.com/docs/

  • attendee_name (String) (defaults to: nil)

    The name of the attendee [cal.com](cal.com/docs/api-reference/v2/booking

  • attendee_timezone (String) (defaults to: nil)

    The timezone of the attendee [cal.com](cal.com/docs/api-reference/v2/boo



# File 'lib/telnyx/models/book_appointment_tool_params.rb', line 38

Instance Attribute Details

#api_key_refString

Reference to an integration secret that contains your Cal.com API key. You would pass the ‘identifier` for an integration secret [/v2/integration_secrets](developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) that refers to your Cal.com API key.

Returns:

  • (String)


13
# File 'lib/telnyx/models/book_appointment_tool_params.rb', line 13

required :api_key_ref, String

#attendee_nameString?

The name of the attendee [cal.com](cal.com/docs/api-reference/v2/bookings/create-a-booking#body-attendee-name). If not provided, the assistant will ask for the attendee’s name.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/book_appointment_tool_params.rb', line 28

optional :attendee_name, String

#attendee_timezoneString?

The timezone of the attendee [cal.com](cal.com/docs/api-reference/v2/bookings/create-a-booking#body-attendee-timezone). If not provided, the assistant will ask for the attendee’s timezone.

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/book_appointment_tool_params.rb', line 36

optional :attendee_timezone, String

#event_type_idInteger

Event Type ID for which slots are being fetched. [cal.com](cal.com/docs/api-reference/v2/bookings/create-a-booking#body-event-type-id)

Returns:

  • (Integer)


20
# File 'lib/telnyx/models/book_appointment_tool_params.rb', line 20

required :event_type_id, Integer