Class: Telnyx::Models::BundlePricing::BillingBundleSummary
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::BundlePricing::BillingBundleSummary
- Defined in:
- lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb
Overview
Instance Attribute Summary collapse
-
#cost_code ⇒ String
Bundle’s cost code, this is used to identify the bundle in the billing system.
-
#created_at ⇒ Date
Date the bundle was created.
-
#currency ⇒ String?
Bundle’s currency code.
-
#id ⇒ String
Bundle’s ID, this is used to identify the bundle in the API.
-
#is_public ⇒ Boolean
Available to all customers or only to specific customers.
-
#mrc_price ⇒ Float?
Monthly recurring charge price.
-
#name ⇒ String
Bundle’s name, this is used to identify the bundle in the UI.
-
#slug ⇒ String?
Slugified version of the bundle’s name.
- #specs ⇒ Array<String>?
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, cost_code:, created_at:, is_public:, name:, currency: nil, mrc_price: nil, slug: nil, specs: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 61
|
Instance Attribute Details
#cost_code ⇒ String
Bundle’s cost code, this is used to identify the bundle in the billing system.
18 |
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 18 required :cost_code, String |
#created_at ⇒ Date
Date the bundle was created.
24 |
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 24 required :created_at, Date |
#currency ⇒ String?
Bundle’s currency code.
42 |
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 42 optional :currency, String |
#id ⇒ String
Bundle’s ID, this is used to identify the bundle in the API.
12 |
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 12 required :id, String |
#is_public ⇒ Boolean
Available to all customers or only to specific customers.
30 |
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 30 required :is_public, Telnyx::Internal::Type::Boolean |
#mrc_price ⇒ Float?
Monthly recurring charge price.
48 |
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 48 optional :mrc_price, Float |
#name ⇒ String
Bundle’s name, this is used to identify the bundle in the UI.
36 |
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 36 required :name, String |
#slug ⇒ String?
Slugified version of the bundle’s name.
54 |
# File 'lib/telnyx/models/bundle_pricing/billing_bundle_summary.rb', line 54 optional :slug, String |