Class: Telnyx::Models::CallAnswered::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallAnswered::Payload
- Defined in:
- lib/telnyx/models/call_answered.rb
Overview
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers set on answer command.
-
#from ⇒ String?
Number or SIP URI placing the call.
-
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
User-to-User and Diversion headers from sip invite.
-
#start_time ⇒ Time?
ISO 8601 datetime of when the call started.
-
#state ⇒ Symbol, ...
State received from a command.
-
#tags ⇒ Array<String>?
Array of tags associated to number.
-
#to ⇒ String?
Destination number or SIP URI of the call.
Instance Method Summary collapse
-
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, custom_headers: nil, from: nil, sip_headers: nil, start_time: nil, state: nil, tags: nil, to: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, custom_headers: nil, from: nil, sip_headers: nil, start_time: nil, state: nil, tags: nil, to: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallAnswered::Payload for more details.
|
|
# File 'lib/telnyx/models/call_answered.rb', line 134
|
Instance Attribute Details
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
64 |
# File 'lib/telnyx/models/call_answered.rb', line 64 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
70 |
# File 'lib/telnyx/models/call_answered.rb', line 70 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
78 |
# File 'lib/telnyx/models/call_answered.rb', line 78 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command.
84 |
# File 'lib/telnyx/models/call_answered.rb', line 84 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
90 |
# File 'lib/telnyx/models/call_answered.rb', line 90 optional :connection_id, String |
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers set on answer command
96 |
# File 'lib/telnyx/models/call_answered.rb', line 96 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] } |
#from ⇒ String?
Number or SIP URI placing the call.
102 |
# File 'lib/telnyx/models/call_answered.rb', line 102 optional :from, String |
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
User-to-User and Diversion headers from sip invite.
108 |
# File 'lib/telnyx/models/call_answered.rb', line 108 optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] } |
#start_time ⇒ Time?
ISO 8601 datetime of when the call started.
114 |
# File 'lib/telnyx/models/call_answered.rb', line 114 optional :start_time, Time |
#state ⇒ Symbol, ...
State received from a command.
120 |
# File 'lib/telnyx/models/call_answered.rb', line 120 optional :state, enum: -> { Telnyx::CallAnswered::Payload::State } |
#tags ⇒ Array<String>?
Array of tags associated to number.
126 |
# File 'lib/telnyx/models/call_answered.rb', line 126 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#to ⇒ String?
Destination number or SIP URI of the call.
132 |
# File 'lib/telnyx/models/call_answered.rb', line 132 optional :to, String |