Class: Telnyx::Models::CallControlApplication
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallControlApplication
- Defined in:
- lib/telnyx/models/call_control_application.rb
Overview
Defined Under Namespace
Modules: AnchorsiteOverride, DtmfType, RecordType, WebhookAPIVersion
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Specifies whether the connection can be used.
-
#anchorsite_override ⇒ Symbol, ...
Latencydirects Telnyx to route media through the site with the lowest round-trip time to the user’s connection. -
#application_name ⇒ String?
A user-assigned name to help manage the application.
-
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this Call Control Application.
-
#created_at ⇒ String?
ISO 8601 formatted date of when the resource was created.
-
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection.
-
#first_command_timeout ⇒ Boolean?
Specifies whether calls to phone numbers associated with this connection should hangup after timing out.
-
#first_command_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a dial command.
- #id ⇒ String?
- #inbound ⇒ Telnyx::Models::CallControlApplicationInbound?
- #outbound ⇒ Telnyx::Models::CallControlApplicationOutbound?
- #record_type ⇒ Symbol, ...
-
#redact_dtmf_debug_logging ⇒ Boolean?
When enabled, DTMF digits entered by users will be redacted in debug logs to protect PII data entered through IVR interactions.
-
#tags ⇒ Array<String>?
Tags assigned to the Call Control Application.
-
#updated_at ⇒ String?
ISO 8601 formatted date of when the resource was last updated.
-
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent.
- #webhook_timeout_secs ⇒ Integer?
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, active: nil, anchorsite_override: nil, application_name: nil, call_cost_in_webhooks: nil, created_at: nil, dtmf_type: nil, first_command_timeout: nil, first_command_timeout_secs: nil, inbound: nil, outbound: nil, record_type: nil, redact_dtmf_debug_logging: nil, tags: nil, updated_at: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallControlApplication for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, active: nil, anchorsite_override: nil, application_name: nil, call_cost_in_webhooks: nil, created_at: nil, dtmf_type: nil, first_command_timeout: nil, first_command_timeout_secs: nil, inbound: nil, outbound: nil, record_type: nil, redact_dtmf_debug_logging: nil, tags: nil, updated_at: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallControlApplication for more details.
|
|
# File 'lib/telnyx/models/call_control_application.rb', line 125
|
Instance Attribute Details
#active ⇒ Boolean?
Specifies whether the connection can be used.
16 |
# File 'lib/telnyx/models/call_control_application.rb', line 16 optional :active, Telnyx::Internal::Type::Boolean |
#anchorsite_override ⇒ Symbol, ...
Latency directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.
25 |
# File 'lib/telnyx/models/call_control_application.rb', line 25 optional :anchorsite_override, enum: -> { Telnyx::CallControlApplication::AnchorsiteOverride } |
#application_name ⇒ String?
A user-assigned name to help manage the application.
31 |
# File 'lib/telnyx/models/call_control_application.rb', line 31 optional :application_name, String |
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this Call Control Application.
38 |
# File 'lib/telnyx/models/call_control_application.rb', line 38 optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean |
#created_at ⇒ String?
ISO 8601 formatted date of when the resource was created
44 |
# File 'lib/telnyx/models/call_control_application.rb', line 44 optional :created_at, String |
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.
51 |
# File 'lib/telnyx/models/call_control_application.rb', line 51 optional :dtmf_type, enum: -> { Telnyx::CallControlApplication::DtmfType } |
#first_command_timeout ⇒ Boolean?
Specifies whether calls to phone numbers associated with this connection should hangup after timing out.
58 |
# File 'lib/telnyx/models/call_control_application.rb', line 58 optional :first_command_timeout, Telnyx::Internal::Type::Boolean |
#first_command_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a dial command.
64 |
# File 'lib/telnyx/models/call_control_application.rb', line 64 optional :first_command_timeout_secs, Integer |
#id ⇒ String?
10 |
# File 'lib/telnyx/models/call_control_application.rb', line 10 optional :id, String |
#inbound ⇒ Telnyx::Models::CallControlApplicationInbound?
69 |
# File 'lib/telnyx/models/call_control_application.rb', line 69 optional :inbound, -> { Telnyx::CallControlApplicationInbound } |
#outbound ⇒ Telnyx::Models::CallControlApplicationOutbound?
74 |
# File 'lib/telnyx/models/call_control_application.rb', line 74 optional :outbound, -> { Telnyx::CallControlApplicationOutbound } |
#record_type ⇒ Symbol, ...
79 |
# File 'lib/telnyx/models/call_control_application.rb', line 79 optional :record_type, enum: -> { Telnyx::CallControlApplication::RecordType } |
#redact_dtmf_debug_logging ⇒ Boolean?
When enabled, DTMF digits entered by users will be redacted in debug logs to protect PII data entered through IVR interactions.
86 |
# File 'lib/telnyx/models/call_control_application.rb', line 86 optional :redact_dtmf_debug_logging, Telnyx::Internal::Type::Boolean |
#tags ⇒ Array<String>?
Tags assigned to the Call Control Application.
92 |
# File 'lib/telnyx/models/call_control_application.rb', line 92 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#updated_at ⇒ String?
ISO 8601 formatted date of when the resource was last updated
98 |
# File 'lib/telnyx/models/call_control_application.rb', line 98 optional :updated_at, String |
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
104 |
# File 'lib/telnyx/models/call_control_application.rb', line 104 optional :webhook_api_version, enum: -> { Telnyx::CallControlApplication::WebhookAPIVersion } |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https`.
111 |
# File 'lib/telnyx/models/call_control_application.rb', line 111 optional :webhook_event_failover_url, String, nil?: true |
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https`.
118 |
# File 'lib/telnyx/models/call_control_application.rb', line 118 optional :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
123 |
# File 'lib/telnyx/models/call_control_application.rb', line 123 optional :webhook_timeout_secs, Integer, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/call_control_application.rb', line 186
|