Class: Telnyx::Models::CallControlApplicationCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallControlApplicationCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/call_control_application_create_params.rb
Overview
Defined Under Namespace
Modules: AnchorsiteOverride, DtmfType, WebhookAPIVersion
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Specifies whether the connection can be used.
-
#anchorsite_override ⇒ Symbol, ...
Latencydirects Telnyx to route media through the site with the lowest round-trip time to the user’s connection. -
#application_name ⇒ String
A user-assigned name to help manage the application.
-
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this Call Control Application.
-
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection.
-
#first_command_timeout ⇒ Boolean?
Specifies whether calls to phone numbers associated with this connection should hangup after timing out.
-
#first_command_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a dial command.
- #inbound ⇒ Telnyx::Models::CallControlApplicationInbound?
- #outbound ⇒ Telnyx::Models::CallControlApplicationOutbound?
-
#redact_dtmf_debug_logging ⇒ Boolean?
When enabled, DTMF digits entered by users will be redacted in debug logs to protect PII data entered through IVR interactions.
-
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String
The URL where webhooks related to this connection will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(application_name:, webhook_event_url:, active: nil, anchorsite_override: nil, call_cost_in_webhooks: nil, dtmf_type: nil, first_command_timeout: nil, first_command_timeout_secs: nil, inbound: nil, outbound: nil, redact_dtmf_debug_logging: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallControlApplicationCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(application_name:, webhook_event_url:, active: nil, anchorsite_override: nil, call_cost_in_webhooks: nil, dtmf_type: nil, first_command_timeout: nil, first_command_timeout_secs: nil, inbound: nil, outbound: nil, redact_dtmf_debug_logging: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallControlApplicationCreateParams for more details.
|
|
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 101
|
Instance Attribute Details
#active ⇒ Boolean?
Specifies whether the connection can be used.
27 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 27 optional :active, Telnyx::Internal::Type::Boolean |
#anchorsite_override ⇒ Symbol, ...
Latency directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.
36 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 36 optional :anchorsite_override, enum: -> { Telnyx::CallControlApplicationCreateParams::AnchorsiteOverride } |
#application_name ⇒ String
A user-assigned name to help manage the application.
14 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 14 required :application_name, String |
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this Call Control Application.
43 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 43 optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean |
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.
50 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 50 optional :dtmf_type, enum: -> { Telnyx::CallControlApplicationCreateParams::DtmfType } |
#first_command_timeout ⇒ Boolean?
Specifies whether calls to phone numbers associated with this connection should hangup after timing out.
57 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 57 optional :first_command_timeout, Telnyx::Internal::Type::Boolean |
#first_command_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a dial command.
63 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 63 optional :first_command_timeout_secs, Integer |
#inbound ⇒ Telnyx::Models::CallControlApplicationInbound?
68 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 68 optional :inbound, -> { Telnyx::CallControlApplicationInbound } |
#outbound ⇒ Telnyx::Models::CallControlApplicationOutbound?
73 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 73 optional :outbound, -> { Telnyx::CallControlApplicationOutbound } |
#redact_dtmf_debug_logging ⇒ Boolean?
When enabled, DTMF digits entered by users will be redacted in debug logs to protect PII data entered through IVR interactions.
80 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 80 optional :redact_dtmf_debug_logging, Telnyx::Internal::Type::Boolean |
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
86 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 86 optional :webhook_api_version, enum: -> { Telnyx::CallControlApplicationCreateParams::WebhookAPIVersion } |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.
93 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 93 optional :webhook_event_failover_url, String, nil?: true |
#webhook_event_url ⇒ String
The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.
21 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 21 required :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
99 |
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 99 optional :webhook_timeout_secs, Integer, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/call_control_application_create_params.rb', line 152
|