Class: Telnyx::Models::CallConversationEnded::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallConversationEnded::Payload
- Defined in:
- lib/telnyx/models/call_conversation_ended.rb
Overview
Defined Under Namespace
Modules: CallingPartyType
Instance Attribute Summary collapse
-
#assistant_id ⇒ String?
Unique identifier of the assistant involved in the call.
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call leg.
-
#call_session_id ⇒ String?
ID that is unique to the call session (group of related call legs).
-
#calling_party_type ⇒ Symbol, ...
The type of calling party connection.
-
#client_state ⇒ String?
Base64-encoded state received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#conversation_id ⇒ String?
ID unique to the conversation or insight group generated for the call.
-
#duration_sec ⇒ Integer?
Duration of the conversation in seconds.
-
#from ⇒ String?
The caller’s number or identifier.
-
#llm_model ⇒ String?
The large language model used during the conversation.
-
#stt_model ⇒ String?
The speech-to-text model used in the conversation.
-
#to ⇒ String?
The callee’s number or SIP address.
-
#tts_model_id ⇒ String?
The model ID used for text-to-speech synthesis.
-
#tts_provider ⇒ String?
The text-to-speech provider used in the call.
-
#tts_voice_id ⇒ String?
Voice ID used for TTS.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assistant_id: nil, call_control_id: nil, call_leg_id: nil, call_session_id: nil, calling_party_type: nil, client_state: nil, connection_id: nil, conversation_id: nil, duration_sec: nil, from: nil, llm_model: nil, stt_model: nil, to: nil, tts_model_id: nil, tts_provider: nil, tts_voice_id: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/call_conversation_ended.rb', line 164
|
Instance Attribute Details
#assistant_id ⇒ String?
Unique identifier of the assistant involved in the call.
72 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 72 optional :assistant_id, String |
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
78 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 78 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call leg.
84 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 84 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session (group of related call legs).
90 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 90 optional :call_session_id, String |
#calling_party_type ⇒ Symbol, ...
The type of calling party connection.
96 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 96 optional :calling_party_type, enum: -> { Telnyx::CallConversationEnded::Payload::CallingPartyType } |
#client_state ⇒ String?
Base64-encoded state received from a command.
102 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 102 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
108 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 108 optional :connection_id, String |
#conversation_id ⇒ String?
ID unique to the conversation or insight group generated for the call.
114 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 114 optional :conversation_id, String |
#duration_sec ⇒ Integer?
Duration of the conversation in seconds.
120 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 120 optional :duration_sec, Integer |
#from ⇒ String?
The caller’s number or identifier.
126 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 126 optional :from, String |
#llm_model ⇒ String?
The large language model used during the conversation.
132 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 132 optional :llm_model, String |
#stt_model ⇒ String?
The speech-to-text model used in the conversation.
138 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 138 optional :stt_model, String |
#to ⇒ String?
The callee’s number or SIP address.
144 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 144 optional :to, String |
#tts_model_id ⇒ String?
The model ID used for text-to-speech synthesis.
150 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 150 optional :tts_model_id, String |
#tts_provider ⇒ String?
The text-to-speech provider used in the call.
156 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 156 optional :tts_provider, String |
#tts_voice_id ⇒ String?
Voice ID used for TTS.
162 |
# File 'lib/telnyx/models/call_conversation_ended.rb', line 162 optional :tts_voice_id, String |