Class: Telnyx::Models::CallCostWebhookEvent::Data::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallCostWebhookEvent::Data::Payload
- Defined in:
- lib/telnyx/models/call_cost_webhook_event.rb
Overview
Defined Under Namespace
Modules: Status Classes: CostPart
Instance Attribute Summary collapse
-
#billed_duration_secs ⇒ Integer?
The longest billed duration across all cost parts, in seconds.
-
#billing_group_id ⇒ String?
Identifies the billing group associated with the call.
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#cost_parts ⇒ Array<Telnyx::Models::CallCostWebhookEvent::Data::Payload::CostPart>?
Breakdown of costs by call part.
-
#occurred_at ⇒ Time?
ISO 8601 datetime of when the event occurred.
-
#status ⇒ Symbol, ...
The status of the cost calculation (‘success` or `error`).
-
#total_cost ⇒ String?
The total cost of the call.
Instance Method Summary collapse
-
#initialize(billed_duration_secs: nil, call_part: nil, cost: nil, currency: nil, rate: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CostPart for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billed_duration_secs: nil, call_part: nil, cost: nil, currency: nil, rate: nil) ⇒ Object
Some parameter documentations has been truncated, see CostPart for more details.
|
|
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 198
|
Instance Attribute Details
#billed_duration_secs ⇒ Integer?
The longest billed duration across all cost parts, in seconds.
74 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 74 optional :billed_duration_secs, Integer, nil?: true |
#billing_group_id ⇒ String?
Identifies the billing group associated with the call.
80 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 80 optional :billing_group_id, String, nil?: true |
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
86 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 86 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
92 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 92 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
100 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 100 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command. Base64-encoded.
106 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 106 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
112 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 112 optional :connection_id, String |
#cost_parts ⇒ Array<Telnyx::Models::CallCostWebhookEvent::Data::Payload::CostPart>?
Breakdown of costs by call part.
118 119 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 118 optional :cost_parts, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CallCostWebhookEvent::Data::Payload::CostPart] } |
#occurred_at ⇒ Time?
ISO 8601 datetime of when the event occurred.
125 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 125 optional :occurred_at, Time |
#status ⇒ Symbol, ...
The status of the cost calculation (‘success` or `error`).
131 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 131 optional :status, enum: -> { Telnyx::CallCostWebhookEvent::Data::Payload::Status } |
#total_cost ⇒ String?
The total cost of the call.
137 |
# File 'lib/telnyx/models/call_cost_webhook_event.rb', line 137 optional :total_cost, String, nil?: true |