Class: Telnyx::Models::CallDeepfakeDetectionErrorWebhookEvent::Data::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallDeepfakeDetectionErrorWebhookEvent::Data::Payload
- Defined in:
- lib/telnyx/models/call_deepfake_detection_error_webhook_event.rb
Overview
Defined Under Namespace
Modules: ErrorMessage
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#error_message ⇒ Symbol, ...
The error that occurred.
Instance Method Summary collapse
-
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, error_message: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, error_message: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallDeepfakeDetectionErrorWebhookEvent::Data::Payload for more details.
|
|
# File 'lib/telnyx/models/call_deepfake_detection_error_webhook_event.rb', line 111
|
Instance Attribute Details
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
74 |
# File 'lib/telnyx/models/call_deepfake_detection_error_webhook_event.rb', line 74 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
80 |
# File 'lib/telnyx/models/call_deepfake_detection_error_webhook_event.rb', line 80 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
88 |
# File 'lib/telnyx/models/call_deepfake_detection_error_webhook_event.rb', line 88 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command.
94 |
# File 'lib/telnyx/models/call_deepfake_detection_error_webhook_event.rb', line 94 optional :client_state, String, nil?: true |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
100 |
# File 'lib/telnyx/models/call_deepfake_detection_error_webhook_event.rb', line 100 optional :connection_id, String |
#error_message ⇒ Symbol, ...
The error that occurred. ‘detection_timeout’ = no DFD response received, ‘rtp_timeout’ = no RTP audio received, ‘dfd_connection_error’/‘dfd_stream_error’
service connectivity issues.
108 109 |
# File 'lib/telnyx/models/call_deepfake_detection_error_webhook_event.rb', line 108 optional :error_message, enum: -> { Telnyx::CallDeepfakeDetectionErrorWebhookEvent::Data::Payload::ErrorMessage } |