Class: Telnyx::Models::CallDialParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/call_dial_params.rb

Overview

Defined Under Namespace

Modules: AnsweringMachineDetection, MediaEncryption, Record, RecordChannels, RecordFormat, RecordTrack, RecordTrim, SipRegion, SipTransportProtocol, StreamTrack, SupervisorRole, To, WebhookURLMethod Classes: AnsweringMachineDetectionConfig, ConferenceConfig

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after_greeting_silence_millis: nil, between_words_silence_millis: nil, greeting_duration_millis: nil, greeting_silence_duration_millis: nil, greeting_total_analysis_time_millis: nil, initial_silence_millis: nil, maximum_number_of_words: nil, maximum_word_length_millis: nil, silence_threshold: nil, total_analysis_time_millis: nil) ⇒ Object

Some parameter documentations has been truncated, see AnsweringMachineDetectionConfig for more details.

Optional configuration parameters to modify ‘answering_machine_detection’ performance.

Parameters:

  • after_greeting_silence_millis (Integer) (defaults to: nil)

    Silence duration threshold after a greeting message or voice for it be considere

  • between_words_silence_millis (Integer) (defaults to: nil)

    Maximum threshold for silence between words.

  • greeting_duration_millis (Integer) (defaults to: nil)

    Maximum threshold of a human greeting. If greeting longer than this value, consi

  • greeting_silence_duration_millis (Integer) (defaults to: nil)

    If machine already detected, maximum threshold for silence between words. If exc

  • greeting_total_analysis_time_millis (Integer) (defaults to: nil)

    If machine already detected, maximum timeout threshold to determine the end of t

  • initial_silence_millis (Integer) (defaults to: nil)

    If initial silence duration is greater than this value, consider it a machine.

  • maximum_number_of_words (Integer) (defaults to: nil)

    If number of detected words is greater than this value, consder it a machine.

  • maximum_word_length_millis (Integer) (defaults to: nil)

    If a single word lasts longer than this threshold, consider it a machine.

  • silence_threshold (Integer) (defaults to: nil)

    Minimum noise threshold for any analysis.

  • total_analysis_time_millis (Integer) (defaults to: nil)

    Maximum timeout threshold for overall detection.



# File 'lib/telnyx/models/call_dial_params.rb', line 388

Instance Attribute Details

#answering_machine_detectionSymbol, ...

Enables Answering Machine Detection. Telnyx offers Premium and Standard detections. With Premium detection, when a call is answered, Telnyx runs real-time detection and sends a ‘call.machine.premium.detection.ended` webhook with one of the following results: `human_residence`, `human_business`, `machine`, `silence` or `fax_detected`. If we detect a beep, we also send a `call.machine.premium.greeting.ended` webhook with the result of `beep_detected`. If we detect a beep before `call.machine.premium.detection.ended` we only send `call.machine.premium.greeting.ended`, and if we detect a beep after `call.machine.premium.detection.ended`, we send both webhooks. With Standard detection, when a call is answered, Telnyx runs real-time detection to determine if it was picked up by a human or a machine and sends an `call.machine.detection.ended` webhook with the analysis result. If `greeting_end` or `detect_words` is used and a `machine` is detected, you will receive another `call.machine.greeting.ended` webhook when the answering machine greeting ends with a beep or silence. If `detect_beep` is used, you will only receive `call.machine.greeting.ended` if a beep is detected.



51
# File 'lib/telnyx/models/call_dial_params.rb', line 51

optional :answering_machine_detection, enum: -> { Telnyx::CallDialParams::AnsweringMachineDetection }

#answering_machine_detection_configTelnyx::Models::CallDialParams::AnsweringMachineDetectionConfig?

Optional configuration parameters to modify ‘answering_machine_detection’ performance.



58
59
# File 'lib/telnyx/models/call_dial_params.rb', line 58

optional :answering_machine_detection_config,
-> { Telnyx::CallDialParams::AnsweringMachineDetectionConfig }

#audio_urlString?

The URL of a file to be played back to the callee when the call is answered. The URL can point to either a WAV or MP3 file. media_name and audio_url cannot be used together in one request.

Returns:

  • (String, nil)


67
# File 'lib/telnyx/models/call_dial_params.rb', line 67

optional :audio_url, String

#billing_group_idString?

Use this field to set the Billing Group ID for the call. Must be a valid and existing Billing Group ID.

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/call_dial_params.rb', line 74

optional :billing_group_id, String

#bridge_intentBoolean?

Indicates the intent to bridge this call with the call specified in link_to. When bridge_intent is true, link_to becomes required and the from number will be overwritten by the from number from the linked call.

Returns:

  • (Boolean, nil)


82
# File 'lib/telnyx/models/call_dial_params.rb', line 82

optional :bridge_intent, Telnyx::Internal::Type::Boolean

#bridge_on_answerBoolean?

Whether to automatically bridge answered call to the call specified in link_to. When bridge_on_answer is true, link_to becomes required.

Returns:

  • (Boolean, nil)


89
# File 'lib/telnyx/models/call_dial_params.rb', line 89

optional :bridge_on_answer, Telnyx::Internal::Type::Boolean

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


96
# File 'lib/telnyx/models/call_dial_params.rb', line 96

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore others Dial commands with the same ‘command_id`.

Returns:

  • (String, nil)


103
# File 'lib/telnyx/models/call_dial_params.rb', line 103

optional :command_id, String

#conference_configTelnyx::Models::CallDialParams::ConferenceConfig?

Optional configuration parameters to dial new participant into a conference.



109
# File 'lib/telnyx/models/call_dial_params.rb', line 109

optional :conference_config, -> { Telnyx::CallDialParams::ConferenceConfig }

#connection_idString

The ID of the Call Control App (formerly ID of the connection) to be used when dialing the destination.

Returns:

  • (String)


15
# File 'lib/telnyx/models/call_dial_params.rb', line 15

required :connection_id, String

#custom_headersArray<Telnyx::Models::CustomSipHeader>?

Custom headers to be added to the SIP INVITE.

Returns:



115
# File 'lib/telnyx/models/call_dial_params.rb', line 115

optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] }

#dialogflow_configTelnyx::Models::DialogflowConfig?



120
# File 'lib/telnyx/models/call_dial_params.rb', line 120

optional :dialogflow_config, -> { Telnyx::DialogflowConfig }

#enable_dialogflowBoolean?

Enables Dialogflow for the current call. The default value is false.

Returns:

  • (Boolean, nil)


126
# File 'lib/telnyx/models/call_dial_params.rb', line 126

optional :enable_dialogflow, Telnyx::Internal::Type::Boolean

#fromString

The ‘from` number to be used as the caller id presented to the destination (`to` number). The number should be in +E164 format.

Returns:

  • (String)


22
# File 'lib/telnyx/models/call_dial_params.rb', line 22

required :from, String

#from_display_nameString?

The ‘from_display_name` string to be used as the caller id name (SIP From Display Name) presented to the destination (`to` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and -_~!.+ special characters. If ommited, the display name will be the same as the number in the `from` field.

Returns:

  • (String, nil)


136
# File 'lib/telnyx/models/call_dial_params.rb', line 136

optional :from_display_name, String

Use another call’s control id for sharing the same call session id

Returns:

  • (String, nil)


142
# File 'lib/telnyx/models/call_dial_params.rb', line 142

optional :link_to, String

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the call.



148
# File 'lib/telnyx/models/call_dial_params.rb', line 148

optional :media_encryption, enum: -> { Telnyx::CallDialParams::MediaEncryption }

#media_nameString?

The media_name of a file to be played back to the callee when the call is answered. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file.

Returns:

  • (String, nil)


157
# File 'lib/telnyx/models/call_dial_params.rb', line 157

optional :media_name, String

#park_after_unbridgeString?

If supplied with the value ‘self`, the current leg will be parked after unbridge. If not set, the default behavior is to hang up the leg. When park_after_unbridge is set, link_to becomes required.

Returns:

  • (String, nil)


165
# File 'lib/telnyx/models/call_dial_params.rb', line 165

optional :park_after_unbridge, String

#preferred_codecsString?

The list of comma-separated codecs in a preferred order for the forked media to be received.

Returns:

  • (String, nil)


172
# File 'lib/telnyx/models/call_dial_params.rb', line 172

optional :preferred_codecs, String

#recordSymbol, ...

Start recording automatically after an event. Disabled by default.

Returns:



178
# File 'lib/telnyx/models/call_dial_params.rb', line 178

optional :record, enum: -> { Telnyx::CallDialParams::Record }

#record_channelsSymbol, ...

Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.



185
# File 'lib/telnyx/models/call_dial_params.rb', line 185

optional :record_channels, enum: -> { Telnyx::CallDialParams::RecordChannels }

#record_custom_file_nameString?

The custom recording file name to be used instead of the default ‘call_leg_id`. Telnyx will still add a Unix timestamp suffix.

Returns:

  • (String, nil)


192
# File 'lib/telnyx/models/call_dial_params.rb', line 192

optional :record_custom_file_name, String

#record_formatSymbol, ...

Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.



198
# File 'lib/telnyx/models/call_dial_params.rb', line 198

optional :record_format, enum: -> { Telnyx::CallDialParams::RecordFormat }

#record_max_lengthInteger?

Defines the maximum length for the recording in seconds when ‘record` is specified. The minimum value is 0. The maximum value is 43200. The default value is 0 (infinite).

Returns:

  • (Integer, nil)


206
# File 'lib/telnyx/models/call_dial_params.rb', line 206

optional :record_max_length, Integer

#record_timeout_secsInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified. The timer only starts when the speech is detected. Please note that call transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite).

Returns:

  • (Integer, nil)


216
# File 'lib/telnyx/models/call_dial_params.rb', line 216

optional :record_timeout_secs, Integer

#record_trackSymbol, ...

The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. If only single track is specified (`inbound`, `outbound`), `channels` configuration is ignored and it will be recorded as mono (single channel).



224
# File 'lib/telnyx/models/call_dial_params.rb', line 224

optional :record_track, enum: -> { Telnyx::CallDialParams::RecordTrack }

#record_trimSymbol, ...

When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.



231
# File 'lib/telnyx/models/call_dial_params.rb', line 231

optional :record_trim, enum: -> { Telnyx::CallDialParams::RecordTrim }

#send_silence_when_idleBoolean?

Generate silence RTP packets when no transmission available.

Returns:

  • (Boolean, nil)


237
# File 'lib/telnyx/models/call_dial_params.rb', line 237

optional :send_silence_when_idle, Telnyx::Internal::Type::Boolean

#sip_auth_passwordString?

SIP Authentication password used for SIP challenges.

Returns:

  • (String, nil)


243
# File 'lib/telnyx/models/call_dial_params.rb', line 243

optional :sip_auth_password, String

#sip_auth_usernameString?

SIP Authentication username used for SIP challenges.

Returns:

  • (String, nil)


249
# File 'lib/telnyx/models/call_dial_params.rb', line 249

optional :sip_auth_username, String

#sip_headersArray<Telnyx::Models::SipHeader>?

SIP headers to be added to the SIP INVITE request. Currently only User-to-User header is supported.

Returns:



256
# File 'lib/telnyx/models/call_dial_params.rb', line 256

optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] }

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



262
# File 'lib/telnyx/models/call_dial_params.rb', line 262

optional :sip_region, enum: -> { Telnyx::CallDialParams::SipRegion }

#sip_transport_protocolSymbol, ...

Defines SIP transport protocol to be used on the call.



268
# File 'lib/telnyx/models/call_dial_params.rb', line 268

optional :sip_transport_protocol, enum: -> { Telnyx::CallDialParams::SipTransportProtocol }

#sound_modificationsTelnyx::Models::SoundModifications?

Use this field to modify sound effects, for example adjust the pitch.



274
# File 'lib/telnyx/models/call_dial_params.rb', line 274

optional :sound_modifications, -> { Telnyx::SoundModifications }

#stream_bidirectional_codecSymbol, ...

Indicates codec for bidirectional streaming RTP payloads. Used only with stream_bidirectional_mode=rtp. Case sensitive.



281
# File 'lib/telnyx/models/call_dial_params.rb', line 281

optional :stream_bidirectional_codec, enum: -> { Telnyx::StreamBidirectionalCodec }

#stream_bidirectional_modeSymbol, ...

Configures method of bidirectional streaming (mp3, rtp).

Returns:



287
# File 'lib/telnyx/models/call_dial_params.rb', line 287

optional :stream_bidirectional_mode, enum: -> { Telnyx::StreamBidirectionalMode }

#stream_bidirectional_sampling_rateInteger, ...

Audio sampling rate.



293
# File 'lib/telnyx/models/call_dial_params.rb', line 293

optional :stream_bidirectional_sampling_rate, enum: -> { Telnyx::StreamBidirectionalSamplingRate }

#stream_bidirectional_target_legsSymbol, ...

Specifies which call legs should receive the bidirectional stream audio.



299
# File 'lib/telnyx/models/call_dial_params.rb', line 299

optional :stream_bidirectional_target_legs, enum: -> { Telnyx::StreamBidirectionalTargetLegs }

#stream_codecSymbol, ...

Specifies the codec to be used for the streamed audio. When set to ‘default’ or when transcoding is not possible, the codec from the call will be used.

Returns:



306
# File 'lib/telnyx/models/call_dial_params.rb', line 306

optional :stream_codec, enum: -> { Telnyx::StreamCodec }

#stream_establish_before_call_originateBoolean?

Establish websocket connection before dialing the destination. This is useful for cases where the websocket connection takes a long time to establish.

Returns:

  • (Boolean, nil)


313
# File 'lib/telnyx/models/call_dial_params.rb', line 313

optional :stream_establish_before_call_originate, Telnyx::Internal::Type::Boolean

#stream_trackSymbol, ...

Specifies which track should be streamed.



319
# File 'lib/telnyx/models/call_dial_params.rb', line 319

optional :stream_track, enum: -> { Telnyx::CallDialParams::StreamTrack }

#stream_urlString?

The destination WebSocket address where the stream is going to be delivered.

Returns:

  • (String, nil)


325
# File 'lib/telnyx/models/call_dial_params.rb', line 325

optional :stream_url, String

#supervise_call_control_idString?

The call leg which will be supervised by the new call.

Returns:

  • (String, nil)


331
# File 'lib/telnyx/models/call_dial_params.rb', line 331

optional :supervise_call_control_id, String

#supervisor_roleSymbol, ...

The role of the supervisor call. ‘barge’ means that supervisor call hears and is being heard by both ends of the call (caller & callee). ‘whisper’ means that only supervised_call_control_id hears supervisor but supervisor can hear everything. ‘monitor’ means that nobody can hear supervisor call, but supervisor can hear everything on the call.



341
# File 'lib/telnyx/models/call_dial_params.rb', line 341

optional :supervisor_role, enum: -> { Telnyx::CallDialParams::SupervisorRole }

#time_limit_secsInteger?

Sets the maximum duration of a Call Control Leg in seconds. If the time limit is reached, the call will hangup and a ‘call.hangup` webhook with a `hangup_cause` of `time_limit` will be sent. For example, by setting a time limit of 120 seconds, a Call Leg will be automatically terminated two minutes after being answered. The default time limit is 14400 seconds or 4 hours and this is also the maximum allowed call length.

Returns:

  • (Integer, nil)


352
# File 'lib/telnyx/models/call_dial_params.rb', line 352

optional :time_limit_secs, Integer

#timeout_secsInteger?

The number of seconds that Telnyx will wait for the call to be answered by the destination to which it is being called. If the timeout is reached before an answer is received, the call will hangup and a ‘call.hangup` webhook with a `hangup_cause` of `timeout` will be sent. Minimum value is 5 seconds. Maximum value is 600 seconds.

Returns:

  • (Integer, nil)


362
# File 'lib/telnyx/models/call_dial_params.rb', line 362

optional :timeout_secs, Integer

#toString+

The DID or SIP URI to dial out to. Multiple DID or SIP URIs can be provided using an array of strings

Returns:

  • (String, Array<String>)


29
# File 'lib/telnyx/models/call_dial_params.rb', line 29

required :to, union: -> { Telnyx::CallDialParams::To }

#transcriptionBoolean?

Enable transcription upon call answer. The default value is false.

Returns:

  • (Boolean, nil)


368
# File 'lib/telnyx/models/call_dial_params.rb', line 368

optional :transcription, Telnyx::Internal::Type::Boolean

#transcription_configTelnyx::Models::Calls::TranscriptionStartRequest?



373
# File 'lib/telnyx/models/call_dial_params.rb', line 373

optional :transcription_config, -> { Telnyx::Calls::TranscriptionStartRequest }

#webhook_urlString?

Use this field to override the URL for which Telnyx will send subsequent webhooks to for this call.

Returns:

  • (String, nil)


380
# File 'lib/telnyx/models/call_dial_params.rb', line 380

optional :webhook_url, String

#webhook_url_methodSymbol, ...

HTTP request type used for ‘webhook_url`.



386
# File 'lib/telnyx/models/call_dial_params.rb', line 386

optional :webhook_url_method, enum: -> { Telnyx::CallDialParams::WebhookURLMethod }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_dial_params.rb', line 542