Module: Telnyx::Models::CallDialParams::AnsweringMachineDetection
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/call_dial_params.rb,
sig/telnyx/models/call_dial_params.rbs
Overview
Enables Answering Machine Detection. Telnyx offers Premium and Standard
detections. With Premium detection, when a call is answered, Telnyx runs
real-time detection and sends a call.machine.premium.detection.ended webhook
with one of the following results: human_residence, human_business,
machine, silence or fax_detected. If we detect a beep, we also send a
call.machine.premium.greeting.ended webhook with the result of
beep_detected. If we detect a beep before
call.machine.premium.detection.ended we only send
call.machine.premium.greeting.ended, and if we detect a beep after
call.machine.premium.detection.ended, we send both webhooks. With Standard
detection, when a call is answered, Telnyx runs real-time detection to determine
if it was picked up by a human or a machine and sends an
call.machine.detection.ended webhook with the analysis result. If
greeting_end or detect_words is used and a machine is detected, you will
receive another call.machine.greeting.ended webhook when the answering machine
greeting ends with a beep or silence. If detect_beep is used, you will only
receive call.machine.greeting.ended if a beep is detected.
Constant Summary collapse
- PREMIUM =
:premium- DETECT =
:detect- DETECT_BEEP =
:detect_beep- DETECT_WORDS =
:detect_words- GREETING_END =
:greeting_end- DISABLED =
:disabled
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::CallDialParams::answering_machine_detection]
536 |
# File 'sig/telnyx/models/call_dial_params.rbs', line 536
def self?.values: -> ::Array[Telnyx::Models::CallDialParams::answering_machine_detection]
|