Class: Telnyx::Models::CallDialParams::AnsweringMachineDetectionConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallDialParams::AnsweringMachineDetectionConfig
- Defined in:
- lib/telnyx/models/call_dial_params.rb,
sig/telnyx/models/call_dial_params.rbs
Defined Under Namespace
Modules: BeepDetectionProfile
Instance Attribute Summary collapse
-
#after_greeting_silence_millis ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human.
-
#beep_detection_profile ⇒ Symbol, ...
Selects which detectors must validate a beep.
-
#between_words_silence_millis ⇒ Integer?
Maximum threshold for silence between words.
-
#greeting_duration_millis ⇒ Integer?
Maximum threshold of a human greeting.
-
#greeting_silence_duration_millis ⇒ Integer?
If machine already detected, maximum threshold for silence between words.
-
#greeting_total_analysis_time_millis ⇒ Integer?
If machine already detected, maximum timeout threshold to determine the end of the machine greeting.
-
#initial_silence_millis ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine.
-
#maximum_number_of_words ⇒ Integer?
If number of detected words is greater than this value, consder it a machine.
-
#maximum_word_length_millis ⇒ Integer?
If a single word lasts longer than this threshold, consider it a machine.
-
#silence_threshold ⇒ Integer?
Minimum noise threshold for any analysis.
-
#total_analysis_time_millis ⇒ Integer?
Maximum timeout threshold for overall detection.
Instance Method Summary collapse
-
#initialize(after_greeting_silence_millis: nil, beep_detection_profile: nil, between_words_silence_millis: nil, greeting_duration_millis: nil, greeting_silence_duration_millis: nil, greeting_total_analysis_time_millis: nil, initial_silence_millis: nil, maximum_number_of_words: nil, maximum_word_length_millis: nil, silence_threshold: nil, total_analysis_time_millis: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AnsweringMachineDetectionConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after_greeting_silence_millis: nil, beep_detection_profile: nil, between_words_silence_millis: nil, greeting_duration_millis: nil, greeting_silence_duration_millis: nil, greeting_total_analysis_time_millis: nil, initial_silence_millis: nil, maximum_number_of_words: nil, maximum_word_length_millis: nil, silence_threshold: nil, total_analysis_time_millis: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallDialParams::AnsweringMachineDetectionConfig for more details.
Optional configuration parameters to modify 'answering_machine_detection'
performance. Only total_analysis_time_millis and greeting_duration_millis
parameters are applicable when premium is selected as
answering_machine_detection.
|
|
# File 'lib/telnyx/models/call_dial_params.rb', line 775
|
Instance Attribute Details
#after_greeting_silence_millis ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human.
707 |
# File 'lib/telnyx/models/call_dial_params.rb', line 707 optional :after_greeting_silence_millis, Integer |
#beep_detection_profile ⇒ Symbol, ...
Selects which detectors must validate a beep. both requires the amplitude and
frequency detectors to agree. freq_only uses the frequency detector alone, for
beeps whose volume is too unsteady for the default profile.
715 716 |
# File 'lib/telnyx/models/call_dial_params.rb', line 715 optional :beep_detection_profile, enum: -> { Telnyx::CallDialParams::AnsweringMachineDetectionConfig::BeepDetectionProfile } |
#between_words_silence_millis ⇒ Integer?
Maximum threshold for silence between words.
722 |
# File 'lib/telnyx/models/call_dial_params.rb', line 722 optional :between_words_silence_millis, Integer |
#greeting_duration_millis ⇒ Integer?
Maximum threshold of a human greeting. If greeting longer than this value, considered machine.
729 |
# File 'lib/telnyx/models/call_dial_params.rb', line 729 optional :greeting_duration_millis, Integer |
#greeting_silence_duration_millis ⇒ Integer?
If machine already detected, maximum threshold for silence between words. If exceeded, the greeting is considered ended.
736 |
# File 'lib/telnyx/models/call_dial_params.rb', line 736 optional :greeting_silence_duration_millis, Integer |
#greeting_total_analysis_time_millis ⇒ Integer?
If machine already detected, maximum timeout threshold to determine the end of the machine greeting.
743 |
# File 'lib/telnyx/models/call_dial_params.rb', line 743 optional :greeting_total_analysis_time_millis, Integer |
#initial_silence_millis ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine.
749 |
# File 'lib/telnyx/models/call_dial_params.rb', line 749 optional :initial_silence_millis, Integer |
#maximum_number_of_words ⇒ Integer?
If number of detected words is greater than this value, consder it a machine.
755 |
# File 'lib/telnyx/models/call_dial_params.rb', line 755 optional :maximum_number_of_words, Integer |
#maximum_word_length_millis ⇒ Integer?
If a single word lasts longer than this threshold, consider it a machine.
761 |
# File 'lib/telnyx/models/call_dial_params.rb', line 761 optional :maximum_word_length_millis, Integer |
#silence_threshold ⇒ Integer?
Minimum noise threshold for any analysis.
767 |
# File 'lib/telnyx/models/call_dial_params.rb', line 767 optional :silence_threshold, Integer |
#total_analysis_time_millis ⇒ Integer?
Maximum timeout threshold for overall detection.
773 |
# File 'lib/telnyx/models/call_dial_params.rb', line 773 optional :total_analysis_time_millis, Integer |
Instance Method Details
#to_hash ⇒ {
631 |
# File 'sig/telnyx/models/call_dial_params.rbs', line 631
def to_hash: -> {
|