Class: Telnyx::Models::CallDialParams::ConferenceConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallDialParams::ConferenceConfig
- Defined in:
- lib/telnyx/models/call_dial_params.rb,
sig/telnyx/models/call_dial_params.rbs
Defined Under Namespace
Modules: BeepEnabled, SupervisorRole
Instance Attribute Summary collapse
-
#beep_enabled ⇒ Symbol, ...
Whether a beep sound should be played when the participant joins and/or leaves the conference.
-
#conference_name ⇒ String?
Conference name to be joined.
-
#early_media ⇒ Boolean?
Controls the moment when dialled call is joined into conference.
-
#end_conference_on_exit ⇒ Boolean?
Whether the conference should end and all remaining participants be hung up after the participant leaves the conference.
-
#hold ⇒ Boolean?
Whether the participant should be put on hold immediately after joining the conference.
-
#hold_audio_url ⇒ String?
The URL of a file to be played to the participant when they are put on hold after joining the conference.
-
#hold_media_name ⇒ String?
The media_name of a file to be played to the participant when they are put on hold after joining the conference.
-
#id ⇒ String?
Conference ID to be joined.
-
#mute ⇒ Boolean?
Whether the participant should be muted immediately after joining the conference.
-
#soft_end_conference_on_exit ⇒ Boolean?
Whether the conference should end after the participant leaves the conference.
-
#start_conference_on_create ⇒ Boolean?
Whether the conference should be started on creation.
-
#start_conference_on_enter ⇒ Boolean?
Whether the conference should be started after the participant joins the conference.
-
#supervisor_role ⇒ Symbol, ...
Sets the joining participant as a supervisor for the conference.
-
#whisper_call_control_ids ⇒ Array<String>?
Array of unique call_control_ids the joining supervisor can whisper to.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, beep_enabled: nil, conference_name: nil, early_media: nil, end_conference_on_exit: nil, hold: nil, hold_audio_url: nil, hold_media_name: nil, mute: nil, soft_end_conference_on_exit: nil, start_conference_on_create: nil, start_conference_on_enter: nil, supervisor_role: nil, whisper_call_control_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConferenceConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, beep_enabled: nil, conference_name: nil, early_media: nil, end_conference_on_exit: nil, hold: nil, hold_audio_url: nil, hold_media_name: nil, mute: nil, soft_end_conference_on_exit: nil, start_conference_on_create: nil, start_conference_on_enter: nil, supervisor_role: nil, whisper_call_control_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallDialParams::ConferenceConfig for more details.
Optional configuration parameters to dial new participant into a conference.
|
|
# File 'lib/telnyx/models/call_dial_params.rb', line 882
|
Instance Attribute Details
#beep_enabled ⇒ Symbol, ...
Whether a beep sound should be played when the participant joins and/or leaves the conference. Can be used to override the conference-level setting.
784 |
# File 'lib/telnyx/models/call_dial_params.rb', line 784 optional :beep_enabled, enum: -> { Telnyx::CallDialParams::ConferenceConfig::BeepEnabled } |
#conference_name ⇒ String?
Conference name to be joined
790 |
# File 'lib/telnyx/models/call_dial_params.rb', line 790 optional :conference_name, String |
#early_media ⇒ Boolean?
Controls the moment when dialled call is joined into conference. If set to
true user will be joined as soon as media is available (ringback). If false
user will be joined when call is answered. Defaults to true
798 |
# File 'lib/telnyx/models/call_dial_params.rb', line 798 optional :early_media, Telnyx::Internal::Type::Boolean |
#end_conference_on_exit ⇒ Boolean?
Whether the conference should end and all remaining participants be hung up after the participant leaves the conference. Defaults to "false".
805 |
# File 'lib/telnyx/models/call_dial_params.rb', line 805 optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean |
#hold ⇒ Boolean?
Whether the participant should be put on hold immediately after joining the conference. Defaults to "false".
812 |
# File 'lib/telnyx/models/call_dial_params.rb', line 812 optional :hold, Telnyx::Internal::Type::Boolean |
#hold_audio_url ⇒ String?
The URL of a file to be played to the participant when they are put on hold after joining the conference. hold_media_name and hold_audio_url cannot be used together in one request. Takes effect only when "start_conference_on_create" is set to "false". This property takes effect only if "hold" is set to "true".
821 |
# File 'lib/telnyx/models/call_dial_params.rb', line 821 optional :hold_audio_url, String |
#hold_media_name ⇒ String?
The media_name of a file to be played to the participant when they are put on hold after joining the conference. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file. Takes effect only when "start_conference_on_create" is set to "false". This property takes effect only if "hold" is set to "true".
832 |
# File 'lib/telnyx/models/call_dial_params.rb', line 832 optional :hold_media_name, String |
#id ⇒ String?
Conference ID to be joined
777 |
# File 'lib/telnyx/models/call_dial_params.rb', line 777 optional :id, String |
#mute ⇒ Boolean?
Whether the participant should be muted immediately after joining the conference. Defaults to "false".
839 |
# File 'lib/telnyx/models/call_dial_params.rb', line 839 optional :mute, Telnyx::Internal::Type::Boolean |
#soft_end_conference_on_exit ⇒ Boolean?
Whether the conference should end after the participant leaves the conference. NOTE this doesn't hang up the other participants. Defaults to "false".
846 |
# File 'lib/telnyx/models/call_dial_params.rb', line 846 optional :soft_end_conference_on_exit, Telnyx::Internal::Type::Boolean |
#start_conference_on_create ⇒ Boolean?
Whether the conference should be started on creation. If the conference isn't started all participants that join are automatically put on hold. Defaults to "true".
854 |
# File 'lib/telnyx/models/call_dial_params.rb', line 854 optional :start_conference_on_create, Telnyx::Internal::Type::Boolean |
#start_conference_on_enter ⇒ Boolean?
Whether the conference should be started after the participant joins the conference. Defaults to "false".
861 |
# File 'lib/telnyx/models/call_dial_params.rb', line 861 optional :start_conference_on_enter, Telnyx::Internal::Type::Boolean |
#supervisor_role ⇒ Symbol, ...
Sets the joining participant as a supervisor for the conference. A conference can have multiple supervisors. "barge" means the supervisor enters the conference as a normal participant. This is the same as "none". "monitor" means the supervisor is muted but can hear all participants. "whisper" means that only the specified "whisper_call_control_ids" can hear the supervisor. Defaults to "none".
872 |
# File 'lib/telnyx/models/call_dial_params.rb', line 872 optional :supervisor_role, enum: -> { Telnyx::CallDialParams::ConferenceConfig::SupervisorRole } |
#whisper_call_control_ids ⇒ Array<String>?
Array of unique call_control_ids the joining supervisor can whisper to. If none provided, the supervisor will join the conference as a monitoring participant only.
880 |
# File 'lib/telnyx/models/call_dial_params.rb', line 880 optional :whisper_call_control_ids, Telnyx::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/call_dial_params.rb', line 928
|
Instance Method Details
#to_hash ⇒ {
717 |
# File 'sig/telnyx/models/call_dial_params.rbs', line 717
def to_hash: -> {
|