Class: Telnyx::Models::CallDialParams::ConferenceConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/call_dial_params.rb

Defined Under Namespace

Modules: BeepEnabled, SupervisorRole

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, beep_enabled: nil, conference_name: nil, early_media: nil, end_conference_on_exit: nil, hold: nil, hold_audio_url: nil, hold_media_name: nil, mute: nil, soft_end_conference_on_exit: nil, start_conference_on_create: nil, start_conference_on_enter: nil, supervisor_role: nil, whisper_call_control_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::CallDialParams::ConferenceConfig for more details.

Optional configuration parameters to dial new participant into a conference.

Parameters:

  • id (String) (defaults to: nil)

    Conference ID to be joined

  • beep_enabled (Symbol, Telnyx::Models::CallDialParams::ConferenceConfig::BeepEnabled) (defaults to: nil)

    Whether a beep sound should be played when the participant joins and/or leaves t

  • conference_name (String) (defaults to: nil)

    Conference name to be joined

  • early_media (Boolean) (defaults to: nil)

    Controls the moment when dialled call is joined into conference. If set to ‘true

  • end_conference_on_exit (Boolean) (defaults to: nil)

    Whether the conference should end and all remaining participants be hung up afte

  • hold (Boolean) (defaults to: nil)

    Whether the participant should be put on hold immediately after joining the conf

  • hold_audio_url (String) (defaults to: nil)

    The URL of a file to be played to the participant when they are put on hold afte

  • hold_media_name (String) (defaults to: nil)

    The media_name of a file to be played to the participant when they are put on ho

  • mute (Boolean) (defaults to: nil)

    Whether the participant should be muted immediately after joining the conference

  • soft_end_conference_on_exit (Boolean) (defaults to: nil)

    Whether the conference should end after the participant leaves the conference. N

  • start_conference_on_create (Boolean) (defaults to: nil)

    Whether the conference should be started on creation. If the conference isn’t st

  • start_conference_on_enter (Boolean) (defaults to: nil)

    Whether the conference should be started after the participant joins the confere

  • supervisor_role (Symbol, Telnyx::Models::CallDialParams::ConferenceConfig::SupervisorRole) (defaults to: nil)

    Sets the joining participant as a supervisor for the conference. A conference ca

  • whisper_call_control_ids (Array<String>) (defaults to: nil)

    Array of unique call_control_ids the joining supervisor can whisper to. If none



# File 'lib/telnyx/models/call_dial_params.rb', line 829

Instance Attribute Details

#beep_enabledSymbol, ...

Whether a beep sound should be played when the participant joins and/or leaves the conference. Can be used to override the conference-level setting.



731
# File 'lib/telnyx/models/call_dial_params.rb', line 731

optional :beep_enabled, enum: -> { Telnyx::CallDialParams::ConferenceConfig::BeepEnabled }

#conference_nameString?

Conference name to be joined

Returns:

  • (String, nil)


737
# File 'lib/telnyx/models/call_dial_params.rb', line 737

optional :conference_name, String

#early_mediaBoolean?

Controls the moment when dialled call is joined into conference. If set to ‘true` user will be joined as soon as media is available (ringback). If `false` user will be joined when call is answered. Defaults to `true`

Returns:

  • (Boolean, nil)


745
# File 'lib/telnyx/models/call_dial_params.rb', line 745

optional :early_media, Telnyx::Internal::Type::Boolean

#end_conference_on_exitBoolean?

Whether the conference should end and all remaining participants be hung up after the participant leaves the conference. Defaults to “false”.

Returns:

  • (Boolean, nil)


752
# File 'lib/telnyx/models/call_dial_params.rb', line 752

optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean

#holdBoolean?

Whether the participant should be put on hold immediately after joining the conference. Defaults to “false”.

Returns:

  • (Boolean, nil)


759
# File 'lib/telnyx/models/call_dial_params.rb', line 759

optional :hold, Telnyx::Internal::Type::Boolean

#hold_audio_urlString?

The URL of a file to be played to the participant when they are put on hold after joining the conference. hold_media_name and hold_audio_url cannot be used together in one request. Takes effect only when “start_conference_on_create” is set to “false”. This property takes effect only if “hold” is set to “true”.

Returns:

  • (String, nil)


768
# File 'lib/telnyx/models/call_dial_params.rb', line 768

optional :hold_audio_url, String

#hold_media_nameString?

The media_name of a file to be played to the participant when they are put on hold after joining the conference. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file. Takes effect only when “start_conference_on_create” is set to “false”. This property takes effect only if “hold” is set to “true”.

Returns:

  • (String, nil)


779
# File 'lib/telnyx/models/call_dial_params.rb', line 779

optional :hold_media_name, String

#idString?

Conference ID to be joined

Returns:

  • (String, nil)


724
# File 'lib/telnyx/models/call_dial_params.rb', line 724

optional :id, String

#muteBoolean?

Whether the participant should be muted immediately after joining the conference. Defaults to “false”.

Returns:

  • (Boolean, nil)


786
# File 'lib/telnyx/models/call_dial_params.rb', line 786

optional :mute, Telnyx::Internal::Type::Boolean

#soft_end_conference_on_exitBoolean?

Whether the conference should end after the participant leaves the conference. NOTE this doesn’t hang up the other participants. Defaults to “false”.

Returns:

  • (Boolean, nil)


793
# File 'lib/telnyx/models/call_dial_params.rb', line 793

optional :soft_end_conference_on_exit, Telnyx::Internal::Type::Boolean

#start_conference_on_createBoolean?

Whether the conference should be started on creation. If the conference isn’t started all participants that join are automatically put on hold. Defaults to “true”.

Returns:

  • (Boolean, nil)


801
# File 'lib/telnyx/models/call_dial_params.rb', line 801

optional :start_conference_on_create, Telnyx::Internal::Type::Boolean

#start_conference_on_enterBoolean?

Whether the conference should be started after the participant joins the conference. Defaults to “false”.

Returns:

  • (Boolean, nil)


808
# File 'lib/telnyx/models/call_dial_params.rb', line 808

optional :start_conference_on_enter, Telnyx::Internal::Type::Boolean

#supervisor_roleSymbol, ...

Sets the joining participant as a supervisor for the conference. A conference can have multiple supervisors. “barge” means the supervisor enters the conference as a normal participant. This is the same as “none”. “monitor” means the supervisor is muted but can hear all participants. “whisper” means that only the specified “whisper_call_control_ids” can hear the supervisor. Defaults to “none”.



819
# File 'lib/telnyx/models/call_dial_params.rb', line 819

optional :supervisor_role, enum: -> { Telnyx::CallDialParams::ConferenceConfig::SupervisorRole }

#whisper_call_control_idsArray<String>?

Array of unique call_control_ids the joining supervisor can whisper to. If none provided, the supervisor will join the conference as a monitoring participant only.

Returns:

  • (Array<String>, nil)


827
# File 'lib/telnyx/models/call_dial_params.rb', line 827

optional :whisper_call_control_ids, Telnyx::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/call_dial_params.rb', line 875