Class: Telnyx::Models::CallDialParams::DeepfakeDetection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallDialParams::DeepfakeDetection
- Defined in:
- lib/telnyx/models/call_dial_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Whether deepfake detection is enabled.
-
#rtp_timeout ⇒ Integer?
Maximum time in seconds to wait for RTP audio before timing out.
-
#timeout ⇒ Integer?
Maximum time in seconds to wait for a detection result before timing out.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#enabled ⇒ Boolean
Whether deepfake detection is enabled.
905 |
# File 'lib/telnyx/models/call_dial_params.rb', line 905 required :enabled, Telnyx::Internal::Type::Boolean |
#rtp_timeout ⇒ Integer?
Maximum time in seconds to wait for RTP audio before timing out. If no audio is received within this window, detection stops with an error.
912 |
# File 'lib/telnyx/models/call_dial_params.rb', line 912 optional :rtp_timeout, Integer |
#timeout ⇒ Integer?
Maximum time in seconds to wait for a detection result before timing out.
918 |
# File 'lib/telnyx/models/call_dial_params.rb', line 918 optional :timeout, Integer |