Module: Telnyx::Models::CallDialParams::SupervisorRole
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/call_dial_params.rb,
sig/telnyx/models/call_dial_params.rbs
Overview
The role of the supervisor call. 'barge' means that supervisor call hears and is being heard by both ends of the call (caller & callee). 'whisper' means that only supervised_call_control_id hears supervisor but supervisor can hear everything. 'monitor' means that nobody can hear supervisor call, but supervisor can hear everything on the call.
Constant Summary collapse
- BARGE =
:barge- WHISPER =
:whisper- MONITOR =
:monitor
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::CallDialParams::supervisor_role]
912 |
# File 'sig/telnyx/models/call_dial_params.rbs', line 912
def self?.values: -> ::Array[Telnyx::Models::CallDialParams::supervisor_role]
|