Class: Telnyx::Models::CallHangup::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallHangup::Payload
- Defined in:
- lib/telnyx/models/call_hangup.rb
Overview
Defined Under Namespace
Modules: HangupCause, HangupSource, State Classes: CallQualityStats
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_quality_stats ⇒ Telnyx::Models::CallHangup::Payload::CallQualityStats?
Call quality statistics aggregated from the CHANNEL_HANGUP_COMPLETE event.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers set on answer command.
-
#from ⇒ String?
Number or SIP URI placing the call.
-
#hangup_cause ⇒ Symbol, ...
The reason the call was ended (‘call_rejected`, `normal_clearing`, `originator_cancel`, `timeout`, `time_limit`, `user_busy`, `not_found`, `no_answer` or `unspecified`).
-
#hangup_source ⇒ Symbol, ...
The party who ended the call (‘callee`, `caller`, `unknown`).
-
#sip_hangup_cause ⇒ String?
The reason the call was ended (SIP response code).
-
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
User-to-User and Diversion headers from sip invite.
-
#start_time ⇒ Time?
ISO 8601 datetime of when the call started.
-
#state ⇒ Symbol, ...
State received from a command.
-
#tags ⇒ Array<String>?
Array of tags associated to number.
-
#to ⇒ String?
Destination number or SIP URI of the call.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(packet_count: nil, skip_packet_count: nil) ⇒ Object
constructor
Outbound call quality statistics.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(packet_count: nil, skip_packet_count: nil) ⇒ Object
Outbound call quality statistics.
|
|
# File 'lib/telnyx/models/call_hangup.rb', line 163
|
Instance Attribute Details
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
64 |
# File 'lib/telnyx/models/call_hangup.rb', line 64 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
70 |
# File 'lib/telnyx/models/call_hangup.rb', line 70 optional :call_leg_id, String |
#call_quality_stats ⇒ Telnyx::Models::CallHangup::Payload::CallQualityStats?
Call quality statistics aggregated from the CHANNEL_HANGUP_COMPLETE event. Only includes metrics that are available (filters out nil values). Returns nil if no metrics are available.
78 |
# File 'lib/telnyx/models/call_hangup.rb', line 78 optional :call_quality_stats, -> { Telnyx::CallHangup::Payload::CallQualityStats }, nil?: true |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
86 |
# File 'lib/telnyx/models/call_hangup.rb', line 86 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command.
92 |
# File 'lib/telnyx/models/call_hangup.rb', line 92 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
98 |
# File 'lib/telnyx/models/call_hangup.rb', line 98 optional :connection_id, String |
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers set on answer command
104 |
# File 'lib/telnyx/models/call_hangup.rb', line 104 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] } |
#from ⇒ String?
Number or SIP URI placing the call.
110 |
# File 'lib/telnyx/models/call_hangup.rb', line 110 optional :from, String |
#hangup_cause ⇒ Symbol, ...
The reason the call was ended (‘call_rejected`, `normal_clearing`, `originator_cancel`, `timeout`, `time_limit`, `user_busy`, `not_found`, `no_answer` or `unspecified`).
118 |
# File 'lib/telnyx/models/call_hangup.rb', line 118 optional :hangup_cause, enum: -> { Telnyx::CallHangup::Payload::HangupCause } |
#hangup_source ⇒ Symbol, ...
The party who ended the call (‘callee`, `caller`, `unknown`).
124 |
# File 'lib/telnyx/models/call_hangup.rb', line 124 optional :hangup_source, enum: -> { Telnyx::CallHangup::Payload::HangupSource } |
#sip_hangup_cause ⇒ String?
The reason the call was ended (SIP response code). If the SIP response is unavailable (in inbound calls for example) this is set to ‘unspecified`.
131 |
# File 'lib/telnyx/models/call_hangup.rb', line 131 optional :sip_hangup_cause, String |
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
User-to-User and Diversion headers from sip invite.
137 |
# File 'lib/telnyx/models/call_hangup.rb', line 137 optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] } |
#start_time ⇒ Time?
ISO 8601 datetime of when the call started.
143 |
# File 'lib/telnyx/models/call_hangup.rb', line 143 optional :start_time, Time |
#state ⇒ Symbol, ...
State received from a command.
149 |
# File 'lib/telnyx/models/call_hangup.rb', line 149 optional :state, enum: -> { Telnyx::CallHangup::Payload::State } |
#tags ⇒ Array<String>?
Array of tags associated to number.
155 |
# File 'lib/telnyx/models/call_hangup.rb', line 155 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#to ⇒ String?
Destination number or SIP URI of the call.
161 |
# File 'lib/telnyx/models/call_hangup.rb', line 161 optional :to, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/call_hangup.rb', line 309
|