Class: Telnyx::Models::CallInitiated::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallInitiated::Payload
- Defined in:
- lib/telnyx/models/call_initiated.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_screening_result ⇒ String?
Call screening result.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#caller_id_name ⇒ String?
Caller id.
-
#client_state ⇒ String?
State received from a command.
-
#connection_codecs ⇒ String?
The list of comma-separated codecs enabled for the connection.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers from sip invite.
-
#direction ⇒ Symbol, ...
Whether the call is ‘incoming` or `outgoing`.
-
#from ⇒ String?
Number or SIP URI placing the call.
-
#offered_codecs ⇒ String?
The list of comma-separated codecs offered by caller.
-
#shaken_stir_attestation ⇒ String?
SHAKEN/STIR attestation level.
-
#shaken_stir_validated ⇒ Boolean?
Whether attestation was successfully validated or not.
-
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
User-to-User and Diversion headers from sip invite.
-
#start_time ⇒ Time?
ISO 8601 datetime of when the call started.
-
#state ⇒ Symbol, ...
State received from a command.
-
#tags ⇒ Array<String>?
Array of tags associated to number.
-
#to ⇒ String?
Destination number or SIP URI of the call.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(call_control_id: nil, call_leg_id: nil, call_screening_result: nil, call_session_id: nil, caller_id_name: nil, client_state: nil, connection_codecs: nil, connection_id: nil, custom_headers: nil, direction: nil, from: nil, offered_codecs: nil, shaken_stir_attestation: nil, shaken_stir_validated: nil, sip_headers: nil, start_time: nil, state: nil, tags: nil, to: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id: nil, call_leg_id: nil, call_screening_result: nil, call_session_id: nil, caller_id_name: nil, client_state: nil, connection_codecs: nil, connection_id: nil, custom_headers: nil, direction: nil, from: nil, offered_codecs: nil, shaken_stir_attestation: nil, shaken_stir_validated: nil, sip_headers: nil, start_time: nil, state: nil, tags: nil, to: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallInitiated::Payload for more details.
|
|
# File 'lib/telnyx/models/call_initiated.rb', line 176
|
Instance Attribute Details
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
64 |
# File 'lib/telnyx/models/call_initiated.rb', line 64 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
70 |
# File 'lib/telnyx/models/call_initiated.rb', line 70 optional :call_leg_id, String |
#call_screening_result ⇒ String?
Call screening result.
76 |
# File 'lib/telnyx/models/call_initiated.rb', line 76 optional :call_screening_result, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
84 |
# File 'lib/telnyx/models/call_initiated.rb', line 84 optional :call_session_id, String |
#caller_id_name ⇒ String?
Caller id.
90 |
# File 'lib/telnyx/models/call_initiated.rb', line 90 optional :caller_id_name, String |
#client_state ⇒ String?
State received from a command.
96 |
# File 'lib/telnyx/models/call_initiated.rb', line 96 optional :client_state, String |
#connection_codecs ⇒ String?
The list of comma-separated codecs enabled for the connection.
102 |
# File 'lib/telnyx/models/call_initiated.rb', line 102 optional :connection_codecs, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
108 |
# File 'lib/telnyx/models/call_initiated.rb', line 108 optional :connection_id, String |
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers from sip invite
114 |
# File 'lib/telnyx/models/call_initiated.rb', line 114 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] } |
#direction ⇒ Symbol, ...
Whether the call is ‘incoming` or `outgoing`.
120 |
# File 'lib/telnyx/models/call_initiated.rb', line 120 optional :direction, enum: -> { Telnyx::CallInitiated::Payload::Direction } |
#from ⇒ String?
Number or SIP URI placing the call.
126 |
# File 'lib/telnyx/models/call_initiated.rb', line 126 optional :from, String |
#offered_codecs ⇒ String?
The list of comma-separated codecs offered by caller.
132 |
# File 'lib/telnyx/models/call_initiated.rb', line 132 optional :offered_codecs, String |
#shaken_stir_attestation ⇒ String?
SHAKEN/STIR attestation level.
138 |
# File 'lib/telnyx/models/call_initiated.rb', line 138 optional :shaken_stir_attestation, String |
#shaken_stir_validated ⇒ Boolean?
Whether attestation was successfully validated or not.
144 |
# File 'lib/telnyx/models/call_initiated.rb', line 144 optional :shaken_stir_validated, Telnyx::Internal::Type::Boolean |
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
User-to-User and Diversion headers from sip invite.
150 |
# File 'lib/telnyx/models/call_initiated.rb', line 150 optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] } |
#start_time ⇒ Time?
ISO 8601 datetime of when the call started.
156 |
# File 'lib/telnyx/models/call_initiated.rb', line 156 optional :start_time, Time |
#state ⇒ Symbol, ...
State received from a command.
162 |
# File 'lib/telnyx/models/call_initiated.rb', line 162 optional :state, enum: -> { Telnyx::CallInitiated::Payload::State } |
#tags ⇒ Array<String>?
Array of tags associated to number.
168 |
# File 'lib/telnyx/models/call_initiated.rb', line 168 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#to ⇒ String?
Destination number or SIP URI of the call.
174 |
# File 'lib/telnyx/models/call_initiated.rb', line 174 optional :to, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/call_initiated.rb', line 227
|