Class: Telnyx::Models::CallPaymentCompletedWebhookEvent::Data::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallPaymentCompletedWebhookEvent::Data::Payload
- Defined in:
- lib/telnyx/models/call_payment_completed_webhook_event.rb,
sig/telnyx/models/call_payment_completed_webhook_event.rbs
Overview
Defined Under Namespace
Modules: ConnectorError, PaymentCardType, PaymentMethod, Result
Instance Attribute Summary collapse
-
#bank_account_number ⇒ String?
Masked bank account number with only the last two digits visible.
-
#bank_account_type ⇒ String?
Bank account type, when available.
-
#bank_routing_number ⇒ String?
Bank routing number collected from the caller.
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID unique to the call leg.
-
#call_session_id ⇒ String?
ID shared by related call legs in the same call session.
-
#charge_id ⇒ String?
Charge identifier returned for a successful charge transaction.
-
#client_state ⇒ String?
Base64-encoded state received from the command.
-
#connection_id ⇒ String?
Call Control App ID used in the call.
-
#connector_error ⇒ String, ...
Additional connector error information, when supplied by the processor.
-
#expiration_date ⇒ String?
Card expiration date in MMYY format.
-
#from ⇒ String?
Number or SIP URI placing the call.
-
#pay_error_code ⇒ String?
Error code returned by the payment connector or processor.
-
#payment_card_number ⇒ String?
Masked card number with only the last four digits visible.
-
#payment_card_postal_code ⇒ String?
Billing postal code collected from the caller.
-
#payment_card_type ⇒ Symbol, ...
Detected card type.
-
#payment_confirmation_code ⇒ String?
Payment confirmation code returned by the processor, when available.
-
#payment_connector ⇒ String?
Name of the Pay connector used.
-
#payment_error ⇒ String?
Step-level or processor error associated with the final result.
-
#payment_method ⇒ Symbol, ...
Payment method being collected.
-
#result ⇒ Symbol, ...
Final Pay session result.
-
#security_code ⇒ String?
Fully masked card security code.
-
#to ⇒ String?
Destination number or SIP URI of the call.
-
#token_id ⇒ String?
Token identifier returned for a successful tokenize transaction.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(bank_account_number: nil, bank_account_type: nil, bank_routing_number: nil, call_control_id: nil, call_leg_id: nil, call_session_id: nil, charge_id: nil, client_state: nil, connection_id: nil, connector_error: nil, expiration_date: nil, from: nil, pay_error_code: nil, payment_card_number: nil, payment_card_postal_code: nil, payment_card_type: nil, payment_confirmation_code: nil, payment_connector: nil, payment_error: nil, payment_method: nil, result: nil, security_code: nil, to: nil, token_id: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bank_account_number: nil, bank_account_type: nil, bank_routing_number: nil, call_control_id: nil, call_leg_id: nil, call_session_id: nil, charge_id: nil, client_state: nil, connection_id: nil, connector_error: nil, expiration_date: nil, from: nil, pay_error_code: nil, payment_card_number: nil, payment_card_postal_code: nil, payment_card_type: nil, payment_confirmation_code: nil, payment_connector: nil, payment_error: nil, payment_method: nil, result: nil, security_code: nil, to: nil, token_id: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 217
|
Instance Attribute Details
#bank_account_number ⇒ String?
Masked bank account number with only the last two digits visible.
74 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 74 optional :bank_account_number, String |
#bank_account_type ⇒ String?
Bank account type, when available.
80 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 80 optional :bank_account_type, String |
#bank_routing_number ⇒ String?
Bank routing number collected from the caller.
86 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 86 optional :bank_routing_number, String |
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
92 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 92 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID unique to the call leg.
98 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 98 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID shared by related call legs in the same call session.
104 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 104 optional :call_session_id, String |
#charge_id ⇒ String?
Charge identifier returned for a successful charge transaction.
110 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 110 optional :charge_id, String |
#client_state ⇒ String?
Base64-encoded state received from the command.
116 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 116 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID used in the call.
122 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 122 optional :connection_id, String |
#connector_error ⇒ String, ...
Additional connector error information, when supplied by the processor.
128 129 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 128 optional :connector_error, union: -> { Telnyx::CallPaymentCompletedWebhookEvent::Data::Payload::ConnectorError } |
#expiration_date ⇒ String?
Card expiration date in MMYY format.
135 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 135 optional :expiration_date, String |
#from ⇒ String?
Number or SIP URI placing the call.
141 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 141 optional :from, String |
#pay_error_code ⇒ String?
Error code returned by the payment connector or processor.
147 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 147 optional :pay_error_code, String |
#payment_card_number ⇒ String?
Masked card number with only the last four digits visible.
153 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 153 optional :payment_card_number, String |
#payment_card_postal_code ⇒ String?
Billing postal code collected from the caller.
159 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 159 optional :payment_card_postal_code, String |
#payment_card_type ⇒ Symbol, ...
Detected card type. Present only for the recognized card brands listed below.
165 166 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 165 optional :payment_card_type, enum: -> { Telnyx::CallPaymentCompletedWebhookEvent::Data::Payload::PaymentCardType } |
#payment_confirmation_code ⇒ String?
Payment confirmation code returned by the processor, when available.
172 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 172 optional :payment_confirmation_code, String |
#payment_connector ⇒ String?
Name of the Pay connector used.
178 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 178 optional :payment_connector, String |
#payment_error ⇒ String?
Step-level or processor error associated with the final result.
184 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 184 optional :payment_error, String |
#payment_method ⇒ Symbol, ...
Payment method being collected.
190 191 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 190 optional :payment_method, enum: -> { Telnyx::CallPaymentCompletedWebhookEvent::Data::Payload::PaymentMethod } |
#result ⇒ Symbol, ...
Final Pay session result.
197 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 197 optional :result, enum: -> { Telnyx::CallPaymentCompletedWebhookEvent::Data::Payload::Result } |
#security_code ⇒ String?
Fully masked card security code.
203 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 203 optional :security_code, String |
#to ⇒ String?
Destination number or SIP URI of the call.
209 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 209 optional :to, String |
#token_id ⇒ String?
Token identifier returned for a successful tokenize transaction.
215 |
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 215 optional :token_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/call_payment_completed_webhook_event.rb', line 296
|
Instance Method Details
#to_hash ⇒ {
241 |
# File 'sig/telnyx/models/call_payment_completed_webhook_event.rbs', line 241
def to_hash: -> {
|