Class: Telnyx::Models::CallPlaybackEnded::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallPlaybackEnded::Payload
- Defined in:
- lib/telnyx/models/call_playback_ended.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#media_name ⇒ String?
The name of the audio media file being played back, if media_name has been used to start.
-
#media_url ⇒ String?
The audio URL being played back, if audio_url has been used to start.
-
#overlay ⇒ Boolean?
Whether the stopped audio was in overlay mode or not.
-
#status ⇒ Symbol, ...
Reflects how command ended.
-
#status_detail ⇒ String?
Provides details in case of failure.
Instance Method Summary collapse
-
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, media_name: nil, media_url: nil, overlay: nil, status: nil, status_detail: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id: nil, call_leg_id: nil, call_session_id: nil, client_state: nil, connection_id: nil, media_name: nil, media_url: nil, overlay: nil, status: nil, status_detail: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CallPlaybackEnded::Payload for more details.
|
|
# File 'lib/telnyx/models/call_playback_ended.rb', line 123
|
Instance Attribute Details
#call_control_id ⇒ String?
Call ID used to issue commands via Call Control API.
64 |
# File 'lib/telnyx/models/call_playback_ended.rb', line 64 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
70 |
# File 'lib/telnyx/models/call_playback_ended.rb', line 70 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
78 |
# File 'lib/telnyx/models/call_playback_ended.rb', line 78 optional :call_session_id, String |
#client_state ⇒ String?
State received from a command.
84 |
# File 'lib/telnyx/models/call_playback_ended.rb', line 84 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
90 |
# File 'lib/telnyx/models/call_playback_ended.rb', line 90 optional :connection_id, String |
#media_name ⇒ String?
The name of the audio media file being played back, if media_name has been used to start.
97 |
# File 'lib/telnyx/models/call_playback_ended.rb', line 97 optional :media_name, String |
#media_url ⇒ String?
The audio URL being played back, if audio_url has been used to start.
103 |
# File 'lib/telnyx/models/call_playback_ended.rb', line 103 optional :media_url, String |
#overlay ⇒ Boolean?
Whether the stopped audio was in overlay mode or not.
109 |
# File 'lib/telnyx/models/call_playback_ended.rb', line 109 optional :overlay, Telnyx::Internal::Type::Boolean |
#status ⇒ Symbol, ...
Reflects how command ended.
115 |
# File 'lib/telnyx/models/call_playback_ended.rb', line 115 optional :status, enum: -> { Telnyx::CallPlaybackEnded::Payload::Status } |
#status_detail ⇒ String?
Provides details in case of failure.
121 |
# File 'lib/telnyx/models/call_playback_ended.rb', line 121 optional :status_detail, String |