Class: Telnyx::Models::CallRecordingSaved::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CallRecordingSaved::Payload
- Defined in:
- lib/telnyx/models/call_recording_saved.rb
Overview
Defined Under Namespace
Modules: Channels Classes: PublicRecordingURLs, RecordingURLs
Instance Attribute Summary collapse
-
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#channels ⇒ Symbol, ...
Whether recording was recorded in ‘single` or `dual` channel.
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#public_recording_urls ⇒ Telnyx::Models::CallRecordingSaved::Payload::PublicRecordingURLs?
Recording URLs in requested format.
-
#recording_ended_at ⇒ Time?
ISO 8601 datetime of when recording ended.
-
#recording_started_at ⇒ Time?
ISO 8601 datetime of when recording started.
-
#recording_urls ⇒ Telnyx::Models::CallRecordingSaved::Payload::RecordingURLs?
Recording URLs in requested format.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(mp3: nil, wav: nil) ⇒ Object
constructor
Recording URLs in requested format.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mp3: nil, wav: nil) ⇒ Object
Recording URLs in requested format. The URL is valid for as long as the file exists. For security purposes, this feature is activated on a per request basis. Please contact customer support with your Account ID to request activation.
|
|
# File 'lib/telnyx/models/call_recording_saved.rb', line 120
|
Instance Attribute Details
#call_leg_id ⇒ String?
ID that is unique to the call and can be used to correlate webhook events.
64 |
# File 'lib/telnyx/models/call_recording_saved.rb', line 64 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
72 |
# File 'lib/telnyx/models/call_recording_saved.rb', line 72 optional :call_session_id, String |
#channels ⇒ Symbol, ...
Whether recording was recorded in ‘single` or `dual` channel.
78 |
# File 'lib/telnyx/models/call_recording_saved.rb', line 78 optional :channels, enum: -> { Telnyx::CallRecordingSaved::Payload::Channels } |
#client_state ⇒ String?
State received from a command.
84 |
# File 'lib/telnyx/models/call_recording_saved.rb', line 84 optional :client_state, String |
#connection_id ⇒ String?
Call Control App ID (formerly Telnyx connection ID) used in the call.
90 |
# File 'lib/telnyx/models/call_recording_saved.rb', line 90 optional :connection_id, String |
#public_recording_urls ⇒ Telnyx::Models::CallRecordingSaved::Payload::PublicRecordingURLs?
Recording URLs in requested format. The URL is valid for as long as the file exists. For security purposes, this feature is activated on a per request basis. Please contact customer support with your Account ID to request activation.
98 |
# File 'lib/telnyx/models/call_recording_saved.rb', line 98 optional :public_recording_urls, -> { Telnyx::CallRecordingSaved::Payload::PublicRecordingURLs } |
#recording_ended_at ⇒ Time?
ISO 8601 datetime of when recording ended.
104 |
# File 'lib/telnyx/models/call_recording_saved.rb', line 104 optional :recording_ended_at, Time |
#recording_started_at ⇒ Time?
ISO 8601 datetime of when recording started.
110 |
# File 'lib/telnyx/models/call_recording_saved.rb', line 110 optional :recording_started_at, Time |
#recording_urls ⇒ Telnyx::Models::CallRecordingSaved::Payload::RecordingURLs?
Recording URLs in requested format. These URLs are valid for 10 minutes. After 10 minutes, you may retrieve recordings via API using Reports -> Call Recordings documentation, or via Mission Control under Reporting -> Recordings.
118 |
# File 'lib/telnyx/models/call_recording_saved.rb', line 118 optional :recording_urls, -> { Telnyx::CallRecordingSaved::Payload::RecordingURLs } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/call_recording_saved.rb', line 151
|