Class: Telnyx::Models::Calls::ActionAddAIAssistantMessagesParams::Message::Developer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionAddAIAssistantMessagesParams::Message::Developer
- Defined in:
- lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb
Instance Attribute Summary collapse
-
#content ⇒ String
The contents of the developer message.
-
#metadata ⇒ Hash{Symbol=>Object}?
Metadata to add to the message.
-
#role ⇒ Symbol, :developer
The role of the messages author, in this case developer.
Instance Method Summary collapse
-
#initialize(content:, metadata: nil, role: :developer) ⇒ Object
constructor
Developer-provided instructions that the model should follow, regardless of messages sent by the user.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content:, metadata: nil, role: :developer) ⇒ Object
Developer-provided instructions that the model should follow, regardless of messages sent by the user.
|
|
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 279
|
Instance Attribute Details
#content ⇒ String
The contents of the developer message.
265 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 265 required :content, String |
#metadata ⇒ Hash{Symbol=>Object}?
Metadata to add to the message
277 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 277 optional :metadata, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#role ⇒ Symbol, :developer
The role of the messages author, in this case developer.
271 |
# File 'lib/telnyx/models/calls/action_add_ai_assistant_messages_params.rb', line 271 required :role, const: :developer |