Class: Telnyx::Models::Calls::ActionAnswerParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionAnswerParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_answer_params.rb
Overview
Defined Under Namespace
Modules: PreferredCodecs, Record, RecordChannels, RecordFormat, RecordTrack, RecordTrim, StreamTrack, WebhookURLMethod, WebhookURLsMethod Classes: WebhookRetriesPolicy
Instance Attribute Summary collapse
-
#assistant ⇒ Telnyx::Models::CallAssistantRequest?
AI Assistant configuration.
-
#billing_group_id ⇒ String?
Use this field to set the Billing Group ID for the call.
- #call_control_id ⇒ String
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers to be added to the SIP INVITE response.
-
#preferred_codecs ⇒ Symbol, ...
The list of comma-separated codecs in a preferred order for the forked media to be received.
-
#record ⇒ Symbol, ...
Start recording automatically after an event.
-
#record_channels ⇒ Symbol, ...
Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.
-
#record_custom_file_name ⇒ String?
The custom recording file name to be used instead of the default ‘call_leg_id`.
-
#record_format ⇒ Symbol, ...
Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.
-
#record_max_length ⇒ Integer?
Defines the maximum length for the recording in seconds when ‘record` is specified.
-
#record_timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified.
-
#record_track ⇒ Symbol, ...
The audio track to be recorded.
-
#record_trim ⇒ Symbol, ...
When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.
-
#send_silence_when_idle ⇒ Boolean?
Generate silence RTP packets when no transmission available.
-
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
SIP headers to be added to the SIP INVITE response.
-
#sound_modifications ⇒ Telnyx::Models::SoundModifications?
Use this field to modify sound effects, for example adjust the pitch.
-
#stream_bidirectional_codec ⇒ Symbol, ...
Indicates codec for bidirectional streaming RTP payloads.
-
#stream_bidirectional_mode ⇒ Symbol, ...
Configures method of bidirectional streaming (mp3, rtp).
-
#stream_bidirectional_target_legs ⇒ Symbol, ...
Specifies which call legs should receive the bidirectional stream audio.
-
#stream_codec ⇒ Symbol, ...
Specifies the codec to be used for the streamed audio.
-
#stream_track ⇒ Symbol, ...
Specifies which track should be streamed.
-
#stream_url ⇒ String?
The destination WebSocket address where the stream is going to be delivered.
-
#transcription ⇒ Boolean?
Enable transcription upon call answer.
- #transcription_config ⇒ Telnyx::Models::Calls::TranscriptionStartRequest?
-
#webhook_retries_policies ⇒ Hash{Symbol=>Telnyx::Models::Calls::ActionAnswerParams::WebhookRetriesPolicy}?
A map of event types to retry policies.
-
#webhook_url ⇒ String?
Use this field to override the URL for which Telnyx will send subsequent webhooks to for this call.
-
#webhook_url_method ⇒ Symbol, ...
HTTP request type used for ‘webhook_url`.
-
#webhook_urls ⇒ Hash{Symbol=>String}?
A map of event types to webhook URLs.
-
#webhook_urls_method ⇒ Symbol, ...
HTTP request method to invoke ‘webhook_urls`.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(retries_ms: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebhookRetriesPolicy for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(retries_ms: nil) ⇒ Object
Some parameter documentations has been truncated, see WebhookRetriesPolicy for more details.
|
|
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 221
|
Instance Attribute Details
#assistant ⇒ Telnyx::Models::CallAssistantRequest?
AI Assistant configuration. All fields except ‘id` are optional — the assistant’s stored configuration will be used as fallback for any omitted fields.
22 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 22 optional :assistant, -> { Telnyx::CallAssistantRequest } |
#billing_group_id ⇒ String?
Use this field to set the Billing Group ID for the call. Must be a valid and existing Billing Group ID.
29 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 29 optional :billing_group_id, String |
#call_control_id ⇒ String
14 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 14 required :call_control_id, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
36 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 36 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
43 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 43 optional :command_id, String |
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers to be added to the SIP INVITE response.
49 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 49 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] } |
#preferred_codecs ⇒ Symbol, ...
The list of comma-separated codecs in a preferred order for the forked media to be received.
56 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 56 optional :preferred_codecs, enum: -> { Telnyx::Calls::ActionAnswerParams::PreferredCodecs } |
#record ⇒ Symbol, ...
Start recording automatically after an event. Disabled by default.
62 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 62 optional :record, enum: -> { Telnyx::Calls::ActionAnswerParams::Record } |
#record_channels ⇒ Symbol, ...
Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.
69 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 69 optional :record_channels, enum: -> { Telnyx::Calls::ActionAnswerParams::RecordChannels } |
#record_custom_file_name ⇒ String?
The custom recording file name to be used instead of the default ‘call_leg_id`. Telnyx will still add a Unix timestamp suffix.
76 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 76 optional :record_custom_file_name, String |
#record_format ⇒ Symbol, ...
Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.
82 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 82 optional :record_format, enum: -> { Telnyx::Calls::ActionAnswerParams::RecordFormat } |
#record_max_length ⇒ Integer?
Defines the maximum length for the recording in seconds when ‘record` is specified. The minimum value is 0. The maximum value is 43200. The default value is 0 (infinite).
90 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 90 optional :record_max_length, Integer |
#record_timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified. The timer only starts when the speech is detected. Please note that call transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite).
100 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 100 optional :record_timeout_secs, Integer |
#record_track ⇒ Symbol, ...
The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. If only single track is specified (`inbound`, `outbound`), `channels` configuration is ignored and it will be recorded as mono (single channel).
108 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 108 optional :record_track, enum: -> { Telnyx::Calls::ActionAnswerParams::RecordTrack } |
#record_trim ⇒ Symbol, ...
When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.
115 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 115 optional :record_trim, enum: -> { Telnyx::Calls::ActionAnswerParams::RecordTrim } |
#send_silence_when_idle ⇒ Boolean?
Generate silence RTP packets when no transmission available.
121 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 121 optional :send_silence_when_idle, Telnyx::Internal::Type::Boolean |
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
SIP headers to be added to the SIP INVITE response. Currently only User-to-User header is supported.
128 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 128 optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] } |
#sound_modifications ⇒ Telnyx::Models::SoundModifications?
Use this field to modify sound effects, for example adjust the pitch.
134 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 134 optional :sound_modifications, -> { Telnyx::SoundModifications } |
#stream_bidirectional_codec ⇒ Symbol, ...
Indicates codec for bidirectional streaming RTP payloads. Used only with stream_bidirectional_mode=rtp. Case sensitive.
141 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 141 optional :stream_bidirectional_codec, enum: -> { Telnyx::StreamBidirectionalCodec } |
#stream_bidirectional_mode ⇒ Symbol, ...
Configures method of bidirectional streaming (mp3, rtp).
147 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 147 optional :stream_bidirectional_mode, enum: -> { Telnyx::StreamBidirectionalMode } |
#stream_bidirectional_target_legs ⇒ Symbol, ...
Specifies which call legs should receive the bidirectional stream audio.
153 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 153 optional :stream_bidirectional_target_legs, enum: -> { Telnyx::StreamBidirectionalTargetLegs } |
#stream_codec ⇒ Symbol, ...
Specifies the codec to be used for the streamed audio. When set to ‘default’ or when transcoding is not possible, the codec from the call will be used.
160 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 160 optional :stream_codec, enum: -> { Telnyx::StreamCodec } |
#stream_track ⇒ Symbol, ...
Specifies which track should be streamed.
166 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 166 optional :stream_track, enum: -> { Telnyx::Calls::ActionAnswerParams::StreamTrack } |
#stream_url ⇒ String?
The destination WebSocket address where the stream is going to be delivered.
172 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 172 optional :stream_url, String |
#transcription ⇒ Boolean?
Enable transcription upon call answer. The default value is false.
178 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 178 optional :transcription, Telnyx::Internal::Type::Boolean |
#transcription_config ⇒ Telnyx::Models::Calls::TranscriptionStartRequest?
183 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 183 optional :transcription_config, -> { Telnyx::Calls::TranscriptionStartRequest } |
#webhook_retries_policies ⇒ Hash{Symbol=>Telnyx::Models::Calls::ActionAnswerParams::WebhookRetriesPolicy}?
A map of event types to retry policies. Each retry policy contains an array of ‘retries_ms` specifying the delays between retry attempts in milliseconds. Maximum 5 retries, total delay cannot exceed 60 seconds.
191 192 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 191 optional :webhook_retries_policies, -> { Telnyx::Internal::Type::HashOf[Telnyx::Calls::ActionAnswerParams::WebhookRetriesPolicy] } |
#webhook_url ⇒ String?
Use this field to override the URL for which Telnyx will send subsequent webhooks to for this call.
199 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 199 optional :webhook_url, String |
#webhook_url_method ⇒ Symbol, ...
HTTP request type used for ‘webhook_url`.
205 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 205 optional :webhook_url_method, enum: -> { Telnyx::Calls::ActionAnswerParams::WebhookURLMethod } |
#webhook_urls ⇒ Hash{Symbol=>String}?
A map of event types to webhook URLs. When an event of the specified type occurs, the webhook URL associated with that event type will be called instead of ‘webhook_url`. Events not mapped here will use the default `webhook_url`.
213 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 213 optional :webhook_urls, Telnyx::Internal::Type::HashOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 297
|