Class: Telnyx::Models::Calls::ActionAnswerParams::DeepfakeDetection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionAnswerParams::DeepfakeDetection
- Defined in:
- lib/telnyx/models/calls/action_answer_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Whether deepfake detection is enabled.
-
#rtp_timeout ⇒ Integer?
Maximum time in seconds to wait for RTP audio before timing out.
-
#timeout ⇒ Integer?
Maximum time in seconds to wait for a detection result before timing out.
Instance Method Summary collapse
-
#initialize(call_control_id:, assistant: nil, billing_group_id: nil, client_state: nil, command_id: nil, custom_headers: nil, deepfake_detection: nil, preferred_codecs: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, send_silence_when_idle: nil, sip_headers: nil, sound_modifications: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, transcription: nil, transcription_config: nil, webhook_retries_policies: nil, webhook_url: nil, webhook_url_method: nil, webhook_urls: nil, webhook_urls_method: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionAnswerParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id:, assistant: nil, billing_group_id: nil, client_state: nil, command_id: nil, custom_headers: nil, deepfake_detection: nil, preferred_codecs: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, send_silence_when_idle: nil, sip_headers: nil, sound_modifications: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, transcription: nil, transcription_config: nil, webhook_retries_policies: nil, webhook_url: nil, webhook_url_method: nil, webhook_urls: nil, webhook_urls_method: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionAnswerParams for more details.
stream_
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 301 class DeepfakeDetection < Telnyx::Internal::Type::BaseModel # @!attribute enabled # Whether deepfake detection is enabled. # # @return [Boolean] required :enabled, Telnyx::Internal::Type::Boolean # @!attribute rtp_timeout # Maximum time in seconds to wait for RTP audio before timing out. If no audio is # received within this window, detection stops with an error. # # @return [Integer, nil] optional :rtp_timeout, Integer # @!attribute timeout # Maximum time in seconds to wait for a detection result before timing out. # # @return [Integer, nil] optional :timeout, Integer # @!method initialize(enabled:, rtp_timeout: nil, timeout: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::Calls::ActionAnswerParams::DeepfakeDetection} for more details. # # Enables deepfake detection on the call. When enabled, audio from the remote # party is streamed to a detection service that analyzes whether the voice is # AI-generated. Results are delivered via the `call.deepfake_detection.result` # webhook. # # @param enabled [Boolean] Whether deepfake detection is enabled. # # @param rtp_timeout [Integer] Maximum time in seconds to wait for RTP audio before timing out. If no audio is # # @param timeout [Integer] Maximum time in seconds to wait for a detection result before timing out. end |
Instance Attribute Details
#enabled ⇒ Boolean
Whether deepfake detection is enabled.
306 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 306 required :enabled, Telnyx::Internal::Type::Boolean |
#rtp_timeout ⇒ Integer?
Maximum time in seconds to wait for RTP audio before timing out. If no audio is received within this window, detection stops with an error.
313 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 313 optional :rtp_timeout, Integer |
#timeout ⇒ Integer?
Maximum time in seconds to wait for a detection result before timing out.
319 |
# File 'lib/telnyx/models/calls/action_answer_params.rb', line 319 optional :timeout, Integer |