Class: Telnyx::Models::Calls::ActionBridgeParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionBridgeParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_bridge_params.rb
Overview
Defined Under Namespace
Modules: MuteDtmf, Record, RecordChannels, RecordFormat, RecordTrack, RecordTrim, Ringtone
Instance Attribute Summary collapse
-
#call_control_id_to_bridge_with ⇒ String
The Call Control ID of the call you want to bridge with, can’t be used together with queue parameter or video_room_id parameter.
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#mute_dtmf ⇒ Symbol, ...
When enabled, DTMF tones are not passed to the call participant.
-
#park_after_unbridge ⇒ String?
Specifies behavior after the bridge ends (i.e. the opposite leg either hangs up or is transferred).
-
#play_ringtone ⇒ Boolean?
Specifies whether to play a ringtone if the call you want to bridge with has not yet been answered.
-
#queue ⇒ String?
The name of the queue you want to bridge with, can’t be used together with call_control_id parameter or video_room_id parameter.
-
#record ⇒ Symbol, ...
Start recording automatically after an event.
-
#record_channels ⇒ Symbol, ...
Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.
-
#record_custom_file_name ⇒ String?
The custom recording file name to be used instead of the default ‘call_leg_id`.
-
#record_format ⇒ Symbol, ...
Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.
-
#record_max_length ⇒ Integer?
Defines the maximum length for the recording in seconds when ‘record` is specified.
-
#record_timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified.
-
#record_track ⇒ Symbol, ...
The audio track to be recorded.
-
#record_trim ⇒ Symbol, ...
When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.
-
#ringtone ⇒ Symbol, ...
Specifies which country ringtone to play when ‘play_ringtone` is set to `true`.
-
#video_room_context ⇒ String?
The additional parameter that will be passed to the video conference.
-
#video_room_id ⇒ String?
The ID of the video room you want to bridge with, can’t be used together with call_control_id parameter or queue parameter.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(call_control_id_to_bridge_with:, client_state: nil, command_id: nil, mute_dtmf: nil, park_after_unbridge: nil, play_ringtone: nil, queue: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, ringtone: nil, video_room_context: nil, video_room_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionBridgeParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id_to_bridge_with:, client_state: nil, command_id: nil, mute_dtmf: nil, park_after_unbridge: nil, play_ringtone: nil, queue: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, ringtone: nil, video_room_context: nil, video_room_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionBridgeParams for more details.
call_
|
|
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 146
|
Instance Attribute Details
#call_control_id_to_bridge_with ⇒ String
The Call Control ID of the call you want to bridge with, can’t be used together with queue parameter or video_room_id parameter.
16 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 16 required :call_control_id_to_bridge_with, String, api_name: :call_control_id |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
23 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 23 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
30 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 30 optional :command_id, String |
#mute_dtmf ⇒ Symbol, ...
When enabled, DTMF tones are not passed to the call participant. The webhooks containing the DTMF information will be sent.
37 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 37 optional :mute_dtmf, enum: -> { Telnyx::Calls::ActionBridgeParams::MuteDtmf } |
#park_after_unbridge ⇒ String?
Specifies behavior after the bridge ends (i.e. the opposite leg either hangs up or is transferred). If supplied with the value ‘self`, the current leg will be parked after unbridge. If not set, the default behavior is to hang up the leg.
45 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 45 optional :park_after_unbridge, String |
#play_ringtone ⇒ Boolean?
Specifies whether to play a ringtone if the call you want to bridge with has not yet been answered.
52 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 52 optional :play_ringtone, Telnyx::Internal::Type::Boolean |
#queue ⇒ String?
The name of the queue you want to bridge with, can’t be used together with call_control_id parameter or video_room_id parameter. Bridging with a queue means bridging with the first call in the queue. The call will always be removed from the queue regardless of whether bridging succeeds. Returns an error when the queue is empty.
62 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 62 optional :queue, String |
#record ⇒ Symbol, ...
Start recording automatically after an event. Disabled by default.
68 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 68 optional :record, enum: -> { Telnyx::Calls::ActionBridgeParams::Record } |
#record_channels ⇒ Symbol, ...
Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.
75 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 75 optional :record_channels, enum: -> { Telnyx::Calls::ActionBridgeParams::RecordChannels } |
#record_custom_file_name ⇒ String?
The custom recording file name to be used instead of the default ‘call_leg_id`. Telnyx will still add a Unix timestamp suffix.
82 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 82 optional :record_custom_file_name, String |
#record_format ⇒ Symbol, ...
Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.
88 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 88 optional :record_format, enum: -> { Telnyx::Calls::ActionBridgeParams::RecordFormat } |
#record_max_length ⇒ Integer?
Defines the maximum length for the recording in seconds when ‘record` is specified. The minimum value is 0. The maximum value is 43200. The default value is 0 (infinite).
96 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 96 optional :record_max_length, Integer |
#record_timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified. The timer only starts when the speech is detected. Please note that call transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite).
106 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 106 optional :record_timeout_secs, Integer |
#record_track ⇒ Symbol, ...
The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. If only single track is specified (`inbound`, `outbound`), `channels` configuration is ignored and it will be recorded as mono (single channel).
114 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 114 optional :record_track, enum: -> { Telnyx::Calls::ActionBridgeParams::RecordTrack } |
#record_trim ⇒ Symbol, ...
When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.
121 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 121 optional :record_trim, enum: -> { Telnyx::Calls::ActionBridgeParams::RecordTrim } |
#ringtone ⇒ Symbol, ...
Specifies which country ringtone to play when ‘play_ringtone` is set to `true`. If not set, the US ringtone will be played.
128 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 128 optional :ringtone, enum: -> { Telnyx::Calls::ActionBridgeParams::Ringtone } |
#video_room_context ⇒ String?
The additional parameter that will be passed to the video conference. It is a text field and the user can decide how to use it. For example, you can set the participant name or pass JSON text. It can be used only with video_room_id parameter.
137 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 137 optional :video_room_context, String |
#video_room_id ⇒ String?
The ID of the video room you want to bridge with, can’t be used together with call_control_id parameter or queue parameter.
144 |
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 144 optional :video_room_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_bridge_params.rb', line 199
|