Class: Telnyx::Models::Calls::ActionGatherParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_gather_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(client_state: nil, command_id: nil, gather_id: nil, initial_timeout_millis: nil, inter_digit_timeout_millis: nil, maximum_digits: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionGatherParams for more details.

Parameters:

  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. It must be a valid Base

  • command_id (String) (defaults to: nil)

    Use this field to avoid duplicate commands. Telnyx will ignore any command with

  • gather_id (String) (defaults to: nil)

    An id that will be sent back in the corresponding ‘call.gather.ended` webhook. W

  • initial_timeout_millis (Integer) (defaults to: nil)

    The number of milliseconds to wait for the first DTMF.

  • inter_digit_timeout_millis (Integer) (defaults to: nil)

    The number of milliseconds to wait for input between digits.

  • maximum_digits (Integer) (defaults to: nil)

    The maximum number of digits to fetch. This parameter has a maximum value of 128

  • minimum_digits (Integer) (defaults to: nil)

    The minimum number of digits to fetch. This parameter has a minimum value of 1.

  • terminating_digit (String) (defaults to: nil)

    The digit used to terminate input if fewer than ‘maximum_digits` digits have bee

  • timeout_millis (Integer) (defaults to: nil)

    The number of milliseconds to wait to complete the request.

  • valid_digits (String) (defaults to: nil)

    A list of all digits accepted as valid.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/calls/action_gather_params.rb', line 76

Instance Attribute Details

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 16

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 23

optional :command_id, String

#gather_idString?

An id that will be sent back in the corresponding ‘call.gather.ended` webhook. Will be randomly generated if not specified.

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 30

optional :gather_id, String

#initial_timeout_millisInteger?

The number of milliseconds to wait for the first DTMF.

Returns:

  • (Integer, nil)


36
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 36

optional :initial_timeout_millis, Integer

#inter_digit_timeout_millisInteger?

The number of milliseconds to wait for input between digits.

Returns:

  • (Integer, nil)


42
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 42

optional :inter_digit_timeout_millis, Integer

#maximum_digitsInteger?

The maximum number of digits to fetch. This parameter has a maximum value of 128.

Returns:

  • (Integer, nil)


49
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 49

optional :maximum_digits, Integer

#minimum_digitsInteger?

The minimum number of digits to fetch. This parameter has a minimum value of 1.

Returns:

  • (Integer, nil)


55
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 55

optional :minimum_digits, Integer

#terminating_digitString?

The digit used to terminate input if fewer than ‘maximum_digits` digits have been gathered.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 62

optional :terminating_digit, String

#timeout_millisInteger?

The number of milliseconds to wait to complete the request.

Returns:

  • (Integer, nil)


68
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 68

optional :timeout_millis, Integer

#valid_digitsString?

A list of all digits accepted as valid.

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 74

optional :valid_digits, String