Class: Telnyx::Models::Calls::ActionGatherParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionGatherParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_gather_params.rb
Overview
Instance Attribute Summary collapse
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#gather_id ⇒ String?
An id that will be sent back in the corresponding ‘call.gather.ended` webhook.
-
#initial_timeout_millis ⇒ Integer?
The number of milliseconds to wait for the first DTMF.
-
#inter_digit_timeout_millis ⇒ Integer?
The number of milliseconds to wait for input between digits.
-
#maximum_digits ⇒ Integer?
The maximum number of digits to fetch.
-
#minimum_digits ⇒ Integer?
The minimum number of digits to fetch.
-
#terminating_digit ⇒ String?
The digit used to terminate input if fewer than ‘maximum_digits` digits have been gathered.
-
#timeout_millis ⇒ Integer?
The number of milliseconds to wait to complete the request.
-
#valid_digits ⇒ String?
A list of all digits accepted as valid.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(client_state: nil, command_id: nil, gather_id: nil, initial_timeout_millis: nil, inter_digit_timeout_millis: nil, maximum_digits: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionGatherParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(client_state: nil, command_id: nil, gather_id: nil, initial_timeout_millis: nil, inter_digit_timeout_millis: nil, maximum_digits: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionGatherParams for more details.
|
|
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 76
|
Instance Attribute Details
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
16 |
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 16 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
23 |
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 23 optional :command_id, String |
#gather_id ⇒ String?
An id that will be sent back in the corresponding ‘call.gather.ended` webhook. Will be randomly generated if not specified.
30 |
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 30 optional :gather_id, String |
#initial_timeout_millis ⇒ Integer?
The number of milliseconds to wait for the first DTMF.
36 |
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 36 optional :initial_timeout_millis, Integer |
#inter_digit_timeout_millis ⇒ Integer?
The number of milliseconds to wait for input between digits.
42 |
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 42 optional :inter_digit_timeout_millis, Integer |
#maximum_digits ⇒ Integer?
The maximum number of digits to fetch. This parameter has a maximum value of 128.
49 |
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 49 optional :maximum_digits, Integer |
#minimum_digits ⇒ Integer?
The minimum number of digits to fetch. This parameter has a minimum value of 1.
55 |
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 55 optional :minimum_digits, Integer |
#terminating_digit ⇒ String?
The digit used to terminate input if fewer than ‘maximum_digits` digits have been gathered.
62 |
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 62 optional :terminating_digit, String |
#timeout_millis ⇒ Integer?
The number of milliseconds to wait to complete the request.
68 |
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 68 optional :timeout_millis, Integer |
#valid_digits ⇒ String?
A list of all digits accepted as valid.
74 |
# File 'lib/telnyx/models/calls/action_gather_params.rb', line 74 optional :valid_digits, String |