Class: Telnyx::Models::Calls::ActionGatherUsingSpeakParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionGatherUsingSpeakParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_gather_using_speak_params.rb,
sig/telnyx/models/calls/action_gather_using_speak_params.rbs
Overview
Defined Under Namespace
Modules: Language, PayloadType, ServiceLevel, VoiceSettings
Instance Attribute Summary collapse
- #call_control_id ⇒ String
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#inter_digit_timeout_millis ⇒ Integer?
The number of milliseconds to wait for input between digits.
-
#invalid_payload ⇒ String?
The text or SSML to be converted into speech when digits don't match the
valid_digitsparameter or the number of digits is not betweenminandmax. -
#language ⇒ Symbol, ...
The language you want spoken.
-
#maximum_digits ⇒ Integer?
The maximum number of digits to fetch.
-
#maximum_tries ⇒ Integer?
The maximum number of times that a file should be played back if there is no input from the user on the call.
-
#minimum_digits ⇒ Integer?
The minimum number of digits to fetch.
-
#payload ⇒ String
The text or SSML to be converted into speech.
-
#payload_type ⇒ Symbol, ...
The type of the provided payload.
-
#service_level ⇒ Symbol, ...
This parameter impacts speech quality, language options and payload types.
-
#terminating_digit ⇒ String?
The digit used to terminate input if fewer than
maximum_digitsdigits have been gathered. -
#timeout_millis ⇒ Integer?
The number of milliseconds to wait for a DTMF response after speak ends before a replaying the sound file.
-
#valid_digits ⇒ String?
A list of all digits accepted as valid.
-
#voice ⇒ String
Specifies the voice used in speech synthesis.
-
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(call_control_id:, payload:, voice:, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_payload: nil, language: nil, maximum_digits: nil, maximum_tries: nil, minimum_digits: nil, payload_type: nil, service_level: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, voice_settings: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionGatherUsingSpeakParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id:, payload:, voice:, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_payload: nil, language: nil, maximum_digits: nil, maximum_tries: nil, minimum_digits: nil, payload_type: nil, service_level: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, voice_settings: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionGatherUsingSpeakParams for more details.
`valid_
|
|
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 168
|
Instance Attribute Details
#call_control_id ⇒ String
14 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 14 required :call_control_id, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
78 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 78 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with
the same command_id for the same call_control_id.
85 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 85 optional :command_id, String |
#inter_digit_timeout_millis ⇒ Integer?
The number of milliseconds to wait for input between digits.
91 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 91 optional :inter_digit_timeout_millis, Integer |
#invalid_payload ⇒ String?
The text or SSML to be converted into speech when digits don't match the
valid_digits parameter or the number of digits is not between min and max.
There is a 3,000 character limit.
99 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 99 optional :invalid_payload, String |
#language ⇒ Symbol, ...
The language you want spoken. This parameter is ignored when a Polly.* voice
is specified.
106 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 106 optional :language, enum: -> { Telnyx::Calls::ActionGatherUsingSpeakParams::Language } |
#maximum_digits ⇒ Integer?
The maximum number of digits to fetch. This parameter has a maximum value of 128.
113 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 113 optional :maximum_digits, Integer |
#maximum_tries ⇒ Integer?
The maximum number of times that a file should be played back if there is no input from the user on the call.
120 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 120 optional :maximum_tries, Integer |
#minimum_digits ⇒ Integer?
The minimum number of digits to fetch. This parameter has a minimum value of 1.
126 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 126 optional :minimum_digits, Integer |
#payload ⇒ String
The text or SSML to be converted into speech. There is a 3,000 character limit.
20 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 20 required :payload, String |
#payload_type ⇒ Symbol, ...
The type of the provided payload. The payload can either be plain text, or Speech Synthesis Markup Language (SSML).
133 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 133 optional :payload_type, enum: -> { Telnyx::Calls::ActionGatherUsingSpeakParams::PayloadType } |
#service_level ⇒ Symbol, ...
This parameter impacts speech quality, language options and payload types. When
using basic, only the en-US language and payload type text are allowed.
140 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 140 optional :service_level, enum: -> { Telnyx::Calls::ActionGatherUsingSpeakParams::ServiceLevel } |
#terminating_digit ⇒ String?
The digit used to terminate input if fewer than maximum_digits digits have
been gathered.
147 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 147 optional :terminating_digit, String |
#timeout_millis ⇒ Integer?
The number of milliseconds to wait for a DTMF response after speak ends before a replaying the sound file.
154 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 154 optional :timeout_millis, Integer |
#valid_digits ⇒ String?
A list of all digits accepted as valid.
160 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 160 optional :valid_digits, String |
#voice ⇒ String
Specifies the voice used in speech synthesis.
-
Define voices using the format
<Provider>.<Model>.<VoiceId>. Specifying only the provider will give default values for voice_id and model_id.Supported Providers:
-
AWS: Use
AWS.Polly.<VoiceId>(e.g.,AWS.Polly.Joanna). For neural voices, which provide more realistic, human-like speech, append-Neuralto theVoiceId(e.g.,AWS.Polly.Joanna-Neural). Check the available voices for compatibility. -
Azure: Use
Azure.<VoiceId>(e.g.,Azure.en-CA-ClaraNeural,Azure.en-US-BrianMultilingualNeural,Azure.en-US-Ava:DragonHDLatestNeural). For a complete list of voices, go to Azure Voice Gallery. Usevoice_settingsto configure custom deployments, regions, or API keys. -
ElevenLabs: Use
ElevenLabs.<ModelId>.<VoiceId>(e.g.,ElevenLabs.eleven_multilingual_v2.21m00Tcm4TlvDq8ikWAM). TheModelIdpart is optional. To use ElevenLabs, you must provide your ElevenLabs API key as an integration identifier secret in"voice_settings": {"api_key_ref": "<secret_identifier>"}. See integration secrets documentation for details. Check available voices. -
Telnyx: Use
Telnyx.<model_id>.<voice_id>(e.g.,Telnyx.KokoroTTS.af). Usevoice_settingsto configure voice_speed and other synthesis parameters. -
Minimax: Use
Minimax.<ModelId>.<VoiceId>(e.g.,Minimax.speech-02-hd.Wise_Woman). Supported models:speech-02-turbo,speech-02-hd,speech-2.6-turbo,speech-2.8-turbo. Usevoice_settingsto configure speed, volume, pitch, and language_boost. -
Rime: Use
Rime.<model_id>.<voice_id>(e.g.,Rime.Arcana.cove). Supported model_ids:Arcana,Mist,ArcanaV3,Coda. Usevoice_settingsto configure voice_speed. -
Resemble: Use
Resemble.Turbo.<voice_id>(e.g.,Resemble.Turbo.my_voice). OnlyTurbomodel is supported. Usevoice_settingsto configure precision, sample_rate, and format. -
Inworld: Use
Inworld.<ModelId>.<VoiceId>(e.g.,Inworld.Mini.Loretta,Inworld.Max.Oliver,Inworld.TTS2.Loretta). Supported models:Mini,Max,TTS2. Usevoice_settingsto configuredelivery_mode(STABLE,BALANCED,CREATIVE), supported byTTS2only. -
xAI: Use
xAI.<VoiceId>(e.g.,xAI.eve). Available voices:eve,ara,rex,sal,leo.
For service_level basic, you may define the gender of the speaker (male or female).
71 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 71 required :voice, String |
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected
166 |
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 166 optional :voice_settings, union: -> { Telnyx::Calls::ActionGatherUsingSpeakParams::VoiceSettings } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 244
|
Instance Method Details
#to_hash ⇒ {
121 |
# File 'sig/telnyx/models/calls/action_gather_using_speak_params.rbs', line 121
def to_hash: -> {
|