Class: Telnyx::Models::Calls::ActionGatherUsingSpeakParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_gather_using_speak_params.rb

Overview

Defined Under Namespace

Modules: Language, PayloadType, ServiceLevel, VoiceSettings

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, payload:, voice:, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_payload: nil, language: nil, maximum_digits: nil, maximum_tries: nil, minimum_digits: nil, payload_type: nil, service_level: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, voice_settings: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionGatherUsingSpeakParams for more details.

‘valid_

Parameters:



# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 164

Instance Attribute Details

#call_control_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


74
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 74

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


81
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 81

optional :command_id, String

#inter_digit_timeout_millisInteger?

The number of milliseconds to wait for input between digits.

Returns:

  • (Integer, nil)


87
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 87

optional :inter_digit_timeout_millis, Integer

#invalid_payloadString?

The text or SSML to be converted into speech when digits don’t match the ‘valid_digits` parameter or the number of digits is not between `min` and `max`. There is a 3,000 character limit.

Returns:

  • (String, nil)


95
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 95

optional :invalid_payload, String

#languageSymbol, ...

The language you want spoken. This parameter is ignored when a ‘Polly.*` voice is specified.



102
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 102

optional :language, enum: -> { Telnyx::Calls::ActionGatherUsingSpeakParams::Language }

#maximum_digitsInteger?

The maximum number of digits to fetch. This parameter has a maximum value of 128.

Returns:

  • (Integer, nil)


109
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 109

optional :maximum_digits, Integer

#maximum_triesInteger?

The maximum number of times that a file should be played back if there is no input from the user on the call.

Returns:

  • (Integer, nil)


116
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 116

optional :maximum_tries, Integer

#minimum_digitsInteger?

The minimum number of digits to fetch. This parameter has a minimum value of 1.

Returns:

  • (Integer, nil)


122
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 122

optional :minimum_digits, Integer

#payloadString

The text or SSML to be converted into speech. There is a 3,000 character limit.

Returns:

  • (String)


20
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 20

required :payload, String

#payload_typeSymbol, ...

The type of the provided payload. The payload can either be plain text, or Speech Synthesis Markup Language (SSML).



129
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 129

optional :payload_type, enum: -> { Telnyx::Calls::ActionGatherUsingSpeakParams::PayloadType }

#service_levelSymbol, ...

This parameter impacts speech quality, language options and payload types. When using ‘basic`, only the `en-US` language and payload type `text` are allowed.



136
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 136

optional :service_level, enum: -> { Telnyx::Calls::ActionGatherUsingSpeakParams::ServiceLevel }

#terminating_digitString?

The digit used to terminate input if fewer than ‘maximum_digits` digits have been gathered.

Returns:

  • (String, nil)


143
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 143

optional :terminating_digit, String

#timeout_millisInteger?

The number of milliseconds to wait for a DTMF response after speak ends before a replaying the sound file.

Returns:

  • (Integer, nil)


150
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 150

optional :timeout_millis, Integer

#valid_digitsString?

A list of all digits accepted as valid.

Returns:

  • (String, nil)


156
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 156

optional :valid_digits, String

#voiceString

Specifies the voice used in speech synthesis.

  • Define voices using the format ‘<Provider>.<Model>.<VoiceId>`. Specifying only the provider will give default values for voice_id and model_id.

    **Supported Providers:**

  • AWS: Use ‘AWS.Polly.<VoiceId>` (e.g., `AWS.Polly.Joanna`). For neural voices, which provide more realistic, human-like speech, append `-Neural` to the `VoiceId` (e.g., `AWS.Polly.Joanna-Neural`). Check the [available voices](docs.aws.amazon.com/polly/latest/dg/available-voices.html) for compatibility.

  • Azure: Use ‘Azure.<VoiceId>` (e.g., `Azure.en-CA-ClaraNeural`, `Azure.en-US-BrianMultilingualNeural`, `Azure.en-US-Ava:DragonHDLatestNeural`). For a complete list of voices, go to [Azure Voice Gallery](speech.microsoft.com/portal/voicegallery). Use `voice_settings` to configure custom deployments, regions, or API keys.

  • ElevenLabs: Use ‘ElevenLabs.<ModelId>.<VoiceId>` (e.g., `ElevenLabs.eleven_multilingual_v2.21m00Tcm4TlvDq8ikWAM`). The `ModelId` part is optional. To use ElevenLabs, you must provide your ElevenLabs API key as an integration identifier secret in `“voice_settings”: “<secret_identifier>”`. See [integration secrets documentation](developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) for details. Check [available voices](elevenlabs.io/docs/api-reference/get-voices).

  • Telnyx: Use ‘Telnyx.<model_id>.<voice_id>` (e.g., `Telnyx.KokoroTTS.af`). Use `voice_settings` to configure voice_speed and other synthesis parameters.

  • Minimax: Use ‘Minimax.<ModelId>.<VoiceId>` (e.g., `Minimax.speech-02-hd.Wise_Woman`). Supported models: `speech-02-turbo`, `speech-02-hd`, `speech-2.6-turbo`, `speech-2.8-turbo`. Use `voice_settings` to configure speed, volume, pitch, and language_boost.

  • Rime: Use ‘Rime.<model_id>.<voice_id>` (e.g., `Rime.Arcana.cove`). Supported model_ids: `Arcana`, `Mist`. Use `voice_settings` to configure voice_speed.

  • Resemble: Use ‘Resemble.Turbo.<voice_id>` (e.g., `Resemble.Turbo.my_voice`). Only `Turbo` model is supported. Use `voice_settings` to configure precision, sample_rate, and format.

  • Inworld: Use ‘Inworld.<ModelId>.<VoiceId>` (e.g., `Inworld.Mini.Loretta`, `Inworld.Max.Oliver`). Supported models: `Mini`, `Max`.

For service_level basic, you may define the gender of the speaker (male or female).

Returns:

  • (String)


67
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 67

required :voice, String

#voice_settingsTelnyx::Models::Calls::ElevenLabsVoiceSettings, ...

The settings associated with the voice selected



162
# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 162

optional :voice_settings, union: -> { Telnyx::Calls::ActionGatherUsingSpeakParams::VoiceSettings }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_gather_using_speak_params.rb', line 240