Class: Telnyx::Models::Calls::ActionPayParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionPayParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_pay_params.rb,
sig/telnyx/models/calls/action_pay_params.rbs
Overview
Defined Under Namespace
Modules: Currency, PaymentMethod, TransactionType Classes: Prompts
Instance Attribute Summary collapse
-
#amount ⇒ Float?
Amount to charge.
- #call_control_id ⇒ String
-
#client_state ⇒ String?
Base64-encoded state included in subsequent webhooks.
-
#command_id ⇒ String?
Idempotency key for the command.
-
#connector_name ⇒ String?
Name of the Pay connector used to process the transaction.
-
#currency ⇒ Symbol, ...
Currency used for the transaction.
-
#description ⇒ String?
Optional description forwarded with the payment transaction.
-
#inter_digit_timeout_millis ⇒ Integer?
Time in milliseconds to wait between consecutive DTMF digits.
-
#language ⇒ String?
Language used for payment prompts.
-
#max_attempts ⇒ Integer?
Maximum number of attempts for each payment collection step.
-
#metadata ⇒ Hash{Symbol=>Object}?
Metadata forwarded to the Pay connector.
-
#parameters ⇒ Hash{Symbol=>Object}?
Additional parameters forwarded to the Pay connector.
-
#payment_method ⇒ Symbol, ...
Payment method to collect.
-
#payment_token ⇒ String?
Existing payment token.
-
#prompts ⇒ Telnyx::Models::Calls::ActionPayParams::Prompts?
Custom text-to-speech prompts keyed by payment collection step.
-
#service_level ⇒ String?
Speech synthesis service level used for payment prompts.
-
#timeout_millis ⇒ Integer?
Time in milliseconds to wait for DTMF input for each collection step.
-
#transaction_type ⇒ Symbol, ...
Transaction to perform.
-
#voice ⇒ String?
Voice used for payment prompts.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(bank_account_number: nil, bank_routing_number: nil, expiration_date: nil, payment_card_number: nil, postal_code: nil, security_code: nil) ⇒ Object
constructor
Custom text-to-speech prompts keyed by payment collection step.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bank_account_number: nil, bank_routing_number: nil, expiration_date: nil, payment_card_number: nil, postal_code: nil, security_code: nil) ⇒ Object
Custom text-to-speech prompts keyed by payment collection step.
|
|
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 129
|
Instance Attribute Details
#amount ⇒ Float?
Amount to charge. Required when transaction_type is charge.
20 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 20 optional :amount, Float |
#call_control_id ⇒ String
14 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 14 required :call_control_id, String |
#client_state ⇒ String?
Base64-encoded state included in subsequent webhooks.
26 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 26 optional :client_state, String |
#command_id ⇒ String?
Idempotency key for the command. Telnyx ignores a duplicate command with the
same command_id for the same call_control_id.
33 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 33 optional :command_id, String |
#connector_name ⇒ String?
Name of the Pay connector used to process the transaction.
39 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 39 optional :connector_name, String |
#currency ⇒ Symbol, ...
Currency used for the transaction. Pay currently supports USD only.
45 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 45 optional :currency, enum: -> { Telnyx::Calls::ActionPayParams::Currency } |
#description ⇒ String?
Optional description forwarded with the payment transaction.
51 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 51 optional :description, String |
#inter_digit_timeout_millis ⇒ Integer?
Time in milliseconds to wait between consecutive DTMF digits.
57 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 57 optional :inter_digit_timeout_millis, Integer |
#language ⇒ String?
Language used for payment prompts.
63 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 63 optional :language, String |
#max_attempts ⇒ Integer?
Maximum number of attempts for each payment collection step.
69 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 69 optional :max_attempts, Integer |
#metadata ⇒ Hash{Symbol=>Object}?
Metadata forwarded to the Pay connector.
75 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 75 optional :metadata, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#parameters ⇒ Hash{Symbol=>Object}?
Additional parameters forwarded to the Pay connector.
81 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 81 optional :parameters, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#payment_method ⇒ Symbol, ...
Payment method to collect.
87 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 87 optional :payment_method, enum: -> { Telnyx::Calls::ActionPayParams::PaymentMethod } |
#payment_token ⇒ String?
Existing payment token. When supplied, payment-detail collection is skipped.
93 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 93 optional :payment_token, String |
#prompts ⇒ Telnyx::Models::Calls::ActionPayParams::Prompts?
Custom text-to-speech prompts keyed by payment collection step.
99 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 99 optional :prompts, -> { Telnyx::Calls::ActionPayParams::Prompts } |
#service_level ⇒ String?
Speech synthesis service level used for payment prompts. Pay defaults to
premium.
106 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 106 optional :service_level, String |
#timeout_millis ⇒ Integer?
Time in milliseconds to wait for DTMF input for each collection step.
112 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 112 optional :timeout_millis, Integer |
#transaction_type ⇒ Symbol, ...
Transaction to perform. If omitted, Pay infers tokenize when amount is
absent or zero and charge when amount is positive.
119 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 119 optional :transaction_type, enum: -> { Telnyx::Calls::ActionPayParams::TransactionType } |
#voice ⇒ String?
Voice used for payment prompts. Accepts male, female, or a provider voice in
<Provider>.<Model>.<VoiceId> format, for example AWS.Polly.Joanna or
Telnyx.KokoroTTS.af.
127 |
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 127 optional :voice, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_pay_params.rb', line 180
|
Instance Method Details
#to_hash ⇒ {
137 |
# File 'sig/telnyx/models/calls/action_pay_params.rbs', line 137
def to_hash: -> {
|