Class: Telnyx::Models::Calls::ActionSpeakParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionSpeakParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_speak_params.rb
Overview
Defined Under Namespace
Modules: Language, PayloadType, ServiceLevel, VoiceSettings
Instance Attribute Summary collapse
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#language ⇒ Symbol, ...
The language you want spoken.
-
#payload ⇒ String
The text or SSML to be converted into speech.
-
#payload_type ⇒ Symbol, ...
The type of the provided payload.
-
#service_level ⇒ Symbol, ...
This parameter impacts speech quality, language options and payload types.
-
#stop ⇒ String?
When specified, it stops the current audio being played.
-
#voice ⇒ String
Specifies the voice used in speech synthesis.
-
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(payload:, voice:, client_state: nil, command_id: nil, language: nil, payload_type: nil, service_level: nil, stop: nil, voice_settings: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionSpeakParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(payload:, voice:, client_state: nil, command_id: nil, language: nil, payload_type: nil, service_level: nil, stop: nil, voice_settings: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionSpeakParams for more details.
|
|
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 100
|
Instance Attribute Details
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
55 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 55 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
62 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 62 optional :command_id, String |
#language ⇒ Symbol, ...
The language you want spoken. This parameter is ignored when a ‘Polly.*` voice is specified.
69 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 69 optional :language, enum: -> { Telnyx::Calls::ActionSpeakParams::Language } |
#payload ⇒ String
The text or SSML to be converted into speech. There is a 3,000 character limit.
15 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 15 required :payload, String |
#payload_type ⇒ Symbol, ...
The type of the provided payload. The payload can either be plain text, or Speech Synthesis Markup Language (SSML).
76 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 76 optional :payload_type, enum: -> { Telnyx::Calls::ActionSpeakParams::PayloadType } |
#service_level ⇒ Symbol, ...
This parameter impacts speech quality, language options and payload types. When using ‘basic`, only the `en-US` language and payload type `text` are allowed.
83 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 83 optional :service_level, enum: -> { Telnyx::Calls::ActionSpeakParams::ServiceLevel } |
#stop ⇒ String?
When specified, it stops the current audio being played. Specify ‘current` to stop the current audio being played, and to play the next file in the queue. Specify `all` to stop the current audio file being played and to also clear all audio files from the queue.
92 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 92 optional :stop, String |
#voice ⇒ String
Specifies the voice used in speech synthesis.
-
Define voices using the format ‘<Provider>.<Model>.<VoiceId>`. Specifying only the provider will give default values for voice_id and model_id.
**Supported Providers:**
-
AWS: Use ‘AWS.Polly.<VoiceId>` (e.g., `AWS.Polly.Joanna`). For neural voices, which provide more realistic, human-like speech, append `-Neural` to the `VoiceId` (e.g., `AWS.Polly.Joanna-Neural`). Check the [available voices](docs.aws.amazon.com/polly/latest/dg/available-voices.html) for compatibility.
-
Azure: Use ‘Azure.<VoiceId>. (e.g. Azure.en-CA-ClaraNeural, Azure.en-CA-LiamNeural, Azure.en-US-BrianMultilingualNeural, Azure.en-US-Ava:DragonHDLatestNeural. For a complete list of voices, go to [Azure Voice Gallery](speech.microsoft.com/portal/voicegallery).)
-
ElevenLabs: Use ‘ElevenLabs.<ModelId>.<VoiceId>` (e.g., `ElevenLabs.eleven_multilingual_v2.21m00Tcm4TlvDq8ikWAM`). The `ModelId` part is optional. To use ElevenLabs, you must provide your ElevenLabs API key as an integration identifier secret in `“voice_settings”: “<secret_identifier>”`. See [integration secrets documentation](developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) for details. Check [available voices](elevenlabs.io/docs/api-reference/get-voices).
-
Telnyx: Use ‘Telnyx.<model_id>.<voice_id>`
For service_level basic, you may define the gender of the speaker (male or female).
48 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 48 required :voice, String |
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected
98 |
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 98 optional :voice_settings, union: -> { Telnyx::Calls::ActionSpeakParams::VoiceSettings } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_speak_params.rb', line 159
|