Class: Telnyx::Models::Calls::ActionStartAIAssistantParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_start_ai_assistant_params.rb,
sig/telnyx/models/calls/action_start_ai_assistant_params.rbs

Overview

See Also:

  • Telnyx::Resources::Calls::Actions#start_ai_assistant

Defined Under Namespace

Modules: MessageHistory

Constant Summary collapse

Telnyx =

Returns:

  • (:CallAssistantRequest)

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_control_id:, assistant: nil, client_state: nil, command_id: nil, greeting: nil, interruption_settings: nil, message_history: nil, participants: nil, send_message_history_updates: nil, transcription: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStartAIAssistantParams for more details.

Parameters:



# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 82

Instance Attribute Details

#assistantTelnyx::Models::CallAssistantRequest?

AI Assistant configuration. All fields except id are optional — the assistant's stored configuration will be used as fallback for any omitted fields.



22
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 22

optional :assistant, -> { Telnyx::CallAssistantRequest }

#call_control_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Parameters:

  • (String)

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 29

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same command_id for the same call_control_id.

Parameters:

  • (String)

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 36

optional :command_id, String

#greetingString?

Text that will be played when the assistant starts, if none then nothing will be played when the assistant starts. The greeting can be text for any voice or SSML for AWS.Polly.<voice_id> voices. There is a 3,000 character limit.

Parameters:

  • (String)

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 44

optional :greeting, String

#interruption_settingsTelnyx::Models::Calls::InterruptionSettings?

Settings for handling user interruptions during assistant speech



50
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 50

optional :interruption_settings, -> { Telnyx::Calls::InterruptionSettings }

#message_historyArray<Telnyx::Models::Calls::UserMessage, Telnyx::Models::Calls::AssistantMessage, Telnyx::Models::Calls::ToolMessage, Telnyx::Models::Calls::SystemMessage, Telnyx::Models::Calls::DeveloperMessage>?

A list of messages to seed the conversation history before the assistant starts. Follows the same message format as the ai_assistant_add_messages command.



57
58
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 57

optional :message_history,
-> { Telnyx::Internal::Type::ArrayOf[union: Telnyx::Calls::ActionStartAIAssistantParams::MessageHistory] }

#participantsArray<Telnyx::Models::Calls::AIAssistantJoinParticipant>?

A list of participants to add to the conversation when it starts.



64
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 64

optional :participants, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Calls::AIAssistantJoinParticipant] }

#send_message_history_updatesBoolean?

When true, a webhook is sent each time the conversation message history is updated.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


71
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 71

optional :send_message_history_updates, Telnyx::Internal::Type::Boolean

#transcriptionTelnyx::Models::Calls::TranscriptionConfig?

The settings associated with speech to text for the voice assistant. This is only relevant if the assistant uses a text-to-text language model. Any assistant using a model with native audio support (e.g. fixie-ai/ultravox-v0_4) will ignore this field.



80
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 80

optional :transcription, -> { Telnyx::Calls::TranscriptionConfig }

Instance Method Details

#to_hash{

Returns:

  • ({)


85
# File 'sig/telnyx/models/calls/action_start_ai_assistant_params.rbs', line 85

def to_hash: -> {