Class: Telnyx::Models::Calls::ActionStartAIAssistantParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionStartAIAssistantParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_start_ai_assistant_params.rb
Overview
Defined Under Namespace
Modules: MessageHistory, VoiceSettings Classes: Participant
Instance Attribute Summary collapse
-
#assistant ⇒ Telnyx::Models::CallAssistantRequest?
AI Assistant configuration.
- #call_control_id ⇒ String
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#greeting ⇒ String?
Text that will be played when the assistant starts, if none then nothing will be played when the assistant starts.
-
#interruption_settings ⇒ Telnyx::Models::Calls::InterruptionSettings?
Settings for handling user interruptions during assistant speech.
-
#message_history ⇒ Array<Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::User, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Assistant, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Tool, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::System, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Developer>?
A list of messages to seed the conversation history before the assistant starts.
-
#participants ⇒ Array<Telnyx::Models::Calls::ActionStartAIAssistantParams::Participant>?
A list of participants to add to the conversation when it starts.
-
#send_message_history_updates ⇒ Boolean?
When ‘true`, a webhook is sent each time the conversation message history is updated.
-
#transcription ⇒ Telnyx::Models::Calls::TranscriptionConfig?
The settings associated with speech to text for the voice assistant.
-
#voice ⇒ String?
The voice to be used by the voice assistant.
-
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::User, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Assistant, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Tool, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::System, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Developer)
Instance Method Summary collapse
-
#initialize(content:, metadata: nil, role: :developer) ⇒ Object
constructor
Developer-provided instructions that the model should follow, regardless of messages sent by the user.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content:, metadata: nil, role: :developer) ⇒ Object
Developer-provided instructions that the model should follow, regardless of messages sent by the user.
|
|
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 118
|
Instance Attribute Details
#assistant ⇒ Telnyx::Models::CallAssistantRequest?
AI Assistant configuration. All fields except ‘id` are optional — the assistant’s stored configuration will be used as fallback for any omitted fields.
22 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 22 optional :assistant, -> { Telnyx::CallAssistantRequest } |
#call_control_id ⇒ String
14 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 14 required :call_control_id, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
29 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 29 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
36 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 36 optional :command_id, String |
#greeting ⇒ String?
Text that will be played when the assistant starts, if none then nothing will be played when the assistant starts. The greeting can be text for any voice or SSML for ‘AWS.Polly.<voice_id>` voices. There is a 3,000 character limit.
44 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 44 optional :greeting, String |
#interruption_settings ⇒ Telnyx::Models::Calls::InterruptionSettings?
Settings for handling user interruptions during assistant speech
50 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 50 optional :interruption_settings, -> { Telnyx::Calls::InterruptionSettings } |
#message_history ⇒ Array<Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::User, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Assistant, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Tool, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::System, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Developer>?
A list of messages to seed the conversation history before the assistant starts. Follows the same message format as the ‘ai_assistant_add_messages` command.
57 58 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 57 optional :message_history, -> { Telnyx::Internal::Type::ArrayOf[union: Telnyx::Calls::ActionStartAIAssistantParams::MessageHistory] } |
#participants ⇒ Array<Telnyx::Models::Calls::ActionStartAIAssistantParams::Participant>?
A list of participants to add to the conversation when it starts.
64 65 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 64 optional :participants, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Calls::ActionStartAIAssistantParams::Participant] } |
#send_message_history_updates ⇒ Boolean?
When ‘true`, a webhook is sent each time the conversation message history is updated.
72 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 72 optional :send_message_history_updates, Telnyx::Internal::Type::Boolean |
#transcription ⇒ Telnyx::Models::Calls::TranscriptionConfig?
The settings associated with speech to text for the voice assistant. This is only relevant if the assistant uses a text-to-text language model. Any assistant using a model with native audio support (e.g. ‘fixie-ai/ultravox-v0_4`) will ignore this field.
81 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 81 optional :transcription, -> { Telnyx::Calls::TranscriptionConfig } |
#voice ⇒ String?
The voice to be used by the voice assistant. Currently we support ElevenLabs, Telnyx and AWS voices.
**Supported Providers:**
-
AWS: Use ‘AWS.Polly.<VoiceId>` (e.g., `AWS.Polly.Joanna`). For neural voices, which provide more realistic, human-like speech, append `-Neural` to the `VoiceId` (e.g., `AWS.Polly.Joanna-Neural`). Check the [available voices](docs.aws.amazon.com/polly/latest/dg/available-voices.html) for compatibility.
-
Azure: Use ‘Azure.<VoiceId>. (e.g. Azure.en-CA-ClaraNeural, Azure.en-CA-LiamNeural, Azure.en-US-BrianMultilingualNeural, Azure.en-US-Ava:DragonHDLatestNeural. For a complete list of voices, go to [Azure Voice Gallery](speech.microsoft.com/portal/voicegallery).)
-
ElevenLabs: Use ‘ElevenLabs.<ModelId>.<VoiceId>` (e.g., `ElevenLabs.BaseModel.John`). The `ModelId` part is optional. To use ElevenLabs, you must provide your ElevenLabs API key as an integration secret under `“voice_settings”: “<secret_id>”`. See [integration secrets documentation](developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) for details. Check [available voices](elevenlabs.io/docs/api-reference/get-voices).
-
Telnyx: Use ‘Telnyx.<model_id>.<voice_id>`
-
Inworld: Use ‘Inworld.<ModelId>.<VoiceId>` (e.g., `Inworld.Mini.Loretta`, `Inworld.Max.Oliver`). Supported models: `Mini`, `Max`.
110 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 110 optional :voice, String |
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected
116 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 116 optional :voice_settings, union: -> { Telnyx::Calls::ActionStartAIAssistantParams::VoiceSettings } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 446
|
.variants ⇒ Array(Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::User, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Assistant, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Tool, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::System, Telnyx::Models::Calls::ActionStartAIAssistantParams::MessageHistory::Developer)
|
|
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 387
|