Class: Telnyx::Models::Calls::ActionStartAIAssistantParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_start_ai_assistant_params.rb

Overview

Defined Under Namespace

Modules: VoiceSettings Classes: Assistant

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, instructions: nil, openai_api_key_ref: nil) ⇒ Object

Some parameter documentations has been truncated, see Assistant for more details.

AI Assistant configuration

Parameters:

  • id (String) (defaults to: nil)

    The identifier of the AI assistant to use

  • instructions (String) (defaults to: nil)

    The system instructions that the voice assistant uses during the start assistant

  • openai_api_key_ref (String) (defaults to: nil)

    Reference to the OpenAI API key. Required only when using OpenAI models



# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 130

Instance Attribute Details

#assistantTelnyx::Models::Calls::ActionStartAIAssistantParams::Assistant?

AI Assistant configuration



15
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 15

optional :assistant, -> { Telnyx::Calls::ActionStartAIAssistantParams::Assistant }

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 22

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 29

optional :command_id, String

#greetingString?

Text that will be played when the assistant starts, if none then nothing will be played when the assistant starts. The greeting can be text for any voice or SSML for ‘AWS.Polly.<voice_id>` voices. There is a 3,000 character limit.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 37

optional :greeting, String

#interruption_settingsTelnyx::Models::Calls::InterruptionSettings?

Settings for handling user interruptions during assistant speech



43
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 43

optional :interruption_settings, -> { Telnyx::Calls::InterruptionSettings }

#transcriptionTelnyx::Models::Calls::TranscriptionConfig?

The settings associated with speech to text for the voice assistant. This is only relevant if the assistant uses a text-to-text language model. Any assistant using a model with native audio support (e.g. ‘fixie-ai/ultravox-v0_4`) will ignore this field.



52
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 52

optional :transcription, -> { Telnyx::Calls::TranscriptionConfig }

#voiceString?

The voice to be used by the voice assistant. Currently we support ElevenLabs, Telnyx and AWS voices.

**Supported Providers:**

Returns:

  • (String, nil)


79
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 79

optional :voice, String

#voice_settingsTelnyx::Models::Calls::ElevenLabsVoiceSettings, ...

The settings associated with the voice selected



85
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 85

optional :voice_settings, union: -> { Telnyx::Calls::ActionStartAIAssistantParams::VoiceSettings }