Class: Telnyx::Models::Calls::ActionStartAIAssistantParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionStartAIAssistantParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_start_ai_assistant_params.rb
Overview
Defined Under Namespace
Modules: VoiceSettings Classes: Assistant
Instance Attribute Summary collapse
-
#assistant ⇒ Telnyx::Models::Calls::ActionStartAIAssistantParams::Assistant?
AI Assistant configuration.
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#greeting ⇒ String?
Text that will be played when the assistant starts, if none then nothing will be played when the assistant starts.
-
#interruption_settings ⇒ Telnyx::Models::Calls::InterruptionSettings?
Settings for handling user interruptions during assistant speech.
-
#transcription ⇒ Telnyx::Models::Calls::TranscriptionConfig?
The settings associated with speech to text for the voice assistant.
-
#voice ⇒ String?
The voice to be used by the voice assistant.
-
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id: nil, instructions: nil, openai_api_key_ref: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Assistant for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, instructions: nil, openai_api_key_ref: nil) ⇒ Object
Some parameter documentations has been truncated, see Assistant for more details.
AI Assistant configuration
|
|
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 130
|
Instance Attribute Details
#assistant ⇒ Telnyx::Models::Calls::ActionStartAIAssistantParams::Assistant?
AI Assistant configuration
15 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 15 optional :assistant, -> { Telnyx::Calls::ActionStartAIAssistantParams::Assistant } |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
22 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 22 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
29 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 29 optional :command_id, String |
#greeting ⇒ String?
Text that will be played when the assistant starts, if none then nothing will be played when the assistant starts. The greeting can be text for any voice or SSML for ‘AWS.Polly.<voice_id>` voices. There is a 3,000 character limit.
37 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 37 optional :greeting, String |
#interruption_settings ⇒ Telnyx::Models::Calls::InterruptionSettings?
Settings for handling user interruptions during assistant speech
43 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 43 optional :interruption_settings, -> { Telnyx::Calls::InterruptionSettings } |
#transcription ⇒ Telnyx::Models::Calls::TranscriptionConfig?
The settings associated with speech to text for the voice assistant. This is only relevant if the assistant uses a text-to-text language model. Any assistant using a model with native audio support (e.g. ‘fixie-ai/ultravox-v0_4`) will ignore this field.
52 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 52 optional :transcription, -> { Telnyx::Calls::TranscriptionConfig } |
#voice ⇒ String?
The voice to be used by the voice assistant. Currently we support ElevenLabs, Telnyx and AWS voices.
**Supported Providers:**
-
AWS: Use ‘AWS.Polly.<VoiceId>` (e.g., `AWS.Polly.Joanna`). For neural voices, which provide more realistic, human-like speech, append `-Neural` to the `VoiceId` (e.g., `AWS.Polly.Joanna-Neural`). Check the [available voices](docs.aws.amazon.com/polly/latest/dg/available-voices.html) for compatibility.
-
Azure: Use ‘Azure.<VoiceId>. (e.g. Azure.en-CA-ClaraNeural, Azure.en-CA-LiamNeural, Azure.en-US-BrianMultilingualNeural, Azure.en-US-Ava:DragonHDLatestNeural. For a complete list of voices, go to [Azure Voice Gallery](speech.microsoft.com/portal/voicegallery).)
-
ElevenLabs: Use ‘ElevenLabs.<ModelId>.<VoiceId>` (e.g., `ElevenLabs.BaseModel.John`). The `ModelId` part is optional. To use ElevenLabs, you must provide your ElevenLabs API key as an integration secret under `“voice_settings”: “<secret_id>”`. See [integration secrets documentation](developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) for details. Check [available voices](elevenlabs.io/docs/api-reference/get-voices).
-
Telnyx: Use ‘Telnyx.<model_id>.<voice_id>`
79 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 79 optional :voice, String |
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected
85 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 85 optional :voice_settings, union: -> { Telnyx::Calls::ActionStartAIAssistantParams::VoiceSettings } |