Class: Telnyx::Models::Calls::ActionStartAIAssistantParams::Assistant
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionStartAIAssistantParams::Assistant
- Defined in:
- lib/telnyx/models/calls/action_start_ai_assistant_params.rb
Instance Attribute Summary collapse
-
#id ⇒ String?
The identifier of the AI assistant to use.
-
#instructions ⇒ String?
The system instructions that the voice assistant uses during the start assistant command.
-
#openai_api_key_ref ⇒ String?
Reference to the OpenAI API key.
Instance Method Summary collapse
-
#initialize(assistant: nil, client_state: nil, command_id: nil, greeting: nil, interruption_settings: nil, transcription: nil, voice: nil, voice_settings: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStartAIAssistantParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assistant: nil, client_state: nil, command_id: nil, greeting: nil, interruption_settings: nil, transcription: nil, voice: nil, voice_settings: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStartAIAssistantParams for more details.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 109 class Assistant < Telnyx::Internal::Type::BaseModel # @!attribute id # The identifier of the AI assistant to use # # @return [String, nil] optional :id, String # @!attribute instructions # The system instructions that the voice assistant uses during the start assistant # command. This will overwrite the instructions set in the assistant # configuration. # # @return [String, nil] optional :instructions, String # @!attribute openai_api_key_ref # Reference to the OpenAI API key. Required only when using OpenAI models # # @return [String, nil] optional :openai_api_key_ref, String # @!method initialize(id: nil, instructions: nil, openai_api_key_ref: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::Calls::ActionStartAIAssistantParams::Assistant} for more # details. # # AI Assistant configuration # # @param id [String] The identifier of the AI assistant to use # # @param instructions [String] The system instructions that the voice assistant uses during the start assistant # # @param openai_api_key_ref [String] Reference to the OpenAI API key. Required only when using OpenAI models end |
Instance Attribute Details
#id ⇒ String?
The identifier of the AI assistant to use
114 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 114 optional :id, String |
#instructions ⇒ String?
The system instructions that the voice assistant uses during the start assistant command. This will overwrite the instructions set in the assistant configuration.
122 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 122 optional :instructions, String |
#openai_api_key_ref ⇒ String?
Reference to the OpenAI API key. Required only when using OpenAI models
128 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 128 optional :openai_api_key_ref, String |