Class: Telnyx::Models::Calls::ActionStartAIAssistantParams::Participant
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionStartAIAssistantParams::Participant
- Defined in:
- lib/telnyx/models/calls/action_start_ai_assistant_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#id ⇒ String
The call_control_id of the participant to add to the conversation.
-
#name ⇒ String?
Display name for the participant.
-
#on_hangup ⇒ Symbol, ...
Determines what happens to the conversation when this participant hangs up.
-
#role ⇒ Symbol, Telnyx::Models::Calls::ActionStartAIAssistantParams::Participant::Role
The role of the participant in the conversation.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, role:, name: nil, on_hangup: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 416
|
Instance Attribute Details
#id ⇒ String
The call_control_id of the participant to add to the conversation.
396 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 396 required :id, String |
#name ⇒ String?
Display name for the participant.
408 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 408 optional :name, String |
#on_hangup ⇒ Symbol, ...
Determines what happens to the conversation when this participant hangs up.
414 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 414 optional :on_hangup, enum: -> { Telnyx::Calls::ActionStartAIAssistantParams::Participant::OnHangup } |
#role ⇒ Symbol, Telnyx::Models::Calls::ActionStartAIAssistantParams::Participant::Role
The role of the participant in the conversation.
402 |
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 402 required :role, enum: -> { Telnyx::Calls::ActionStartAIAssistantParams::Participant::Role } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_start_ai_assistant_params.rb', line 433
|