Class: Telnyx::Models::Calls::ActionStartConversationRelayParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_start_conversation_relay_params.rb

Overview

Defined Under Namespace

Modules: VoiceSettings Classes: Assistant, InterruptionSettings, Language, Participant, Transcription

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(language: nil, model: nil, provider: nil) ⇒ Object

Speech-to-text settings for Conversation Relay.

Parameters:

  • language (String) (defaults to: nil)

    Transcription language.

  • model (String) (defaults to: nil)

    Transcription model to use.

  • provider (String) (defaults to: nil)

    Transcription provider to use.



# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 203

Instance Attribute Details

#assistantTelnyx::Models::Calls::ActionStartConversationRelayParams::Assistant?

Custom parameters for the Conversation Relay session. Pass key-value data as ‘assistant.dynamic_variables` to make it available to the relay session.



28
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 28

optional :assistant, -> { Telnyx::Calls::ActionStartConversationRelayParams::Assistant }

#call_control_idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 14

required :call_control_id, String

#client_stateString?

Use this field to add state to subsequent webhooks. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 35

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 42

optional :command_id, String

#conversation_relay_dtmf_detectionBoolean?

Enable DTMF detection for the relay session.

Returns:

  • (Boolean, nil)


48
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 48

optional :conversation_relay_dtmf_detection, Telnyx::Internal::Type::Boolean

#conversation_relay_urlString

WebSocket URL for your Conversation Relay server. Must start with ‘ws://` or `wss://`.

Returns:

  • (String)


21
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 21

required :conversation_relay_url, String

#greetingString?

Text played when the relay session starts.

Returns:

  • (String, nil)


54
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 54

optional :greeting, String

#interruption_settingsTelnyx::Models::Calls::ActionStartConversationRelayParams::InterruptionSettings?

Settings for handling caller interruptions during Conversation Relay speech.



60
61
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 60

optional :interruption_settings,
-> { Telnyx::Calls::ActionStartConversationRelayParams::InterruptionSettings }

#languageString?

Default language for the relay session. This value is used for both text-to-speech and speech recognition unless ‘tts_language` or `transcription_language` are provided.

Returns:

  • (String, nil)


69
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 69

optional :language, String

#languagesArray<Telnyx::Models::Calls::ActionStartConversationRelayParams::Language>?

Language-specific TTS and transcription settings. Use this when the relay session needs per-language provider, voice, or speech model configuration.



76
77
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 76

optional :languages,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Calls::ActionStartConversationRelayParams::Language] }

#participantsArray<Telnyx::Models::Calls::ActionStartConversationRelayParams::Participant>?

Participants to add to the conversation.



83
84
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 83

optional :participants,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Calls::ActionStartConversationRelayParams::Participant] }

#send_message_history_updatesBoolean?

When true, sends message history update webhooks.

Returns:

  • (Boolean, nil)


90
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 90

optional :send_message_history_updates, Telnyx::Internal::Type::Boolean

#transcriptionTelnyx::Models::Calls::ActionStartConversationRelayParams::Transcription?

Speech-to-text settings for Conversation Relay.



96
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 96

optional :transcription, -> { Telnyx::Calls::ActionStartConversationRelayParams::Transcription }

#transcription_languageString?

Language to use for speech recognition. Overrides ‘language` for transcription when provided.

Returns:

  • (String, nil)


103
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 103

optional :transcription_language, String

#tts_languageString?

Language to use for text-to-speech. Overrides ‘language` for TTS when provided.

Returns:

  • (String, nil)


109
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 109

optional :tts_language, String

#user_response_timeout_msInteger?

Time in milliseconds to wait for caller input before timing out.

Returns:

  • (Integer, nil)


115
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 115

optional :user_response_timeout_ms, Integer

#voiceString?

The voice to be used by the voice assistant. Currently we support ElevenLabs, Telnyx and AWS voices.

**Supported Providers:**

  • AWS: Use ‘AWS.Polly.<VoiceId>` (e.g., `AWS.Polly.Joanna`). For neural voices, which provide more realistic, human-like speech, append `-Neural` to the `VoiceId` (e.g., `AWS.Polly.Joanna-Neural`). Check the [available voices](docs.aws.amazon.com/polly/latest/dg/available-voices.html) for compatibility.

  • Azure: Use ‘Azure.<VoiceId>. (e.g. Azure.en-CA-ClaraNeural, Azure.en-CA-LiamNeural, Azure.en-US-BrianMultilingualNeural, Azure.en-US-Ava:DragonHDLatestNeural. For a complete list of voices, go to [Azure Voice Gallery](speech.microsoft.com/portal/voicegallery).)

  • ElevenLabs: Use ‘ElevenLabs.<ModelId>.<VoiceId>` (e.g., `ElevenLabs.BaseModel.John`). The `ModelId` part is optional. To use ElevenLabs, you must provide your ElevenLabs API key as an integration secret under `“voice_settings”: “<secret_id>”`. See [integration secrets documentation](developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) for details. Check [available voices](elevenlabs.io/docs/api-reference/get-voices).

  • Telnyx: Use ‘Telnyx.<model_id>.<voice_id>`

  • Inworld: Use ‘Inworld.<ModelId>.<VoiceId>` (e.g., `Inworld.Mini.Loretta`, `Inworld.Max.Oliver`). Supported models: `Mini`, `Max`.

  • xAI: Use ‘xAI.<VoiceId>` (e.g., `xAI.eve`). Available voices: `eve`, `ara`, `rex`, `sal`, `leo`.

Returns:

  • (String, nil)


146
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 146

optional :voice, String

#voice_settingsTelnyx::Models::Calls::ElevenLabsVoiceSettings, ...

The settings associated with the voice selected



152
# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 152

optional :voice_settings, union: -> { Telnyx::Calls::ActionStartConversationRelayParams::VoiceSettings }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_start_conversation_relay_params.rb', line 307