Class: Telnyx::Models::Calls::ActionStartRecordingParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_start_recording_params.rb

Overview

Defined Under Namespace

Modules: Channels, Format, RecordingTrack, TranscriptionEngine, TranscriptionLanguage, Trim

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channels:, format_:, client_state: nil, command_id: nil, custom_file_name: nil, max_length: nil, play_beep: nil, recording_track: nil, timeout_secs: nil, transcription: nil, transcription_engine: nil, transcription_language: nil, transcription_max_speaker_count: nil, transcription_min_speaker_count: nil, transcription_profanity_filter: nil, transcription_speaker_diarization: nil, trim: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStartRecordingParams for more details.

Parameters:

  • channels (Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::Channels)

    When ‘dual`, final audio file will be stereo recorded with the first leg on chan

  • format_ (Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::Format)

    The audio file format used when storing the call recording. Can be either ‘mp3`

  • client_state (String) (defaults to: nil)

    Use this field to add state to every subsequent webhook. It must be a valid Base

  • command_id (String) (defaults to: nil)

    Use this field to avoid duplicate commands. Telnyx will ignore any command with

  • custom_file_name (String) (defaults to: nil)

    The custom recording file name to be used instead of the default ‘call_leg_id`.

  • max_length (Integer) (defaults to: nil)

    Defines the maximum length for the recording in seconds. The minimum value is 0.

  • play_beep (Boolean) (defaults to: nil)

    If enabled, a beep sound will be played at the start of a recording.

  • recording_track (Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::RecordingTrack) (defaults to: nil)

    The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. I

  • timeout_secs (Integer) (defaults to: nil)

    The number of seconds that Telnyx will wait for the recording to be stopped if s

  • transcription (Boolean) (defaults to: nil)

    Enable post recording transcription. The default value is false.

  • transcription_engine (Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::TranscriptionEngine) (defaults to: nil)

    Engine to use for speech recognition. ‘A` - `Google`, `B` - `Telnyx`, `deepgram/

  • transcription_language (Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::TranscriptionLanguage) (defaults to: nil)
  • transcription_max_speaker_count (Integer) (defaults to: nil)

    Defines maximum number of speakers in the conversation. Applies to ‘google` engi

  • transcription_min_speaker_count (Integer) (defaults to: nil)

    Defines minimum number of speakers in the conversation. Applies to ‘google` engi

  • transcription_profanity_filter (Boolean) (defaults to: nil)

    Enables profanity_filter. Applies to ‘google` engine only.

  • transcription_speaker_diarization (Boolean) (defaults to: nil)

    Enables speaker diarization. Applies to ‘google` engine only.

  • trim (Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::Trim) (defaults to: nil)

    When set to ‘trim-silence`, silence will be removed from the beginning and end o

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 130

Instance Attribute Details

#channelsSymbol, Telnyx::Models::Calls::ActionStartRecordingParams::Channels

When ‘dual`, final audio file will be stereo recorded with the first leg on channel A, and the rest on channel B.



16
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 16

required :channels, enum: -> { Telnyx::Calls::ActionStartRecordingParams::Channels }

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 30

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 37

optional :command_id, String

#custom_file_nameString?

The custom recording file name to be used instead of the default ‘call_leg_id`. Telnyx will still add a Unix timestamp suffix.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 44

optional :custom_file_name, String

#format_Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::Format

The audio file format used when storing the call recording. Can be either ‘mp3` or `wav`.



23
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 23

required :format_, enum: -> { Telnyx::Calls::ActionStartRecordingParams::Format }, api_name: :format

#max_lengthInteger?

Defines the maximum length for the recording in seconds. The minimum value is 0. The maximum value is 14400. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


51
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 51

optional :max_length, Integer

#play_beepBoolean?

If enabled, a beep sound will be played at the start of a recording.

Returns:

  • (Boolean, nil)


57
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 57

optional :play_beep, Telnyx::Internal::Type::Boolean

#recording_trackSymbol, ...

The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. If only single track is specified (`inbound`, `outbound`), `channels` configuration is ignored and it will be recorded as mono (single channel).



65
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 65

optional :recording_track, enum: -> { Telnyx::Calls::ActionStartRecordingParams::RecordingTrack }

#timeout_secsInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that call transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


74
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 74

optional :timeout_secs, Integer

#transcriptionBoolean?

Enable post recording transcription. The default value is false.

Returns:

  • (Boolean, nil)


80
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 80

optional :transcription, Telnyx::Internal::Type::Boolean

#transcription_engineSymbol, ...

Engine to use for speech recognition. ‘A` - `Google`, `B` - `Telnyx`, `deepgram/nova-3` - `Deepgram Nova-3`. Note: `deepgram/nova-3` supports only `en` and `en-Region` languages.



88
89
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 88

optional :transcription_engine,
enum: -> { Telnyx::Calls::ActionStartRecordingParams::TranscriptionEngine }

#transcription_languageSymbol, ...



94
95
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 94

optional :transcription_language,
enum: -> { Telnyx::Calls::ActionStartRecordingParams::TranscriptionLanguage }

#transcription_max_speaker_countInteger?

Defines maximum number of speakers in the conversation. Applies to ‘google` engine only.

Returns:

  • (Integer, nil)


102
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 102

optional :transcription_max_speaker_count, Integer

#transcription_min_speaker_countInteger?

Defines minimum number of speakers in the conversation. Applies to ‘google` engine only.

Returns:

  • (Integer, nil)


109
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 109

optional :transcription_min_speaker_count, Integer

#transcription_profanity_filterBoolean?

Enables profanity_filter. Applies to ‘google` engine only.

Returns:

  • (Boolean, nil)


115
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 115

optional :transcription_profanity_filter, Telnyx::Internal::Type::Boolean

#transcription_speaker_diarizationBoolean?

Enables speaker diarization. Applies to ‘google` engine only.

Returns:

  • (Boolean, nil)


121
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 121

optional :transcription_speaker_diarization, Telnyx::Internal::Type::Boolean

#trimSymbol, ...

When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.



128
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 128

optional :trim, enum: -> { Telnyx::Calls::ActionStartRecordingParams::Trim }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 178