Class: Telnyx::Models::Calls::ActionStartRecordingParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionStartRecordingParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_start_recording_params.rb
Overview
Defined Under Namespace
Modules: Channels, Format, RecordingTrack, TranscriptionEngine, TranscriptionLanguage, Trim
Instance Attribute Summary collapse
-
#channels ⇒ Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::Channels
When ‘dual`, final audio file will be stereo recorded with the first leg on channel A, and the rest on channel B.
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#custom_file_name ⇒ String?
The custom recording file name to be used instead of the default ‘call_leg_id`.
-
#format_ ⇒ Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::Format
The audio file format used when storing the call recording.
-
#max_length ⇒ Integer?
Defines the maximum length for the recording in seconds.
-
#play_beep ⇒ Boolean?
If enabled, a beep sound will be played at the start of a recording.
-
#recording_track ⇒ Symbol, ...
The audio track to be recorded.
-
#timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected.
-
#transcription ⇒ Boolean?
Enable post recording transcription.
-
#transcription_engine ⇒ Symbol, ...
Engine to use for speech recognition.
- #transcription_language ⇒ Symbol, ...
-
#transcription_max_speaker_count ⇒ Integer?
Defines maximum number of speakers in the conversation.
-
#transcription_min_speaker_count ⇒ Integer?
Defines minimum number of speakers in the conversation.
-
#transcription_profanity_filter ⇒ Boolean?
Enables profanity_filter.
-
#transcription_speaker_diarization ⇒ Boolean?
Enables speaker diarization.
-
#trim ⇒ Symbol, ...
When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(channels:, format_:, client_state: nil, command_id: nil, custom_file_name: nil, max_length: nil, play_beep: nil, recording_track: nil, timeout_secs: nil, transcription: nil, transcription_engine: nil, transcription_language: nil, transcription_max_speaker_count: nil, transcription_min_speaker_count: nil, transcription_profanity_filter: nil, transcription_speaker_diarization: nil, trim: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionStartRecordingParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channels:, format_:, client_state: nil, command_id: nil, custom_file_name: nil, max_length: nil, play_beep: nil, recording_track: nil, timeout_secs: nil, transcription: nil, transcription_engine: nil, transcription_language: nil, transcription_max_speaker_count: nil, transcription_min_speaker_count: nil, transcription_profanity_filter: nil, transcription_speaker_diarization: nil, trim: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStartRecordingParams for more details.
|
|
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 130
|
Instance Attribute Details
#channels ⇒ Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::Channels
When ‘dual`, final audio file will be stereo recorded with the first leg on channel A, and the rest on channel B.
16 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 16 required :channels, enum: -> { Telnyx::Calls::ActionStartRecordingParams::Channels } |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
30 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 30 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
37 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 37 optional :command_id, String |
#custom_file_name ⇒ String?
The custom recording file name to be used instead of the default ‘call_leg_id`. Telnyx will still add a Unix timestamp suffix.
44 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 44 optional :custom_file_name, String |
#format_ ⇒ Symbol, Telnyx::Models::Calls::ActionStartRecordingParams::Format
The audio file format used when storing the call recording. Can be either ‘mp3` or `wav`.
23 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 23 required :format_, enum: -> { Telnyx::Calls::ActionStartRecordingParams::Format }, api_name: :format |
#max_length ⇒ Integer?
Defines the maximum length for the recording in seconds. The minimum value is 0. The maximum value is 14400. The default value is 0 (infinite)
51 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 51 optional :max_length, Integer |
#play_beep ⇒ Boolean?
If enabled, a beep sound will be played at the start of a recording.
57 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 57 optional :play_beep, Telnyx::Internal::Type::Boolean |
#recording_track ⇒ Symbol, ...
The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. If only single track is specified (`inbound`, `outbound`), `channels` configuration is ignored and it will be recorded as mono (single channel).
65 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 65 optional :recording_track, enum: -> { Telnyx::Calls::ActionStartRecordingParams::RecordingTrack } |
#timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that call transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)
74 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 74 optional :timeout_secs, Integer |
#transcription ⇒ Boolean?
Enable post recording transcription. The default value is false.
80 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 80 optional :transcription, Telnyx::Internal::Type::Boolean |
#transcription_engine ⇒ Symbol, ...
Engine to use for speech recognition. ‘A` - `Google`, `B` - `Telnyx`, `deepgram/nova-3` - `Deepgram Nova-3`. Note: `deepgram/nova-3` supports only `en` and `en-Region` languages.
88 89 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 88 optional :transcription_engine, enum: -> { Telnyx::Calls::ActionStartRecordingParams::TranscriptionEngine } |
#transcription_language ⇒ Symbol, ...
94 95 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 94 optional :transcription_language, enum: -> { Telnyx::Calls::ActionStartRecordingParams::TranscriptionLanguage } |
#transcription_max_speaker_count ⇒ Integer?
Defines maximum number of speakers in the conversation. Applies to ‘google` engine only.
102 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 102 optional :transcription_max_speaker_count, Integer |
#transcription_min_speaker_count ⇒ Integer?
Defines minimum number of speakers in the conversation. Applies to ‘google` engine only.
109 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 109 optional :transcription_min_speaker_count, Integer |
#transcription_profanity_filter ⇒ Boolean?
Enables profanity_filter. Applies to ‘google` engine only.
115 |
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 115 optional :transcription_profanity_filter, Telnyx::Internal::Type::Boolean |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_start_recording_params.rb', line 178
|