Class: Telnyx::Models::Calls::ActionStartStreamingParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionStartStreamingParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_start_streaming_params.rb
Overview
Defined Under Namespace
Modules: StreamTrack
Instance Attribute Summary collapse
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
- #dialogflow_config ⇒ Telnyx::Models::DialogflowConfig?
-
#enable_dialogflow ⇒ Boolean?
Enables Dialogflow for the current call.
-
#stream_bidirectional_codec ⇒ Symbol, ...
Indicates codec for bidirectional streaming RTP payloads.
-
#stream_bidirectional_mode ⇒ Symbol, ...
Configures method of bidirectional streaming (mp3, rtp).
-
#stream_bidirectional_sampling_rate ⇒ Integer, ...
Audio sampling rate.
-
#stream_bidirectional_target_legs ⇒ Symbol, ...
Specifies which call legs should receive the bidirectional stream audio.
-
#stream_codec ⇒ Symbol, ...
Specifies the codec to be used for the streamed audio.
-
#stream_track ⇒ Symbol, ...
Specifies which track should be streamed.
-
#stream_url ⇒ String?
The destination WebSocket address where the stream is going to be delivered.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(client_state: nil, command_id: nil, dialogflow_config: nil, enable_dialogflow: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_sampling_rate: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionStartStreamingParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(client_state: nil, command_id: nil, dialogflow_config: nil, enable_dialogflow: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_sampling_rate: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::ActionStartStreamingParams for more details.
stream_
|
|
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 80
|
Instance Attribute Details
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
16 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 16 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
23 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 23 optional :command_id, String |
#dialogflow_config ⇒ Telnyx::Models::DialogflowConfig?
28 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 28 optional :dialogflow_config, -> { Telnyx::DialogflowConfig } |
#enable_dialogflow ⇒ Boolean?
Enables Dialogflow for the current call. The default value is false.
34 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 34 optional :enable_dialogflow, Telnyx::Internal::Type::Boolean |
#stream_bidirectional_codec ⇒ Symbol, ...
Indicates codec for bidirectional streaming RTP payloads. Used only with stream_bidirectional_mode=rtp. Case sensitive.
41 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 41 optional :stream_bidirectional_codec, enum: -> { Telnyx::StreamBidirectionalCodec } |
#stream_bidirectional_mode ⇒ Symbol, ...
Configures method of bidirectional streaming (mp3, rtp).
47 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 47 optional :stream_bidirectional_mode, enum: -> { Telnyx::StreamBidirectionalMode } |
#stream_bidirectional_sampling_rate ⇒ Integer, ...
Audio sampling rate.
53 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 53 optional :stream_bidirectional_sampling_rate, enum: -> { Telnyx::StreamBidirectionalSamplingRate } |
#stream_bidirectional_target_legs ⇒ Symbol, ...
Specifies which call legs should receive the bidirectional stream audio.
59 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 59 optional :stream_bidirectional_target_legs, enum: -> { Telnyx::StreamBidirectionalTargetLegs } |
#stream_codec ⇒ Symbol, ...
Specifies the codec to be used for the streamed audio. When set to ‘default’ or when transcoding is not possible, the codec from the call will be used.
66 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 66 optional :stream_codec, enum: -> { Telnyx::StreamCodec } |
#stream_track ⇒ Symbol, ...
Specifies which track should be streamed.
72 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 72 optional :stream_track, enum: -> { Telnyx::Calls::ActionStartStreamingParams::StreamTrack } |
#stream_url ⇒ String?
The destination WebSocket address where the stream is going to be delivered.
78 |
# File 'lib/telnyx/models/calls/action_start_streaming_params.rb', line 78 optional :stream_url, String |