Class: Telnyx::Models::Calls::ActionTransferParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionTransferParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_transfer_params.rb
Overview
Defined Under Namespace
Modules: AnsweringMachineDetection, MediaEncryption, MuteDtmf, Privacy, Record, RecordChannels, RecordFormat, RecordTrack, RecordTrim, SipRegion, SipTransportProtocol, WebhookURLMethod, WebhookURLsMethod Classes: AnsweringMachineDetectionConfig, WebhookRetriesPolicy
Instance Attribute Summary collapse
-
#answering_machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection.
-
#answering_machine_detection_config ⇒ Telnyx::Models::Calls::ActionTransferParams::AnsweringMachineDetectionConfig?
Optional configuration parameters to modify ‘answering_machine_detection’ performance.
-
#audio_url ⇒ String?
The URL of a file to be played back when the transfer destination answers before bridging the call.
- #call_control_id ⇒ String
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers to be added to the SIP INVITE.
-
#early_media ⇒ Boolean?
If set to false, early media will not be passed to the originating leg.
-
#from ⇒ String?
The ‘from` number to be used as the caller id presented to the destination (`to` number).
-
#from_display_name ⇒ String?
The ‘from_display_name` string to be used as the caller id name (SIP From Display Name) presented to the destination (`to` number).
-
#media_encryption ⇒ Symbol, ...
Defines whether media should be encrypted on the new call leg.
-
#media_name ⇒ String?
The media_name of a file to be played back when the transfer destination answers before bridging the call.
-
#mute_dtmf ⇒ Symbol, ...
When enabled, DTMF tones are not passed to the call participant.
-
#park_after_unbridge ⇒ String?
Specifies behavior after the bridge ends (i.e. the opposite leg either hangs up or is transferred).
-
#preferred_codecs ⇒ String?
The list of comma-separated codecs in order of preference to be used during the call.
-
#privacy ⇒ Symbol, ...
Indicates the privacy level to be used for the call.
-
#record ⇒ Symbol, ...
Start recording automatically after an event.
-
#record_channels ⇒ Symbol, ...
Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.
-
#record_custom_file_name ⇒ String?
The custom recording file name to be used instead of the default ‘call_leg_id`.
-
#record_format ⇒ Symbol, ...
Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.
-
#record_max_length ⇒ Integer?
Defines the maximum length for the recording in seconds when ‘record` is specified.
-
#record_timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified.
-
#record_track ⇒ Symbol, ...
The audio track to be recorded.
-
#record_trim ⇒ Symbol, ...
When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.
-
#sip_auth_password ⇒ String?
SIP Authentication password used for SIP challenges.
-
#sip_auth_username ⇒ String?
SIP Authentication username used for SIP challenges.
-
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
SIP headers to be added to the SIP INVITE.
-
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
-
#sip_transport_protocol ⇒ Symbol, ...
Defines SIP transport protocol to be used on the call.
-
#sound_modifications ⇒ Telnyx::Models::SoundModifications?
Use this field to modify sound effects, for example adjust the pitch.
-
#target_leg_client_state ⇒ String?
Use this field to add state to every subsequent webhook for the new leg.
-
#time_limit_secs ⇒ Integer?
Sets the maximum duration of a Call Control Leg in seconds.
-
#timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the call to be answered by the destination to which it is being transferred.
-
#to ⇒ String
The DID or SIP URI to dial out to.
-
#webhook_retries_policies ⇒ Hash{Symbol=>Telnyx::Models::Calls::ActionTransferParams::WebhookRetriesPolicy}?
A map of event types to retry policies.
-
#webhook_url ⇒ String?
Use this field to override the URL for which Telnyx will send subsequent webhooks to for this call.
-
#webhook_url_method ⇒ Symbol, ...
HTTP request type used for ‘webhook_url`.
-
#webhook_urls ⇒ Hash{Symbol=>String}?
A map of event types to webhook URLs.
-
#webhook_urls_method ⇒ Symbol, ...
HTTP request method to invoke ‘webhook_urls`.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(retries_ms: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebhookRetriesPolicy for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(retries_ms: nil) ⇒ Object
Some parameter documentations has been truncated, see WebhookRetriesPolicy for more details.
|
|
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 301
|
Instance Attribute Details
#answering_machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection. When a call is answered, Telnyx runs real-time detection to determine if it was picked up by a human or a machine and sends an ‘call.machine.detection.ended` webhook with the analysis result. If ’greeting_end’ or ‘detect_words’ is used and a ‘machine’ is detected, you will receive another ‘call.machine.greeting.ended’ webhook when the answering machine greeting ends with a beep or silence. If ‘detect_beep` is used, you will only receive ’call.machine.greeting.ended’ if a beep is detected.
32 33 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 32 optional :answering_machine_detection, enum: -> { Telnyx::Calls::ActionTransferParams::AnsweringMachineDetection } |
#answering_machine_detection_config ⇒ Telnyx::Models::Calls::ActionTransferParams::AnsweringMachineDetectionConfig?
Optional configuration parameters to modify ‘answering_machine_detection’ performance.
40 41 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 40 optional :answering_machine_detection_config, -> { Telnyx::Calls::ActionTransferParams::AnsweringMachineDetectionConfig } |
#audio_url ⇒ String?
The URL of a file to be played back when the transfer destination answers before bridging the call. The URL can point to either a WAV or MP3 file. media_name and audio_url cannot be used together in one request.
49 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 49 optional :audio_url, String |
#call_control_id ⇒ String
14 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 14 required :call_control_id, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
56 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 56 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
63 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 63 optional :command_id, String |
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers to be added to the SIP INVITE.
69 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 69 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] } |
#early_media ⇒ Boolean?
If set to false, early media will not be passed to the originating leg.
75 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 75 optional :early_media, Telnyx::Internal::Type::Boolean |
#from ⇒ String?
The ‘from` number to be used as the caller id presented to the destination (`to` number). The number should be in +E164 format. This attribute will default to the `to` number of the original call if omitted.
83 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 83 optional :from, String |
#from_display_name ⇒ String?
The ‘from_display_name` string to be used as the caller id name (SIP From Display Name) presented to the destination (`to` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and -_~!.+ special characters. If ommited, the display name will be the same as the number in the `from` field.
93 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 93 optional :from_display_name, String |
#media_encryption ⇒ Symbol, ...
Defines whether media should be encrypted on the new call leg.
99 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 99 optional :media_encryption, enum: -> { Telnyx::Calls::ActionTransferParams::MediaEncryption } |
#media_name ⇒ String?
The media_name of a file to be played back when the transfer destination answers before bridging the call. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file.
108 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 108 optional :media_name, String |
#mute_dtmf ⇒ Symbol, ...
When enabled, DTMF tones are not passed to the call participant. The webhooks containing the DTMF information will be sent.
115 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 115 optional :mute_dtmf, enum: -> { Telnyx::Calls::ActionTransferParams::MuteDtmf } |
#park_after_unbridge ⇒ String?
Specifies behavior after the bridge ends (i.e. the opposite leg either hangs up or is transferred). If supplied with the value ‘self`, the current leg will be parked after unbridge. If not set, the default behavior is to hang up the leg.
123 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 123 optional :park_after_unbridge, String |
#preferred_codecs ⇒ String?
The list of comma-separated codecs in order of preference to be used during the call. The codecs supported are ‘G722`, `PCMU`, `PCMA`, `G729`, `OPUS`, `VP8`, `H264`, `AMR-WB`.
131 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 131 optional :preferred_codecs, String |
#privacy ⇒ Symbol, ...
Indicates the privacy level to be used for the call. When set to ‘id`, caller ID information (name and number) will be hidden from the called party. When set to `none` or omitted, caller ID will be shown normally.
139 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 139 optional :privacy, enum: -> { Telnyx::Calls::ActionTransferParams::Privacy } |
#record ⇒ Symbol, ...
Start recording automatically after an event. Disabled by default.
145 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 145 optional :record, enum: -> { Telnyx::Calls::ActionTransferParams::Record } |
#record_channels ⇒ Symbol, ...
Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.
152 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 152 optional :record_channels, enum: -> { Telnyx::Calls::ActionTransferParams::RecordChannels } |
#record_custom_file_name ⇒ String?
The custom recording file name to be used instead of the default ‘call_leg_id`. Telnyx will still add a Unix timestamp suffix.
159 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 159 optional :record_custom_file_name, String |
#record_format ⇒ Symbol, ...
Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.
165 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 165 optional :record_format, enum: -> { Telnyx::Calls::ActionTransferParams::RecordFormat } |
#record_max_length ⇒ Integer?
Defines the maximum length for the recording in seconds when ‘record` is specified. The minimum value is 0. The maximum value is 43200. The default value is 0 (infinite).
173 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 173 optional :record_max_length, Integer |
#record_timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified. The timer only starts when the speech is detected. Please note that call transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite).
183 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 183 optional :record_timeout_secs, Integer |
#record_track ⇒ Symbol, ...
The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. If only single track is specified (`inbound`, `outbound`), `channels` configuration is ignored and it will be recorded as mono (single channel).
191 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 191 optional :record_track, enum: -> { Telnyx::Calls::ActionTransferParams::RecordTrack } |
#record_trim ⇒ Symbol, ...
When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.
198 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 198 optional :record_trim, enum: -> { Telnyx::Calls::ActionTransferParams::RecordTrim } |
#sip_auth_password ⇒ String?
SIP Authentication password used for SIP challenges.
204 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 204 optional :sip_auth_password, String |
#sip_auth_username ⇒ String?
SIP Authentication username used for SIP challenges.
210 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 210 optional :sip_auth_username, String |
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
SIP headers to be added to the SIP INVITE. Currently only User-to-User header is supported.
217 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 217 optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] } |
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
223 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 223 optional :sip_region, enum: -> { Telnyx::Calls::ActionTransferParams::SipRegion } |
#sip_transport_protocol ⇒ Symbol, ...
Defines SIP transport protocol to be used on the call.
229 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 229 optional :sip_transport_protocol, enum: -> { Telnyx::Calls::ActionTransferParams::SipTransportProtocol } |
#sound_modifications ⇒ Telnyx::Models::SoundModifications?
Use this field to modify sound effects, for example adjust the pitch.
235 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 235 optional :sound_modifications, -> { Telnyx::SoundModifications } |
#target_leg_client_state ⇒ String?
Use this field to add state to every subsequent webhook for the new leg. It must be a valid Base-64 encoded string.
242 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 242 optional :target_leg_client_state, String |
#time_limit_secs ⇒ Integer?
Sets the maximum duration of a Call Control Leg in seconds. If the time limit is reached, the call will hangup and a ‘call.hangup` webhook with a `hangup_cause` of `time_limit` will be sent. For example, by setting a time limit of 120 seconds, a Call Leg will be automatically terminated two minutes after being answered. The default time limit is 14400 seconds or 4 hours and this is also the maximum allowed call length.
253 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 253 optional :time_limit_secs, Integer |
#timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the call to be answered by the destination to which it is being transferred. If the timeout is reached before an answer is received, the call will hangup and a ‘call.hangup` webhook with a `hangup_cause` of `timeout` will be sent. Minimum value is 5 seconds. Maximum value is 600 seconds.
263 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 263 optional :timeout_secs, Integer |
#to ⇒ String
The DID or SIP URI to dial out to.
20 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 20 required :to, String |
#webhook_retries_policies ⇒ Hash{Symbol=>Telnyx::Models::Calls::ActionTransferParams::WebhookRetriesPolicy}?
A map of event types to retry policies. Each retry policy contains an array of ‘retries_ms` specifying the delays between retry attempts in milliseconds. Maximum 5 retries, total delay cannot exceed 60 seconds.
271 272 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 271 optional :webhook_retries_policies, -> { Telnyx::Internal::Type::HashOf[Telnyx::Calls::ActionTransferParams::WebhookRetriesPolicy] } |
#webhook_url ⇒ String?
Use this field to override the URL for which Telnyx will send subsequent webhooks to for this call.
279 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 279 optional :webhook_url, String |
#webhook_url_method ⇒ Symbol, ...
HTTP request type used for ‘webhook_url`.
285 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 285 optional :webhook_url_method, enum: -> { Telnyx::Calls::ActionTransferParams::WebhookURLMethod } |
#webhook_urls ⇒ Hash{Symbol=>String}?
A map of event types to webhook URLs. When an event of the specified type occurs, the webhook URL associated with that event type will be called instead of ‘webhook_url`. Events not mapped here will use the default `webhook_url`.
293 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 293 optional :webhook_urls, Telnyx::Internal::Type::HashOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 402
|