Class: Telnyx::Models::Calls::ActionTransferParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/calls/action_transfer_params.rb

Overview

Defined Under Namespace

Modules: AnsweringMachineDetection, MediaEncryption, MuteDtmf, Record, RecordChannels, RecordFormat, RecordTrack, RecordTrim, SipRegion, SipTransportProtocol, WebhookURLMethod Classes: AnsweringMachineDetectionConfig

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after_greeting_silence_millis: nil, between_words_silence_millis: nil, greeting_duration_millis: nil, greeting_silence_duration_millis: nil, greeting_total_analysis_time_millis: nil, initial_silence_millis: nil, maximum_number_of_words: nil, maximum_word_length_millis: nil, silence_threshold: nil, total_analysis_time_millis: nil) ⇒ Object

Some parameter documentations has been truncated, see AnsweringMachineDetectionConfig for more details.

Optional configuration parameters to modify ‘answering_machine_detection’ performance.

Parameters:

  • after_greeting_silence_millis (Integer) (defaults to: nil)

    Silence duration threshold after a greeting message or voice for it be considere

  • between_words_silence_millis (Integer) (defaults to: nil)

    Maximum threshold for silence between words.

  • greeting_duration_millis (Integer) (defaults to: nil)

    Maximum threshold of a human greeting. If greeting longer than this value, consi

  • greeting_silence_duration_millis (Integer) (defaults to: nil)

    If machine already detected, maximum threshold for silence between words. If exc

  • greeting_total_analysis_time_millis (Integer) (defaults to: nil)

    If machine already detected, maximum timeout threshold to determine the end of t

  • initial_silence_millis (Integer) (defaults to: nil)

    If initial silence duration is greater than this value, consider it a machine.

  • maximum_number_of_words (Integer) (defaults to: nil)

    If number of detected words is greater than this value, consder it a machine.

  • maximum_word_length_millis (Integer) (defaults to: nil)

    If a single word lasts longer than this threshold, consider it a machine.

  • silence_threshold (Integer) (defaults to: nil)

    Minimum noise threshold for any analysis.

  • total_analysis_time_millis (Integer) (defaults to: nil)

    Maximum timeout threshold for overall detection.



# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 257

Instance Attribute Details

#answering_machine_detectionSymbol, ...

Enables Answering Machine Detection. When a call is answered, Telnyx runs real-time detection to determine if it was picked up by a human or a machine and sends an ‘call.machine.detection.ended` webhook with the analysis result. If ’greeting_end’ or ‘detect_words’ is used and a ‘machine’ is detected, you will receive another ‘call.machine.greeting.ended’ webhook when the answering machine greeting ends with a beep or silence. If ‘detect_beep` is used, you will only receive ’call.machine.greeting.ended’ if a beep is detected.



27
28
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 27

optional :answering_machine_detection,
enum: -> { Telnyx::Calls::ActionTransferParams::AnsweringMachineDetection }

#answering_machine_detection_configTelnyx::Models::Calls::ActionTransferParams::AnsweringMachineDetectionConfig?

Optional configuration parameters to modify ‘answering_machine_detection’ performance.



35
36
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 35

optional :answering_machine_detection_config,
-> { Telnyx::Calls::ActionTransferParams::AnsweringMachineDetectionConfig }

#audio_urlString?

The URL of a file to be played back when the transfer destination answers before bridging the call. The URL can point to either a WAV or MP3 file. media_name and audio_url cannot be used together in one request.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 44

optional :audio_url, String

#client_stateString?

Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


51
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 51

optional :client_state, String

#command_idString?

Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.

Returns:

  • (String, nil)


58
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 58

optional :command_id, String

#custom_headersArray<Telnyx::Models::CustomSipHeader>?

Custom headers to be added to the SIP INVITE.

Returns:



64
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 64

optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] }

#early_mediaBoolean?

If set to false, early media will not be passed to the originating leg.

Returns:

  • (Boolean, nil)


70
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 70

optional :early_media, Telnyx::Internal::Type::Boolean

#fromString?

The ‘from` number to be used as the caller id presented to the destination (`to` number). The number should be in +E164 format. This attribute will default to the `to` number of the original call if omitted.

Returns:

  • (String, nil)


78
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 78

optional :from, String

#from_display_nameString?

The ‘from_display_name` string to be used as the caller id name (SIP From Display Name) presented to the destination (`to` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and -_~!.+ special characters. If ommited, the display name will be the same as the number in the `from` field.

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 88

optional :from_display_name, String

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the new call leg.



94
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 94

optional :media_encryption, enum: -> { Telnyx::Calls::ActionTransferParams::MediaEncryption }

#media_nameString?

The media_name of a file to be played back when the transfer destination answers before bridging the call. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file.

Returns:

  • (String, nil)


103
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 103

optional :media_name, String

#mute_dtmfSymbol, ...

When enabled, DTMF tones are not passed to the call participant. The webhooks containing the DTMF information will be sent.



110
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 110

optional :mute_dtmf, enum: -> { Telnyx::Calls::ActionTransferParams::MuteDtmf }

#park_after_unbridgeString?

Specifies behavior after the bridge ends (i.e. the opposite leg either hangs up or is transferred). If supplied with the value ‘self`, the current leg will be parked after unbridge. If not set, the default behavior is to hang up the leg.

Returns:

  • (String, nil)


118
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 118

optional :park_after_unbridge, String

#recordSymbol, ...

Start recording automatically after an event. Disabled by default.



124
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 124

optional :record, enum: -> { Telnyx::Calls::ActionTransferParams::Record }

#record_channelsSymbol, ...

Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.



131
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 131

optional :record_channels, enum: -> { Telnyx::Calls::ActionTransferParams::RecordChannels }

#record_custom_file_nameString?

The custom recording file name to be used instead of the default ‘call_leg_id`. Telnyx will still add a Unix timestamp suffix.

Returns:

  • (String, nil)


138
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 138

optional :record_custom_file_name, String

#record_formatSymbol, ...

Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.



144
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 144

optional :record_format, enum: -> { Telnyx::Calls::ActionTransferParams::RecordFormat }

#record_max_lengthInteger?

Defines the maximum length for the recording in seconds when ‘record` is specified. The minimum value is 0. The maximum value is 43200. The default value is 0 (infinite).

Returns:

  • (Integer, nil)


152
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 152

optional :record_max_length, Integer

#record_timeout_secsInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified. The timer only starts when the speech is detected. Please note that call transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite).

Returns:

  • (Integer, nil)


162
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 162

optional :record_timeout_secs, Integer

#record_trackSymbol, ...

The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. If only single track is specified (`inbound`, `outbound`), `channels` configuration is ignored and it will be recorded as mono (single channel).



170
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 170

optional :record_track, enum: -> { Telnyx::Calls::ActionTransferParams::RecordTrack }

#record_trimSymbol, ...

When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.



177
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 177

optional :record_trim, enum: -> { Telnyx::Calls::ActionTransferParams::RecordTrim }

#sip_auth_passwordString?

SIP Authentication password used for SIP challenges.

Returns:

  • (String, nil)


183
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 183

optional :sip_auth_password, String

#sip_auth_usernameString?

SIP Authentication username used for SIP challenges.

Returns:

  • (String, nil)


189
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 189

optional :sip_auth_username, String

#sip_headersArray<Telnyx::Models::SipHeader>?

SIP headers to be added to the SIP INVITE. Currently only User-to-User header is supported.

Returns:



196
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 196

optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] }

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



202
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 202

optional :sip_region, enum: -> { Telnyx::Calls::ActionTransferParams::SipRegion }

#sip_transport_protocolSymbol, ...

Defines SIP transport protocol to be used on the call.



208
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 208

optional :sip_transport_protocol, enum: -> { Telnyx::Calls::ActionTransferParams::SipTransportProtocol }

#sound_modificationsTelnyx::Models::SoundModifications?

Use this field to modify sound effects, for example adjust the pitch.



214
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 214

optional :sound_modifications, -> { Telnyx::SoundModifications }

#target_leg_client_stateString?

Use this field to add state to every subsequent webhook for the new leg. It must be a valid Base-64 encoded string.

Returns:

  • (String, nil)


221
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 221

optional :target_leg_client_state, String

#time_limit_secsInteger?

Sets the maximum duration of a Call Control Leg in seconds. If the time limit is reached, the call will hangup and a ‘call.hangup` webhook with a `hangup_cause` of `time_limit` will be sent. For example, by setting a time limit of 120 seconds, a Call Leg will be automatically terminated two minutes after being answered. The default time limit is 14400 seconds or 4 hours and this is also the maximum allowed call length.

Returns:

  • (Integer, nil)


232
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 232

optional :time_limit_secs, Integer

#timeout_secsInteger?

The number of seconds that Telnyx will wait for the call to be answered by the destination to which it is being transferred. If the timeout is reached before an answer is received, the call will hangup and a ‘call.hangup` webhook with a `hangup_cause` of `timeout` will be sent. Minimum value is 5 seconds. Maximum value is 600 seconds.

Returns:

  • (Integer, nil)


242
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 242

optional :timeout_secs, Integer

#toString

The DID or SIP URI to dial out to.

Returns:

  • (String)


15
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 15

required :to, String

#webhook_urlString?

Use this field to override the URL for which Telnyx will send subsequent webhooks to for this call.

Returns:

  • (String, nil)


249
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 249

optional :webhook_url, String

#webhook_url_methodSymbol, ...

HTTP request type used for ‘webhook_url`.



255
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 255

optional :webhook_url_method, enum: -> { Telnyx::Calls::ActionTransferParams::WebhookURLMethod }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 346