Class: Telnyx::Models::Calls::ActionTransferParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::ActionTransferParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/calls/action_transfer_params.rb
Overview
Defined Under Namespace
Modules: AnsweringMachineDetection, MediaEncryption, MuteDtmf, Record, RecordChannels, RecordFormat, RecordTrack, RecordTrim, SipRegion, SipTransportProtocol, WebhookURLMethod Classes: AnsweringMachineDetectionConfig
Instance Attribute Summary collapse
-
#answering_machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection.
-
#answering_machine_detection_config ⇒ Telnyx::Models::Calls::ActionTransferParams::AnsweringMachineDetectionConfig?
Optional configuration parameters to modify ‘answering_machine_detection’ performance.
-
#audio_url ⇒ String?
The URL of a file to be played back when the transfer destination answers before bridging the call.
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers to be added to the SIP INVITE.
-
#early_media ⇒ Boolean?
If set to false, early media will not be passed to the originating leg.
-
#from ⇒ String?
The ‘from` number to be used as the caller id presented to the destination (`to` number).
-
#from_display_name ⇒ String?
The ‘from_display_name` string to be used as the caller id name (SIP From Display Name) presented to the destination (`to` number).
-
#media_encryption ⇒ Symbol, ...
Defines whether media should be encrypted on the new call leg.
-
#media_name ⇒ String?
The media_name of a file to be played back when the transfer destination answers before bridging the call.
-
#mute_dtmf ⇒ Symbol, ...
When enabled, DTMF tones are not passed to the call participant.
-
#park_after_unbridge ⇒ String?
Specifies behavior after the bridge ends (i.e. the opposite leg either hangs up or is transferred).
-
#record ⇒ Symbol, ...
Start recording automatically after an event.
-
#record_channels ⇒ Symbol, ...
Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.
-
#record_custom_file_name ⇒ String?
The custom recording file name to be used instead of the default ‘call_leg_id`.
-
#record_format ⇒ Symbol, ...
Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.
-
#record_max_length ⇒ Integer?
Defines the maximum length for the recording in seconds when ‘record` is specified.
-
#record_timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified.
-
#record_track ⇒ Symbol, ...
The audio track to be recorded.
-
#record_trim ⇒ Symbol, ...
When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.
-
#sip_auth_password ⇒ String?
SIP Authentication password used for SIP challenges.
-
#sip_auth_username ⇒ String?
SIP Authentication username used for SIP challenges.
-
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
SIP headers to be added to the SIP INVITE.
-
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
-
#sip_transport_protocol ⇒ Symbol, ...
Defines SIP transport protocol to be used on the call.
-
#sound_modifications ⇒ Telnyx::Models::SoundModifications?
Use this field to modify sound effects, for example adjust the pitch.
-
#target_leg_client_state ⇒ String?
Use this field to add state to every subsequent webhook for the new leg.
-
#time_limit_secs ⇒ Integer?
Sets the maximum duration of a Call Control Leg in seconds.
-
#timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the call to be answered by the destination to which it is being transferred.
-
#to ⇒ String
The DID or SIP URI to dial out to.
-
#webhook_url ⇒ String?
Use this field to override the URL for which Telnyx will send subsequent webhooks to for this call.
-
#webhook_url_method ⇒ Symbol, ...
HTTP request type used for ‘webhook_url`.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(after_greeting_silence_millis: nil, between_words_silence_millis: nil, greeting_duration_millis: nil, greeting_silence_duration_millis: nil, greeting_total_analysis_time_millis: nil, initial_silence_millis: nil, maximum_number_of_words: nil, maximum_word_length_millis: nil, silence_threshold: nil, total_analysis_time_millis: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AnsweringMachineDetectionConfig for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after_greeting_silence_millis: nil, between_words_silence_millis: nil, greeting_duration_millis: nil, greeting_silence_duration_millis: nil, greeting_total_analysis_time_millis: nil, initial_silence_millis: nil, maximum_number_of_words: nil, maximum_word_length_millis: nil, silence_threshold: nil, total_analysis_time_millis: nil) ⇒ Object
Some parameter documentations has been truncated, see AnsweringMachineDetectionConfig for more details.
Optional configuration parameters to modify ‘answering_machine_detection’ performance.
|
|
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 257
|
Instance Attribute Details
#answering_machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection. When a call is answered, Telnyx runs real-time detection to determine if it was picked up by a human or a machine and sends an ‘call.machine.detection.ended` webhook with the analysis result. If ’greeting_end’ or ‘detect_words’ is used and a ‘machine’ is detected, you will receive another ‘call.machine.greeting.ended’ webhook when the answering machine greeting ends with a beep or silence. If ‘detect_beep` is used, you will only receive ’call.machine.greeting.ended’ if a beep is detected.
27 28 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 27 optional :answering_machine_detection, enum: -> { Telnyx::Calls::ActionTransferParams::AnsweringMachineDetection } |
#answering_machine_detection_config ⇒ Telnyx::Models::Calls::ActionTransferParams::AnsweringMachineDetectionConfig?
Optional configuration parameters to modify ‘answering_machine_detection’ performance.
35 36 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 35 optional :answering_machine_detection_config, -> { Telnyx::Calls::ActionTransferParams::AnsweringMachineDetectionConfig } |
#audio_url ⇒ String?
The URL of a file to be played back when the transfer destination answers before bridging the call. The URL can point to either a WAV or MP3 file. media_name and audio_url cannot be used together in one request.
44 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 44 optional :audio_url, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
51 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 51 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
58 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 58 optional :command_id, String |
#custom_headers ⇒ Array<Telnyx::Models::CustomSipHeader>?
Custom headers to be added to the SIP INVITE.
64 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 64 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::CustomSipHeader] } |
#early_media ⇒ Boolean?
If set to false, early media will not be passed to the originating leg.
70 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 70 optional :early_media, Telnyx::Internal::Type::Boolean |
#from ⇒ String?
The ‘from` number to be used as the caller id presented to the destination (`to` number). The number should be in +E164 format. This attribute will default to the `to` number of the original call if omitted.
78 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 78 optional :from, String |
#from_display_name ⇒ String?
The ‘from_display_name` string to be used as the caller id name (SIP From Display Name) presented to the destination (`to` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and -_~!.+ special characters. If ommited, the display name will be the same as the number in the `from` field.
88 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 88 optional :from_display_name, String |
#media_encryption ⇒ Symbol, ...
Defines whether media should be encrypted on the new call leg.
94 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 94 optional :media_encryption, enum: -> { Telnyx::Calls::ActionTransferParams::MediaEncryption } |
#media_name ⇒ String?
The media_name of a file to be played back when the transfer destination answers before bridging the call. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file.
103 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 103 optional :media_name, String |
#mute_dtmf ⇒ Symbol, ...
When enabled, DTMF tones are not passed to the call participant. The webhooks containing the DTMF information will be sent.
110 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 110 optional :mute_dtmf, enum: -> { Telnyx::Calls::ActionTransferParams::MuteDtmf } |
#park_after_unbridge ⇒ String?
Specifies behavior after the bridge ends (i.e. the opposite leg either hangs up or is transferred). If supplied with the value ‘self`, the current leg will be parked after unbridge. If not set, the default behavior is to hang up the leg.
118 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 118 optional :park_after_unbridge, String |
#record ⇒ Symbol, ...
Start recording automatically after an event. Disabled by default.
124 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 124 optional :record, enum: -> { Telnyx::Calls::ActionTransferParams::Record } |
#record_channels ⇒ Symbol, ...
Defines which channel should be recorded (‘single’ or ‘dual’) when ‘record` is specified.
131 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 131 optional :record_channels, enum: -> { Telnyx::Calls::ActionTransferParams::RecordChannels } |
#record_custom_file_name ⇒ String?
The custom recording file name to be used instead of the default ‘call_leg_id`. Telnyx will still add a Unix timestamp suffix.
138 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 138 optional :record_custom_file_name, String |
#record_format ⇒ Symbol, ...
Defines the format of the recording (‘wav’ or ‘mp3’) when ‘record` is specified.
144 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 144 optional :record_format, enum: -> { Telnyx::Calls::ActionTransferParams::RecordFormat } |
#record_max_length ⇒ Integer?
Defines the maximum length for the recording in seconds when ‘record` is specified. The minimum value is 0. The maximum value is 43200. The default value is 0 (infinite).
152 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 152 optional :record_max_length, Integer |
#record_timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected when ‘record` is specified. The timer only starts when the speech is detected. Please note that call transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite).
162 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 162 optional :record_timeout_secs, Integer |
#record_track ⇒ Symbol, ...
The audio track to be recorded. Can be either ‘both`, `inbound` or `outbound`. If only single track is specified (`inbound`, `outbound`), `channels` configuration is ignored and it will be recorded as mono (single channel).
170 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 170 optional :record_track, enum: -> { Telnyx::Calls::ActionTransferParams::RecordTrack } |
#record_trim ⇒ Symbol, ...
When set to ‘trim-silence`, silence will be removed from the beginning and end of the recording.
177 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 177 optional :record_trim, enum: -> { Telnyx::Calls::ActionTransferParams::RecordTrim } |
#sip_auth_password ⇒ String?
SIP Authentication password used for SIP challenges.
183 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 183 optional :sip_auth_password, String |
#sip_auth_username ⇒ String?
SIP Authentication username used for SIP challenges.
189 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 189 optional :sip_auth_username, String |
#sip_headers ⇒ Array<Telnyx::Models::SipHeader>?
SIP headers to be added to the SIP INVITE. Currently only User-to-User header is supported.
196 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 196 optional :sip_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::SipHeader] } |
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
202 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 202 optional :sip_region, enum: -> { Telnyx::Calls::ActionTransferParams::SipRegion } |
#sip_transport_protocol ⇒ Symbol, ...
Defines SIP transport protocol to be used on the call.
208 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 208 optional :sip_transport_protocol, enum: -> { Telnyx::Calls::ActionTransferParams::SipTransportProtocol } |
#sound_modifications ⇒ Telnyx::Models::SoundModifications?
Use this field to modify sound effects, for example adjust the pitch.
214 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 214 optional :sound_modifications, -> { Telnyx::SoundModifications } |
#target_leg_client_state ⇒ String?
Use this field to add state to every subsequent webhook for the new leg. It must be a valid Base-64 encoded string.
221 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 221 optional :target_leg_client_state, String |
#time_limit_secs ⇒ Integer?
Sets the maximum duration of a Call Control Leg in seconds. If the time limit is reached, the call will hangup and a ‘call.hangup` webhook with a `hangup_cause` of `time_limit` will be sent. For example, by setting a time limit of 120 seconds, a Call Leg will be automatically terminated two minutes after being answered. The default time limit is 14400 seconds or 4 hours and this is also the maximum allowed call length.
232 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 232 optional :time_limit_secs, Integer |
#timeout_secs ⇒ Integer?
The number of seconds that Telnyx will wait for the call to be answered by the destination to which it is being transferred. If the timeout is reached before an answer is received, the call will hangup and a ‘call.hangup` webhook with a `hangup_cause` of `timeout` will be sent. Minimum value is 5 seconds. Maximum value is 600 seconds.
242 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 242 optional :timeout_secs, Integer |
#to ⇒ String
The DID or SIP URI to dial out to.
15 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 15 required :to, String |
#webhook_url ⇒ String?
Use this field to override the URL for which Telnyx will send subsequent webhooks to for this call.
249 |
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 249 optional :webhook_url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 346
|