Class: Telnyx::Models::Calls::ActionTransferParams::AnsweringMachineDetectionConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/action_transfer_params.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#after_greeting_silence_millisInteger?

Silence duration threshold after a greeting message or voice for it be considered human.

Returns:

  • (Integer, nil)


412
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 412

optional :after_greeting_silence_millis, Integer

#between_words_silence_millisInteger?

Maximum threshold for silence between words.

Returns:

  • (Integer, nil)


418
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 418

optional :between_words_silence_millis, Integer

#greeting_duration_millisInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine.

Returns:

  • (Integer, nil)


425
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 425

optional :greeting_duration_millis, Integer

#greeting_silence_duration_millisInteger?

If machine already detected, maximum threshold for silence between words. If exceeded, the greeting is considered ended.

Returns:

  • (Integer, nil)


432
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 432

optional :greeting_silence_duration_millis, Integer

#greeting_total_analysis_time_millisInteger?

If machine already detected, maximum timeout threshold to determine the end of the machine greeting.

Returns:

  • (Integer, nil)


439
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 439

optional :greeting_total_analysis_time_millis, Integer

#initial_silence_millisInteger?

If initial silence duration is greater than this value, consider it a machine.

Returns:

  • (Integer, nil)


445
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 445

optional :initial_silence_millis, Integer

#maximum_number_of_wordsInteger?

If number of detected words is greater than this value, consder it a machine.

Returns:

  • (Integer, nil)


451
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 451

optional :maximum_number_of_words, Integer

#maximum_word_length_millisInteger?

If a single word lasts longer than this threshold, consider it a machine.

Returns:

  • (Integer, nil)


457
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 457

optional :maximum_word_length_millis, Integer

#silence_thresholdInteger?

Minimum noise threshold for any analysis.

Returns:

  • (Integer, nil)


463
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 463

optional :silence_threshold, Integer

#total_analysis_time_millisInteger?

Maximum timeout threshold for overall detection.

Returns:

  • (Integer, nil)


469
# File 'lib/telnyx/models/calls/action_transfer_params.rb', line 469

optional :total_analysis_time_millis, Integer