Module: Telnyx::Models::Calls::ActionTransferParams::MediaEncryption
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/calls/action_transfer_params.rb,
sig/telnyx/models/calls/action_transfer_params.rbs
Overview
Defines whether media should be encrypted on the new call leg. For SIP URI
destinations, media encryption can also be requested per endpoint with the
secure URI parameter: ;secure=true or ;secure=srtp enables SRTP, and
;secure=dtls enables DTLS. This parameter, when set to SRTP or DTLS, takes
precedence over the per-endpoint secure value.
Constant Summary collapse
- DISABLED =
:disabled- SRTP =
:SRTP- DTLS =
:DTLS
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::Calls::ActionTransferParams::media_encryption]
445 |
# File 'sig/telnyx/models/calls/action_transfer_params.rbs', line 445
def self?.values: -> ::Array[Telnyx::Models::Calls::ActionTransferParams::media_encryption]
|