Class: Telnyx::Models::Calls::DeepgramNova3Config
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::DeepgramNova3Config
- Defined in:
- lib/telnyx/models/calls/deepgram_nova3_config.rb
Defined Under Namespace
Modules: Language, TranscriptionEngine, TranscriptionModel
Instance Attribute Summary collapse
-
#interim_results ⇒ Boolean?
Whether to send also interim results.
-
#keywords_boosting ⇒ Hash{Symbol=>Float}?
Keywords and their respective intensifiers (boosting values) to improve transcription accuracy for specific words or phrases.
-
#language ⇒ Symbol, ...
Language to use for speech recognition with nova-3 model.
- #transcription_engine ⇒ Symbol, Telnyx::Models::Calls::DeepgramNova3Config::TranscriptionEngine
- #transcription_model ⇒ Symbol, Telnyx::Models::Calls::DeepgramNova3Config::TranscriptionModel
-
#utterance_end_ms ⇒ Integer?
Number of milliseconds of silence to consider an utterance ended.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(transcription_engine:, transcription_model:, interim_results: nil, keywords_boosting: nil, language: nil, utterance_end_ms: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DeepgramNova3Config for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transcription_engine:, transcription_model:, interim_results: nil, keywords_boosting: nil, language: nil, utterance_end_ms: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::DeepgramNova3Config for more details.
|
|
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 45
|
Instance Attribute Details
#interim_results ⇒ Boolean?
Whether to send also interim results. If set to false, only final results will be sent.
22 |
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 22 optional :interim_results, Telnyx::Internal::Type::Boolean |
#keywords_boosting ⇒ Hash{Symbol=>Float}?
Keywords and their respective intensifiers (boosting values) to improve transcription accuracy for specific words or phrases. The intensifier should be a numeric value. Example: ‘5, “systrom”: 2, “krieger”: 1`.
30 |
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 30 optional :keywords_boosting, Telnyx::Internal::Type::HashOf[Float] |
#language ⇒ Symbol, ...
Language to use for speech recognition with nova-3 model
36 |
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 36 optional :language, enum: -> { Telnyx::Calls::DeepgramNova3Config::Language } |
#transcription_engine ⇒ Symbol, Telnyx::Models::Calls::DeepgramNova3Config::TranscriptionEngine
10 |
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 10 required :transcription_engine, enum: -> { Telnyx::Calls::DeepgramNova3Config::TranscriptionEngine } |
#transcription_model ⇒ Symbol, Telnyx::Models::Calls::DeepgramNova3Config::TranscriptionModel
15 |
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 15 required :transcription_model, enum: -> { Telnyx::Calls::DeepgramNova3Config::TranscriptionModel } |
#utterance_end_ms ⇒ Integer?
Number of milliseconds of silence to consider an utterance ended. Ranges from 0 to 5000 ms.
43 |
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 43 optional :utterance_end_ms, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/deepgram_nova3_config.rb', line 67
|