Class: Telnyx::Models::Calls::StopRecordingRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::StopRecordingRequest
- Defined in:
- lib/telnyx/models/calls/stop_recording_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#recording_id ⇒ String?
Uniquely identifies the resource.
Instance Method Summary collapse
-
#initialize(client_state: nil, command_id: nil, recording_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see StopRecordingRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(client_state: nil, command_id: nil, recording_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::StopRecordingRequest for more details.
|
|
# File 'lib/telnyx/models/calls/stop_recording_request.rb', line 27
|
Instance Attribute Details
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
12 |
# File 'lib/telnyx/models/calls/stop_recording_request.rb', line 12 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
19 |
# File 'lib/telnyx/models/calls/stop_recording_request.rb', line 19 optional :command_id, String |
#recording_id ⇒ String?
Uniquely identifies the resource.
25 |
# File 'lib/telnyx/models/calls/stop_recording_request.rb', line 25 optional :recording_id, String |