Class: Telnyx::Models::Calls::TranscriptionConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/calls/transcription_config.rb

Defined Under Namespace

Modules: Model

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(language: nil, model: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Calls::TranscriptionConfig for more details.

The settings associated with speech to text for the voice assistant. This is only relevant if the assistant uses a text-to-text language model. Any assistant using a model with native audio support (e.g. ‘fixie-ai/ultravox-v0_4`) will ignore this field.

Parameters:

  • language (String) (defaults to: nil)

    The language of the audio to be transcribed. If not set, or if set to ‘auto`, su

  • model (Symbol, Telnyx::Models::Calls::TranscriptionConfig::Model) (defaults to: nil)

    The speech to text model to be used by the voice assistant. Supported models inc



# File 'lib/telnyx/models/calls/transcription_config.rb', line 39

Instance Attribute Details

#languageString?

The language of the audio to be transcribed. If not set, or if set to ‘auto`, supported models will automatically detect the language. Supported and meaningful values depend on the selected transcription `model`. For `deepgram/flux`, supported values are: `auto` (Telnyx language detection controls the language hint), `multi` (no language hint), and language-specific hints `en`, `es`, `fr`, `de`, `hi`, `ru`, `pt`, `ja`, `it`, and `nl`.

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/calls/transcription_config.rb', line 16

optional :language, String

#modelSymbol, ...

The speech to text model to be used by the voice assistant. Supported models include:

  • ‘deepgram/flux` (or `flux`) for live streaming turn-taking.

  • ‘deepgram/nova-3` and `deepgram/nova-2` for live streaming transcription.

  • ‘speechmatics/standard` and `speechmatics/enhanced` for live streaming transcription.

  • ‘assemblyai/universal-streaming` for live streaming transcription.

  • ‘xai/grok-stt` for live streaming transcription.

  • ‘azure/fast` and `azure/realtime`; Azure models require `region`, and unsupported regions require `api_key_ref`.

  • ‘google/latest_long` for non-streaming multilingual transcription.

  • ‘distil-whisper/distil-large-v2` for lower-latency English-only non-streaming transcription.

  • ‘openai/whisper-large-v3-turbo` for multilingual non-streaming transcription with automatic language detection.



37
# File 'lib/telnyx/models/calls/transcription_config.rb', line 37

optional :model, enum: -> { Telnyx::Calls::TranscriptionConfig::Model }