Class: Telnyx::Models::Calls::TranscriptionConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::TranscriptionConfig
- Defined in:
- lib/telnyx/models/calls/transcription_config.rb
Instance Attribute Summary collapse
-
#model ⇒ String?
The speech to text model to be used by the voice assistant.
Instance Method Summary collapse
-
#initialize(model: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TranscriptionConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(model: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::TranscriptionConfig for more details.
The settings associated with speech to text for the voice assistant. This is only relevant if the assistant uses a text-to-text language model. Any assistant using a model with native audio support (e.g. ‘fixie-ai/ultravox-v0_4`) will ignore this field.
|
|
# File 'lib/telnyx/models/calls/transcription_config.rb', line 19
|
Instance Attribute Details
#model ⇒ String?
The speech to text model to be used by the voice assistant.
-
‘distil-whisper/distil-large-v2` is lower latency but English-only.
-
‘openai/whisper-large-v3-turbo` is multi-lingual with automatic language detection but slightly higher latency.
-
‘google` is a multi-lingual option, please describe the language in the `language` field.
17 |
# File 'lib/telnyx/models/calls/transcription_config.rb', line 17 optional :model, String |