Module: Telnyx::Models::Calls::TranscriptionConfig::Model
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/calls/transcription_config.rb,
sig/telnyx/models/calls/transcription_config.rbs
Overview
The speech to text model to be used by the voice assistant. Supported models include:
deepgram/flux(orflux) for live streaming turn-taking.deepgram/nova-3anddeepgram/nova-2for live streaming transcription.speechmatics/standardandspeechmatics/enhancedfor live streaming transcription.assemblyai/universal-streamingfor live streaming transcription.xai/grok-sttfor live streaming transcription.soniox/stt-rt-v4for live streaming multilingual transcription with automatic language detection.parakeet/tdt-0.6b-v3for multilingual transcription with automatic language detection.azure/fastandazure/realtime; Azure models requireregion, and unsupported regions requireapi_key_ref.google/latest_longfor non-streaming multilingual transcription.distil-whisper/distil-large-v2for lower-latency English-only non-streaming transcription.openai/whisper-large-v3-turbofor multilingual non-streaming transcription with automatic language detection.
Constant Summary collapse
- DEEPGRAM_FLUX =
:"deepgram/flux"- FLUX =
:flux- DEEPGRAM_NOVA_3 =
:"deepgram/nova-3"- DEEPGRAM_NOVA_2 =
:"deepgram/nova-2"- SPEECHMATICS_STANDARD =
:"speechmatics/standard"- SPEECHMATICS_ENHANCED =
:"speechmatics/enhanced"- ASSEMBLYAI_UNIVERSAL_STREAMING =
:"assemblyai/universal-streaming"- XAI_GROK_STT =
:"xai/grok-stt"- SONIOX_STT_RT_V4 =
:"soniox/stt-rt-v4"- PARAKEET_TDT_0_6B_V3 =
:"parakeet/tdt-0.6b-v3"- AZURE_FAST =
:"azure/fast"- AZURE_REALTIME =
:"azure/realtime"- GOOGLE_LATEST_LONG =
:"google/latest_long"- DISTIL_WHISPER_DISTIL_LARGE_V2 =
:"distil-whisper/distil-large-v2"- OPENAI_WHISPER_LARGE_V3_TURBO =
:"openai/whisper-large-v3-turbo"
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/transcription_config.rb', line 99
|
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::Calls::TranscriptionConfig::model]
67 |
# File 'sig/telnyx/models/calls/transcription_config.rbs', line 67
def self?.values: -> ::Array[Telnyx::Models::Calls::TranscriptionConfig::model]
|