Class: Telnyx::Models::Calls::TranscriptionStartRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::TranscriptionStartRequest
- Defined in:
- lib/telnyx/models/calls/transcription_start_request.rb
Direct Known Subclasses
Defined Under Namespace
Modules: TranscriptionEngine, TranscriptionEngineConfig
Instance Attribute Summary collapse
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
-
#transcription_engine ⇒ Symbol, ...
Engine to use for speech recognition.
- #transcription_engine_config ⇒ Telnyx::Models::Calls::TranscriptionEngineGoogleConfig, ...
-
#transcription_tracks ⇒ String?
Indicates which leg of the call will be transcribed.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(client_state: nil, command_id: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_tracks: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TranscriptionStartRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(client_state: nil, command_id: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_tracks: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::TranscriptionStartRequest for more details.
|
|
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 42
|
Instance Attribute Details
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
12 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 12 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
19 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 19 optional :command_id, String |
#transcription_engine ⇒ Symbol, ...
Engine to use for speech recognition. Legacy values ‘A` - `Google`, `B` - `Telnyx` are supported for backward compatibility.
26 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 26 optional :transcription_engine, enum: -> { Telnyx::Calls::TranscriptionStartRequest::TranscriptionEngine } |
#transcription_engine_config ⇒ Telnyx::Models::Calls::TranscriptionEngineGoogleConfig, ...
31 32 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 31 optional :transcription_engine_config, union: -> { Telnyx::Calls::TranscriptionStartRequest::TranscriptionEngineConfig } |
#transcription_tracks ⇒ String?
Indicates which leg of the call will be transcribed. Use ‘inbound` for the leg that requested the transcription, `outbound` for the other leg, and `both` for both legs of the call. Will default to `inbound`.
40 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 40 optional :transcription_tracks, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 70
|