Class: Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::Soniox
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::Soniox
- Defined in:
- lib/telnyx/models/calls/transcription_start_request.rb
Defined Under Namespace
Modules: TranscriptionModel
Instance Attribute Summary collapse
-
#enable_endpoint_detection ⇒ Boolean?
When true, Soniox emits end-of-utterance events at the cadence configured by ‘max_endpoint_delay_ms`.
-
#interim_results ⇒ Boolean?
Whether to send also interim results.
-
#language ⇒ String?
ISO 639-1 language hint (e.g. ‘en`, `es`), or `auto` to omit the hint and let Soniox auto-detect supported languages multilingually.
-
#max_endpoint_delay_ms ⇒ Integer?
Maximum silence (in milliseconds) before Soniox emits an end-of-utterance event.
-
#transcription_engine ⇒ Symbol, :Soniox
Engine identifier for Soniox transcription service.
-
#transcription_model ⇒ Symbol, ...
The model to use for transcription.
Instance Method Summary collapse
-
#initialize(enable_endpoint_detection: nil, interim_results: nil, language: nil, max_endpoint_delay_ms: nil, transcription_model: nil, transcription_engine: :Soniox) ⇒ Object
constructor
Some parameter documentations has been truncated, see Soniox for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(enable_endpoint_detection: nil, interim_results: nil, language: nil, max_endpoint_delay_ms: nil, transcription_model: nil, transcription_engine: :Soniox) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Calls::TranscriptionStartRequest::TranscriptionEngineConfig::Soniox for more details.
|
|
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 244
|
Instance Attribute Details
#enable_endpoint_detection ⇒ Boolean?
When true, Soniox emits end-of-utterance events at the cadence configured by ‘max_endpoint_delay_ms`.
214 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 214 optional :enable_endpoint_detection, Telnyx::Internal::Type::Boolean |
#interim_results ⇒ Boolean?
Whether to send also interim results. If set to false, only final results will be sent.
221 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 221 optional :interim_results, Telnyx::Internal::Type::Boolean |
#language ⇒ String?
ISO 639-1 language hint (e.g. ‘en`, `es`), or `auto` to omit the hint and let Soniox auto-detect supported languages multilingually.
228 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 228 optional :language, String |
#max_endpoint_delay_ms ⇒ Integer?
Maximum silence (in milliseconds) before Soniox emits an end-of-utterance event. Only honored when ‘enable_endpoint_detection` is true. Range: 500-3000 ms.
235 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 235 optional :max_endpoint_delay_ms, Integer |
#transcription_engine ⇒ Symbol, :Soniox
Engine identifier for Soniox transcription service
207 |
# File 'lib/telnyx/models/calls/transcription_start_request.rb', line 207 required :transcription_engine, const: :Soniox |