Class: Telnyx::Models::Conference
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Conference
- Defined in:
- lib/telnyx/models/conference.rb
Overview
Defined Under Namespace
Modules: EndReason, RecordType, Status Classes: EndedBy
Instance Attribute Summary collapse
-
#connection_id ⇒ String?
Identifies the connection associated with the conference.
-
#created_at ⇒ String
ISO 8601 formatted date of when the conference was created.
-
#end_reason ⇒ Symbol, ...
Reason why the conference ended.
-
#ended_by ⇒ Telnyx::Models::Conference::EndedBy?
IDs related to who ended the conference.
-
#expires_at ⇒ String
ISO 8601 formatted date of when the conference will expire.
-
#id ⇒ String
Uniquely identifies the conference.
-
#name ⇒ String
Name of the conference.
- #record_type ⇒ Symbol, Telnyx::Models::Conference::RecordType
-
#region ⇒ String?
Region where the conference is hosted.
-
#status ⇒ Symbol, ...
Status of the conference.
-
#updated_at ⇒ String?
ISO 8601 formatted date of when the conference was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(call_control_id: nil, call_session_id: nil) ⇒ Object
constructor
IDs related to who ended the conference.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id: nil, call_session_id: nil) ⇒ Object
IDs related to who ended the conference. It is expected for them to all be there or all be null
|
|
# File 'lib/telnyx/models/conference.rb', line 73
|
Instance Attribute Details
#connection_id ⇒ String?
Identifies the connection associated with the conference
40 |
# File 'lib/telnyx/models/conference.rb', line 40 optional :connection_id, String |
#created_at ⇒ String
ISO 8601 formatted date of when the conference was created
17 |
# File 'lib/telnyx/models/conference.rb', line 17 required :created_at, String |
#end_reason ⇒ Symbol, ...
Reason why the conference ended
46 |
# File 'lib/telnyx/models/conference.rb', line 46 optional :end_reason, enum: -> { Telnyx::Conference::EndReason } |
#ended_by ⇒ Telnyx::Models::Conference::EndedBy?
IDs related to who ended the conference. It is expected for them to all be there or all be null
53 |
# File 'lib/telnyx/models/conference.rb', line 53 optional :ended_by, -> { Telnyx::Conference::EndedBy } |
#expires_at ⇒ String
ISO 8601 formatted date of when the conference will expire
23 |
# File 'lib/telnyx/models/conference.rb', line 23 required :expires_at, String |
#id ⇒ String
Uniquely identifies the conference
11 |
# File 'lib/telnyx/models/conference.rb', line 11 required :id, String |
#name ⇒ String
Name of the conference
29 |
# File 'lib/telnyx/models/conference.rb', line 29 required :name, String |
#record_type ⇒ Symbol, Telnyx::Models::Conference::RecordType
34 |
# File 'lib/telnyx/models/conference.rb', line 34 required :record_type, enum: -> { Telnyx::Conference::RecordType } |
#region ⇒ String?
Region where the conference is hosted
59 |
# File 'lib/telnyx/models/conference.rb', line 59 optional :region, String |
#status ⇒ Symbol, ...
Status of the conference
65 |
# File 'lib/telnyx/models/conference.rb', line 65 optional :status, enum: -> { Telnyx::Conference::Status } |
#updated_at ⇒ String?
ISO 8601 formatted date of when the conference was last updated
71 |
# File 'lib/telnyx/models/conference.rb', line 71 optional :updated_at, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/conference.rb', line 105
|