Class: Telnyx::Models::ConferenceCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ConferenceCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/conference_create_params.rb
Overview
Defined Under Namespace
Modules: BeepEnabled, Region
Instance Attribute Summary collapse
-
#beep_enabled ⇒ Symbol, ...
Whether a beep sound should be played when participants join and/or leave the conference.
-
#call_control_id ⇒ String
Unique identifier and token for controlling the call.
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#comfort_noise ⇒ Boolean?
Toggle background comfort noise.
-
#command_id ⇒ String?
Use this field to avoid execution of duplicate commands.
-
#duration_minutes ⇒ Integer?
Time length (minutes) after which the conference will end.
-
#hold_audio_url ⇒ String?
The URL of a file to be played to participants joining the conference.
-
#hold_media_name ⇒ String?
The media_name of a file to be played to participants joining the conference.
-
#max_participants ⇒ Integer?
The maximum number of active conference participants to allow.
-
#name ⇒ String
Name of the conference.
-
#region ⇒ Symbol, ...
Sets the region where the conference data will be hosted.
-
#start_conference_on_create ⇒ Boolean?
Whether the conference should be started on creation.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(call_control_id:, name:, beep_enabled: nil, client_state: nil, comfort_noise: nil, command_id: nil, duration_minutes: nil, hold_audio_url: nil, hold_media_name: nil, max_participants: nil, region: nil, start_conference_on_create: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConferenceCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id:, name:, beep_enabled: nil, client_state: nil, comfort_noise: nil, command_id: nil, duration_minutes: nil, hold_audio_url: nil, hold_media_name: nil, max_participants: nil, region: nil, start_conference_on_create: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ConferenceCreateParams for more details.
|
|
# File 'lib/telnyx/models/conference_create_params.rb', line 98
|
Instance Attribute Details
#beep_enabled ⇒ Symbol, ...
Whether a beep sound should be played when participants join and/or leave the conference.
27 |
# File 'lib/telnyx/models/conference_create_params.rb', line 27 optional :beep_enabled, enum: -> { Telnyx::ConferenceCreateParams::BeepEnabled } |
#call_control_id ⇒ String
Unique identifier and token for controlling the call
14 |
# File 'lib/telnyx/models/conference_create_params.rb', line 14 required :call_control_id, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string. The client_state will be updated for the creator call leg and will be used for all webhooks related to the created conference.
35 |
# File 'lib/telnyx/models/conference_create_params.rb', line 35 optional :client_state, String |
#comfort_noise ⇒ Boolean?
Toggle background comfort noise.
41 |
# File 'lib/telnyx/models/conference_create_params.rb', line 41 optional :comfort_noise, Telnyx::Internal::Type::Boolean |
#command_id ⇒ String?
Use this field to avoid execution of duplicate commands. Telnyx will ignore subsequent commands with the same ‘command_id` as one that has already been executed.
49 |
# File 'lib/telnyx/models/conference_create_params.rb', line 49 optional :command_id, String |
#duration_minutes ⇒ Integer?
Time length (minutes) after which the conference will end.
55 |
# File 'lib/telnyx/models/conference_create_params.rb', line 55 optional :duration_minutes, Integer |
#hold_audio_url ⇒ String?
The URL of a file to be played to participants joining the conference. The URL can point to either a WAV or MP3 file. hold_media_name and hold_audio_url cannot be used together in one request. Takes effect only when “start_conference_on_create” is set to “false”.
64 |
# File 'lib/telnyx/models/conference_create_params.rb', line 64 optional :hold_audio_url, String |
#hold_media_name ⇒ String?
The media_name of a file to be played to participants joining the conference. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file. Takes effect only when “start_conference_on_create” is set to “false”.
74 |
# File 'lib/telnyx/models/conference_create_params.rb', line 74 optional :hold_media_name, String |
#max_participants ⇒ Integer?
The maximum number of active conference participants to allow. Must be between 2 and 800. Defaults to 250
81 |
# File 'lib/telnyx/models/conference_create_params.rb', line 81 optional :max_participants, Integer |
#name ⇒ String
Name of the conference
20 |
# File 'lib/telnyx/models/conference_create_params.rb', line 20 required :name, String |
#region ⇒ Symbol, ...
Sets the region where the conference data will be hosted. Defaults to the region defined in user’s data locality settings (Europe or US).
88 |
# File 'lib/telnyx/models/conference_create_params.rb', line 88 optional :region, enum: -> { Telnyx::ConferenceCreateParams::Region } |
#start_conference_on_create ⇒ Boolean?
Whether the conference should be started on creation. If the conference isn’t started all participants that join are automatically put on hold. Defaults to “true”.
96 |
# File 'lib/telnyx/models/conference_create_params.rb', line 96 optional :start_conference_on_create, Telnyx::Internal::Type::Boolean |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/conference_create_params.rb', line 138
|