Class: Telnyx::Models::ConferenceListParticipantsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ConferenceListParticipantsResponse
- Defined in:
- lib/telnyx/models/conference_list_participants_response.rb
Overview
Defined Under Namespace
Modules: RecordType, Status Classes: Conference
Instance Attribute Summary collapse
-
#call_control_id ⇒ String
Call Control ID associated with the partiipant of the conference.
-
#call_leg_id ⇒ String
Uniquely identifies the call leg associated with the participant.
-
#conference ⇒ Telnyx::Models::ConferenceListParticipantsResponse::Conference
Info about the conference that the participant is in.
-
#created_at ⇒ String
ISO 8601 formatted date of when the participant was created.
-
#end_conference_on_exit ⇒ Boolean
Whether the conference will end and all remaining participants be hung up after the participant leaves the conference.
-
#id ⇒ String
Uniquely identifies the participant.
-
#muted ⇒ Boolean
Whether the participant is muted.
-
#on_hold ⇒ Boolean
Whether the participant is put on_hold.
- #record_type ⇒ Symbol, Telnyx::Models::ConferenceListParticipantsResponse::RecordType
-
#soft_end_conference_on_exit ⇒ Boolean
Whether the conference will end after the participant leaves the conference.
-
#status ⇒ Symbol, Telnyx::Models::ConferenceListParticipantsResponse::Status
The status of the participant with respect to the lifecycle within the conference.
-
#updated_at ⇒ String
ISO 8601 formatted date of when the participant was last updated.
-
#whisper_call_control_ids ⇒ Array<String>
Array of unique call_control_ids the participant can whisper to..
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, name: nil) ⇒ Object
constructor
Info about the conference that the participant is in.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, name: nil) ⇒ Object
Info about the conference that the participant is in
|
|
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 86
|
Instance Attribute Details
#call_control_id ⇒ String
Call Control ID associated with the partiipant of the conference
17 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 17 required :call_control_id, String |
#call_leg_id ⇒ String
Uniquely identifies the call leg associated with the participant
23 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 23 required :call_leg_id, String |
#conference ⇒ Telnyx::Models::ConferenceListParticipantsResponse::Conference
Info about the conference that the participant is in
29 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 29 required :conference, -> { Telnyx::Models::ConferenceListParticipantsResponse::Conference } |
#created_at ⇒ String
ISO 8601 formatted date of when the participant was created
35 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 35 required :created_at, String |
#end_conference_on_exit ⇒ Boolean
Whether the conference will end and all remaining participants be hung up after the participant leaves the conference.
42 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 42 required :end_conference_on_exit, Telnyx::Internal::Type::Boolean |
#id ⇒ String
Uniquely identifies the participant
11 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 11 required :id, String |
#muted ⇒ Boolean
Whether the participant is muted.
48 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 48 required :muted, Telnyx::Internal::Type::Boolean |
#on_hold ⇒ Boolean
Whether the participant is put on_hold.
54 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 54 required :on_hold, Telnyx::Internal::Type::Boolean |
#record_type ⇒ Symbol, Telnyx::Models::ConferenceListParticipantsResponse::RecordType
59 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 59 required :record_type, enum: -> { Telnyx::Models::ConferenceListParticipantsResponse::RecordType } |
#soft_end_conference_on_exit ⇒ Boolean
Whether the conference will end after the participant leaves the conference.
65 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 65 required :soft_end_conference_on_exit, Telnyx::Internal::Type::Boolean |
#status ⇒ Symbol, Telnyx::Models::ConferenceListParticipantsResponse::Status
The status of the participant with respect to the lifecycle within the conference
72 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 72 required :status, enum: -> { Telnyx::Models::ConferenceListParticipantsResponse::Status } |
#updated_at ⇒ String
ISO 8601 formatted date of when the participant was last updated
78 |
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 78 required :updated_at, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/conference_list_participants_response.rb', line 144
|