Class: Telnyx::Models::ConferencePlaybackEnded::Payload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/conference_playback_ended.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#conference_idString?

ID of the conference the text was spoken in.

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/conference_playback_ended.rb', line 56

optional :conference_id, String

#connection_idString?

Call Control App ID (formerly Telnyx connection ID) used in the call.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/conference_playback_ended.rb', line 62

optional :connection_id, String

#creator_call_session_idString?

ID that is unique to the call session that started the conference.

Returns:

  • (String, nil)


68
# File 'lib/telnyx/models/conference_playback_ended.rb', line 68

optional :creator_call_session_id, String

#media_nameString?

The name of the audio media file being played back, if media_name has been used to start.

Returns:

  • (String, nil)


75
# File 'lib/telnyx/models/conference_playback_ended.rb', line 75

optional :media_name, String

#media_urlString?

The audio URL being played back, if audio_url has been used to start.

Returns:

  • (String, nil)


81
# File 'lib/telnyx/models/conference_playback_ended.rb', line 81

optional :media_url, String

#occurred_atTime?

ISO 8601 datetime of when the event occurred.

Returns:

  • (Time, nil)


87
# File 'lib/telnyx/models/conference_playback_ended.rb', line 87

optional :occurred_at, Time