Class: Telnyx::Models::Conferences::ActionGatherDtmfAudioParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Conferences::ActionGatherDtmfAudioParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb
Overview
Instance Attribute Summary collapse
-
#audio_url ⇒ String?
The URL of the audio file to play as the gather prompt.
-
#call_control_id ⇒ String
Unique identifier and token for controlling the call leg that will receive the gather prompt.
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#gather_id ⇒ String?
Identifier for this gather command.
- #id ⇒ String
-
#initial_timeout_millis ⇒ Integer?
Duration in milliseconds to wait for the first digit before timing out.
-
#inter_digit_timeout_millis ⇒ Integer?
Duration in milliseconds to wait between digits.
-
#invalid_audio_url ⇒ String?
URL of audio file to play when invalid input is received.
-
#invalid_media_name ⇒ String?
Name of media file to play when invalid input is received.
-
#maximum_digits ⇒ Integer?
Maximum number of digits to gather.
-
#maximum_tries ⇒ Integer?
Maximum number of times to play the prompt if no input is received.
-
#media_name ⇒ String?
The name of the media file uploaded to the Media Storage API to play as the gather prompt.
-
#minimum_digits ⇒ Integer?
Minimum number of digits to gather.
-
#stop_playback_on_dtmf ⇒ Boolean?
Whether to stop the audio playback when a DTMF digit is received.
-
#terminating_digit ⇒ String?
Digit that terminates gathering.
-
#timeout_millis ⇒ Integer?
Duration in milliseconds to wait for input before timing out.
-
#valid_digits ⇒ String?
Digits that are valid for gathering.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, call_control_id:, audio_url: nil, client_state: nil, gather_id: nil, initial_timeout_millis: nil, inter_digit_timeout_millis: nil, invalid_audio_url: nil, invalid_media_name: nil, maximum_digits: nil, maximum_tries: nil, media_name: nil, minimum_digits: nil, stop_playback_on_dtmf: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionGatherDtmfAudioParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, call_control_id:, audio_url: nil, client_state: nil, gather_id: nil, initial_timeout_millis: nil, inter_digit_timeout_millis: nil, invalid_audio_url: nil, invalid_media_name: nil, maximum_digits: nil, maximum_tries: nil, media_name: nil, minimum_digits: nil, stop_playback_on_dtmf: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionGatherDtmfAudioParams for more details.
|
|
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 117
|
Instance Attribute Details
#audio_url ⇒ String?
The URL of the audio file to play as the gather prompt. Must be WAV or MP3 format.
28 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 28 optional :audio_url, String |
#call_control_id ⇒ String
Unique identifier and token for controlling the call leg that will receive the gather prompt.
21 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 21 required :call_control_id, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. Must be a valid Base-64 encoded string.
35 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 35 optional :client_state, String |
#gather_id ⇒ String?
Identifier for this gather command. Will be included in the gather ended webhook. Maximum 100 characters.
42 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 42 optional :gather_id, String |
#id ⇒ String
14 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 14 required :id, String |
#initial_timeout_millis ⇒ Integer?
Duration in milliseconds to wait for the first digit before timing out.
48 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 48 optional :initial_timeout_millis, Integer |
#inter_digit_timeout_millis ⇒ Integer?
Duration in milliseconds to wait between digits.
54 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 54 optional :inter_digit_timeout_millis, Integer |
#invalid_audio_url ⇒ String?
URL of audio file to play when invalid input is received.
60 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 60 optional :invalid_audio_url, String |
#invalid_media_name ⇒ String?
Name of media file to play when invalid input is received.
66 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 66 optional :invalid_media_name, String |
#maximum_digits ⇒ Integer?
Maximum number of digits to gather.
72 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 72 optional :maximum_digits, Integer |
#maximum_tries ⇒ Integer?
Maximum number of times to play the prompt if no input is received.
78 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 78 optional :maximum_tries, Integer |
#media_name ⇒ String?
The name of the media file uploaded to the Media Storage API to play as the gather prompt.
85 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 85 optional :media_name, String |
#minimum_digits ⇒ Integer?
Minimum number of digits to gather.
91 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 91 optional :minimum_digits, Integer |
#stop_playback_on_dtmf ⇒ Boolean?
Whether to stop the audio playback when a DTMF digit is received.
97 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 97 optional :stop_playback_on_dtmf, Telnyx::Internal::Type::Boolean |
#terminating_digit ⇒ String?
Digit that terminates gathering.
103 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 103 optional :terminating_digit, String |
#timeout_millis ⇒ Integer?
Duration in milliseconds to wait for input before timing out.
109 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 109 optional :timeout_millis, Integer |
#valid_digits ⇒ String?
Digits that are valid for gathering. All other digits will be ignored.
115 |
# File 'lib/telnyx/models/conferences/action_gather_dtmf_audio_params.rb', line 115 optional :valid_digits, String |