Class: Telnyx::Models::Conferences::ActionHoldParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Conferences::ActionHoldParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/conferences/action_hold_params.rb
Overview
Defined Under Namespace
Modules: Region
Instance Attribute Summary collapse
-
#audio_url ⇒ String?
The URL of a file to be played to the participants when they are put on hold.
-
#call_control_ids ⇒ Array<String>?
List of unique identifiers and tokens for controlling the call.
- #id ⇒ String
-
#media_name ⇒ String?
The media_name of a file to be played to the participants when they are put on hold.
-
#region ⇒ Symbol, ...
Region where the conference data is located.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, audio_url: nil, call_control_ids: nil, media_name: nil, region: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionHoldParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, audio_url: nil, call_control_ids: nil, media_name: nil, region: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionHoldParams for more details.
|
|
# File 'lib/telnyx/models/conferences/action_hold_params.rb', line 46
|
Instance Attribute Details
#audio_url ⇒ String?
The URL of a file to be played to the participants when they are put on hold. media_name and audio_url cannot be used together in one request.
21 |
# File 'lib/telnyx/models/conferences/action_hold_params.rb', line 21 optional :audio_url, String |
#call_control_ids ⇒ Array<String>?
List of unique identifiers and tokens for controlling the call. When empty all participants will be placed on hold.
28 |
# File 'lib/telnyx/models/conferences/action_hold_params.rb', line 28 optional :call_control_ids, Telnyx::Internal::Type::ArrayOf[String] |
#id ⇒ String
14 |
# File 'lib/telnyx/models/conferences/action_hold_params.rb', line 14 required :id, String |
#media_name ⇒ String?
The media_name of a file to be played to the participants when they are put on hold. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file.
37 |
# File 'lib/telnyx/models/conferences/action_hold_params.rb', line 37 optional :media_name, String |
#region ⇒ Symbol, ...
Region where the conference data is located. Defaults to the region defined in user’s data locality settings (Europe or US).
44 |
# File 'lib/telnyx/models/conferences/action_hold_params.rb', line 44 optional :region, enum: -> { Telnyx::Conferences::ActionHoldParams::Region } |