Class: Telnyx::Models::Conferences::ActionJoinParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Conferences::ActionJoinParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/conferences/action_join_params.rb
Overview
Defined Under Namespace
Modules: BeepEnabled, Region, SupervisorRole
Instance Attribute Summary collapse
-
#beep_enabled ⇒ Symbol, ...
Whether a beep sound should be played when the participant joins and/or leaves the conference.
-
#call_control_id ⇒ String
Unique identifier and token for controlling the call.
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid execution of duplicate commands.
-
#end_conference_on_exit ⇒ Boolean?
Whether the conference should end and all remaining participants be hung up after the participant leaves the conference.
-
#hold ⇒ Boolean?
Whether the participant should be put on hold immediately after joining the conference.
-
#hold_audio_url ⇒ String?
The URL of a file to be played to the participant when they are put on hold after joining the conference.
-
#hold_media_name ⇒ String?
The media_name of a file to be played to the participant when they are put on hold after joining the conference.
- #id ⇒ String
-
#mute ⇒ Boolean?
Whether the participant should be muted immediately after joining the conference.
-
#region ⇒ Symbol, ...
Region where the conference data is located.
-
#soft_end_conference_on_exit ⇒ Boolean?
Whether the conference should end after the participant leaves the conference.
-
#start_conference_on_enter ⇒ Boolean?
Whether the conference should be started after the participant joins the conference.
-
#supervisor_role ⇒ Symbol, ...
Sets the joining participant as a supervisor for the conference.
-
#whisper_call_control_ids ⇒ Array<String>?
Array of unique call_control_ids the joining supervisor can whisper to.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, call_control_id:, beep_enabled: nil, client_state: nil, command_id: nil, end_conference_on_exit: nil, hold: nil, hold_audio_url: nil, hold_media_name: nil, mute: nil, region: nil, soft_end_conference_on_exit: nil, start_conference_on_enter: nil, supervisor_role: nil, whisper_call_control_ids: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionJoinParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, call_control_id:, beep_enabled: nil, client_state: nil, command_id: nil, end_conference_on_exit: nil, hold: nil, hold_audio_url: nil, hold_media_name: nil, mute: nil, region: nil, soft_end_conference_on_exit: nil, start_conference_on_enter: nil, supervisor_role: nil, whisper_call_control_ids: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionJoinParams for more details.
|
|
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 127
|
Instance Attribute Details
#beep_enabled ⇒ Symbol, ...
Whether a beep sound should be played when the participant joins and/or leaves the conference. Can be used to override the conference-level setting.
27 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 27 optional :beep_enabled, enum: -> { Telnyx::Conferences::ActionJoinParams::BeepEnabled } |
#call_control_id ⇒ String
Unique identifier and token for controlling the call
20 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 20 required :call_control_id, String |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string. Please note that the client_state will be updated for the participient call leg and the change will not affect conferencing webhooks unless the participient is the owner of the conference.
36 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 36 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid execution of duplicate commands. Telnyx will ignore subsequent commands with the same ‘command_id` as one that has already been executed.
44 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 44 optional :command_id, String |
#end_conference_on_exit ⇒ Boolean?
Whether the conference should end and all remaining participants be hung up after the participant leaves the conference. Defaults to “false”.
51 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 51 optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean |
#hold ⇒ Boolean?
Whether the participant should be put on hold immediately after joining the conference. Defaults to “false”.
58 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 58 optional :hold, Telnyx::Internal::Type::Boolean |
#hold_audio_url ⇒ String?
The URL of a file to be played to the participant when they are put on hold after joining the conference. hold_media_name and hold_audio_url cannot be used together in one request. Takes effect only when “start_conference_on_create” is set to “false”. This property takes effect only if “hold” is set to “true”.
67 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 67 optional :hold_audio_url, String |
#hold_media_name ⇒ String?
The media_name of a file to be played to the participant when they are put on hold after joining the conference. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file. Takes effect only when “start_conference_on_create” is set to “false”. This property takes effect only if “hold” is set to “true”.
78 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 78 optional :hold_media_name, String |
#id ⇒ String
14 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 14 required :id, String |
#mute ⇒ Boolean?
Whether the participant should be muted immediately after joining the conference. Defaults to “false”.
85 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 85 optional :mute, Telnyx::Internal::Type::Boolean |
#region ⇒ Symbol, ...
Region where the conference data is located. Defaults to the region defined in user’s data locality settings (Europe or US).
92 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 92 optional :region, enum: -> { Telnyx::Conferences::ActionJoinParams::Region } |
#soft_end_conference_on_exit ⇒ Boolean?
Whether the conference should end after the participant leaves the conference. NOTE this doesn’t hang up the other participants. Defaults to “false”.
99 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 99 optional :soft_end_conference_on_exit, Telnyx::Internal::Type::Boolean |
#start_conference_on_enter ⇒ Boolean?
Whether the conference should be started after the participant joins the conference. Defaults to “false”.
106 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 106 optional :start_conference_on_enter, Telnyx::Internal::Type::Boolean |
#supervisor_role ⇒ Symbol, ...
Sets the joining participant as a supervisor for the conference. A conference can have multiple supervisors. “barge” means the supervisor enters the conference as a normal participant. This is the same as “none”. “monitor” means the supervisor is muted but can hear all participants. “whisper” means that only the specified “whisper_call_control_ids” can hear the supervisor. Defaults to “none”.
117 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 117 optional :supervisor_role, enum: -> { Telnyx::Conferences::ActionJoinParams::SupervisorRole } |
#whisper_call_control_ids ⇒ Array<String>?
Array of unique call_control_ids the joining supervisor can whisper to. If none provided, the supervisor will join the conference as a monitoring participant only.
125 |
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 125 optional :whisper_call_control_ids, Telnyx::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/conferences/action_join_params.rb', line 173
|