Module: Telnyx::Models::Conferences::ActionJoinParams::SupervisorRole

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/conferences/action_join_params.rb

Overview

Sets the joining participant as a supervisor for the conference. A conference can have multiple supervisors. “barge” means the supervisor enters the conference as a normal participant. This is the same as “none”. “monitor” means the supervisor is muted but can hear all participants. “whisper” means that only the specified “whisper_call_control_ids” can hear the supervisor. Defaults to “none”.

Constant Summary collapse

BARGE =
:barge
MONITOR =
:monitor
NONE =
:none
WHISPER =
:whisper

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/conferences/action_join_params.rb', line 205