Class: Telnyx::Models::Conferences::ActionPlayParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Conferences::ActionPlayParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/conferences/action_play_params.rb
Overview
Defined Under Namespace
Modules: Region
Instance Attribute Summary collapse
-
#audio_url ⇒ String?
The URL of a file to be played back in the conference.
-
#call_control_ids ⇒ Array<String>?
List of call control ids identifying participants the audio file should be played to.
- #id ⇒ String
-
#loop_ ⇒ String, ...
The number of times the audio file should be played.
-
#media_name ⇒ String?
The media_name of a file to be played back in the conference.
-
#region ⇒ Symbol, ...
Region where the conference data is located.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, audio_url: nil, call_control_ids: nil, loop_: nil, media_name: nil, region: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionPlayParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, audio_url: nil, call_control_ids: nil, loop_: nil, media_name: nil, region: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionPlayParams for more details.
|
|
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 53
|
Instance Attribute Details
#audio_url ⇒ String?
The URL of a file to be played back in the conference. media_name and audio_url cannot be used together in one request.
21 |
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 21 optional :audio_url, String |
#call_control_ids ⇒ Array<String>?
List of call control ids identifying participants the audio file should be played to. If not given, the audio file will be played to the entire conference.
28 |
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 28 optional :call_control_ids, Telnyx::Internal::Type::ArrayOf[String] |
#id ⇒ String
14 |
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 14 required :id, String |
#loop_ ⇒ String, ...
The number of times the audio file should be played. If supplied, the value must be an integer between 1 and 100, or the special string ‘infinity` for an endless loop.
36 |
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 36 optional :loop_, union: -> { Telnyx::Calls::Loopcount }, api_name: :loop |
#media_name ⇒ String?
The media_name of a file to be played back in the conference. The media_name must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. The file must either be a WAV or MP3 file.
44 |
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 44 optional :media_name, String |
#region ⇒ Symbol, ...
Region where the conference data is located. Defaults to the region defined in user’s data locality settings (Europe or US).
51 |
# File 'lib/telnyx/models/conferences/action_play_params.rb', line 51 optional :region, enum: -> { Telnyx::Conferences::ActionPlayParams::Region } |