Module: Telnyx::Models::Conferences::ActionRecordStartParams::Channels
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/conferences/action_record_start_params.rb
Overview
When ‘dual`, final audio file will be stereo recorded with the conference creator on the first channel, and the rest on the second channel.
Constant Summary collapse
- SINGLE =
:single- DUAL =
:dual
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info