Class: Telnyx::Models::Conferences::ActionRecordStopParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Conferences::ActionRecordStopParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/conferences/action_record_stop_params.rb
Overview
Defined Under Namespace
Modules: Region
Instance Attribute Summary collapse
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#command_id ⇒ String?
Use this field to avoid duplicate commands.
- #id ⇒ String
-
#recording_id ⇒ String?
Uniquely identifies the resource.
-
#region ⇒ Symbol, ...
Region where the conference data is located.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, client_state: nil, command_id: nil, recording_id: nil, region: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionRecordStopParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, client_state: nil, command_id: nil, recording_id: nil, region: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionRecordStopParams for more details.
|
|
# File 'lib/telnyx/models/conferences/action_record_stop_params.rb', line 43
|
Instance Attribute Details
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
21 |
# File 'lib/telnyx/models/conferences/action_record_stop_params.rb', line 21 optional :client_state, String |
#command_id ⇒ String?
Use this field to avoid duplicate commands. Telnyx will ignore any command with the same ‘command_id` for the same `call_control_id`.
28 |
# File 'lib/telnyx/models/conferences/action_record_stop_params.rb', line 28 optional :command_id, String |
#id ⇒ String
14 |
# File 'lib/telnyx/models/conferences/action_record_stop_params.rb', line 14 required :id, String |
#recording_id ⇒ String?
Uniquely identifies the resource.
34 |
# File 'lib/telnyx/models/conferences/action_record_stop_params.rb', line 34 optional :recording_id, String |
#region ⇒ Symbol, ...
Region where the conference data is located. Defaults to the region defined in user’s data locality settings (Europe or US).
41 |
# File 'lib/telnyx/models/conferences/action_record_stop_params.rb', line 41 optional :region, enum: -> { Telnyx::Conferences::ActionRecordStopParams::Region } |