Class: Telnyx::Models::Conferences::ActionSpeakParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/conferences/action_speak_params.rb

Overview

Defined Under Namespace

Modules: Language, PayloadType, Region, VoiceSettings

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, payload:, voice:, call_control_ids: nil, command_id: nil, language: nil, payload_type: nil, region: nil, voice_settings: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionSpeakParams for more details.

Parameters:



# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 111

Instance Attribute Details

#call_control_idsArray<String>?

Call Control IDs of participants who will hear the spoken text. When empty all participants will hear the spoken text.

Returns:

  • (Array<String>, nil)


74
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 74

optional :call_control_ids, Telnyx::Internal::Type::ArrayOf[String]

#command_idString?

Use this field to avoid execution of duplicate commands. Telnyx will ignore subsequent commands with the same ‘command_id` as one that has already been executed.

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 82

optional :command_id, String

#idString

Returns:

  • (String)


14
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 14

required :id, String

#languageSymbol, ...

The language you want spoken. This parameter is ignored when a ‘Polly.*` voice is specified.



89
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 89

optional :language, enum: -> { Telnyx::Conferences::ActionSpeakParams::Language }

#payloadString

The text or SSML to be converted into speech. There is a 3,000 character limit.

Returns:

  • (String)


20
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 20

required :payload, String

#payload_typeSymbol, ...

The type of the provided payload. The payload can either be plain text, or Speech Synthesis Markup Language (SSML).



96
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 96

optional :payload_type, enum: -> { Telnyx::Conferences::ActionSpeakParams::PayloadType }

#regionSymbol, ...

Region where the conference data is located. Defaults to the region defined in user’s data locality settings (Europe or US).



103
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 103

optional :region, enum: -> { Telnyx::Conferences::ActionSpeakParams::Region }

#voiceString

Specifies the voice used in speech synthesis.

  • Define voices using the format ‘<Provider>.<Model>.<VoiceId>`. Specifying only the provider will give default values for voice_id and model_id.

    **Supported Providers:**

  • AWS: Use ‘AWS.Polly.<VoiceId>` (e.g., `AWS.Polly.Joanna`). For neural voices, which provide more realistic, human-like speech, append `-Neural` to the `VoiceId` (e.g., `AWS.Polly.Joanna-Neural`). Check the [available voices](docs.aws.amazon.com/polly/latest/dg/available-voices.html) for compatibility.

  • Azure: Use ‘Azure.<VoiceId>` (e.g., `Azure.en-CA-ClaraNeural`, `Azure.en-US-BrianMultilingualNeural`, `Azure.en-US-Ava:DragonHDLatestNeural`). For a complete list of voices, go to [Azure Voice Gallery](speech.microsoft.com/portal/voicegallery). Use `voice_settings` to configure custom deployments, regions, or API keys.

  • ElevenLabs: Use ‘ElevenLabs.<ModelId>.<VoiceId>` (e.g., `ElevenLabs.eleven_multilingual_v2.21m00Tcm4TlvDq8ikWAM`). The `ModelId` part is optional. To use ElevenLabs, you must provide your ElevenLabs API key as an integration identifier secret in `“voice_settings”: “<secret_identifier>”`. See [integration secrets documentation](developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) for details. Check [available voices](elevenlabs.io/docs/api-reference/get-voices).

  • Telnyx: Use ‘Telnyx.<model_id>.<voice_id>` (e.g., `Telnyx.KokoroTTS.af`). Use `voice_settings` to configure voice_speed and other synthesis parameters.

  • Minimax: Use ‘Minimax.<ModelId>.<VoiceId>` (e.g., `Minimax.speech-02-hd.Wise_Woman`). Supported models: `speech-02-turbo`, `speech-02-hd`, `speech-2.6-turbo`, `speech-2.8-turbo`. Use `voice_settings` to configure speed, volume, pitch, and language_boost.

  • Rime: Use ‘Rime.<model_id>.<voice_id>` (e.g., `Rime.Arcana.cove`). Supported model_ids: `Arcana`, `Mist`. Use `voice_settings` to configure voice_speed.

  • Resemble: Use ‘Resemble.Turbo.<voice_id>` (e.g., `Resemble.Turbo.my_voice`). Only `Turbo` model is supported. Use `voice_settings` to configure precision, sample_rate, and format.

  • Inworld: Use ‘Inworld.<ModelId>.<VoiceId>` (e.g., `Inworld.Mini.Loretta`, `Inworld.Max.Oliver`). Supported models: `Mini`, `Max`.

For service_level basic, you may define the gender of the speaker (male or female).

Returns:

  • (String)


67
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 67

required :voice, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 170