Class: Telnyx::Models::Conferences::ActionSpeakParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Conferences::ActionSpeakParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/conferences/action_speak_params.rb
Overview
Defined Under Namespace
Modules: Language, PayloadType, Region, VoiceSettings
Instance Attribute Summary collapse
-
#call_control_ids ⇒ Array<String>?
Call Control IDs of participants who will hear the spoken text.
-
#command_id ⇒ String?
Use this field to avoid execution of duplicate commands.
-
#language ⇒ Symbol, ...
The language you want spoken.
-
#payload ⇒ String
The text or SSML to be converted into speech.
-
#payload_type ⇒ Symbol, ...
The type of the provided payload.
-
#region ⇒ Symbol, ...
Region where the conference data is located.
-
#voice ⇒ String
Specifies the voice used in speech synthesis.
-
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(payload:, voice:, call_control_ids: nil, command_id: nil, language: nil, payload_type: nil, region: nil, voice_settings: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionSpeakParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(payload:, voice:, call_control_ids: nil, command_id: nil, language: nil, payload_type: nil, region: nil, voice_settings: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Conferences::ActionSpeakParams for more details.
|
|
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 92
|
Instance Attribute Details
#call_control_ids ⇒ Array<String>?
Call Control IDs of participants who will hear the spoken text. When empty all participants will hear the spoken text.
55 |
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 55 optional :call_control_ids, Telnyx::Internal::Type::ArrayOf[String] |
#command_id ⇒ String?
Use this field to avoid execution of duplicate commands. Telnyx will ignore subsequent commands with the same ‘command_id` as one that has already been executed.
63 |
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 63 optional :command_id, String |
#language ⇒ Symbol, ...
The language you want spoken. This parameter is ignored when a ‘Polly.*` voice is specified.
70 |
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 70 optional :language, enum: -> { Telnyx::Conferences::ActionSpeakParams::Language } |
#payload ⇒ String
The text or SSML to be converted into speech. There is a 3,000 character limit.
15 |
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 15 required :payload, String |
#payload_type ⇒ Symbol, ...
The type of the provided payload. The payload can either be plain text, or Speech Synthesis Markup Language (SSML).
77 |
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 77 optional :payload_type, enum: -> { Telnyx::Conferences::ActionSpeakParams::PayloadType } |
#region ⇒ Symbol, ...
Region where the conference data is located. Defaults to the region defined in user’s data locality settings (Europe or US).
84 |
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 84 optional :region, enum: -> { Telnyx::Conferences::ActionSpeakParams::Region } |
#voice ⇒ String
Specifies the voice used in speech synthesis.
-
Define voices using the format ‘<Provider>.<Model>.<VoiceId>`. Specifying only the provider will give default values for voice_id and model_id.
**Supported Providers:**
-
AWS: Use ‘AWS.Polly.<VoiceId>` (e.g., `AWS.Polly.Joanna`). For neural voices, which provide more realistic, human-like speech, append `-Neural` to the `VoiceId` (e.g., `AWS.Polly.Joanna-Neural`). Check the [available voices](docs.aws.amazon.com/polly/latest/dg/available-voices.html) for compatibility.
-
Azure: Use ‘Azure.<VoiceId>. (e.g. Azure.en-CA-ClaraNeural, Azure.en-CA-LiamNeural, Azure.en-US-BrianMultilingualNeural, Azure.en-US-Ava:DragonHDLatestNeural. For a complete list of voices, go to [Azure Voice Gallery](speech.microsoft.com/portal/voicegallery).)
-
ElevenLabs: Use ‘ElevenLabs.<ModelId>.<VoiceId>` (e.g., `ElevenLabs.eleven_multilingual_v2.21m00Tcm4TlvDq8ikWAM`). The `ModelId` part is optional. To use ElevenLabs, you must provide your ElevenLabs API key as an integration identifier secret in `“voice_settings”: “<secret_identifier>”`. See [integration secrets documentation](developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret) for details. Check [available voices](elevenlabs.io/docs/api-reference/get-voices).
-
Telnyx: Use ‘Telnyx.<model_id>.<voice_id>`
For service_level basic, you may define the gender of the speaker (male or female).
48 |
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 48 required :voice, String |
#voice_settings ⇒ Telnyx::Models::Calls::ElevenLabsVoiceSettings, ...
The settings associated with the voice selected
90 |
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 90 optional :voice_settings, union: -> { Telnyx::Conferences::ActionSpeakParams::VoiceSettings } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/conferences/action_speak_params.rb', line 149
|