Module: Telnyx::Models::Conferences::UpdateConference::SupervisorRole
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/conferences/update_conference.rb,
sig/telnyx/models/conferences/update_conference.rbs
Overview
Sets the participant as a supervisor for the conference. A conference can have multiple supervisors. "barge" means the supervisor enters the conference as a normal participant. This is the same as "none". "monitor" means the supervisor is muted but can hear all participants. "whisper" means that only the specified "whisper_call_control_ids" can hear the supervisor. Defaults to "none".
Constant Summary collapse
- BARGE =
:barge- MONITOR =
:monitor- NONE =
:none- WHISPER =
:whisper
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::Conferences::UpdateConference::supervisor_role]
60 |
# File 'sig/telnyx/models/conferences/update_conference.rbs', line 60
def self?.values: -> ::Array[Telnyx::Models::Conferences::UpdateConference::supervisor_role]
|