Class: Telnyx::Models::ConnectionListActiveCallsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ConnectionListActiveCallsResponse
- Defined in:
- lib/telnyx/models/connection_list_active_calls_response.rb
Overview
Defined Under Namespace
Modules: RecordType
Instance Attribute Summary collapse
-
#call_control_id ⇒ String
Unique identifier and token for controlling the call.
-
#call_duration ⇒ Integer
Indicates the duration of the call in seconds.
-
#call_leg_id ⇒ String
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String
ID that is unique to the call session and can be used to correlate webhook events.
-
#client_state ⇒ String
State received from a command.
- #record_type ⇒ Symbol, Telnyx::Models::ConnectionListActiveCallsResponse::RecordType
Instance Method Summary collapse
-
#initialize(call_control_id:, call_duration:, call_leg_id:, call_session_id:, client_state:, record_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConnectionListActiveCallsResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id:, call_duration:, call_leg_id:, call_session_id:, client_state:, record_type:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ConnectionListActiveCallsResponse for more details.
|
|
# File 'lib/telnyx/models/connection_list_active_calls_response.rb', line 44
|
Instance Attribute Details
#call_control_id ⇒ String
Unique identifier and token for controlling the call.
11 |
# File 'lib/telnyx/models/connection_list_active_calls_response.rb', line 11 required :call_control_id, String |
#call_duration ⇒ Integer
Indicates the duration of the call in seconds
17 |
# File 'lib/telnyx/models/connection_list_active_calls_response.rb', line 17 required :call_duration, Integer |
#call_leg_id ⇒ String
ID that is unique to the call and can be used to correlate webhook events
23 |
# File 'lib/telnyx/models/connection_list_active_calls_response.rb', line 23 required :call_leg_id, String |
#call_session_id ⇒ String
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call
31 |
# File 'lib/telnyx/models/connection_list_active_calls_response.rb', line 31 required :call_session_id, String |
#client_state ⇒ String
State received from a command.
37 |
# File 'lib/telnyx/models/connection_list_active_calls_response.rb', line 37 required :client_state, String |
#record_type ⇒ Symbol, Telnyx::Models::ConnectionListActiveCallsResponse::RecordType
42 |
# File 'lib/telnyx/models/connection_list_active_calls_response.rb', line 42 required :record_type, enum: -> { Telnyx::Models::ConnectionListActiveCallsResponse::RecordType } |