Class: Telnyx::Models::ConnectionListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ConnectionListResponse
- Defined in:
- lib/telnyx/models/connection_list_response.rb
Overview
Defined Under Namespace
Modules: WebhookAPIVersion
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Defaults to true.
-
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection.
- #connection_name ⇒ String?
-
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
-
#id ⇒ String?
Identifies the specific resource.
-
#outbound_voice_profile_id ⇒ String?
Identifies the associated outbound voice profile.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#tags ⇒ Array<String>?
Tags associated with the connection.
-
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
-
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent.
Instance Method Summary collapse
-
#initialize(id: nil, active: nil, anchorsite_override: nil, connection_name: nil, created_at: nil, outbound_voice_profile_id: nil, record_type: nil, tags: nil, updated_at: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConnectionListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, active: nil, anchorsite_override: nil, connection_name: nil, created_at: nil, outbound_voice_profile_id: nil, record_type: nil, tags: nil, updated_at: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ConnectionListResponse for more details.
|
|
# File 'lib/telnyx/models/connection_list_response.rb', line 81
|
Instance Attribute Details
#active ⇒ Boolean?
Defaults to true
17 |
# File 'lib/telnyx/models/connection_list_response.rb', line 17 optional :active, Telnyx::Internal::Type::Boolean |
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.
25 |
# File 'lib/telnyx/models/connection_list_response.rb', line 25 optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride } |
#connection_name ⇒ String?
30 |
# File 'lib/telnyx/models/connection_list_response.rb', line 30 optional :connection_name, String |
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
36 |
# File 'lib/telnyx/models/connection_list_response.rb', line 36 optional :created_at, String |
#id ⇒ String?
Identifies the specific resource.
11 |
# File 'lib/telnyx/models/connection_list_response.rb', line 11 optional :id, String |
#outbound_voice_profile_id ⇒ String?
Identifies the associated outbound voice profile.
42 |
# File 'lib/telnyx/models/connection_list_response.rb', line 42 optional :outbound_voice_profile_id, String |
#record_type ⇒ String?
Identifies the type of the resource.
48 |
# File 'lib/telnyx/models/connection_list_response.rb', line 48 optional :record_type, String |
#tags ⇒ Array<String>?
Tags associated with the connection.
54 |
# File 'lib/telnyx/models/connection_list_response.rb', line 54 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
60 |
# File 'lib/telnyx/models/connection_list_response.rb', line 60 optional :updated_at, String |
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
66 |
# File 'lib/telnyx/models/connection_list_response.rb', line 66 optional :webhook_api_version, enum: -> { Telnyx::Models::ConnectionListResponse::WebhookAPIVersion } |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
73 |
# File 'lib/telnyx/models/connection_list_response.rb', line 73 optional :webhook_event_failover_url, String, nil?: true |
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent.
79 |
# File 'lib/telnyx/models/connection_list_response.rb', line 79 optional :webhook_event_url, String, nil?: true |