Class: Telnyx::Models::ConnectionRtcpSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ConnectionRtcpSettings
- Defined in:
- lib/telnyx/models/connection_rtcp_settings.rb
Defined Under Namespace
Modules: Port
Instance Attribute Summary collapse
-
#capture_enabled ⇒ Boolean?
BETA - Enable the capture and storage of RTCP messages to create QoS reports on the Telnyx Mission Control Portal.
-
#port ⇒ Symbol, ...
RTCP port by default is rtp+1, it can also be set to rtcp-mux.
-
#report_frequency_secs ⇒ Integer?
RTCP reports are sent to customers based on the frequency set.
Instance Method Summary collapse
-
#initialize(capture_enabled: nil, port: nil, report_frequency_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConnectionRtcpSettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(capture_enabled: nil, port: nil, report_frequency_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ConnectionRtcpSettings for more details.
|
|
# File 'lib/telnyx/models/connection_rtcp_settings.rb', line 26
|
Instance Attribute Details
#capture_enabled ⇒ Boolean?
BETA - Enable the capture and storage of RTCP messages to create QoS reports on the Telnyx Mission Control Portal.
11 |
# File 'lib/telnyx/models/connection_rtcp_settings.rb', line 11 optional :capture_enabled, Telnyx::Internal::Type::Boolean |
#port ⇒ Symbol, ...
RTCP port by default is rtp+1, it can also be set to rtcp-mux
17 |
# File 'lib/telnyx/models/connection_rtcp_settings.rb', line 17 optional :port, enum: -> { Telnyx::ConnectionRtcpSettings::Port } |
#report_frequency_secs ⇒ Integer?
RTCP reports are sent to customers based on the frequency set. Frequency is in seconds and it can be set to values from 5 to 3000 seconds.
24 |
# File 'lib/telnyx/models/connection_rtcp_settings.rb', line 24 optional :report_frequency_secs, Integer |