Class: Telnyx::Models::CredentialConnection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CredentialConnection
- Defined in:
- lib/telnyx/models/credential_connection.rb
Overview
Defined Under Namespace
Modules: NoiseSuppression, SipUriCallingPreference, WebhookAPIVersion
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Defaults to true.
-
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection.
-
#android_push_credential_id ⇒ String?
The uuid of the push credential for Android.
-
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this connection.
- #connection_name ⇒ String?
-
#created_at ⇒ String?
ISO-8601 formatted date indicating when the resource was created.
-
#default_on_hold_comfort_noise_enabled ⇒ Boolean?
When enabled, Telnyx will generate comfort noise when you place the call on hold.
-
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection.
-
#encode_contact_header_enabled ⇒ Boolean?
Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.
-
#encrypted_media ⇒ Symbol, ...
Enable use of SRTP for encryption.
-
#id ⇒ String?
Identifies the type of resource.
- #inbound ⇒ Telnyx::Models::CredentialInbound?
-
#ios_push_credential_id ⇒ String?
The uuid of the push credential for Ios.
-
#jitter_buffer ⇒ Telnyx::Models::ConnectionJitterBuffer?
Configuration options for Jitter Buffer.
-
#noise_suppression ⇒ Symbol, ...
Controls when noise suppression is applied to calls.
-
#noise_suppression_details ⇒ Telnyx::Models::ConnectionNoiseSuppressionDetails?
Configuration options for noise suppression.
-
#onnet_t38_passthrough_enabled ⇒ Boolean?
Enable on-net T38 if you prefer the sender and receiver negotiating T38 directly if both are on the Telnyx network.
- #outbound ⇒ Telnyx::Models::CredentialOutbound?
-
#password ⇒ String?
The password to be used as part of the credentials.
-
#record_type ⇒ String?
Identifies the type of the resource.
- #rtcp_settings ⇒ Telnyx::Models::ConnectionRtcpSettings?
-
#sip_uri_calling_preference ⇒ Symbol, ...
This feature enables inbound SIP URI calls to your Credential Auth Connection.
-
#tags ⇒ Array<String>?
Tags associated with the connection.
-
#updated_at ⇒ String?
ISO-8601 formatted date indicating when the resource was updated.
-
#user_name ⇒ String?
The user name to be used as part of the credentials.
-
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, active: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_in_webhooks: nil, connection_name: nil, created_at: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, inbound: nil, ios_push_credential_id: nil, jitter_buffer: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, password: nil, record_type: nil, rtcp_settings: nil, sip_uri_calling_preference: nil, tags: nil, updated_at: nil, user_name: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CredentialConnection for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, active: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_in_webhooks: nil, connection_name: nil, created_at: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, inbound: nil, ios_push_credential_id: nil, jitter_buffer: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, password: nil, record_type: nil, rtcp_settings: nil, sip_uri_calling_preference: nil, tags: nil, updated_at: nil, user_name: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CredentialConnection for more details.
|
|
# File 'lib/telnyx/models/credential_connection.rb', line 205
|
Instance Attribute Details
#active ⇒ Boolean?
Defaults to true
17 |
# File 'lib/telnyx/models/credential_connection.rb', line 17 optional :active, Telnyx::Internal::Type::Boolean |
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.
25 |
# File 'lib/telnyx/models/credential_connection.rb', line 25 optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride } |
#android_push_credential_id ⇒ String?
The uuid of the push credential for Android
31 |
# File 'lib/telnyx/models/credential_connection.rb', line 31 optional :android_push_credential_id, String, nil?: true |
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this connection.
37 |
# File 'lib/telnyx/models/credential_connection.rb', line 37 optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean |
#connection_name ⇒ String?
42 |
# File 'lib/telnyx/models/credential_connection.rb', line 42 optional :connection_name, String |
#created_at ⇒ String?
ISO-8601 formatted date indicating when the resource was created.
48 |
# File 'lib/telnyx/models/credential_connection.rb', line 48 optional :created_at, String |
#default_on_hold_comfort_noise_enabled ⇒ Boolean?
When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.
56 |
# File 'lib/telnyx/models/credential_connection.rb', line 56 optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean |
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.
63 |
# File 'lib/telnyx/models/credential_connection.rb', line 63 optional :dtmf_type, enum: -> { Telnyx::DtmfType } |
#encode_contact_header_enabled ⇒ Boolean?
Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.
70 |
# File 'lib/telnyx/models/credential_connection.rb', line 70 optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean |
#encrypted_media ⇒ Symbol, ...
Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.
77 |
# File 'lib/telnyx/models/credential_connection.rb', line 77 optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true |
#id ⇒ String?
Identifies the type of resource.
11 |
# File 'lib/telnyx/models/credential_connection.rb', line 11 optional :id, String |
#inbound ⇒ Telnyx::Models::CredentialInbound?
82 |
# File 'lib/telnyx/models/credential_connection.rb', line 82 optional :inbound, -> { Telnyx::CredentialInbound } |
#ios_push_credential_id ⇒ String?
The uuid of the push credential for Ios
88 |
# File 'lib/telnyx/models/credential_connection.rb', line 88 optional :ios_push_credential_id, String, nil?: true |
#jitter_buffer ⇒ Telnyx::Models::ConnectionJitterBuffer?
Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.
98 |
# File 'lib/telnyx/models/credential_connection.rb', line 98 optional :jitter_buffer, -> { Telnyx::ConnectionJitterBuffer } |
#noise_suppression ⇒ Symbol, ...
Controls when noise suppression is applied to calls. When set to ‘inbound’, noise suppression is applied to incoming audio. When set to ‘outbound’, it’s applied to outgoing audio. When set to ‘both’, it’s applied in both directions. When set to ‘disabled’, noise suppression is turned off.
107 |
# File 'lib/telnyx/models/credential_connection.rb', line 107 optional :noise_suppression, enum: -> { Telnyx::CredentialConnection::NoiseSuppression } |
#noise_suppression_details ⇒ Telnyx::Models::ConnectionNoiseSuppressionDetails?
Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not ‘disabled’. If you disable noise suppression and later re-enable it, the previously configured settings will be used.
116 |
# File 'lib/telnyx/models/credential_connection.rb', line 116 optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails } |
#onnet_t38_passthrough_enabled ⇒ Boolean?
Enable on-net T38 if you prefer the sender and receiver negotiating T38 directly if both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call depending on each leg’s settings.
124 |
# File 'lib/telnyx/models/credential_connection.rb', line 124 optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean |
#outbound ⇒ Telnyx::Models::CredentialOutbound?
129 |
# File 'lib/telnyx/models/credential_connection.rb', line 129 optional :outbound, -> { Telnyx::CredentialOutbound } |
#password ⇒ String?
The password to be used as part of the credentials. Must be 8 to 128 characters long.
136 |
# File 'lib/telnyx/models/credential_connection.rb', line 136 optional :password, String |
#record_type ⇒ String?
Identifies the type of the resource.
142 |
# File 'lib/telnyx/models/credential_connection.rb', line 142 optional :record_type, String |
#rtcp_settings ⇒ Telnyx::Models::ConnectionRtcpSettings?
147 |
# File 'lib/telnyx/models/credential_connection.rb', line 147 optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings } |
#sip_uri_calling_preference ⇒ Symbol, ...
This feature enables inbound SIP URI calls to your Credential Auth Connection. If enabled for all (unrestricted) then anyone who calls the SIP URI <your-username>@telnyx.com will be connected to your Connection. You can also choose to allow only calls that are originated on any Connections under your account (internal).
157 |
# File 'lib/telnyx/models/credential_connection.rb', line 157 optional :sip_uri_calling_preference, enum: -> { Telnyx::CredentialConnection::SipUriCallingPreference } |
#tags ⇒ Array<String>?
Tags associated with the connection.
163 |
# File 'lib/telnyx/models/credential_connection.rb', line 163 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#updated_at ⇒ String?
ISO-8601 formatted date indicating when the resource was updated.
169 |
# File 'lib/telnyx/models/credential_connection.rb', line 169 optional :updated_at, String |
#user_name ⇒ String?
The user name to be used as part of the credentials. Must be 4-32 characters long and alphanumeric values only (no spaces or special characters). At least one of the first 5 characters must be a letter.
177 |
# File 'lib/telnyx/models/credential_connection.rb', line 177 optional :user_name, String |
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
183 |
# File 'lib/telnyx/models/credential_connection.rb', line 183 optional :webhook_api_version, enum: -> { Telnyx::CredentialConnection::WebhookAPIVersion } |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.
190 |
# File 'lib/telnyx/models/credential_connection.rb', line 190 optional :webhook_event_failover_url, String, nil?: true |
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.
197 |
# File 'lib/telnyx/models/credential_connection.rb', line 197 optional :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
203 |
# File 'lib/telnyx/models/credential_connection.rb', line 203 optional :webhook_timeout_secs, Integer, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/credential_connection.rb', line 281
|