Class: Telnyx::Models::CredentialInbound
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CredentialInbound
- Defined in:
- lib/telnyx/models/credential_inbound.rb
Defined Under Namespace
Modules: AniNumberFormat, DefaultRoutingMethod, DnisNumberFormat, SimultaneousRinging
Instance Attribute Summary collapse
-
#ani_number_format ⇒ Symbol, ...
This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.
-
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
-
#codecs ⇒ Array<String>?
Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order.
-
#default_routing_method ⇒ Symbol, ...
Default routing method to be used when a number is associated with the connection.
- #dnis_number_format ⇒ Symbol, ...
-
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
-
#isup_headers_enabled ⇒ Boolean?
When set, inbound phone calls will receive ISUP parameters via SIP headers.
-
#prack_enabled ⇒ Boolean?
Enable PRACK messages as defined in RFC3262.
-
#shaken_stir_enabled ⇒ Boolean?
When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.
-
#simultaneous_ringing ⇒ Symbol, ...
When enabled, allows multiple devices to ring simultaneously on incoming calls.
-
#sip_compact_headers_enabled ⇒ Boolean?
Defaults to true.
-
#timeout_1xx_secs ⇒ Integer?
Time(sec) before aborting if connection is not made.
-
#timeout_2xx_secs ⇒ Integer?
Time(sec) before aborting if call is unanswered (min: 1, max: 600).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, simultaneous_ringing: nil, sip_compact_headers_enabled: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CredentialInbound for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, simultaneous_ringing: nil, sip_compact_headers_enabled: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::CredentialInbound for more details.
|
|
# File 'lib/telnyx/models/credential_inbound.rb', line 93
|
Instance Attribute Details
#ani_number_format ⇒ Symbol, ...
This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.
11 |
# File 'lib/telnyx/models/credential_inbound.rb', line 11 optional :ani_number_format, enum: -> { Telnyx::CredentialInbound::AniNumberFormat } |
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
18 |
# File 'lib/telnyx/models/credential_inbound.rb', line 18 optional :channel_limit, Integer |
#codecs ⇒ Array<String>?
Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order. This only works when the Connection the number is assigned to uses Media Handling mode: default. OPUS and H.264 codecs are available only when using TCP or TLS transport for SIP.
27 |
# File 'lib/telnyx/models/credential_inbound.rb', line 27 optional :codecs, Telnyx::Internal::Type::ArrayOf[String] |
#default_routing_method ⇒ Symbol, ...
Default routing method to be used when a number is associated with the connection. Must be one of the routing method types or left blank, other values are not allowed.
35 |
# File 'lib/telnyx/models/credential_inbound.rb', line 35 optional :default_routing_method, enum: -> { Telnyx::CredentialInbound::DefaultRoutingMethod } |
#dnis_number_format ⇒ Symbol, ...
40 |
# File 'lib/telnyx/models/credential_inbound.rb', line 40 optional :dnis_number_format, enum: -> { Telnyx::CredentialInbound::DnisNumberFormat } |
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
46 |
# File 'lib/telnyx/models/credential_inbound.rb', line 46 optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean |
#isup_headers_enabled ⇒ Boolean?
When set, inbound phone calls will receive ISUP parameters via SIP headers. (Only when available and only when using TCP or TLS transport.)
53 |
# File 'lib/telnyx/models/credential_inbound.rb', line 53 optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean |
#prack_enabled ⇒ Boolean?
Enable PRACK messages as defined in RFC3262.
59 |
# File 'lib/telnyx/models/credential_inbound.rb', line 59 optional :prack_enabled, Telnyx::Internal::Type::Boolean |
#shaken_stir_enabled ⇒ Boolean?
When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.
67 |
# File 'lib/telnyx/models/credential_inbound.rb', line 67 optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean |
#simultaneous_ringing ⇒ Symbol, ...
When enabled, allows multiple devices to ring simultaneously on incoming calls.
73 |
# File 'lib/telnyx/models/credential_inbound.rb', line 73 optional :simultaneous_ringing, enum: -> { Telnyx::CredentialInbound::SimultaneousRinging } |
#sip_compact_headers_enabled ⇒ Boolean?
Defaults to true.
79 |
# File 'lib/telnyx/models/credential_inbound.rb', line 79 optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean |
#timeout_1xx_secs ⇒ Integer?
Time(sec) before aborting if connection is not made.
85 |
# File 'lib/telnyx/models/credential_inbound.rb', line 85 optional :timeout_1xx_secs, Integer |
#timeout_2xx_secs ⇒ Integer?
Time(sec) before aborting if call is unanswered (min: 1, max: 600).
91 |
# File 'lib/telnyx/models/credential_inbound.rb', line 91 optional :timeout_2xx_secs, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/credential_inbound.rb', line 135
|