Class: Telnyx::Models::CustomerServiceRecord
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CustomerServiceRecord
- Defined in:
- lib/telnyx/models/customer_service_record.rb
Overview
Defined Under Namespace
Modules: Status Classes: Result
Instance Attribute Summary collapse
-
#error_message ⇒ String?
The error message in case status is ‘failed`.
-
#phone_number ⇒ String?
The phone number of the customer service record.
-
#result ⇒ Telnyx::Models::CustomerServiceRecord::Result?
The result of the CSR request.
-
#status ⇒ Symbol, ...
The status of the customer service record.
-
#webhook_url ⇒ String?
Callback URL to receive webhook notifications.
Instance Method Summary collapse
-
#initialize(account_number: nil, authorized_person_name: nil, billing_phone_number: nil, name: nil) ⇒ Object
constructor
The admin of the customer service record.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_number: nil, authorized_person_name: nil, billing_phone_number: nil, name: nil) ⇒ Object
The admin of the customer service record.
|
|
# File 'lib/telnyx/models/customer_service_record.rb', line 65
|
Instance Attribute Details
#error_message ⇒ String?
The error message in case status is ‘failed`. This field would be null in case of `pending` or `completed` status.
12 |
# File 'lib/telnyx/models/customer_service_record.rb', line 12 optional :error_message, String, nil?: true |
#phone_number ⇒ String?
The phone number of the customer service record.
18 |
# File 'lib/telnyx/models/customer_service_record.rb', line 18 optional :phone_number, String |
#result ⇒ Telnyx::Models::CustomerServiceRecord::Result?
The result of the CSR request. This field would be null in case of ‘pending` or `failed` status.
25 |
# File 'lib/telnyx/models/customer_service_record.rb', line 25 optional :result, -> { Telnyx::CustomerServiceRecord::Result }, nil?: true |
#status ⇒ Symbol, ...
The status of the customer service record
31 |
# File 'lib/telnyx/models/customer_service_record.rb', line 31 optional :status, enum: -> { Telnyx::CustomerServiceRecord::Status } |
#webhook_url ⇒ String?
Callback URL to receive webhook notifications.
37 |
# File 'lib/telnyx/models/customer_service_record.rb', line 37 optional :webhook_url, String |