Class: Telnyx::Models::CustomerServiceRecord::Result
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CustomerServiceRecord::Result
- Defined in:
- lib/telnyx/models/customer_service_record.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#address ⇒ Telnyx::Models::CustomerServiceRecord::Result::Address?
The address of the customer service record.
-
#admin ⇒ Telnyx::Models::CustomerServiceRecord::Result::Admin?
The admin of the customer service record.
-
#associated_phone_numbers ⇒ Array<String>?
The associated phone numbers of the customer service record.
-
#carrier_name ⇒ String?
The name of the carrier that the customer service record is for.
Instance Method Summary collapse
-
#initialize(administrative_area: nil, full_address: nil, locality: nil, postal_code: nil, street_address: nil) ⇒ Object
constructor
The address of the customer service record.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(administrative_area: nil, full_address: nil, locality: nil, postal_code: nil, street_address: nil) ⇒ Object
The address of the customer service record
|
|
# File 'lib/telnyx/models/customer_service_record.rb', line 113
|
Instance Attribute Details
#address ⇒ Telnyx::Models::CustomerServiceRecord::Result::Address?
The address of the customer service record
93 |
# File 'lib/telnyx/models/customer_service_record.rb', line 93 optional :address, -> { Telnyx::CustomerServiceRecord::Result::Address } |
#admin ⇒ Telnyx::Models::CustomerServiceRecord::Result::Admin?
The admin of the customer service record.
99 |
# File 'lib/telnyx/models/customer_service_record.rb', line 99 optional :admin, -> { Telnyx::CustomerServiceRecord::Result::Admin } |
#associated_phone_numbers ⇒ Array<String>?
The associated phone numbers of the customer service record.
105 |
# File 'lib/telnyx/models/customer_service_record.rb', line 105 optional :associated_phone_numbers, Telnyx::Internal::Type::ArrayOf[String] |
#carrier_name ⇒ String?
The name of the carrier that the customer service record is for.
111 |
# File 'lib/telnyx/models/customer_service_record.rb', line 111 optional :carrier_name, String |