Class: Telnyx::Models::CustomerServiceRecord::Result::Admin
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CustomerServiceRecord::Result::Admin
- Defined in:
- lib/telnyx/models/customer_service_record.rb,
sig/telnyx/models/customer_service_record.rbs
Overview
Instance Attribute Summary collapse
-
#account_number ⇒ String?
The account number of the customer service record.
-
#authorized_person_name ⇒ String?
The authorized person name of the customer service record.
-
#billing_phone_number ⇒ String?
The billing phone number of the customer service record.
-
#name ⇒ String?
The name of the customer service record.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
190 |
# File 'sig/telnyx/models/customer_service_record.rbs', line 190
def initialize: (
|
Instance Attribute Details
#account_number ⇒ String?
The account number of the customer service record.
177 |
# File 'lib/telnyx/models/customer_service_record.rb', line 177 optional :account_number, String |
#authorized_person_name ⇒ String?
The authorized person name of the customer service record.
183 |
# File 'lib/telnyx/models/customer_service_record.rb', line 183 optional :authorized_person_name, String |
#billing_phone_number ⇒ String?
The billing phone number of the customer service record.
189 |
# File 'lib/telnyx/models/customer_service_record.rb', line 189 optional :billing_phone_number, String |
#name ⇒ String?
The name of the customer service record.
195 |
# File 'lib/telnyx/models/customer_service_record.rb', line 195 optional :name, String |
Instance Method Details
#to_hash ⇒ {
197 |
# File 'sig/telnyx/models/customer_service_record.rbs', line 197
def to_hash: -> {
|