Class: Telnyx::Models::CustomerServiceRecord::Result::Admin

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/customer_service_record.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#account_numberString?

The account number of the customer service record.

Returns:

  • (String, nil)


177
# File 'lib/telnyx/models/customer_service_record.rb', line 177

optional :account_number, String

#authorized_person_nameString?

The authorized person name of the customer service record.

Returns:

  • (String, nil)


183
# File 'lib/telnyx/models/customer_service_record.rb', line 183

optional :authorized_person_name, String

#billing_phone_numberString?

The billing phone number of the customer service record.

Returns:

  • (String, nil)


189
# File 'lib/telnyx/models/customer_service_record.rb', line 189

optional :billing_phone_number, String

#nameString?

The name of the customer service record.

Returns:

  • (String, nil)


195
# File 'lib/telnyx/models/customer_service_record.rb', line 195

optional :name, String