Class: Telnyx::Models::CustomerServiceRecordCreateParams::AdditionalData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::CustomerServiceRecordCreateParams::AdditionalData
- Defined in:
- lib/telnyx/models/customer_service_record_create_params.rb
Instance Attribute Summary collapse
-
#account_number ⇒ String?
The account number of the customer service record.
-
#address_line_1 ⇒ String?
The first line of the address of the customer service record.
-
#authorized_person_name ⇒ String?
The name of the authorized person.
-
#billing_phone_number ⇒ String?
The billing phone number of the customer service record.
-
#city ⇒ String?
The city of the customer service record.
-
#customer_code ⇒ String?
The customer code of the customer service record.
-
#name ⇒ String?
The name of the administrator of CSR.
-
#pin ⇒ String?
The PIN of the customer service record.
-
#state ⇒ String?
The state of the customer service record.
-
#zip_code ⇒ String?
The zip code of the customer service record.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_number: nil, address_line_1: nil, authorized_person_name: nil, billing_phone_number: nil, city: nil, customer_code: nil, name: nil, pin: nil, state: nil, zip_code: nil) ⇒ Object
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 36 class AdditionalData < Telnyx::Internal::Type::BaseModel # @!attribute account_number # The account number of the customer service record. # # @return [String, nil] optional :account_number, String # @!attribute address_line_1 # The first line of the address of the customer service record. # # @return [String, nil] optional :address_line_1, String # @!attribute authorized_person_name # The name of the authorized person. # # @return [String, nil] optional :authorized_person_name, String # @!attribute billing_phone_number # The billing phone number of the customer service record. # # @return [String, nil] optional :billing_phone_number, String # @!attribute city # The city of the customer service record. # # @return [String, nil] optional :city, String # @!attribute customer_code # The customer code of the customer service record. # # @return [String, nil] optional :customer_code, String # @!attribute name # The name of the administrator of CSR. # # @return [String, nil] optional :name, String # @!attribute pin # The PIN of the customer service record. # # @return [String, nil] optional :pin, String # @!attribute state # The state of the customer service record. # # @return [String, nil] optional :state, String # @!attribute zip_code # The zip code of the customer service record. # # @return [String, nil] optional :zip_code, String # @!method initialize(account_number: nil, address_line_1: nil, authorized_person_name: nil, billing_phone_number: nil, city: nil, customer_code: nil, name: nil, pin: nil, state: nil, zip_code: nil) # @param account_number [String] The account number of the customer service record. # # @param address_line_1 [String] The first line of the address of the customer service record. # # @param authorized_person_name [String] The name of the authorized person. # # @param billing_phone_number [String] The billing phone number of the customer service record. # # @param city [String] The city of the customer service record. # # @param customer_code [String] The customer code of the customer service record. # # @param name [String] The name of the administrator of CSR. # # @param pin [String] The PIN of the customer service record. # # @param state [String] The state of the customer service record. # # @param zip_code [String] The zip code of the customer service record. end |
Instance Attribute Details
#account_number ⇒ String?
The account number of the customer service record.
41 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 41 optional :account_number, String |
#address_line_1 ⇒ String?
The first line of the address of the customer service record.
47 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 47 optional :address_line_1, String |
#authorized_person_name ⇒ String?
The name of the authorized person.
53 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 53 optional :authorized_person_name, String |
#billing_phone_number ⇒ String?
The billing phone number of the customer service record.
59 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 59 optional :billing_phone_number, String |
#city ⇒ String?
The city of the customer service record.
65 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 65 optional :city, String |
#customer_code ⇒ String?
The customer code of the customer service record.
71 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 71 optional :customer_code, String |
#name ⇒ String?
The name of the administrator of CSR.
77 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 77 optional :name, String |
#pin ⇒ String?
The PIN of the customer service record.
83 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 83 optional :pin, String |
#state ⇒ String?
The state of the customer service record.
89 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 89 optional :state, String |
#zip_code ⇒ String?
The zip code of the customer service record.
95 |
# File 'lib/telnyx/models/customer_service_record_create_params.rb', line 95 optional :zip_code, String |