Class: Telnyx::Models::DetailRecordListResponse::MessageDetailRecord
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DetailRecordListResponse::MessageDetailRecord
- Defined in:
- lib/telnyx/models/detail_record_list_response.rb
Defined Under Namespace
Modules: Direction, MessageType, Status
Instance Attribute Summary collapse
-
#carrier ⇒ String?
Country-specific carrier used to send or receive the message.
-
#carrier_fee ⇒ String?
Fee charged by certain carriers in order to deliver certain message types.
-
#cld ⇒ String?
The recipient of the message (to parameter in the Messaging API).
-
#cli ⇒ String?
The sender of the message (from parameter in the Messaging API).
-
#completed_at ⇒ Time?
Message completion time.
-
#cost ⇒ String?
Amount, in the user currency, for the Telnyx billing cost.
-
#country_code ⇒ String?
Two-letter representation of the country of the cld property using the ISO 3166-1 alpha-2 format.
-
#created_at ⇒ Time?
Message creation time.
-
#currency ⇒ String?
Telnyx account currency used to describe monetary values, including billing cost.
-
#delivery_status ⇒ String?
Final webhook delivery status.
-
#delivery_status_failover_url ⇒ String?
Failover customer-provided URL which Telnyx posts delivery status webhooks to.
-
#delivery_status_webhook_url ⇒ String?
Primary customer-provided URL which Telnyx posts delivery status webhooks to.
-
#direction ⇒ Symbol, ...
Logical direction of the message from the Telnyx customer’s perspective.
-
#errors ⇒ Array<String>?
Telnyx API error codes returned by the Telnyx gateway.
-
#fteu ⇒ Boolean?
Indicates whether this is a Free-To-End-User (FTEU) short code message.
-
#mcc ⇒ String?
Mobile country code.
-
#message_type ⇒ Symbol, ...
Describes the Messaging service used to send the message.
-
#mnc ⇒ String?
Mobile network code.
-
#on_net ⇒ Boolean?
Indicates whether both sender and recipient numbers are Telnyx-managed.
-
#parts ⇒ Integer?
Number of message parts.
-
#profile_id ⇒ String?
Unique identifier of the Messaging Profile used to send or receive the message.
-
#profile_name ⇒ String?
Name of the Messaging Profile used to send or receive the message.
-
#rate ⇒ String?
Currency amount per billing unit used to calculate the Telnyx billing cost.
-
#record_type ⇒ String
Identifies the record schema.
-
#sent_at ⇒ Time?
Time when the message was sent.
-
#source_country_code ⇒ String?
Two-letter representation of the country of the cli property using the ISO 3166-1 alpha-2 format.
-
#status ⇒ Symbol, ...
Final status of the message after the delivery attempt.
-
#tags ⇒ String?
Comma-separated tags assigned to the Telnyx number associated with the message.
-
#updated_at ⇒ Time?
Message updated time.
-
#user_id ⇒ String?
Identifier of the Telnyx account who owns the message.
-
#uuid ⇒ String?
Unique identifier of the message.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(record_type:, carrier: nil, carrier_fee: nil, cld: nil, cli: nil, completed_at: nil, cost: nil, country_code: nil, created_at: nil, currency: nil, delivery_status: nil, delivery_status_failover_url: nil, delivery_status_webhook_url: nil, direction: nil, errors: nil, fteu: nil, mcc: nil, message_type: nil, mnc: nil, on_net: nil, parts: nil, profile_id: nil, profile_name: nil, rate: nil, sent_at: nil, source_country_code: nil, status: nil, tags: nil, updated_at: nil, user_id: nil, uuid: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessageDetailRecord for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(record_type:, carrier: nil, carrier_fee: nil, cld: nil, cli: nil, completed_at: nil, cost: nil, country_code: nil, created_at: nil, currency: nil, delivery_status: nil, delivery_status_failover_url: nil, delivery_status_webhook_url: nil, direction: nil, errors: nil, fteu: nil, mcc: nil, message_type: nil, mnc: nil, on_net: nil, parts: nil, profile_id: nil, profile_name: nil, rate: nil, sent_at: nil, source_country_code: nil, status: nil, tags: nil, updated_at: nil, user_id: nil, uuid: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::DetailRecordListResponse::MessageDetailRecord for more details.
|
|
# File 'lib/telnyx/models/detail_record_list_response.rb', line 226
|
Instance Attribute Details
#carrier ⇒ String?
Country-specific carrier used to send or receive the message
39 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 39 optional :carrier, String |
#carrier_fee ⇒ String?
Fee charged by certain carriers in order to deliver certain message types. Telnyx passes this fee on to the customer according to our pricing table
46 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 46 optional :carrier_fee, String |
#cld ⇒ String?
The recipient of the message (to parameter in the Messaging API)
52 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 52 optional :cld, String |
#cli ⇒ String?
The sender of the message (from parameter in the Messaging API). For Alphanumeric ID messages, this is the sender ID value
59 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 59 optional :cli, String |
#completed_at ⇒ Time?
Message completion time
65 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 65 optional :completed_at, Time |
#cost ⇒ String?
Amount, in the user currency, for the Telnyx billing cost
71 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 71 optional :cost, String |
#country_code ⇒ String?
Two-letter representation of the country of the cld property using the ISO 3166-1 alpha-2 format
78 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 78 optional :country_code, String |
#created_at ⇒ Time?
Message creation time
84 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 84 optional :created_at, Time |
#currency ⇒ String?
Telnyx account currency used to describe monetary values, including billing cost
90 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 90 optional :currency, String |
#delivery_status ⇒ String?
Final webhook delivery status
96 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 96 optional :delivery_status, String |
#delivery_status_failover_url ⇒ String?
Failover customer-provided URL which Telnyx posts delivery status webhooks to
102 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 102 optional :delivery_status_failover_url, String |
#delivery_status_webhook_url ⇒ String?
Primary customer-provided URL which Telnyx posts delivery status webhooks to
108 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 108 optional :delivery_status_webhook_url, String |
#direction ⇒ Symbol, ...
Logical direction of the message from the Telnyx customer’s perspective. It’s inbound when the Telnyx customer receives the message, or outbound otherwise
115 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 115 optional :direction, enum: -> { Telnyx::Models::DetailRecordListResponse::MessageDetailRecord::Direction } |
#errors ⇒ Array<String>?
Telnyx API error codes returned by the Telnyx gateway
121 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 121 optional :errors, Telnyx::Internal::Type::ArrayOf[String] |
#fteu ⇒ Boolean?
Indicates whether this is a Free-To-End-User (FTEU) short code message
127 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 127 optional :fteu, Telnyx::Internal::Type::Boolean |
#mcc ⇒ String?
Mobile country code. Only available for certain products, such as Global Outbound-Only from Alphanumeric Sender ID
134 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 134 optional :mcc, String |
#message_type ⇒ Symbol, ...
Describes the Messaging service used to send the message. Available services are: Short Message Service (SMS), Multimedia Messaging Service (MMS), and Rich Communication Services (RCS)
142 143 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 142 optional :message_type, enum: -> { Telnyx::Models::DetailRecordListResponse::MessageDetailRecord::MessageType } |
#mnc ⇒ String?
Mobile network code. Only available for certain products, such as Global Outbound-Only from Alphanumeric Sender ID
150 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 150 optional :mnc, String |
#on_net ⇒ Boolean?
Indicates whether both sender and recipient numbers are Telnyx-managed
156 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 156 optional :on_net, Telnyx::Internal::Type::Boolean |
#parts ⇒ Integer?
Number of message parts. The message is broken down in multiple parts when its length surpasses the limit of 160 characters
163 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 163 optional :parts, Integer |
#profile_id ⇒ String?
Unique identifier of the Messaging Profile used to send or receive the message
169 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 169 optional :profile_id, String |
#profile_name ⇒ String?
Name of the Messaging Profile used to send or receive the message
175 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 175 optional :profile_name, String |
#rate ⇒ String?
Currency amount per billing unit used to calculate the Telnyx billing cost
181 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 181 optional :rate, String |
#record_type ⇒ String
Identifies the record schema
33 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 33 required :record_type, String |
#sent_at ⇒ Time?
Time when the message was sent
187 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 187 optional :sent_at, Time |
#source_country_code ⇒ String?
Two-letter representation of the country of the cli property using the ISO 3166-1 alpha-2 format
194 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 194 optional :source_country_code, String |
#status ⇒ Symbol, ...
Final status of the message after the delivery attempt
200 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 200 optional :status, enum: -> { Telnyx::Models::DetailRecordListResponse::MessageDetailRecord::Status } |
#tags ⇒ String?
Comma-separated tags assigned to the Telnyx number associated with the message
206 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 206 optional :tags, String |
#updated_at ⇒ Time?
Message updated time
212 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 212 optional :updated_at, Time |
#user_id ⇒ String?
Identifier of the Telnyx account who owns the message
218 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 218 optional :user_id, String |
#uuid ⇒ String?
Unique identifier of the message
224 |
# File 'lib/telnyx/models/detail_record_list_response.rb', line 224 optional :uuid, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/detail_record_list_response.rb', line 303
|