Class: Telnyx::Models::DialogflowConnectionUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DialogflowConnectionUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/dialogflow_connection_update_params.rb
Overview
Defined Under Namespace
Modules: DialogflowAPI
Instance Attribute Summary collapse
- #connection_id ⇒ String
-
#conversation_profile_id ⇒ String?
The id of a configured conversation profile on your Dialogflow account.
-
#dialogflow_api ⇒ Symbol, ...
Determine which Dialogflow will be used.
-
#environment ⇒ String?
Which Dialogflow environment will be used.
-
#location ⇒ String?
The region of your agent is.
-
#service_account ⇒ Hash{Symbol=>Object}
The JSON map to connect your Dialoglow account.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(connection_id:, service_account:, conversation_profile_id: nil, dialogflow_api: nil, environment: nil, location: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DialogflowConnectionUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_id:, service_account:, conversation_profile_id: nil, dialogflow_api: nil, environment: nil, location: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::DialogflowConnectionUpdateParams for more details.
|
|
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 46
|
Instance Attribute Details
#connection_id ⇒ String
13 |
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 13 required :connection_id, String |
#conversation_profile_id ⇒ String?
The id of a configured conversation profile on your Dialogflow account. (If you use Dialogflow CX, this param is required)
26 |
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 26 optional :conversation_profile_id, String |
#dialogflow_api ⇒ Symbol, ...
Determine which Dialogflow will be used.
32 |
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 32 optional :dialogflow_api, enum: -> { Telnyx::DialogflowConnectionUpdateParams::DialogflowAPI } |
#environment ⇒ String?
Which Dialogflow environment will be used.
38 |
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 38 optional :environment, String |
#location ⇒ String?
The region of your agent is. (If you use Dialogflow CX, this param is required)
44 |
# File 'lib/telnyx/models/dialogflow_connection_update_params.rb', line 44 optional :location, String |