Class: Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document
- Defined in:
- lib/telnyx/models/dir/phone_number_batch_list_response.rb
Defined Under Namespace
Modules: DocumentType
Instance Attribute Summary collapse
- #description ⇒ String?
-
#document_id ⇒ String
Id returned by the Telnyx Documents API after you upload the file (upload via ‘POST /v2/documents`; see developers.telnyx.com/api/documents).
-
#document_type ⇒ Symbol, Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document::DocumentType
Type of supporting document.
Instance Method Summary collapse
-
#initialize(document_id:, document_type:, description: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Document for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(document_id:, document_type:, description: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document for more details.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 93 class Document < Telnyx::Internal::Type::BaseModel # @!attribute document_id # Id returned by the Telnyx Documents API after you upload the file (upload via # `POST /v2/documents`; see https://developers.telnyx.com/api/documents). # # @return [String] required :document_id, String # @!attribute document_type # Type of supporting document. Pick the closest match to what the file actually # contains; `other` triggers manual vetting and may slow approval. The matching # short_name reference list is at `GET /v2/dir/document_types`. # # @return [Symbol, Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document::DocumentType] required :document_type, enum: -> { Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document::DocumentType } # @!attribute description # # @return [String, nil] optional :description, String # @!method initialize(document_id:, document_type:, description: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document} for more details. # # @param document_id [String] Id returned by the Telnyx Documents API after you upload the file (upload via `P # # @param document_type [Symbol, Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document::DocumentType] Type of supporting document. Pick the closest match to what the file actually co # # @param description [String] # Type of supporting document. Pick the closest match to what the file actually # contains; `other` triggers manual vetting and may slow approval. The matching # short_name reference list is at `GET /v2/dir/document_types`. # # @see Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document#document_type module DocumentType extend Telnyx::Internal::Type::Enum LETTER_OF_AUTHORIZATION = :letter_of_authorization BUSINESS_REGISTRATION = :business_registration ARTICLES_OF_INCORPORATION = :articles_of_incorporation TAX_DOCUMENT = :tax_document EIN_LETTER = :ein_letter TRADEMARK_REGISTRATION = :trademark_registration WEBSITE_OWNERSHIP = :website_ownership BUSINESS_LICENSE = :business_license PROFESSIONAL_LICENSE = :professional_license GOVERNMENT_ID = :government_id UTILITY_BILL = :utility_bill BANK_STATEMENT = :bank_statement OTHER = :other # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#description ⇒ String?
113 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 113 optional :description, String |
#document_id ⇒ String
Id returned by the Telnyx Documents API after you upload the file (upload via ‘POST /v2/documents`; see developers.telnyx.com/api/documents).
99 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 99 required :document_id, String |
#document_type ⇒ Symbol, Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document::DocumentType
Type of supporting document. Pick the closest match to what the file actually contains; ‘other` triggers manual vetting and may slow approval. The matching short_name reference list is at `GET /v2/dir/document_types`.
107 108 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 107 required :document_type, enum: -> { Telnyx::Models::Dir::PhoneNumberBatchListResponse::Document::DocumentType } |