Class: Telnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber
- Defined in:
- lib/telnyx/models/dir/phone_number_batch_list_response.rb
Defined Under Namespace
Modules: Status Classes: RejectionReason
Instance Attribute Summary collapse
-
#batch_id ⇒ String?
Id of the batch this number was vetted as part of.
- #dir_id ⇒ String?
- #enterprise_id ⇒ String?
-
#loa_document_id ⇒ String?
Id of the Letter of Authorization document attached to this number’s batch.
-
#phone_number ⇒ String?
E.164 with leading ‘+`.
-
#rejection_reason ⇒ Telnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber::RejectionReason?
Populated when ‘status` is `unsuccessful` or `permanently_rejected`.
-
#status ⇒ Symbol, ...
Phone-number lifecycle status.
Instance Method Summary collapse
-
#initialize(code: nil, detail: nil, message: nil, title: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RejectionReason for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code: nil, detail: nil, message: nil, title: nil) ⇒ Object
Some parameter documentations has been truncated, see RejectionReason for more details.
Populated when ‘status` is `unsuccessful` or `permanently_rejected`.
|
|
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 229
|
Instance Attribute Details
#batch_id ⇒ String?
Id of the batch this number was vetted as part of.
157 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 157 optional :batch_id, String, nil?: true |
#dir_id ⇒ String?
162 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 162 optional :dir_id, String |
#enterprise_id ⇒ String?
167 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 167 optional :enterprise_id, String |
#loa_document_id ⇒ String?
Id of the Letter of Authorization document attached to this number’s batch.
173 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 173 optional :loa_document_id, String, nil?: true |
#phone_number ⇒ String?
E.164 with leading ‘+`.
179 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 179 optional :phone_number, String |
#rejection_reason ⇒ Telnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber::RejectionReason?
Populated when ‘status` is `unsuccessful` or `permanently_rejected`.
185 186 187 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 185 optional :rejection_reason, -> { Telnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber::RejectionReason }, nil?: true |
#status ⇒ Symbol, ...
Phone-number lifecycle status.
-
‘submitted` / `in_review` - Telnyx is reviewing the batch this number belongs to.
-
‘verified` - approved; the DIR’s display identity will be shown on outbound calls from this number.
-
‘unsuccessful` - Telnyx rejected this submission; the customer may re-add to retry.
-
‘suspended` - temporarily disabled (e.g. by an active infringement claim on the DIR).
-
‘expired` - verification expired; re-add to renew.
-
‘permanently_rejected` - terminal; cannot be re-added on this or any other DIR you own.
205 |
# File 'lib/telnyx/models/dir/phone_number_batch_list_response.rb', line 205 optional :status, enum: -> { Telnyx::Models::Dir::PhoneNumberBatchListResponse::PhoneNumber::Status } |