Class: Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse
- Defined in:
- lib/telnyx/models/dir/phone_number_batch_retrieve_response.rb
Overview
Defined Under Namespace
Classes: Data
Instance Attribute Summary collapse
-
#data ⇒ Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data
A phone-number batch groups all numbers added in a single bulk-add request.
Instance Method Summary collapse
-
#initialize(data:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberBatchRetrieveResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse for more details.
|
|
# File 'lib/telnyx/models/dir/phone_number_batch_retrieve_response.rb', line 17
|
Instance Attribute Details
#data ⇒ Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data
A phone-number batch groups all numbers added in a single bulk-add request. Telnyx vets the batch as a unit. The response embeds the full ‘phone_numbers` array so you can read per-number status without a separate call, plus a batch-level `status` summarising the unit’s progress.
15 |
# File 'lib/telnyx/models/dir/phone_number_batch_retrieve_response.rb', line 15 required :data, -> { Telnyx::Models::Dir::PhoneNumberBatchRetrieveResponse::Data } |