Class: Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error
- Defined in:
- lib/telnyx/models/dir/phone_number_remove_response.rb
Defined Under Namespace
Modules: Code
Instance Attribute Summary collapse
-
#code ⇒ Symbol, Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error::Code
Stable per-number error code.
- #detail ⇒ String
- #phone_number ⇒ String
- #title ⇒ String
Instance Method Summary collapse
-
#initialize(code:, detail:, phone_number:, title:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Error for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, detail:, phone_number:, title:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error for more details.
Per-number error returned by the bulk-delete endpoint. Bulk-add does not use this shape - it returns a 400 with the canonical envelope grouping numbers by failure category.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/telnyx/models/dir/phone_number_remove_response.rb', line 46 class Error < Telnyx::Internal::Type::BaseModel # @!attribute code # Stable per-number error code. Currently only `not_associated` is emitted, when # the number is not attached to this DIR. # # @return [Symbol, Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error::Code] required :code, enum: -> { Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error::Code } # @!attribute detail # # @return [String] required :detail, String # @!attribute phone_number # # @return [String] required :phone_number, String # @!attribute title # # @return [String] required :title, String # @!method initialize(code:, detail:, phone_number:, title:) # Some parameter documentations has been truncated, see # {Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error} for more details. # # Per-number error returned by the bulk-delete endpoint. Bulk-add does not use # this shape - it returns a 400 with the canonical envelope grouping numbers by # failure category. # # @param code [Symbol, Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error::Code] Stable per-number error code. Currently only `not_associated` is emitted, when t # # @param detail [String] # # @param phone_number [String] # # @param title [String] # Stable per-number error code. Currently only `not_associated` is emitted, when # the number is not attached to this DIR. # # @see Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error#code module Code extend Telnyx::Internal::Type::Enum NOT_ASSOCIATED = :not_associated # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#code ⇒ Symbol, Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error::Code
Stable per-number error code. Currently only ‘not_associated` is emitted, when the number is not attached to this DIR.
52 |
# File 'lib/telnyx/models/dir/phone_number_remove_response.rb', line 52 required :code, enum: -> { Telnyx::Models::Dir::PhoneNumberRemoveResponse::Meta::Error::Code } |
#detail ⇒ String
57 |
# File 'lib/telnyx/models/dir/phone_number_remove_response.rb', line 57 required :detail, String |
#phone_number ⇒ String
62 |
# File 'lib/telnyx/models/dir/phone_number_remove_response.rb', line 62 required :phone_number, String |
#title ⇒ String
67 |
# File 'lib/telnyx/models/dir/phone_number_remove_response.rb', line 67 required :title, String |