Class: Telnyx::Models::Dir::Reference

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/dir/reference.rb,
sig/telnyx/models/dir/reference.rbs

Defined Under Namespace

Modules: RecordType, RefType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(full_name:, phone_e164:, record_type:, ref_type:, slot:, timezone:, email: nil, job_title: nil, organization: nil, relationship_to_registrant: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Dir::Reference for more details.

A reference (business or financial) on a DIR, in the customer-facing shape. No internal identifiers are exposed.

Parameters:

  • full_name (String)

    Full name of the reference contact.

  • phone_e164 (String)

    Reference phone number in E.164 format.

  • record_type (Symbol, Telnyx::Models::Dir::Reference::RecordType)

    Always dir_reference.

  • ref_type (Symbol, Telnyx::Models::Dir::Reference::RefType)

    Whether this is a business reference or the financial reference.

  • slot (Integer)

    Position within the reference type. Business references occupy slots 0 and 1; th

  • timezone (String)

    IANA timezone id for the reference. Calls are only placed within the reference's

  • email (String, nil) (defaults to: nil)

    Reference contact email address.

  • job_title (String, nil) (defaults to: nil)

    Job title of the reference contact.

  • organization (String, nil) (defaults to: nil)

    Organization the reference contact belongs to.

  • relationship_to_registrant (String, nil) (defaults to: nil)

    How the reference contact is related to the registering business.



# File 'lib/telnyx/models/dir/reference.rb', line 71

Instance Attribute Details

#emailString?

Reference contact email address.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/dir/reference.rb', line 43

optional :email, String, nil?: true

#full_nameString

Full name of the reference contact.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/telnyx/models/dir/reference.rb', line 11

required :full_name, String

#job_titleString?

Job title of the reference contact.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/dir/reference.rb', line 49

optional :job_title, String, nil?: true

#organizationString?

Organization the reference contact belongs to.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


55
# File 'lib/telnyx/models/dir/reference.rb', line 55

optional :organization, String, nil?: true

#phone_e164String

Reference phone number in E.164 format.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/telnyx/models/dir/reference.rb', line 17

required :phone_e164, String

#record_typeTelnyx::Models::Dir::Reference::record_type

Returns the value of attribute record_type.

Returns:

  • (Telnyx::Models::Dir::Reference::record_type)


37
38
39
# File 'sig/telnyx/models/dir/reference.rbs', line 37

def record_type
  @record_type
end

#ref_typeSymbol, Telnyx::Models::Dir::Reference::RefType

Whether this is a business reference or the financial reference.

Parameters:

  • value (Telnyx::Models::Dir::Reference::ref_type)

Returns:



23
# File 'lib/telnyx/models/dir/reference.rb', line 23

required :ref_type, enum: -> { Telnyx::Dir::Reference::RefType }

#relationship_to_registrantString?

How the reference contact is related to the registering business.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/dir/reference.rb', line 61

optional :relationship_to_registrant, String, nil?: true

#slotInteger

Position within the reference type. Business references occupy slots 0 and 1; the financial reference occupies slot 0.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


30
# File 'lib/telnyx/models/dir/reference.rb', line 30

required :slot, Integer

#timezoneString

IANA timezone id for the reference. Calls are only placed within the reference's local 8am-9pm window.

Parameters:

  • value (String)

Returns:

  • (String)


37
# File 'lib/telnyx/models/dir/reference.rb', line 37

required :timezone, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/dir/reference.rb', line 106

Instance Method Details

#to_hash{

Returns:

  • ({)


52
# File 'sig/telnyx/models/dir/reference.rbs', line 52

def to_hash: -> {