Class: Telnyx::Models::DirCreateLoaParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DirCreateLoaParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/dir_create_loa_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#agent ⇒ Telnyx::Models::DirCreateLoaParams::Agent?
Third-party reseller / partner managing the enterprise’s phone numbers.
- #dir_id ⇒ String
-
#phone_numbers ⇒ Array<String>
Telephone numbers to authorize on the DIR, in ‘+E164` format (`+` followed by 10-15 digits).
-
#signature ⇒ Telnyx::Models::DirCreateLoaParams::Signature?
Optional.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(administrative_area:, city:, contact_email:, contact_name:, contact_phone:, contact_title:, country:, legal_name:, postal_code:, street_address:, dba: nil, extended_address: nil) ⇒ Object
constructor
Third-party reseller / partner managing the enterprise’s phone numbers.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(administrative_area:, city:, contact_email:, contact_name:, contact_phone:, contact_title:, country:, legal_name:, postal_code:, street_address:, dba: nil, extended_address: nil) ⇒ Object
Third-party reseller / partner managing the enterprise’s phone numbers. Omit when the enterprise works directly with Telnyx.
|
|
# File 'lib/telnyx/models/dir_create_loa_params.rb', line 112
|
Instance Attribute Details
#agent ⇒ Telnyx::Models::DirCreateLoaParams::Agent?
Third-party reseller / partner managing the enterprise’s phone numbers. Omit when the enterprise works directly with Telnyx.
27 |
# File 'lib/telnyx/models/dir_create_loa_params.rb', line 27 optional :agent, -> { Telnyx::DirCreateLoaParams::Agent } |
#dir_id ⇒ String
13 |
# File 'lib/telnyx/models/dir_create_loa_params.rb', line 13 required :dir_id, String |
#phone_numbers ⇒ Array<String>
Telephone numbers to authorize on the DIR, in ‘+E164` format (`+` followed by 10-15 digits). Max 15 per request.
20 |
# File 'lib/telnyx/models/dir_create_loa_params.rb', line 20 required :phone_numbers, Telnyx::Internal::Type::ArrayOf[String] |
#signature ⇒ Telnyx::Models::DirCreateLoaParams::Signature?
Optional. When provided the rendered PDF embeds the signature image, printed name, and signed-at date. When absent the PDF is returned unsigned so the customer can sign externally and upload it via the Documents API.
35 |
# File 'lib/telnyx/models/dir_create_loa_params.rb', line 35 optional :signature, -> { Telnyx::DirCreateLoaParams::Signature } |