Class: Telnyx::Models::DirListDocumentTypesResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DirListDocumentTypesResponse
- Defined in:
- lib/telnyx/models/dir_list_document_types_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
- #data ⇒ Array<Telnyx::Models::DirListDocumentTypesResponse::Data>
-
#meta ⇒ Telnyx::Models::DirListDocumentTypesResponse::Meta
JSON:API pagination metadata returned with every paginated list response.
Instance Method Summary collapse
-
#initialize(description: nil, short_name: nil) ⇒ Object
constructor
Single supported document type.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description: nil, short_name: nil) ⇒ Object
Single supported document type.
|
|
# File 'lib/telnyx/models/dir_list_document_types_response.rb', line 41
|
Instance Attribute Details
#data ⇒ Array<Telnyx::Models::DirListDocumentTypesResponse::Data>
10 |
# File 'lib/telnyx/models/dir_list_document_types_response.rb', line 10 required :data, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::DirListDocumentTypesResponse::Data] } |
#meta ⇒ Telnyx::Models::DirListDocumentTypesResponse::Meta
JSON:API pagination metadata returned with every paginated list response. Page numbering is 1-based. ‘page_size` reports the number of items actually returned in `data` for this page; the requested size is taken from the `page` query parameter.
19 |
# File 'lib/telnyx/models/dir_list_document_types_response.rb', line 19 required :meta, -> { Telnyx::Models::DirListDocumentTypesResponse::Meta } |