Class: Telnyx::Models::DocReqsRequirement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/doc_reqs_requirement.rb,
sig/telnyx/models/doc_reqs_requirement.rbs

Overview

See Also:

  • Telnyx::Resources::Requirements#list

Defined Under Namespace

Modules: Action, PhoneNumberType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, action: nil, country_code: nil, created_at: nil, locality: nil, phone_number_type: nil, record_type: nil, requirements_types: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::DocReqsRequirement for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the associated document

  • action (Symbol, Telnyx::Models::DocReqsRequirement::Action) (defaults to: nil)

    Indicates whether this requirement applies to branded_calling, ordering, porting

  • country_code (String) (defaults to: nil)

    The 2-character (ISO 3166-1 alpha-2) country code where this requirement applies

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • locality (String) (defaults to: nil)

    The locality where this requirement applies

  • phone_number_type (Symbol, Telnyx::Models::DocReqsRequirement::PhoneNumberType) (defaults to: nil)

    Indicates the phone_number_type this requirement applies to. Leave blank if this

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • requirements_types (Array<Telnyx::Models::DocReqsRequirementType>) (defaults to: nil)

    Lists the requirement types necessary to fulfill this requirement

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was last updated.



# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 65

Instance Attribute Details

#actionSymbol, ...

Indicates whether this requirement applies to branded_calling, ordering, porting, or both ordering and porting



12
# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 12

optional :action, enum: -> { Telnyx::DocReqsRequirement::Action }

#country_codeString?

The 2-character (ISO 3166-1 alpha-2) country code where this requirement applies

Parameters:

  • (String)

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 18

optional :country_code, String

#created_atString? (readonly)

Returns the value of attribute created_at.

Returns:

  • (String, nil)


41
42
43
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 41

def created_at
  @created_at
end

#idString? (readonly)

Returns the value of attribute id.

Returns:

  • (String, nil)


37
38
39
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 37

def id
  @id
end

#localityString?

The locality where this requirement applies

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 24

optional :locality, String

#phone_number_typeSymbol, ...

Indicates the phone_number_type this requirement applies to. Leave blank if this requirement applies to all number_types.



31
# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 31

optional :phone_number_type, enum: -> { Telnyx::DocReqsRequirement::PhoneNumberType }

#record_typeString? (readonly)

Returns the value of attribute record_type.

Returns:

  • (String, nil)


45
46
47
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 45

def record_type
  @record_type
end

#requirements_types::Array[Telnyx::DocReqsRequirementType]? (readonly)

Returns the value of attribute requirements_types.

Returns:



49
50
51
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 49

def requirements_types
  @requirements_types
end

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


55
56
57
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 55

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/doc_reqs_requirement.rb', line 99

Instance Method Details

#created_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


43
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 43

def created_at=: (String) -> String

#id=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


39
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 39

def id=: (String) -> String

#record_type=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


47
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 47

def record_type=: (String) -> String

#requirements_types=Object (readonly)



51
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 51

def requirements_types=: (

#to_hash{

Returns:

  • ({)


71
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 71

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


57
# File 'sig/telnyx/models/doc_reqs_requirement.rbs', line 57

def updated_at=: (String) -> String