Class: Telnyx::Models::DynamicEmergencyAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/dynamic_emergency_address.rb

Overview

Direct Known Subclasses

DynamicEmergencyAddressCreateParams

Defined Under Namespace

Modules: CountryCode, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(administrative_area:, country_code:, house_number:, locality:, postal_code:, street_name:, id: nil, created_at: nil, extended_address: nil, house_suffix: nil, record_type: nil, sip_geolocation_id: nil, status: nil, street_post_directional: nil, street_pre_directional: nil, street_suffix: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::DynamicEmergencyAddress for more details.

Parameters:

  • administrative_area (String)
  • country_code (Symbol, Telnyx::Models::DynamicEmergencyAddress::CountryCode)
  • house_number (String)
  • locality (String)
  • postal_code (String)
  • street_name (String)
  • id (String) (defaults to: nil)
  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the resource was created

  • extended_address (String) (defaults to: nil)
  • house_suffix (String) (defaults to: nil)
  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • sip_geolocation_id (String) (defaults to: nil)

    Unique location reference string to be used in SIP INVITE from / p-asserted head

  • status (Symbol, Telnyx::Models::DynamicEmergencyAddress::Status) (defaults to: nil)

    Status of dynamic emergency address

  • street_post_directional (String) (defaults to: nil)
  • street_pre_directional (String) (defaults to: nil)
  • street_suffix (String) (defaults to: nil)
  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date of when the resource was last updated



# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 100

Instance Attribute Details

#administrative_areaString

Returns:

  • (String)


10
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 10

required :administrative_area, String

#country_codeSymbol, Telnyx::Models::DynamicEmergencyAddress::CountryCode



15
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 15

required :country_code, enum: -> { Telnyx::DynamicEmergencyAddress::CountryCode }

#extended_addressString?

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 40

optional :extended_address, String

#house_numberString

Returns:

  • (String)


20
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 20

required :house_number, String

#house_suffixString?

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 45

optional :house_suffix, String

#localityString

Returns:

  • (String)


25
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 25

required :locality, String

#postal_codeString

Returns:

  • (String)


30
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 30

required :postal_code, String

#street_nameString

Returns:

  • (String)


35
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 35

required :street_name, String

#street_post_directionalString?

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 50

optional :street_post_directional, String

#street_pre_directionalString?

Returns:

  • (String, nil)


55
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 55

optional :street_pre_directional, String

#street_suffixString?

Returns:

  • (String, nil)


60
# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 60

optional :street_suffix, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/dynamic_emergency_address.rb', line 146