Class: Telnyx::Models::DynamicEmergencyEndpoint
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::DynamicEmergencyEndpoint
- Defined in:
- lib/telnyx/models/dynamic_emergency_endpoint.rb,
sig/telnyx/models/dynamic_emergency_endpoint.rbs
Overview
Direct Known Subclasses
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
- #callback_number ⇒ String
- #caller_name ⇒ String
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#dynamic_emergency_address_id ⇒ String
An id of a currently active dynamic emergency location.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#sip_from_id ⇒ String?
readonly
Returns the value of attribute sip_from_id.
-
#status ⇒ Telnyx::Models::DynamicEmergencyEndpoint::status?
readonly
Returns the value of attribute status.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Instance Method Summary collapse
- #created_at ⇒ String readonly
- #id ⇒ String readonly
- #initialize(callback_number:, caller_name:, dynamic_emergency_address_id:, id: nil, created_at: nil, record_type: nil, sip_from_id: nil, status: nil, updated_at: nil) ⇒ Object constructor
- #record_type ⇒ String readonly
- #sip_from_id ⇒ String readonly
- #status ⇒ Object readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(callback_number:, caller_name:, dynamic_emergency_address_id:, id: nil, created_at: nil, record_type: nil, sip_from_id: nil, status: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/dynamic_emergency_endpoint.rb', line 59
|
Instance Attribute Details
#callback_number ⇒ String
10 |
# File 'lib/telnyx/models/dynamic_emergency_endpoint.rb', line 10 required :callback_number, String |
#caller_name ⇒ String
15 |
# File 'lib/telnyx/models/dynamic_emergency_endpoint.rb', line 15 required :caller_name, String |
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
27 28 29 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 27 def created_at @created_at end |
#dynamic_emergency_address_id ⇒ String
An id of a currently active dynamic emergency location.
21 |
# File 'lib/telnyx/models/dynamic_emergency_endpoint.rb', line 21 required :dynamic_emergency_address_id, String |
#id ⇒ String? (readonly)
Returns the value of attribute id.
23 24 25 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 23 def id @id end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
31 32 33 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 31 def record_type @record_type end |
#sip_from_id ⇒ String? (readonly)
Returns the value of attribute sip_from_id.
35 36 37 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 35 def sip_from_id @sip_from_id end |
#status ⇒ Telnyx::Models::DynamicEmergencyEndpoint::status? (readonly)
Returns the value of attribute status.
39 40 41 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 39 def status @status end |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
45 46 47 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 45 def updated_at @updated_at end |
Instance Method Details
#created_at= ⇒ String (readonly)
29 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 29
def created_at=: (String) -> String
|
#id= ⇒ String (readonly)
25 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 25
def id=: (String) -> String
|
#record_type= ⇒ String (readonly)
33 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 33
def record_type=: (String) -> String
|
#sip_from_id= ⇒ String (readonly)
37 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 37
def sip_from_id=: (String) -> String
|
#status= ⇒ Object (readonly)
41 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 41
def status=: (
|
#to_hash ⇒ {
61 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 61
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
47 |
# File 'sig/telnyx/models/dynamic_emergency_endpoint.rbs', line 47
def updated_at=: (String) -> String
|