Class: Telnyx::Models::EmailDomainListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::EmailDomainListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/email_domain_list_params.rb,
sig/telnyx/models/email_domain_list_params.rbs
Overview
Defined Under Namespace
Modules: Sort
Instance Attribute Summary collapse
-
#filter_domain ⇒ String?
Partial match on domain name (case-insensitive).
-
#filter_profile_id ⇒ String?
Filter by profile UUID.
-
#filter_status ⇒ Symbol, ...
Filter domains by verification status: pending, verifying, verified, failed, degraded, or suspended.
-
#filter_type ⇒ Symbol, ...
Filter domains by type: custom, shared, or shared_inbound.
-
#filter_usable_for_inbound ⇒ Boolean?
Filter domains by whether they can currently receive inbound email.
-
#filter_usable_for_sending ⇒ Boolean?
Filter domains by whether they can currently be used to send email.
-
#page_after ⇒ String?
Cursor for records after the provided value (cursor pagination).
-
#page_before ⇒ String?
Cursor for records before the provided value (cursor pagination).
-
#page_number ⇒ Integer?
Page number to return (offset pagination).
-
#page_size ⇒ Integer?
Number of records per page.
-
#sort ⇒ Symbol, ...
Field to sort by.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(filter_domain: nil, filter_profile_id: nil, filter_status: nil, filter_type: nil, filter_usable_for_inbound: nil, filter_usable_for_sending: nil, page_after: nil, page_before: nil, page_number: nil, page_size: nil, sort: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EmailDomainListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filter_domain: nil, filter_profile_id: nil, filter_status: nil, filter_type: nil, filter_usable_for_inbound: nil, filter_usable_for_sending: nil, page_after: nil, page_before: nil, page_number: nil, page_size: nil, sort: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::EmailDomainListParams for more details.
|
|
# File 'lib/telnyx/models/email_domain_list_params.rb', line 77
|
Instance Attribute Details
#filter_domain ⇒ String?
Partial match on domain name (case-insensitive)
14 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 14 optional :filter_domain, String |
#filter_profile_id ⇒ String?
Filter by profile UUID
20 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 20 optional :filter_profile_id, String |
#filter_status ⇒ Symbol, ...
Filter domains by verification status: pending, verifying, verified, failed, degraded, or suspended.
27 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 27 optional :filter_status, enum: -> { Telnyx::EmailDomainStatus } |
#filter_type ⇒ Symbol, ...
Filter domains by type: custom, shared, or shared_inbound.
33 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 33 optional :filter_type, enum: -> { Telnyx::EmailDomainType } |
#filter_usable_for_inbound ⇒ Boolean?
Filter domains by whether they can currently receive inbound email.
39 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 39 optional :filter_usable_for_inbound, Telnyx::Internal::Type::Boolean |
#filter_usable_for_sending ⇒ Boolean?
Filter domains by whether they can currently be used to send email.
45 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 45 optional :filter_usable_for_sending, Telnyx::Internal::Type::Boolean |
#page_after ⇒ String?
Cursor for records after the provided value (cursor pagination)
51 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 51 optional :page_after, String |
#page_before ⇒ String?
Cursor for records before the provided value (cursor pagination)
57 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 57 optional :page_before, String |
#page_number ⇒ Integer?
Page number to return (offset pagination)
63 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 63 optional :page_number, Integer |
#page_size ⇒ Integer?
Number of records per page
69 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 69 optional :page_size, Integer |
#sort ⇒ Symbol, ...
Field to sort by. Prefix with - for descending order.
75 |
# File 'lib/telnyx/models/email_domain_list_params.rb', line 75 optional :sort, enum: -> { Telnyx::EmailDomainListParams::Sort } |
Instance Method Details
#to_hash ⇒ {
88 |
# File 'sig/telnyx/models/email_domain_list_params.rbs', line 88
def to_hash: -> {
|