Class: Telnyx::Models::EmailInboxes::MessageListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::EmailInboxes::MessageListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/email_inboxes/message_list_params.rb,
sig/telnyx/models/email_inboxes/message_list_params.rbs
Overview
Instance Attribute Summary collapse
-
#filter_from ⇒ String?
Case-insensitive literal substring of the sender address.
-
#filter_label ⇒ String?
Returns only messages carrying this label.
-
#filter_read ⇒ Boolean?
Whether the message has a read timestamp.
-
#filter_received_after ⇒ Time?
Inclusive ISO 8601 lower bound for the received timestamp.
-
#filter_received_before ⇒ Time?
Inclusive ISO 8601 upper bound for the received timestamp.
-
#filter_search ⇒ String?
Full-text query over subject and body, up to 500 characters.
-
#filter_subject ⇒ String?
Case-insensitive literal substring of the subject.
-
#filter_unread ⇒ Boolean?
Whether the message has no read timestamp.
- #inbox_id ⇒ String
-
#page_after ⇒ String?
Opaque cursor returned by the previous page.
-
#page_size ⇒ Integer?
Number of results to return.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(inbox_id:, filter_from: nil, filter_label: nil, filter_read: nil, filter_received_after: nil, filter_received_before: nil, filter_search: nil, filter_subject: nil, filter_unread: nil, page_after: nil, page_size: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessageListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(inbox_id:, filter_from: nil, filter_label: nil, filter_read: nil, filter_received_after: nil, filter_received_before: nil, filter_search: nil, filter_subject: nil, filter_unread: nil, page_after: nil, page_size: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::EmailInboxes::MessageListParams for more details.
|
|
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 79
|
Instance Attribute Details
#filter_from ⇒ String?
Case-insensitive literal substring of the sender address.
20 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 20 optional :filter_from, String |
#filter_label ⇒ String?
Returns only messages carrying this label. Matching is exact and case-sensitive.
Reserved telnyx: labels can be filtered on even though they cannot be written
by customers.
28 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 28 optional :filter_label, String |
#filter_read ⇒ Boolean?
Whether the message has a read timestamp.
34 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 34 optional :filter_read, Telnyx::Internal::Type::Boolean |
#filter_received_after ⇒ Time?
Inclusive ISO 8601 lower bound for the received timestamp.
40 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 40 optional :filter_received_after, Time |
#filter_received_before ⇒ Time?
Inclusive ISO 8601 upper bound for the received timestamp.
46 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 46 optional :filter_received_before, Time |
#filter_search ⇒ String?
Full-text query over subject and body, up to 500 characters.
52 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 52 optional :filter_search, String |
#filter_subject ⇒ String?
Case-insensitive literal substring of the subject.
58 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 58 optional :filter_subject, String |
#filter_unread ⇒ Boolean?
Whether the message has no read timestamp. Set to true to return only unread
messages.
65 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 65 optional :filter_unread, Telnyx::Internal::Type::Boolean |
#inbox_id ⇒ String
14 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 14 required :inbox_id, String |
#page_after ⇒ String?
Opaque cursor returned by the previous page.
71 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 71 optional :page_after, String |
#page_size ⇒ Integer?
Number of results to return. Defaults to 25; maximum is 100.
77 |
# File 'lib/telnyx/models/email_inboxes/message_list_params.rb', line 77 optional :page_size, Integer |
Instance Method Details
#to_hash ⇒ {
81 |
# File 'sig/telnyx/models/email_inboxes/message_list_params.rbs', line 81
def to_hash: -> {
|