Class: Telnyx::Models::EnterpriseCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::EnterpriseCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/enterprise_create_params.rb
Overview
Defined Under Namespace
Modules: NumberOfEmployees, OrganizationLegalType, OrganizationType, RoleType
Instance Attribute Summary collapse
- #billing_address ⇒ Telnyx::Models::BillingAddress
- #billing_contact ⇒ Telnyx::Models::BillingContact
-
#corporate_registration_number ⇒ String?
Corporate registration number (optional).
-
#country_code ⇒ String
Country code.
-
#customer_reference ⇒ String?
Optional customer reference identifier for your own tracking.
-
#doing_business_as ⇒ String
Primary business name / DBA name.
-
#dun_bradstreet_number ⇒ String?
D-U-N-S Number (optional).
-
#fein ⇒ String
Federal Employer Identification Number.
-
#industry ⇒ String
Industry classification.
-
#legal_name ⇒ String
Legal name of the enterprise.
-
#number_of_employees ⇒ Symbol, Telnyx::Models::EnterpriseCreateParams::NumberOfEmployees
Employee count range.
-
#organization_contact ⇒ Telnyx::Models::OrganizationContact
Organization contact information.
-
#organization_legal_type ⇒ Symbol, Telnyx::Models::EnterpriseCreateParams::OrganizationLegalType
Legal structure type.
- #organization_physical_address ⇒ Telnyx::Models::PhysicalAddress
-
#organization_type ⇒ Symbol, Telnyx::Models::EnterpriseCreateParams::OrganizationType
Type of organization.
-
#primary_business_domain_sic_code ⇒ String?
SIC Code (optional).
-
#professional_license_number ⇒ String?
Professional license number (optional).
-
#role_type ⇒ Symbol, ...
Role type in Branded Calling / Number Reputation services.
-
#website ⇒ String
Enterprise website URL.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_address:, billing_contact:, country_code:, doing_business_as:, fein:, industry:, legal_name:, number_of_employees:, organization_contact:, organization_legal_type:, organization_physical_address:, organization_type:, website:, corporate_registration_number: nil, customer_reference: nil, dun_bradstreet_number: nil, primary_business_domain_sic_code: nil, professional_license_number: nil, role_type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EnterpriseCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing_address:, billing_contact:, country_code:, doing_business_as:, fein:, industry:, legal_name:, number_of_employees:, organization_contact:, organization_legal_type:, organization_physical_address:, organization_type:, website:, corporate_registration_number: nil, customer_reference: nil, dun_bradstreet_number: nil, primary_business_domain_sic_code: nil, professional_license_number: nil, role_type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::EnterpriseCreateParams for more details.
|
|
# File 'lib/telnyx/models/enterprise_create_params.rb', line 129
|
Instance Attribute Details
#billing_address ⇒ Telnyx::Models::BillingAddress
13 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 13 required :billing_address, -> { Telnyx::BillingAddress } |
#billing_contact ⇒ Telnyx::Models::BillingContact
18 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 18 required :billing_contact, -> { Telnyx::BillingContact } |
#corporate_registration_number ⇒ String?
Corporate registration number (optional)
97 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 97 optional :corporate_registration_number, String |
#country_code ⇒ String
Country code. Currently only ‘US’ is accepted.
24 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 24 required :country_code, String |
#customer_reference ⇒ String?
Optional customer reference identifier for your own tracking
103 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 103 optional :customer_reference, String |
#doing_business_as ⇒ String
Primary business name / DBA name
30 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 30 required :doing_business_as, String |
#dun_bradstreet_number ⇒ String?
D-U-N-S Number (optional)
109 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 109 optional :dun_bradstreet_number, String |
#fein ⇒ String
Federal Employer Identification Number. Format: XX-XXXXXXX or 9-digit number (minimum 9 digits).
37 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 37 required :fein, String |
#industry ⇒ String
Industry classification. Case-insensitive. Accepted values: accounting, finance, billing, collections, business, charity, nonprofit, communications, telecom, customer service, support, delivery, shipping, logistics, education, financial, banking, government, public, healthcare, health, pharmacy, medical, insurance, legal, law, notifications, scheduling, real estate, property, retail, ecommerce, sales, marketing, software, technology, tech, media, surveys, market research, travel, hospitality, hotel
49 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 49 required :industry, String |
#legal_name ⇒ String
Legal name of the enterprise
55 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 55 required :legal_name, String |
#number_of_employees ⇒ Symbol, Telnyx::Models::EnterpriseCreateParams::NumberOfEmployees
Employee count range
61 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 61 required :number_of_employees, enum: -> { Telnyx::EnterpriseCreateParams::NumberOfEmployees } |
#organization_contact ⇒ Telnyx::Models::OrganizationContact
Organization contact information. Note: the response returns this object with the phone field as ‘phone’ (not ‘phone_number’).
68 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 68 required :organization_contact, -> { Telnyx::OrganizationContact } |
#organization_legal_type ⇒ Symbol, Telnyx::Models::EnterpriseCreateParams::OrganizationLegalType
Legal structure type
74 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 74 required :organization_legal_type, enum: -> { Telnyx::EnterpriseCreateParams::OrganizationLegalType } |
#organization_physical_address ⇒ Telnyx::Models::PhysicalAddress
79 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 79 required :organization_physical_address, -> { Telnyx::PhysicalAddress } |
#organization_type ⇒ Symbol, Telnyx::Models::EnterpriseCreateParams::OrganizationType
Type of organization
85 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 85 required :organization_type, enum: -> { Telnyx::EnterpriseCreateParams::OrganizationType } |
#primary_business_domain_sic_code ⇒ String?
SIC Code (optional)
115 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 115 optional :primary_business_domain_sic_code, String |
#professional_license_number ⇒ String?
Professional license number (optional)
121 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 121 optional :professional_license_number, String |
#role_type ⇒ Symbol, ...
Role type in Branded Calling / Number Reputation services
127 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 127 optional :role_type, enum: -> { Telnyx::EnterpriseCreateParams::RoleType } |
#website ⇒ String
Enterprise website URL. Accepts any string — no URL format validation enforced.
91 |
# File 'lib/telnyx/models/enterprise_create_params.rb', line 91 required :website, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/enterprise_create_params.rb', line 185
|