Class: Telnyx::Models::ExternalConnectionCreateParams::Outbound

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/external_connection_create_params.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#channel_limitInteger?

When set, this will limit the number of concurrent outbound calls to phone numbers associated with this connection.

Returns:

  • (Integer, nil)


97
# File 'lib/telnyx/models/external_connection_create_params.rb', line 97

optional :channel_limit, Integer

#outbound_voice_profile_idString?

Identifies the associated outbound voice profile.

Returns:

  • (String, nil)


103
# File 'lib/telnyx/models/external_connection_create_params.rb', line 103

optional :outbound_voice_profile_id, String