Class: Telnyx::Models::ExternalConnections::CivicAddressListResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalConnections::CivicAddressListResponse::Data
- Defined in:
- lib/telnyx/models/external_connections/civic_address_list_response.rb
Defined Under Namespace
Classes: Location
Instance Attribute Summary collapse
- #city_or_town ⇒ String?
- #city_or_town_alias ⇒ String?
- #company_name ⇒ String?
- #country ⇒ String?
- #country_or_district ⇒ String?
-
#default_location_id ⇒ String?
Identifies what is the default location in the list of locations.
- #description ⇒ String?
- #house_number ⇒ String?
- #house_number_suffix ⇒ String?
-
#id ⇒ String?
Uniquely identifies the resource.
- #locations ⇒ Array<Telnyx::Models::ExternalConnections::CivicAddressListResponse::Data::Location>?
- #postal_or_zip_code ⇒ String?
-
#record_type ⇒ String?
Identifies the type of the resource.
- #state_or_province ⇒ String?
- #street_name ⇒ String?
- #street_suffix ⇒ String?
Instance Method Summary collapse
- #initialize(data: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data: nil) ⇒ Object
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 17 class Data < Telnyx::Internal::Type::BaseModel # @!attribute id # Uniquely identifies the resource. # # @return [String, nil] optional :id, String # @!attribute city_or_town # # @return [String, nil] optional :city_or_town, String # @!attribute city_or_town_alias # # @return [String, nil] optional :city_or_town_alias, String # @!attribute company_name # # @return [String, nil] optional :company_name, String # @!attribute country # # @return [String, nil] optional :country, String # @!attribute country_or_district # # @return [String, nil] optional :country_or_district, String # @!attribute default_location_id # Identifies what is the default location in the list of locations. # # @return [String, nil] optional :default_location_id, String # @!attribute description # # @return [String, nil] optional :description, String # @!attribute house_number # # @return [String, nil] optional :house_number, String # @!attribute house_number_suffix # # @return [String, nil] optional :house_number_suffix, String # @!attribute locations # # @return [Array<Telnyx::Models::ExternalConnections::CivicAddressListResponse::Data::Location>, nil] optional :locations, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::ExternalConnections::CivicAddressListResponse::Data::Location] } # @!attribute postal_or_zip_code # # @return [String, nil] optional :postal_or_zip_code, String # @!attribute record_type # Identifies the type of the resource. # # @return [String, nil] optional :record_type, String # @!attribute state_or_province # # @return [String, nil] optional :state_or_province, String # @!attribute street_name # # @return [String, nil] optional :street_name, String # @!attribute street_suffix # # @return [String, nil] optional :street_suffix, String # @!method initialize(id: nil, city_or_town: nil, city_or_town_alias: nil, company_name: nil, country: nil, country_or_district: nil, default_location_id: nil, description: nil, house_number: nil, house_number_suffix: nil, locations: nil, postal_or_zip_code: nil, record_type: nil, state_or_province: nil, street_name: nil, street_suffix: nil) # @param id [String] Uniquely identifies the resource. # # @param city_or_town [String] # # @param city_or_town_alias [String] # # @param company_name [String] # # @param country [String] # # @param country_or_district [String] # # @param default_location_id [String] Identifies what is the default location in the list of locations. # # @param description [String] # # @param house_number [String] # # @param house_number_suffix [String] # # @param locations [Array<Telnyx::Models::ExternalConnections::CivicAddressListResponse::Data::Location>] # # @param postal_or_zip_code [String] # # @param record_type [String] Identifies the type of the resource. # # @param state_or_province [String] # # @param street_name [String] # # @param street_suffix [String] class Location < Telnyx::Internal::Type::BaseModel # @!attribute id # Uniquely identifies the resource. # # @return [String, nil] optional :id, String # @!attribute additional_info # # @return [String, nil] optional :additional_info, String # @!attribute description # # @return [String, nil] optional :description, String # @!attribute is_default # Represents whether the location is the default or not. # # @return [Boolean, nil] optional :is_default, Telnyx::Internal::Type::Boolean # @!method initialize(id: nil, additional_info: nil, description: nil, is_default: nil) # @param id [String] Uniquely identifies the resource. # # @param additional_info [String] # # @param description [String] # # @param is_default [Boolean] Represents whether the location is the default or not. end end |
Instance Attribute Details
#city_or_town ⇒ String?
27 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 27 optional :city_or_town, String |
#city_or_town_alias ⇒ String?
32 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 32 optional :city_or_town_alias, String |
#company_name ⇒ String?
37 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 37 optional :company_name, String |
#country ⇒ String?
42 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 42 optional :country, String |
#country_or_district ⇒ String?
47 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 47 optional :country_or_district, String |
#default_location_id ⇒ String?
Identifies what is the default location in the list of locations.
53 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 53 optional :default_location_id, String |
#description ⇒ String?
58 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 58 optional :description, String |
#house_number ⇒ String?
63 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 63 optional :house_number, String |
#house_number_suffix ⇒ String?
68 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 68 optional :house_number_suffix, String |
#id ⇒ String?
Uniquely identifies the resource.
22 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 22 optional :id, String |
#locations ⇒ Array<Telnyx::Models::ExternalConnections::CivicAddressListResponse::Data::Location>?
73 74 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 73 optional :locations, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::ExternalConnections::CivicAddressListResponse::Data::Location] } |
#postal_or_zip_code ⇒ String?
79 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 79 optional :postal_or_zip_code, String |
#record_type ⇒ String?
Identifies the type of the resource.
85 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 85 optional :record_type, String |
#state_or_province ⇒ String?
90 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 90 optional :state_or_province, String |
#street_name ⇒ String?
95 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 95 optional :street_name, String |
#street_suffix ⇒ String?
100 |
# File 'lib/telnyx/models/external_connections/civic_address_list_response.rb', line 100 optional :street_suffix, String |