Class: Telnyx::Models::ExternalConnections::ExternalConnectionPhoneNumber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalConnections::ExternalConnectionPhoneNumber
- Defined in:
- lib/telnyx/models/external_connections/external_connection_phone_number.rb
Overview
Defined Under Namespace
Modules: AcquiredCapability
Instance Attribute Summary collapse
- #acquired_capabilities ⇒ Array<Symbol, Telnyx::Models::ExternalConnections::ExternalConnectionPhoneNumber::AcquiredCapability>?
-
#civic_address_id ⇒ String?
Identifies the civic address assigned to the phone number.
-
#displayed_country_code ⇒ String?
The iso country code that will be displayed to the user when they receive a call from this phone number.
-
#location_id ⇒ String?
Identifies the location assigned to the phone number.
-
#number_id ⇒ String?
Phone number ID from the Telnyx API.
-
#telephone_number ⇒ String?
Phone number in E164 format.
-
#ticket_id ⇒ String?
Uniquely identifies the resource.
Instance Method Summary collapse
-
#initialize(acquired_capabilities: nil, civic_address_id: nil, displayed_country_code: nil, location_id: nil, number_id: nil, telephone_number: nil, ticket_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalConnectionPhoneNumber for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(acquired_capabilities: nil, civic_address_id: nil, displayed_country_code: nil, location_id: nil, number_id: nil, telephone_number: nil, ticket_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ExternalConnections::ExternalConnectionPhoneNumber for more details.
|
|
# File 'lib/telnyx/models/external_connections/external_connection_phone_number.rb', line 51
|
Instance Attribute Details
#acquired_capabilities ⇒ Array<Symbol, Telnyx::Models::ExternalConnections::ExternalConnectionPhoneNumber::AcquiredCapability>?
11 12 |
# File 'lib/telnyx/models/external_connections/external_connection_phone_number.rb', line 11 optional :acquired_capabilities, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::ExternalConnections::ExternalConnectionPhoneNumber::AcquiredCapability] } |
#civic_address_id ⇒ String?
Identifies the civic address assigned to the phone number.
18 |
# File 'lib/telnyx/models/external_connections/external_connection_phone_number.rb', line 18 optional :civic_address_id, String |
#displayed_country_code ⇒ String?
The iso country code that will be displayed to the user when they receive a call from this phone number.
25 |
# File 'lib/telnyx/models/external_connections/external_connection_phone_number.rb', line 25 optional :displayed_country_code, String |
#location_id ⇒ String?
Identifies the location assigned to the phone number.
31 |
# File 'lib/telnyx/models/external_connections/external_connection_phone_number.rb', line 31 optional :location_id, String |
#number_id ⇒ String?
Phone number ID from the Telnyx API.
37 |
# File 'lib/telnyx/models/external_connections/external_connection_phone_number.rb', line 37 optional :number_id, String |
#telephone_number ⇒ String?
Phone number in E164 format.
43 |
# File 'lib/telnyx/models/external_connections/external_connection_phone_number.rb', line 43 optional :telephone_number, String |
#ticket_id ⇒ String?
Uniquely identifies the resource.
49 |
# File 'lib/telnyx/models/external_connections/external_connection_phone_number.rb', line 49 optional :ticket_id, String |