Class: Telnyx::Models::ExternalConnections::ReleaseRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalConnections::ReleaseRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/external_connections/release_retrieve_response.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
-
#error_message ⇒ String?
A message set if there is an error with the upload process.
-
#status ⇒ Symbol, ...
Represents the status of the release on Microsoft Teams.
- #telephone_numbers ⇒ Array<Telnyx::Models::ExternalConnections::TnReleaseEntry>?
- #tenant_id ⇒ String?
-
#ticket_id ⇒ String?
Uniquely identifies the resource.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at: nil, error_message: nil, status: nil, telephone_numbers: nil, tenant_id: nil, ticket_id: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/external_connections/release_retrieve_response.rb', line 53
|
Instance Attribute Details
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
22 |
# File 'lib/telnyx/models/external_connections/release_retrieve_response.rb', line 22 optional :created_at, String |
#error_message ⇒ String?
A message set if there is an error with the upload process.
28 |
# File 'lib/telnyx/models/external_connections/release_retrieve_response.rb', line 28 optional :error_message, String |
#status ⇒ Symbol, ...
Represents the status of the release on Microsoft Teams.
34 |
# File 'lib/telnyx/models/external_connections/release_retrieve_response.rb', line 34 optional :status, enum: -> { Telnyx::Models::ExternalConnections::ReleaseRetrieveResponse::Data::Status } |
#telephone_numbers ⇒ Array<Telnyx::Models::ExternalConnections::TnReleaseEntry>?
39 40 |
# File 'lib/telnyx/models/external_connections/release_retrieve_response.rb', line 39 optional :telephone_numbers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::ExternalConnections::TnReleaseEntry] } |
#tenant_id ⇒ String?
45 |
# File 'lib/telnyx/models/external_connections/release_retrieve_response.rb', line 45 optional :tenant_id, String |
#ticket_id ⇒ String?
Uniquely identifies the resource.
51 |
# File 'lib/telnyx/models/external_connections/release_retrieve_response.rb', line 51 optional :ticket_id, String |