Class: Telnyx::Models::ExternalConnections::TnUploadEntry
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalConnections::TnUploadEntry
- Defined in:
- lib/telnyx/models/external_connections/tn_upload_entry.rb
Defined Under Namespace
Modules: ErrorCode, InternalStatus, Status
Instance Attribute Summary collapse
-
#civic_address_id ⇒ String?
Identifies the civic address assigned to the phone number entry.
-
#error_code ⇒ Symbol, ...
A code returned by Microsoft Teams if there is an error with the phone number entry upload.
-
#error_message ⇒ String?
A message returned by Microsoft Teams if there is an error with the upload process.
-
#internal_status ⇒ Symbol, ...
Represents the status of the phone number entry upload on Telnyx.
-
#location_id ⇒ String?
Identifies the location assigned to the phone number entry.
-
#number_id ⇒ String?
Uniquely identifies the resource.
-
#phone_number ⇒ String?
Phone number in E164 format.
-
#status ⇒ Symbol, ...
Represents the status of the phone number entry upload on Microsoft Teams.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(civic_address_id: nil, error_code: nil, error_message: nil, internal_status: nil, location_id: nil, number_id: nil, phone_number: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TnUploadEntry for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(civic_address_id: nil, error_code: nil, error_message: nil, internal_status: nil, location_id: nil, number_id: nil, phone_number: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ExternalConnections::TnUploadEntry for more details.
|
|
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 57
|
Instance Attribute Details
#civic_address_id ⇒ String?
Identifies the civic address assigned to the phone number entry.
11 |
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 11 optional :civic_address_id, String |
#error_code ⇒ Symbol, ...
A code returned by Microsoft Teams if there is an error with the phone number entry upload.
18 |
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 18 optional :error_code, enum: -> { Telnyx::ExternalConnections::TnUploadEntry::ErrorCode } |
#error_message ⇒ String?
A message returned by Microsoft Teams if there is an error with the upload process.
25 |
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 25 optional :error_message, String |
#internal_status ⇒ Symbol, ...
Represents the status of the phone number entry upload on Telnyx.
31 |
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 31 optional :internal_status, enum: -> { Telnyx::ExternalConnections::TnUploadEntry::InternalStatus } |
#location_id ⇒ String?
Identifies the location assigned to the phone number entry.
37 |
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 37 optional :location_id, String |
#number_id ⇒ String?
Uniquely identifies the resource.
43 |
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 43 optional :number_id, String |
#phone_number ⇒ String?
Phone number in E164 format.
49 |
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 49 optional :phone_number, String |
#status ⇒ Symbol, ...
Represents the status of the phone number entry upload on Microsoft Teams.
55 |
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 55 optional :status, enum: -> { Telnyx::ExternalConnections::TnUploadEntry::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/external_connections/tn_upload_entry.rb', line 91
|