Module: Telnyx::Models::ExternalConnections::TnUploadEntry::ErrorCode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/external_connections/tn_upload_entry.rb,
sig/telnyx/models/external_connections/tn_upload_entry.rbs
Overview
A code returned by Microsoft Teams if there is an error with the phone number entry upload.
Constant Summary collapse
- INTERNAL_ERROR =
:internal_error- UNABLE_TO_RETRIEVE_DEFAULT_LOCATION =
:unable_to_retrieve_default_location- UNKNOWN_COUNTRY_CODE =
:unknown_country_code- UNABLE_TO_RETRIEVE_LOCATION =
:unable_to_retrieve_location- UNABLE_TO_RETRIEVE_PARTNER_INFO =
:unable_to_retrieve_partner_info- UNABLE_TO_MATCH_GEOGRAPHY_ENTRY =
:unable_to_match_geography_entry
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::ExternalConnections::TnUploadEntry::error_code]
95 |
# File 'sig/telnyx/models/external_connections/tn_upload_entry.rbs', line 95
def self?.values: -> ::Array[Telnyx::Models::ExternalConnections::TnUploadEntry::error_code]
|