Class: Telnyx::Models::ExternalConnections::Upload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalConnections::Upload
- Defined in:
- lib/telnyx/models/external_connections/upload.rb
Overview
Defined Under Namespace
Modules: AvailableUsage, Status
Instance Attribute Summary collapse
- #available_usages ⇒ Array<Symbol, Telnyx::Models::ExternalConnections::Upload::AvailableUsage>?
-
#error_code ⇒ String?
A code returned by Microsoft Teams if there is an error with the upload process.
-
#error_message ⇒ String?
A message set if there is an error with the upload process.
- #location_id ⇒ String?
-
#status ⇒ Symbol, ...
Represents the status of the upload on Microsoft Teams.
- #tenant_id ⇒ String?
-
#ticket_id ⇒ String?
Uniquely identifies the resource.
- #tn_upload_entries ⇒ Array<Telnyx::Models::ExternalConnections::TnUploadEntry>?
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(available_usages: nil, error_code: nil, error_message: nil, location_id: nil, status: nil, tenant_id: nil, ticket_id: nil, tn_upload_entries: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Upload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(available_usages: nil, error_code: nil, error_message: nil, location_id: nil, status: nil, tenant_id: nil, ticket_id: nil, tn_upload_entries: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ExternalConnections::Upload for more details.
|
|
# File 'lib/telnyx/models/external_connections/upload.rb', line 54
|
Instance Attribute Details
#available_usages ⇒ Array<Symbol, Telnyx::Models::ExternalConnections::Upload::AvailableUsage>?
11 12 |
# File 'lib/telnyx/models/external_connections/upload.rb', line 11 optional :available_usages, -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::ExternalConnections::Upload::AvailableUsage] } |
#error_code ⇒ String?
A code returned by Microsoft Teams if there is an error with the upload process.
18 |
# File 'lib/telnyx/models/external_connections/upload.rb', line 18 optional :error_code, String |
#error_message ⇒ String?
A message set if there is an error with the upload process.
24 |
# File 'lib/telnyx/models/external_connections/upload.rb', line 24 optional :error_message, String |
#location_id ⇒ String?
29 |
# File 'lib/telnyx/models/external_connections/upload.rb', line 29 optional :location_id, String |
#status ⇒ Symbol, ...
Represents the status of the upload on Microsoft Teams.
35 |
# File 'lib/telnyx/models/external_connections/upload.rb', line 35 optional :status, enum: -> { Telnyx::ExternalConnections::Upload::Status } |
#tenant_id ⇒ String?
40 |
# File 'lib/telnyx/models/external_connections/upload.rb', line 40 optional :tenant_id, String |
#ticket_id ⇒ String?
Uniquely identifies the resource.
46 |
# File 'lib/telnyx/models/external_connections/upload.rb', line 46 optional :ticket_id, String |
#tn_upload_entries ⇒ Array<Telnyx::Models::ExternalConnections::TnUploadEntry>?
51 52 |
# File 'lib/telnyx/models/external_connections/upload.rb', line 51 optional :tn_upload_entries, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::ExternalConnections::TnUploadEntry] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/external_connections/upload.rb', line 81
|