Class: Telnyx::Models::ExternalConnections::UploadPendingCountResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalConnections::UploadPendingCountResponse::Data
- Defined in:
- lib/telnyx/models/external_connections/upload_pending_count_response.rb
Overview
Instance Attribute Summary collapse
-
#pending_numbers_count ⇒ Integer?
The count of phone numbers that are pending assignment to the external connection.
-
#pending_orders_count ⇒ Integer?
The count of number uploads that have not yet been uploaded to Microsoft.
Instance Method Summary collapse
-
#initialize(pending_numbers_count: nil, pending_orders_count: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(pending_numbers_count: nil, pending_orders_count: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ExternalConnections::UploadPendingCountResponse::Data for more details.
|
|
# File 'lib/telnyx/models/external_connections/upload_pending_count_response.rb', line 31
|
Instance Attribute Details
#pending_numbers_count ⇒ Integer?
The count of phone numbers that are pending assignment to the external connection.
23 |
# File 'lib/telnyx/models/external_connections/upload_pending_count_response.rb', line 23 optional :pending_numbers_count, Integer |
#pending_orders_count ⇒ Integer?
The count of number uploads that have not yet been uploaded to Microsoft.
29 |
# File 'lib/telnyx/models/external_connections/upload_pending_count_response.rb', line 29 optional :pending_orders_count, Integer |