Class: Telnyx::Models::ExternalRequirements::SubNumberOrderRetrieveResponse::Data::FieldsRequired
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ExternalRequirements::SubNumberOrderRetrieveResponse::Data::FieldsRequired
- Defined in:
- lib/telnyx/models/external_requirements/sub_number_order_retrieve_response.rb,
sig/telnyx/models/external_requirements/sub_number_order_retrieve_response.rbs
Instance Attribute Summary collapse
- #description ⇒ String?
-
#name ⇒ String?
The field name to send inside the
requirementobject on the POST. - #type ⇒ String?
-
#value ⇒ String?
The value already stored for this field, or null if not yet provided.
Instance Method Summary collapse
- #initialize(fields_required: nil, regulatory_requirement_id: nil, requirement_action: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(fields_required: nil, regulatory_requirement_id: nil, requirement_action: nil) ⇒ Object
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/telnyx/models/external_requirements/sub_number_order_retrieve_response.rb', line 43 class FieldsRequired < Telnyx::Internal::Type::BaseModel # @!attribute description # # @return [String, nil] optional :description, String # @!attribute name # The field name to send inside the `requirement` object on the POST. # # @return [String, nil] optional :name, String # @!attribute type # # @return [String, nil] optional :type, String # @!attribute value # The value already stored for this field, or null if not yet provided. # # @return [String, nil] optional :value, String, nil?: true # @!method initialize(description: nil, name: nil, type: nil, value: nil) # @param description [String] # # @param name [String] The field name to send inside the `requirement` object on the POST. # # @param type [String] # # @param value [String, nil] The value already stored for this field, or null if not yet provided. end |
Instance Attribute Details
#description ⇒ String?
47 |
# File 'lib/telnyx/models/external_requirements/sub_number_order_retrieve_response.rb', line 47 optional :description, String |
#name ⇒ String?
The field name to send inside the requirement object on the POST.
53 |
# File 'lib/telnyx/models/external_requirements/sub_number_order_retrieve_response.rb', line 53 optional :name, String |
#type ⇒ String?
58 |
# File 'lib/telnyx/models/external_requirements/sub_number_order_retrieve_response.rb', line 58 optional :type, String |
#value ⇒ String?
The value already stored for this field, or null if not yet provided.
64 |
# File 'lib/telnyx/models/external_requirements/sub_number_order_retrieve_response.rb', line 64 optional :value, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
85 |
# File 'sig/telnyx/models/external_requirements/sub_number_order_retrieve_response.rbs', line 85
def to_hash: -> {
|