Class: Telnyx::Models::Fax
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Fax
- Defined in:
- lib/telnyx/models/fax.rb
Overview
Defined Under Namespace
Modules: Direction, Quality, RecordType, Status
Instance Attribute Summary collapse
-
#client_state ⇒ String?
State received from a command.
-
#connection_id ⇒ String?
The ID of the connection used to send the fax.
-
#created_at ⇒ Time?
ISO 8601 timestamp when resource was created.
-
#direction ⇒ Symbol, ...
The direction of the fax.
-
#from ⇒ String?
The phone number, in E.164 format, the fax will be sent from.
-
#from_display_name ⇒ String?
The string used as the caller id name (SIP From Display Name) presented to the destination (‘to` number).
-
#id ⇒ String?
Identifies the type of resource.
-
#media_name ⇒ String?
The media_name used for the fax’s media.
-
#media_url ⇒ String?
The URL (or list of URLs) to the PDF used for the fax’s media.
-
#preview_url ⇒ String?
If ‘store_preview` was set to `true`, this is a link to temporary location.
-
#quality ⇒ Symbol, ...
The quality of the fax.
-
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
-
#status ⇒ Symbol, ...
Status of the fax.
-
#store_media ⇒ Boolean?
Should fax media be stored on temporary URL.
-
#stored_media_url ⇒ String?
If store_media was set to true, this is a link to temporary location.
-
#to ⇒ String?
The phone number, in E.164 format, the fax will be sent to or SIP URI.
-
#updated_at ⇒ Time?
ISO 8601 timestamp when resource was updated.
-
#webhook_failover_url ⇒ String?
Optional failover URL that will receive fax webhooks if webhook_url doesn’t return a 2XX response.
-
#webhook_url ⇒ String?
URL that will receive fax webhooks.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, client_state: nil, connection_id: nil, created_at: nil, direction: nil, from: nil, from_display_name: nil, media_name: nil, media_url: nil, preview_url: nil, quality: nil, record_type: nil, status: nil, store_media: nil, stored_media_url: nil, to: nil, updated_at: nil, webhook_failover_url: nil, webhook_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Fax for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, client_state: nil, connection_id: nil, created_at: nil, direction: nil, from: nil, from_display_name: nil, media_name: nil, media_url: nil, preview_url: nil, quality: nil, record_type: nil, status: nil, store_media: nil, stored_media_url: nil, to: nil, updated_at: nil, webhook_failover_url: nil, webhook_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Fax for more details.
|
|
# File 'lib/telnyx/models/fax.rb', line 130
|
Instance Attribute Details
#client_state ⇒ String?
State received from a command.
17 |
# File 'lib/telnyx/models/fax.rb', line 17 optional :client_state, String |
#connection_id ⇒ String?
The ID of the connection used to send the fax.
23 |
# File 'lib/telnyx/models/fax.rb', line 23 optional :connection_id, String |
#created_at ⇒ Time?
ISO 8601 timestamp when resource was created
29 |
# File 'lib/telnyx/models/fax.rb', line 29 optional :created_at, Time |
#direction ⇒ Symbol, ...
The direction of the fax.
35 |
# File 'lib/telnyx/models/fax.rb', line 35 optional :direction, enum: -> { Telnyx::Fax::Direction } |
#from ⇒ String?
The phone number, in E.164 format, the fax will be sent from.
41 |
# File 'lib/telnyx/models/fax.rb', line 41 optional :from, String |
#from_display_name ⇒ String?
The string used as the caller id name (SIP From Display Name) presented to the destination (‘to` number).
48 |
# File 'lib/telnyx/models/fax.rb', line 48 optional :from_display_name, String |
#id ⇒ String?
Identifies the type of resource.
11 |
# File 'lib/telnyx/models/fax.rb', line 11 optional :id, String |
#media_name ⇒ String?
The media_name used for the fax’s media. Must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. media_name and media_url/contents can’t be submitted together.
56 |
# File 'lib/telnyx/models/fax.rb', line 56 optional :media_name, String |
#media_url ⇒ String?
The URL (or list of URLs) to the PDF used for the fax’s media. media_url and media_name/contents can’t be submitted together.
63 |
# File 'lib/telnyx/models/fax.rb', line 63 optional :media_url, String |
#preview_url ⇒ String?
If ‘store_preview` was set to `true`, this is a link to temporary location. Link expires after 10 minutes.
70 |
# File 'lib/telnyx/models/fax.rb', line 70 optional :preview_url, String |
#quality ⇒ Symbol, ...
The quality of the fax. The ‘ultra` settings provides the highest quality available, but also present longer fax processing times. `ultra_light` is best suited for images, wihle `ultra_dark` is best suited for text.
78 |
# File 'lib/telnyx/models/fax.rb', line 78 optional :quality, enum: -> { Telnyx::Fax::Quality } |
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
84 |
# File 'lib/telnyx/models/fax.rb', line 84 optional :record_type, enum: -> { Telnyx::Fax::RecordType } |
#status ⇒ Symbol, ...
Status of the fax
90 |
# File 'lib/telnyx/models/fax.rb', line 90 optional :status, enum: -> { Telnyx::Fax::Status } |
#store_media ⇒ Boolean?
Should fax media be stored on temporary URL. It does not support media_name.
96 |
# File 'lib/telnyx/models/fax.rb', line 96 optional :store_media, Telnyx::Internal::Type::Boolean |
#stored_media_url ⇒ String?
If store_media was set to true, this is a link to temporary location. Link expires after 10 minutes.
103 |
# File 'lib/telnyx/models/fax.rb', line 103 optional :stored_media_url, String |
#to ⇒ String?
The phone number, in E.164 format, the fax will be sent to or SIP URI
109 |
# File 'lib/telnyx/models/fax.rb', line 109 optional :to, String |
#updated_at ⇒ Time?
ISO 8601 timestamp when resource was updated
115 |
# File 'lib/telnyx/models/fax.rb', line 115 optional :updated_at, Time |
#webhook_failover_url ⇒ String?
Optional failover URL that will receive fax webhooks if webhook_url doesn’t return a 2XX response
122 |
# File 'lib/telnyx/models/fax.rb', line 122 optional :webhook_failover_url, String |
#webhook_url ⇒ String?
URL that will receive fax webhooks
128 |
# File 'lib/telnyx/models/fax.rb', line 128 optional :webhook_url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/fax.rb', line 181
|