Class: Telnyx::Models::FaxApplication
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FaxApplication
- Defined in:
- lib/telnyx/models/fax_application.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Specifies whether the connection can be used.
-
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection.
-
#application_name ⇒ String?
A user-assigned name to help manage the application.
-
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
-
#id ⇒ String?
Uniquely identifies the resource.
- #inbound ⇒ Telnyx::Models::FaxApplication::Inbound?
- #outbound ⇒ Telnyx::Models::FaxApplication::Outbound?
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#tags ⇒ Array<String>?
Tags associated with the Fax Application.
-
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, active: nil, anchorsite_override: nil, application_name: nil, created_at: nil, inbound: nil, outbound: nil, record_type: nil, tags: nil, updated_at: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see FaxApplication for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, active: nil, anchorsite_override: nil, application_name: nil, created_at: nil, inbound: nil, outbound: nil, record_type: nil, tags: nil, updated_at: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::FaxApplication for more details.
|
|
# File 'lib/telnyx/models/fax_application.rb', line 87
|
Instance Attribute Details
#active ⇒ Boolean?
Specifies whether the connection can be used.
17 |
# File 'lib/telnyx/models/fax_application.rb', line 17 optional :active, Telnyx::Internal::Type::Boolean |
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.
25 |
# File 'lib/telnyx/models/fax_application.rb', line 25 optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride } |
#application_name ⇒ String?
A user-assigned name to help manage the application.
31 |
# File 'lib/telnyx/models/fax_application.rb', line 31 optional :application_name, String |
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
37 |
# File 'lib/telnyx/models/fax_application.rb', line 37 optional :created_at, String |
#id ⇒ String?
Uniquely identifies the resource.
11 |
# File 'lib/telnyx/models/fax_application.rb', line 11 optional :id, String |
#inbound ⇒ Telnyx::Models::FaxApplication::Inbound?
42 |
# File 'lib/telnyx/models/fax_application.rb', line 42 optional :inbound, -> { Telnyx::FaxApplication::Inbound } |
#outbound ⇒ Telnyx::Models::FaxApplication::Outbound?
47 |
# File 'lib/telnyx/models/fax_application.rb', line 47 optional :outbound, -> { Telnyx::FaxApplication::Outbound } |
#record_type ⇒ String?
Identifies the type of the resource.
53 |
# File 'lib/telnyx/models/fax_application.rb', line 53 optional :record_type, String |
#tags ⇒ Array<String>?
Tags associated with the Fax Application.
59 |
# File 'lib/telnyx/models/fax_application.rb', line 59 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
65 |
# File 'lib/telnyx/models/fax_application.rb', line 65 optional :updated_at, String |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.
72 |
# File 'lib/telnyx/models/fax_application.rb', line 72 optional :webhook_event_failover_url, String, nil?: true |
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.
79 |
# File 'lib/telnyx/models/fax_application.rb', line 79 optional :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
85 |
# File 'lib/telnyx/models/fax_application.rb', line 85 optional :webhook_timeout_secs, Integer, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/fax_application.rb', line 167
|