Class: Telnyx::Models::FaxApplicationCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/fax_application_create_params.rb

Overview

Defined Under Namespace

Classes: Inbound, Outbound

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#activeBoolean?

Specifies whether the connection can be used.

Returns:

  • (Boolean, nil)


27
# File 'lib/telnyx/models/fax_application_create_params.rb', line 27

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



35
# File 'lib/telnyx/models/fax_application_create_params.rb', line 35

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#application_nameString

A user-assigned name to help manage the application.

Returns:

  • (String)


14
# File 'lib/telnyx/models/fax_application_create_params.rb', line 14

required :application_name, String

#inboundTelnyx::Models::FaxApplicationCreateParams::Inbound?



40
# File 'lib/telnyx/models/fax_application_create_params.rb', line 40

optional :inbound, -> { Telnyx::FaxApplicationCreateParams::Inbound }

#outboundTelnyx::Models::FaxApplicationCreateParams::Outbound?



45
# File 'lib/telnyx/models/fax_application_create_params.rb', line 45

optional :outbound, -> { Telnyx::FaxApplicationCreateParams::Outbound }

#tagsArray<String>?

Tags associated with the Fax Application.

Returns:

  • (Array<String>, nil)


51
# File 'lib/telnyx/models/fax_application_create_params.rb', line 51

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


58
# File 'lib/telnyx/models/fax_application_create_params.rb', line 58

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String)


21
# File 'lib/telnyx/models/fax_application_create_params.rb', line 21

required :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


64
# File 'lib/telnyx/models/fax_application_create_params.rb', line 64

optional :webhook_timeout_secs, Integer, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/fax_application_create_params.rb', line 139