Class: Telnyx::Models::FaxApplicationCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FaxApplicationCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/fax_application_create_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Specifies whether the connection can be used.
-
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection.
-
#application_name ⇒ String
A user-assigned name to help manage the application.
- #inbound ⇒ Telnyx::Models::FaxApplicationCreateParams::Inbound?
- #outbound ⇒ Telnyx::Models::FaxApplicationCreateParams::Outbound?
-
#tags ⇒ Array<String>?
Tags associated with the Fax Application.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String
The URL where webhooks related to this connection will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#active ⇒ Boolean?
Specifies whether the connection can be used.
27 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 27 optional :active, Telnyx::Internal::Type::Boolean |
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.
35 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 35 optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride } |
#application_name ⇒ String
A user-assigned name to help manage the application.
14 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 14 required :application_name, String |
#inbound ⇒ Telnyx::Models::FaxApplicationCreateParams::Inbound?
40 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 40 optional :inbound, -> { Telnyx::FaxApplicationCreateParams::Inbound } |
#outbound ⇒ Telnyx::Models::FaxApplicationCreateParams::Outbound?
45 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 45 optional :outbound, -> { Telnyx::FaxApplicationCreateParams::Outbound } |
#tags ⇒ Array<String>?
Tags associated with the Fax Application.
51 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 51 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.
58 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 58 optional :webhook_event_failover_url, String, nil?: true |
#webhook_event_url ⇒ String
The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.
21 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 21 required :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
64 |
# File 'lib/telnyx/models/fax_application_create_params.rb', line 64 optional :webhook_timeout_secs, Integer, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/fax_application_create_params.rb', line 139
|