Class: Telnyx::Models::FaxApplicationUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FaxApplicationUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/fax_application_update_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Specifies whether the connection can be used.
-
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection.
-
#application_name ⇒ String
A user-assigned name to help manage the application.
-
#fax_email_recipient ⇒ String?
Specifies an email address where faxes sent to this application will be forwarded to (as pdf or tiff attachments).
- #id ⇒ String
- #inbound ⇒ Telnyx::Models::FaxApplicationUpdateParams::Inbound?
- #outbound ⇒ Telnyx::Models::FaxApplicationUpdateParams::Outbound?
-
#tags ⇒ Array<String>?
Tags associated with the Fax Application.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String
The URL where webhooks related to this connection will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#active ⇒ Boolean?
Specifies whether the connection can be used.
32 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 32 optional :active, Telnyx::Internal::Type::Boolean |
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.
40 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 40 optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride } |
#application_name ⇒ String
A user-assigned name to help manage the application.
19 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 19 required :application_name, String |
#fax_email_recipient ⇒ String?
Specifies an email address where faxes sent to this application will be forwarded to (as pdf or tiff attachments)
47 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 47 optional :fax_email_recipient, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 13 required :id, String |
#inbound ⇒ Telnyx::Models::FaxApplicationUpdateParams::Inbound?
52 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 52 optional :inbound, -> { Telnyx::FaxApplicationUpdateParams::Inbound } |
#outbound ⇒ Telnyx::Models::FaxApplicationUpdateParams::Outbound?
57 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 57 optional :outbound, -> { Telnyx::FaxApplicationUpdateParams::Outbound } |
#tags ⇒ Array<String>?
Tags associated with the Fax Application.
63 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 63 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.
70 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 70 optional :webhook_event_failover_url, String, nil?: true |
#webhook_event_url ⇒ String
The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.
26 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 26 required :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
76 |
# File 'lib/telnyx/models/fax_application_update_params.rb', line 76 optional :webhook_timeout_secs, Integer, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/fax_application_update_params.rb', line 155
|