Class: Telnyx::Models::FaxCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FaxCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/fax_create_params.rb
Overview
Defined Under Namespace
Modules: PreviewFormat, Quality
Instance Attribute Summary collapse
-
#black_threshold ⇒ Integer?
The black threshold percentage for monochrome faxes.
-
#client_state ⇒ String?
Use this field to add state to every subsequent webhook.
-
#connection_id ⇒ String
The connection ID to send the fax with.
-
#from ⇒ String
The phone number, in E.164 format, the fax will be sent from.
-
#from_display_name ⇒ String?
The ‘from_display_name` string to be used as the caller id name (SIP From Display Name) presented to the destination (`to` number).
-
#media_name ⇒ String?
The media_name used for the fax’s media.
-
#media_url ⇒ String?
The URL (or list of URLs) to the PDF used for the fax’s media.
-
#monochrome ⇒ Boolean?
The flag to enable monochrome, true black and white fax results.
-
#preview_format ⇒ Symbol, ...
The format for the preview file in case the ‘store_preview` is `true`.
-
#quality ⇒ Symbol, ...
The quality of the fax.
-
#store_media ⇒ Boolean?
Should fax media be stored on temporary URL.
-
#store_preview ⇒ Boolean?
Should fax preview be stored on temporary URL.
-
#t38_enabled ⇒ Boolean?
The flag to disable the T.38 protocol.
-
#to ⇒ String
The phone number, in E.164 format, the fax will be sent to or SIP URI.
-
#webhook_url ⇒ String?
Use this field to override the URL to which Telnyx will send subsequent webhooks for this fax.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(connection_id:, from:, to:, black_threshold: nil, client_state: nil, from_display_name: nil, media_name: nil, media_url: nil, monochrome: nil, preview_format: nil, quality: nil, store_media: nil, store_preview: nil, t38_enabled: nil, webhook_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FaxCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_id:, from:, to:, black_threshold: nil, client_state: nil, from_display_name: nil, media_name: nil, media_url: nil, monochrome: nil, preview_format: nil, quality: nil, store_media: nil, store_preview: nil, t38_enabled: nil, webhook_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::FaxCreateParams for more details.
|
|
# File 'lib/telnyx/models/fax_create_params.rb', line 113
|
Instance Attribute Details
#black_threshold ⇒ Integer?
The black threshold percentage for monochrome faxes. Only applicable if ‘monochrome` is set to `true`.
33 |
# File 'lib/telnyx/models/fax_create_params.rb', line 33 optional :black_threshold, Integer |
#client_state ⇒ String?
Use this field to add state to every subsequent webhook. It must be a valid Base-64 encoded string.
40 |
# File 'lib/telnyx/models/fax_create_params.rb', line 40 optional :client_state, String |
#connection_id ⇒ String
The connection ID to send the fax with.
14 |
# File 'lib/telnyx/models/fax_create_params.rb', line 14 required :connection_id, String |
#from ⇒ String
The phone number, in E.164 format, the fax will be sent from.
20 |
# File 'lib/telnyx/models/fax_create_params.rb', line 20 required :from, String |
#from_display_name ⇒ String?
The ‘from_display_name` string to be used as the caller id name (SIP From Display Name) presented to the destination (`to` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and -_~!.+ special characters. If ommited, the display name will be the same as the number in the `from` field.
50 |
# File 'lib/telnyx/models/fax_create_params.rb', line 50 optional :from_display_name, String |
#media_name ⇒ String?
The media_name used for the fax’s media. Must point to a file previously uploaded to api.telnyx.com/v2/media by the same user/organization. media_name and media_url/contents can’t be submitted together.
58 |
# File 'lib/telnyx/models/fax_create_params.rb', line 58 optional :media_name, String |
#media_url ⇒ String?
The URL (or list of URLs) to the PDF used for the fax’s media. media_url and media_name/contents can’t be submitted together.
65 |
# File 'lib/telnyx/models/fax_create_params.rb', line 65 optional :media_url, String |
#monochrome ⇒ Boolean?
The flag to enable monochrome, true black and white fax results.
71 |
# File 'lib/telnyx/models/fax_create_params.rb', line 71 optional :monochrome, Telnyx::Internal::Type::Boolean |
#preview_format ⇒ Symbol, ...
The format for the preview file in case the ‘store_preview` is `true`.
77 |
# File 'lib/telnyx/models/fax_create_params.rb', line 77 optional :preview_format, enum: -> { Telnyx::FaxCreateParams::PreviewFormat } |
#quality ⇒ Symbol, ...
The quality of the fax. The ‘ultra` settings provides the highest quality available, but also present longer fax processing times. `ultra_light` is best suited for images, wihle `ultra_dark` is best suited for text.
85 |
# File 'lib/telnyx/models/fax_create_params.rb', line 85 optional :quality, enum: -> { Telnyx::FaxCreateParams::Quality } |
#store_media ⇒ Boolean?
Should fax media be stored on temporary URL. It does not support media_name, they can’t be submitted together.
92 |
# File 'lib/telnyx/models/fax_create_params.rb', line 92 optional :store_media, Telnyx::Internal::Type::Boolean |
#store_preview ⇒ Boolean?
Should fax preview be stored on temporary URL.
98 |
# File 'lib/telnyx/models/fax_create_params.rb', line 98 optional :store_preview, Telnyx::Internal::Type::Boolean |
#t38_enabled ⇒ Boolean?
The flag to disable the T.38 protocol.
104 |
# File 'lib/telnyx/models/fax_create_params.rb', line 104 optional :t38_enabled, Telnyx::Internal::Type::Boolean |
#to ⇒ String
The phone number, in E.164 format, the fax will be sent to or SIP URI
26 |
# File 'lib/telnyx/models/fax_create_params.rb', line 26 required :to, String |
#webhook_url ⇒ String?
Use this field to override the URL to which Telnyx will send subsequent webhooks for this fax.
111 |
# File 'lib/telnyx/models/fax_create_params.rb', line 111 optional :webhook_url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/fax_create_params.rb', line 156
|