Class: Telnyx::Models::FaxListParams::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FaxListParams::Filter
- Defined in:
- lib/telnyx/models/fax_list_params.rb,
sig/telnyx/models/fax_list_params.rbs
Defined Under Namespace
Classes: CreatedAt, Direction, From, To
Instance Attribute Summary collapse
-
#created_at ⇒ Telnyx::Models::FaxListParams::Filter::CreatedAt?
Date range filtering operations for fax creation timestamp.
-
#direction ⇒ Telnyx::Models::FaxListParams::Filter::Direction?
Direction filtering operations.
-
#from ⇒ Telnyx::Models::FaxListParams::Filter::From?
From number filtering operations.
-
#to ⇒ Telnyx::Models::FaxListParams::Filter::To?
To number filtering operations.
Instance Method Summary collapse
-
#initialize(eq: nil) ⇒ Object
constructor
From number filtering operations.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(eq: nil) ⇒ Object
From number filtering operations
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/telnyx/models/fax_list_params.rb', line 40 class Filter < Telnyx::Internal::Type::BaseModel # @!attribute created_at # Date range filtering operations for fax creation timestamp # # @return [Telnyx::Models::FaxListParams::Filter::CreatedAt, nil] optional :created_at, -> { Telnyx::FaxListParams::Filter::CreatedAt } # @!attribute direction # Direction filtering operations # # @return [Telnyx::Models::FaxListParams::Filter::Direction, nil] optional :direction, -> { Telnyx::FaxListParams::Filter::Direction } # @!attribute from # From number filtering operations # # @return [Telnyx::Models::FaxListParams::Filter::From, nil] optional :from, -> { Telnyx::FaxListParams::Filter::From } # @!attribute to # To number filtering operations # # @return [Telnyx::Models::FaxListParams::Filter::To, nil] optional :to, -> { Telnyx::FaxListParams::Filter::To } # @!method initialize(created_at: nil, direction: nil, from: nil, to: nil) # Consolidated filter parameter (deepObject style). Originally: # filter[created_at][gte], filter[created_at][gt], filter[created_at][lte], # filter[created_at][lt], filter[direction][eq], filter[from][eq], filter[to][eq] # # @param created_at [Telnyx::Models::FaxListParams::Filter::CreatedAt] Date range filtering operations for fax creation timestamp # # @param direction [Telnyx::Models::FaxListParams::Filter::Direction] Direction filtering operations # # @param from [Telnyx::Models::FaxListParams::Filter::From] From number filtering operations # # @param to [Telnyx::Models::FaxListParams::Filter::To] To number filtering operations # @see Telnyx::Models::FaxListParams::Filter#created_at class CreatedAt < Telnyx::Internal::Type::BaseModel # @!attribute gt # ISO 8601 date time for filtering faxes created after that date # # @return [Time, nil] optional :gt, Time # @!attribute gte # ISO 8601 date time for filtering faxes created after or on that date # # @return [Time, nil] optional :gte, Time # @!attribute lt # ISO 8601 formatted date time for filtering faxes created before that date # # @return [Time, nil] optional :lt, Time # @!attribute lte # ISO 8601 formatted date time for filtering faxes created on or before that date # # @return [Time, nil] optional :lte, Time # @!method initialize(gt: nil, gte: nil, lt: nil, lte: nil) # Date range filtering operations for fax creation timestamp # # @param gt [Time] ISO 8601 date time for filtering faxes created after that date # # @param gte [Time] ISO 8601 date time for filtering faxes created after or on that date # # @param lt [Time] ISO 8601 formatted date time for filtering faxes created before that date # # @param lte [Time] ISO 8601 formatted date time for filtering faxes created on or before that date end # @see Telnyx::Models::FaxListParams::Filter#direction class Direction < Telnyx::Internal::Type::BaseModel # @!attribute eq # The direction, inbound or outbound, for filtering faxes sent from this account # # @return [String, nil] optional :eq, String # @!method initialize(eq: nil) # Direction filtering operations # # @param eq [String] The direction, inbound or outbound, for filtering faxes sent from this account end # @see Telnyx::Models::FaxListParams::Filter#from class From < Telnyx::Internal::Type::BaseModel # @!attribute eq # The phone number, in E.164 format for filtering faxes sent from this number # # @return [String, nil] optional :eq, String # @!method initialize(eq: nil) # From number filtering operations # # @param eq [String] The phone number, in E.164 format for filtering faxes sent from this number end # @see Telnyx::Models::FaxListParams::Filter#to class To < Telnyx::Internal::Type::BaseModel # @!attribute eq # The phone number, in E.164 format for filtering faxes sent to this number # # @return [String, nil] optional :eq, String # @!method initialize(eq: nil) # To number filtering operations # # @param eq [String] The phone number, in E.164 format for filtering faxes sent to this number end end |
Instance Attribute Details
#created_at ⇒ Telnyx::Models::FaxListParams::Filter::CreatedAt?
Date range filtering operations for fax creation timestamp
45 |
# File 'lib/telnyx/models/fax_list_params.rb', line 45 optional :created_at, -> { Telnyx::FaxListParams::Filter::CreatedAt } |
#direction ⇒ Telnyx::Models::FaxListParams::Filter::Direction?
Direction filtering operations
51 |
# File 'lib/telnyx/models/fax_list_params.rb', line 51 optional :direction, -> { Telnyx::FaxListParams::Filter::Direction } |
#from ⇒ Telnyx::Models::FaxListParams::Filter::From?
From number filtering operations
57 |
# File 'lib/telnyx/models/fax_list_params.rb', line 57 optional :from, -> { Telnyx::FaxListParams::Filter::From } |
#to ⇒ Telnyx::Models::FaxListParams::Filter::To?
To number filtering operations
63 |
# File 'lib/telnyx/models/fax_list_params.rb', line 63 optional :to, -> { Telnyx::FaxListParams::Filter::To } |
Instance Method Details
#to_hash ⇒ {
83 |
# File 'sig/telnyx/models/fax_list_params.rbs', line 83 def to_hash: -> { |