Class: Telnyx::Models::Fqdn
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Fqdn
- Defined in:
- lib/telnyx/models/fqdn.rb
Overview
Instance Attribute Summary collapse
-
#connection_id ⇒ String?
ID of the FQDN connection to which this FQDN is attached.
-
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
-
#dns_record_type ⇒ String?
The DNS record type for the FQDN.
-
#fqdn ⇒ String?
FQDN represented by this resource.
-
#id ⇒ String?
Identifies the resource.
-
#port ⇒ Integer?
Port to use when connecting to this FQDN.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
Instance Method Summary collapse
-
#initialize(id: nil, connection_id: nil, created_at: nil, dns_record_type: nil, fqdn: nil, port: nil, record_type: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Fqdn for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, connection_id: nil, created_at: nil, dns_record_type: nil, fqdn: nil, port: nil, record_type: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Fqdn for more details.
|
|
# File 'lib/telnyx/models/fqdn.rb', line 58
|
Instance Attribute Details
#connection_id ⇒ String?
ID of the FQDN connection to which this FQDN is attached.
17 |
# File 'lib/telnyx/models/fqdn.rb', line 17 optional :connection_id, String |
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
23 |
# File 'lib/telnyx/models/fqdn.rb', line 23 optional :created_at, String |
#dns_record_type ⇒ String?
The DNS record type for the FQDN. For cases where a port is not set, the DNS record type must be ‘srv’. For cases where a port is set, the DNS record type must be ‘a’. If the DNS record type is ‘a’ and a port is not specified, 5060 will be used.
32 |
# File 'lib/telnyx/models/fqdn.rb', line 32 optional :dns_record_type, String |
#fqdn ⇒ String?
FQDN represented by this resource.
38 |
# File 'lib/telnyx/models/fqdn.rb', line 38 optional :fqdn, String |
#id ⇒ String?
Identifies the resource.
11 |
# File 'lib/telnyx/models/fqdn.rb', line 11 optional :id, String |
#port ⇒ Integer?
Port to use when connecting to this FQDN.
44 |
# File 'lib/telnyx/models/fqdn.rb', line 44 optional :port, Integer |
#record_type ⇒ String?
Identifies the type of the resource.
50 |
# File 'lib/telnyx/models/fqdn.rb', line 50 optional :record_type, String |
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
56 |
# File 'lib/telnyx/models/fqdn.rb', line 56 optional :updated_at, String |