Class: Telnyx::Models::FqdnConnection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FqdnConnection
- Defined in:
- lib/telnyx/models/fqdn_connection.rb,
sig/telnyx/models/fqdn_connection.rbs
Overview
Constant Summary collapse
- Telnyx =
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Defaults to true.
-
#adjust_dtmf_timestamp ⇒ Boolean?
Indicates whether DTMF timestamp adjustment is enabled.
-
#anchorsite_override ⇒ Symbol, ...
Latencydirects Telnyx to route media through the site with the lowest round-trip time to the user's connection. -
#android_push_credential_id ⇒ String?
The uuid of the push credential for Android.
-
#call_cost_enabled ⇒ Boolean?
Indicates whether call cost calculation is enabled.
-
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this connection.
-
#connection_name ⇒ String
A user-assigned name to help manage the connection.
-
#conversation_persistence ⇒ Boolean?
Whether conversation persistence is enabled for this connection.
-
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
-
#default_on_hold_comfort_noise_enabled ⇒ Boolean?
When enabled, Telnyx will generate comfort noise when you place the call on hold.
-
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection.
-
#encode_contact_header_enabled ⇒ Boolean?
Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.
-
#encrypted_media ⇒ Symbol, ...
Enable use of SRTP for encryption.
-
#id ⇒ String?
Identifies the resource.
-
#ignore_dtmf_duration ⇒ Boolean?
Indicates whether DTMF duration should be ignored.
-
#ignore_mark_bit ⇒ Boolean?
Indicates whether the mark bit should be ignored.
- #inbound ⇒ Telnyx::Models::InboundFqdn?
-
#ios_push_credential_id ⇒ String?
The uuid of the push credential for Ios.
-
#jitter_buffer ⇒ Telnyx::Models::ConnectionJitterBuffer?
Configuration options for Jitter Buffer.
-
#microsoft_teams_sbc ⇒ Boolean?
The connection is enabled for Microsoft Teams Direct Routing.
-
#noise_suppression ⇒ Symbol, ...
Controls when noise suppression is applied to calls.
-
#noise_suppression_details ⇒ Telnyx::Models::ConnectionNoiseSuppressionDetails?
Configuration options for noise suppression.
-
#onnet_t38_passthrough_enabled ⇒ Boolean?
Enable on-net T38 if you prefer that the sender and receiver negotiate T38 directly when both are on the Telnyx network.
- #outbound ⇒ Telnyx::Models::OutboundFqdn?
-
#password ⇒ String?
The password for the FQDN connection.
-
#record_type ⇒ String?
Identifies the type of the resource.
- #rtcp_settings ⇒ Telnyx::Models::ConnectionRtcpSettings?
-
#rtp_pass_codecs_on_stream_change ⇒ Boolean?
Defines if codecs should be passed on stream change.
-
#send_normalized_timestamps ⇒ Boolean?
Indicates whether normalized timestamps should be sent.
-
#tags ⇒ Array<String>?
Tags associated with the connection.
-
#third_party_control_enabled ⇒ Boolean?
Indicates whether third-party control is enabled.
-
#transport_protocol ⇒ Symbol, ...
One of UDP, TLS, or TCP.
-
#txt_name ⇒ String?
The name for the TXT record associated with the FQDN connection.
-
#txt_ttl ⇒ Integer?
The time to live for the TXT record associated with the FQDN connection.
-
#txt_value ⇒ String?
The value for the TXT record associated with the FQDN connection.
-
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
-
#user_name ⇒ String?
The username for the FQDN connection.
-
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Instance Method Summary collapse
-
#initialize(connection_name:, id: nil, active: nil, adjust_dtmf_timestamp: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_enabled: nil, call_cost_in_webhooks: nil, conversation_persistence: nil, created_at: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, ignore_dtmf_duration: nil, ignore_mark_bit: nil, inbound: nil, ios_push_credential_id: nil, jitter_buffer: nil, microsoft_teams_sbc: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, password: nil, record_type: nil, rtcp_settings: nil, rtp_pass_codecs_on_stream_change: nil, send_normalized_timestamps: nil, tags: nil, third_party_control_enabled: nil, transport_protocol: nil, txt_name: nil, txt_ttl: nil, txt_value: nil, updated_at: nil, user_name: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see FqdnConnection for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_name:, id: nil, active: nil, adjust_dtmf_timestamp: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_enabled: nil, call_cost_in_webhooks: nil, conversation_persistence: nil, created_at: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, ignore_dtmf_duration: nil, ignore_mark_bit: nil, inbound: nil, ios_push_credential_id: nil, jitter_buffer: nil, microsoft_teams_sbc: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, password: nil, record_type: nil, rtcp_settings: nil, rtp_pass_codecs_on_stream_change: nil, send_normalized_timestamps: nil, tags: nil, third_party_control_enabled: nil, transport_protocol: nil, txt_name: nil, txt_ttl: nil, txt_value: nil, updated_at: nil, user_name: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::FqdnConnection for more details.
|
|
# File 'lib/telnyx/models/fqdn_connection.rb', line 274
|
Instance Attribute Details
#active ⇒ Boolean?
Defaults to true
23 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 23 optional :active, Telnyx::Internal::Type::Boolean |
#adjust_dtmf_timestamp ⇒ Boolean?
Indicates whether DTMF timestamp adjustment is enabled.
29 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 29 optional :adjust_dtmf_timestamp, Telnyx::Internal::Type::Boolean |
#anchorsite_override ⇒ Symbol, ...
Latency directs Telnyx to route media through the site with the lowest
round-trip time to the user's connection. Telnyx calculates this time using ICMP
ping messages. This can be disabled by specifying a site to handle all media.
37 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 37 optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride } |
#android_push_credential_id ⇒ String?
The uuid of the push credential for Android
43 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 43 optional :android_push_credential_id, String, nil?: true |
#call_cost_enabled ⇒ Boolean?
Indicates whether call cost calculation is enabled.
49 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 49 optional :call_cost_enabled, Telnyx::Internal::Type::Boolean |
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this connection.
55 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 55 optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean |
#connection_name ⇒ String
A user-assigned name to help manage the connection.
11 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 11 required :connection_name, String |
#conversation_persistence ⇒ Boolean?
Whether conversation persistence is enabled for this connection. When enabled, calls handled by the connection are transcribed, stored, and indexed. Defaults to false.
63 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 63 optional :conversation_persistence, Telnyx::Internal::Type::Boolean |
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
69 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 69 optional :created_at, String |
#default_on_hold_comfort_noise_enabled ⇒ Boolean?
When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.
77 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 77 optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean |
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.
84 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 84 optional :dtmf_type, enum: -> { Telnyx::DtmfType } |
#encode_contact_header_enabled ⇒ Boolean?
Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.
91 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 91 optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean |
#encrypted_media ⇒ Symbol, ...
Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.
98 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 98 optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true |
#id ⇒ String?
Identifies the resource.
17 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 17 optional :id, String |
#ignore_dtmf_duration ⇒ Boolean?
Indicates whether DTMF duration should be ignored.
104 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 104 optional :ignore_dtmf_duration, Telnyx::Internal::Type::Boolean |
#ignore_mark_bit ⇒ Boolean?
Indicates whether the mark bit should be ignored.
110 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 110 optional :ignore_mark_bit, Telnyx::Internal::Type::Boolean |
#inbound ⇒ Telnyx::Models::InboundFqdn?
115 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 115 optional :inbound, -> { Telnyx::InboundFqdn } |
#ios_push_credential_id ⇒ String?
The uuid of the push credential for Ios
121 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 121 optional :ios_push_credential_id, String, nil?: true |
#jitter_buffer ⇒ Telnyx::Models::ConnectionJitterBuffer?
Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.
131 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 131 optional :jitter_buffer, -> { Telnyx::ConnectionJitterBuffer } |
#microsoft_teams_sbc ⇒ Boolean?
The connection is enabled for Microsoft Teams Direct Routing.
137 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 137 optional :microsoft_teams_sbc, Telnyx::Internal::Type::Boolean |
#noise_suppression ⇒ Symbol, ...
Controls when noise suppression is applied to calls. When set to 'inbound', noise suppression is applied to incoming audio. When set to 'outbound', it's applied to outgoing audio. When set to 'both', it's applied in both directions. When set to 'disabled', noise suppression is turned off.
146 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 146 optional :noise_suppression, enum: -> { Telnyx::ConnectionNoiseSuppression } |
#noise_suppression_details ⇒ Telnyx::Models::ConnectionNoiseSuppressionDetails?
Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not 'disabled'. If you disable noise suppression and later re-enable it, the previously configured settings will be used.
155 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 155 optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails } |
#onnet_t38_passthrough_enabled ⇒ Boolean?
Enable on-net T38 if you prefer that the sender and receiver negotiate T38 directly when both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call according to each leg's settings.
163 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 163 optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean |
#outbound ⇒ Telnyx::Models::OutboundFqdn?
168 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 168 optional :outbound, -> { Telnyx::OutboundFqdn } |
#password ⇒ String?
The password for the FQDN connection.
174 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 174 optional :password, String |
#record_type ⇒ String?
Identifies the type of the resource.
180 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 180 optional :record_type, String |
#rtcp_settings ⇒ Telnyx::Models::ConnectionRtcpSettings?
185 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 185 optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings } |
#rtp_pass_codecs_on_stream_change ⇒ Boolean?
Defines if codecs should be passed on stream change.
191 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 191 optional :rtp_pass_codecs_on_stream_change, Telnyx::Internal::Type::Boolean |
#send_normalized_timestamps ⇒ Boolean?
Indicates whether normalized timestamps should be sent.
197 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 197 optional :send_normalized_timestamps, Telnyx::Internal::Type::Boolean |
#tags ⇒ Array<String>?
Tags associated with the connection.
203 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 203 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#third_party_control_enabled ⇒ Boolean?
Indicates whether third-party control is enabled.
209 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 209 optional :third_party_control_enabled, Telnyx::Internal::Type::Boolean |
#transport_protocol ⇒ Symbol, ...
One of UDP, TLS, or TCP. Applies only to connections with IP authentication or FQDN authentication.
216 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 216 optional :transport_protocol, enum: -> { Telnyx::TransportProtocol } |
#txt_name ⇒ String?
The name for the TXT record associated with the FQDN connection.
222 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 222 optional :txt_name, String |
#txt_ttl ⇒ Integer?
The time to live for the TXT record associated with the FQDN connection.
228 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 228 optional :txt_ttl, Integer |
#txt_value ⇒ String?
The value for the TXT record associated with the FQDN connection.
234 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 234 optional :txt_value, String |
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
240 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 240 optional :updated_at, String |
#user_name ⇒ String?
The username for the FQDN connection.
246 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 246 optional :user_name, String |
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
252 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 252 optional :webhook_api_version, enum: -> { Telnyx::WebhookAPIVersion } |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as 'https'.
259 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 259 optional :webhook_event_failover_url, String, nil?: true |
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent. Must include a scheme, such as 'https'.
266 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 266 optional :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
272 |
# File 'lib/telnyx/models/fqdn_connection.rb', line 272 optional :webhook_timeout_secs, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ {
259 |
# File 'sig/telnyx/models/fqdn_connection.rbs', line 259
def to_hash: -> {
|