Class: Telnyx::Models::FqdnConnection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/fqdn_connection.rb

Overview

Defined Under Namespace

Modules: NoiseSuppression Classes: JitterBuffer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enable_jitter_buffer: nil, jitterbuffer_msec_max: nil, jitterbuffer_msec_min: nil) ⇒ Object

Some parameter documentations has been truncated, see JitterBuffer for more details.

Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.

Parameters:

  • enable_jitter_buffer (Boolean) (defaults to: nil)

    Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off

  • jitterbuffer_msec_max (Integer) (defaults to: nil)

    The maximum jitter buffer size in milliseconds. Must be between 40 and 400. Has

  • jitterbuffer_msec_min (Integer) (defaults to: nil)

    The minimum jitter buffer size in milliseconds. Must be between 40 and 400. Has



# File 'lib/telnyx/models/fqdn_connection.rb', line 266

Instance Attribute Details

#activeBoolean?

Defaults to true

Returns:

  • (Boolean, nil)


23
# File 'lib/telnyx/models/fqdn_connection.rb', line 23

optional :active, Telnyx::Internal::Type::Boolean

#adjust_dtmf_timestampBoolean?

Indicates whether DTMF timestamp adjustment is enabled.

Returns:

  • (Boolean, nil)


29
# File 'lib/telnyx/models/fqdn_connection.rb', line 29

optional :adjust_dtmf_timestamp, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



37
# File 'lib/telnyx/models/fqdn_connection.rb', line 37

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#android_push_credential_idString?

The uuid of the push credential for Android

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/fqdn_connection.rb', line 43

optional :android_push_credential_id, String, nil?: true

#call_cost_enabledBoolean?

Indicates whether call cost calculation is enabled.

Returns:

  • (Boolean, nil)


49
# File 'lib/telnyx/models/fqdn_connection.rb', line 49

optional :call_cost_enabled, Telnyx::Internal::Type::Boolean

#call_cost_in_webhooksBoolean?

Specifies if call cost webhooks should be sent for this connection.

Returns:

  • (Boolean, nil)


55
# File 'lib/telnyx/models/fqdn_connection.rb', line 55

optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean

#connection_nameString

A user-assigned name to help manage the connection.

Returns:

  • (String)


11
# File 'lib/telnyx/models/fqdn_connection.rb', line 11

required :connection_name, String

#created_atString?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


61
# File 'lib/telnyx/models/fqdn_connection.rb', line 61

optional :created_at, String

#default_on_hold_comfort_noise_enabledBoolean?

When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.

Returns:

  • (Boolean, nil)


69
# File 'lib/telnyx/models/fqdn_connection.rb', line 69

optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean

#dtmf_typeSymbol, ...

Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.

Returns:



76
# File 'lib/telnyx/models/fqdn_connection.rb', line 76

optional :dtmf_type, enum: -> { Telnyx::DtmfType }

#encode_contact_header_enabledBoolean?

Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.

Returns:

  • (Boolean, nil)


83
# File 'lib/telnyx/models/fqdn_connection.rb', line 83

optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean

#encrypted_mediaSymbol, ...

Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.

Returns:



90
# File 'lib/telnyx/models/fqdn_connection.rb', line 90

optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true

#idString?

Identifies the resource.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/fqdn_connection.rb', line 17

optional :id, String

#ignore_dtmf_durationBoolean?

Indicates whether DTMF duration should be ignored.

Returns:

  • (Boolean, nil)


96
# File 'lib/telnyx/models/fqdn_connection.rb', line 96

optional :ignore_dtmf_duration, Telnyx::Internal::Type::Boolean

#ignore_mark_bitBoolean?

Indicates whether the mark bit should be ignored.

Returns:

  • (Boolean, nil)


102
# File 'lib/telnyx/models/fqdn_connection.rb', line 102

optional :ignore_mark_bit, Telnyx::Internal::Type::Boolean

#inboundTelnyx::Models::InboundFqdn?

Returns:



107
# File 'lib/telnyx/models/fqdn_connection.rb', line 107

optional :inbound, -> { Telnyx::InboundFqdn }

#ios_push_credential_idString?

The uuid of the push credential for Ios

Returns:

  • (String, nil)


113
# File 'lib/telnyx/models/fqdn_connection.rb', line 113

optional :ios_push_credential_id, String, nil?: true

#jitter_bufferTelnyx::Models::FqdnConnection::JitterBuffer?

Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.



123
# File 'lib/telnyx/models/fqdn_connection.rb', line 123

optional :jitter_buffer, -> { Telnyx::FqdnConnection::JitterBuffer }

#microsoft_teams_sbcBoolean?

The connection is enabled for Microsoft Teams Direct Routing.

Returns:

  • (Boolean, nil)


129
# File 'lib/telnyx/models/fqdn_connection.rb', line 129

optional :microsoft_teams_sbc, Telnyx::Internal::Type::Boolean

#noise_suppressionSymbol, ...

Controls when noise suppression is applied to calls. When set to ‘inbound’, noise suppression is applied to incoming audio. When set to ‘outbound’, it’s applied to outgoing audio. When set to ‘both’, it’s applied in both directions. When set to ‘disabled’, noise suppression is turned off.



138
# File 'lib/telnyx/models/fqdn_connection.rb', line 138

optional :noise_suppression, enum: -> { Telnyx::FqdnConnection::NoiseSuppression }

#noise_suppression_detailsTelnyx::Models::ConnectionNoiseSuppressionDetails?

Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not ‘disabled’. If you disable noise suppression and later re-enable it, the previously configured settings will be used.



147
# File 'lib/telnyx/models/fqdn_connection.rb', line 147

optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails }

#onnet_t38_passthrough_enabledBoolean?

Enable on-net T38 if you prefer that the sender and receiver negotiate T38 directly when both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call according to each leg’s settings.

Returns:

  • (Boolean, nil)


155
# File 'lib/telnyx/models/fqdn_connection.rb', line 155

optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean

#outboundTelnyx::Models::OutboundFqdn?



160
# File 'lib/telnyx/models/fqdn_connection.rb', line 160

optional :outbound, -> { Telnyx::OutboundFqdn }

#passwordString?

The password for the FQDN connection.

Returns:

  • (String, nil)


166
# File 'lib/telnyx/models/fqdn_connection.rb', line 166

optional :password, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


172
# File 'lib/telnyx/models/fqdn_connection.rb', line 172

optional :record_type, String

#rtcp_settingsTelnyx::Models::ConnectionRtcpSettings?



177
# File 'lib/telnyx/models/fqdn_connection.rb', line 177

optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings }

#rtp_pass_codecs_on_stream_changeBoolean?

Defines if codecs should be passed on stream change.

Returns:

  • (Boolean, nil)


183
# File 'lib/telnyx/models/fqdn_connection.rb', line 183

optional :rtp_pass_codecs_on_stream_change, Telnyx::Internal::Type::Boolean

#send_normalized_timestampsBoolean?

Indicates whether normalized timestamps should be sent.

Returns:

  • (Boolean, nil)


189
# File 'lib/telnyx/models/fqdn_connection.rb', line 189

optional :send_normalized_timestamps, Telnyx::Internal::Type::Boolean

#tagsArray<String>?

Tags associated with the connection.

Returns:

  • (Array<String>, nil)


195
# File 'lib/telnyx/models/fqdn_connection.rb', line 195

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#third_party_control_enabledBoolean?

Indicates whether third-party control is enabled.

Returns:

  • (Boolean, nil)


201
# File 'lib/telnyx/models/fqdn_connection.rb', line 201

optional :third_party_control_enabled, Telnyx::Internal::Type::Boolean

#transport_protocolSymbol, ...

One of UDP, TLS, or TCP. Applies only to connections with IP authentication or FQDN authentication.

Returns:



208
# File 'lib/telnyx/models/fqdn_connection.rb', line 208

optional :transport_protocol, enum: -> { Telnyx::TransportProtocol }

#txt_nameString?

The name for the TXT record associated with the FQDN connection.

Returns:

  • (String, nil)


214
# File 'lib/telnyx/models/fqdn_connection.rb', line 214

optional :txt_name, String

#txt_ttlInteger?

The time to live for the TXT record associated with the FQDN connection.

Returns:

  • (Integer, nil)


220
# File 'lib/telnyx/models/fqdn_connection.rb', line 220

optional :txt_ttl, Integer

#txt_valueString?

The value for the TXT record associated with the FQDN connection.

Returns:

  • (String, nil)


226
# File 'lib/telnyx/models/fqdn_connection.rb', line 226

optional :txt_value, String

#updated_atString?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (String, nil)


232
# File 'lib/telnyx/models/fqdn_connection.rb', line 232

optional :updated_at, String

#user_nameString?

The username for the FQDN connection.

Returns:

  • (String, nil)


238
# File 'lib/telnyx/models/fqdn_connection.rb', line 238

optional :user_name, String

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1 or v2.

Returns:



244
# File 'lib/telnyx/models/fqdn_connection.rb', line 244

optional :webhook_api_version, enum: -> { Telnyx::WebhookAPIVersion }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


251
# File 'lib/telnyx/models/fqdn_connection.rb', line 251

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


258
# File 'lib/telnyx/models/fqdn_connection.rb', line 258

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


264
# File 'lib/telnyx/models/fqdn_connection.rb', line 264

optional :webhook_timeout_secs, Integer, nil?: true