Class: Telnyx::Models::FqdnConnectionUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/fqdn_connection_update_params.rb

Overview

Defined Under Namespace

Modules: NoiseSuppression

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, active: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_in_webhooks: nil, connection_name: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, inbound: nil, ios_push_credential_id: nil, jitter_buffer: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, rtcp_settings: nil, tags: nil, transport_protocol: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::FqdnConnectionUpdateParams for more details.

Parameters:

  • id (String)
  • active (Boolean) (defaults to: nil)

    Defaults to true

  • anchorsite_override (Symbol, Telnyx::Models::AnchorsiteOverride) (defaults to: nil)

    ‘Latency` directs Telnyx to route media through the site with the lowest round-t

  • android_push_credential_id (String, nil) (defaults to: nil)

    The uuid of the push credential for Android

  • call_cost_in_webhooks (Boolean) (defaults to: nil)

    Specifies if call cost webhooks should be sent for this connection.

  • connection_name (String) (defaults to: nil)

    A user-assigned name to help manage the connection.

  • default_on_hold_comfort_noise_enabled (Boolean) (defaults to: nil)

    When enabled, Telnyx will generate comfort noise when you place the call on hold

  • dtmf_type (Symbol, Telnyx::Models::DtmfType) (defaults to: nil)

    Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF

  • encode_contact_header_enabled (Boolean) (defaults to: nil)

    Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scen

  • encrypted_media (Symbol, Telnyx::Models::EncryptedMedia, nil) (defaults to: nil)

    Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TL

  • inbound (Telnyx::Models::InboundFqdn) (defaults to: nil)
  • ios_push_credential_id (String, nil) (defaults to: nil)

    The uuid of the push credential for Ios

  • jitter_buffer (Telnyx::Models::ConnectionJitterBuffer) (defaults to: nil)

    Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams o

  • noise_suppression (Symbol, Telnyx::Models::FqdnConnectionUpdateParams::NoiseSuppression) (defaults to: nil)

    Controls when noise suppression is applied to calls. When set to ‘inbound’, nois

  • noise_suppression_details (Telnyx::Models::ConnectionNoiseSuppressionDetails) (defaults to: nil)

    Configuration options for noise suppression. These settings are stored regardles

  • onnet_t38_passthrough_enabled (Boolean) (defaults to: nil)

    Enable on-net T38 if you prefer that the sender and receiver negotiate T38 direc

  • outbound (Telnyx::Models::OutboundFqdn) (defaults to: nil)
  • rtcp_settings (Telnyx::Models::ConnectionRtcpSettings) (defaults to: nil)
  • tags (Array<String>) (defaults to: nil)

    Tags associated with the connection.

  • transport_protocol (Symbol, Telnyx::Models::TransportProtocol) (defaults to: nil)

    One of UDP, TLS, or TCP. Applies only to connections with IP authentication or F

  • webhook_api_version (Symbol, Telnyx::Models::WebhookAPIVersion) (defaults to: nil)

    Determines which webhook format will be used, Telnyx API v1 or v2.

  • webhook_event_failover_url (String, nil) (defaults to: nil)

    The failover URL where webhooks related to this connection will be sent if sendi

  • webhook_event_url (String) (defaults to: nil)

    The URL where webhooks related to this connection will be sent. Must include a s

  • webhook_timeout_secs (Integer, nil) (defaults to: nil)

    Specifies how many seconds to wait before timing out a webhook.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 172

Instance Attribute Details

#activeBoolean?

Defaults to true

Returns:

  • (Boolean, nil)


19
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 19

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



27
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 27

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#android_push_credential_idString?

The uuid of the push credential for Android

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 33

optional :android_push_credential_id, String, nil?: true

#call_cost_in_webhooksBoolean?

Specifies if call cost webhooks should be sent for this connection.

Returns:

  • (Boolean, nil)


39
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 39

optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean

#connection_nameString?

A user-assigned name to help manage the connection.

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 45

optional :connection_name, String

#default_on_hold_comfort_noise_enabledBoolean?

When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.

Returns:

  • (Boolean, nil)


53
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 53

optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean

#dtmf_typeSymbol, ...

Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.

Returns:



60
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 60

optional :dtmf_type, enum: -> { Telnyx::DtmfType }

#encode_contact_header_enabledBoolean?

Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.

Returns:

  • (Boolean, nil)


67
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 67

optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean

#encrypted_mediaSymbol, ...

Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.

Returns:



74
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 74

optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 13

required :id, String

#inboundTelnyx::Models::InboundFqdn?

Returns:



79
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 79

optional :inbound, -> { Telnyx::InboundFqdn }

#ios_push_credential_idString?

The uuid of the push credential for Ios

Returns:

  • (String, nil)


85
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 85

optional :ios_push_credential_id, String, nil?: true

#jitter_bufferTelnyx::Models::ConnectionJitterBuffer?

Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.



95
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 95

optional :jitter_buffer, -> { Telnyx::ConnectionJitterBuffer }

#noise_suppressionSymbol, ...

Controls when noise suppression is applied to calls. When set to ‘inbound’, noise suppression is applied to incoming audio. When set to ‘outbound’, it’s applied to outgoing audio. When set to ‘both’, it’s applied in both directions. When set to ‘disabled’, noise suppression is turned off.



104
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 104

optional :noise_suppression, enum: -> { Telnyx::FqdnConnectionUpdateParams::NoiseSuppression }

#noise_suppression_detailsTelnyx::Models::ConnectionNoiseSuppressionDetails?

Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not ‘disabled’. If you disable noise suppression and later re-enable it, the previously configured settings will be used.



113
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 113

optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails }

#onnet_t38_passthrough_enabledBoolean?

Enable on-net T38 if you prefer that the sender and receiver negotiate T38 directly when both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call according to each leg’s settings.

Returns:

  • (Boolean, nil)


121
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 121

optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean

#outboundTelnyx::Models::OutboundFqdn?



126
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 126

optional :outbound, -> { Telnyx::OutboundFqdn }

#rtcp_settingsTelnyx::Models::ConnectionRtcpSettings?



131
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 131

optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings }

#tagsArray<String>?

Tags associated with the connection.

Returns:

  • (Array<String>, nil)


137
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 137

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#transport_protocolSymbol, ...

One of UDP, TLS, or TCP. Applies only to connections with IP authentication or FQDN authentication.

Returns:



144
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 144

optional :transport_protocol, enum: -> { Telnyx::TransportProtocol }

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1 or v2.

Returns:



150
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 150

optional :webhook_api_version, enum: -> { Telnyx::WebhookAPIVersion }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


157
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 157

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


164
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 164

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


170
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 170

optional :webhook_timeout_secs, Integer, nil?: true