Class: Telnyx::Models::FqdnConnectionUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/fqdn_connection_update_params.rb

Overview

Defined Under Namespace

Modules: NoiseSuppression Classes: JitterBuffer

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enable_jitter_buffer: nil, jitterbuffer_msec_max: nil, jitterbuffer_msec_min: nil) ⇒ Object

Some parameter documentations has been truncated, see JitterBuffer for more details.

Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.

Parameters:

  • enable_jitter_buffer (Boolean) (defaults to: nil)

    Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off

  • jitterbuffer_msec_max (Integer) (defaults to: nil)

    The maximum jitter buffer size in milliseconds. Must be between 40 and 400. Has

  • jitterbuffer_msec_min (Integer) (defaults to: nil)

    The minimum jitter buffer size in milliseconds. Must be between 40 and 400. Has



# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 241

Instance Attribute Details

#activeBoolean?

Defaults to true

Returns:

  • (Boolean, nil)


14
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 14

optional :active, Telnyx::Internal::Type::Boolean

#anchorsite_overrideSymbol, ...

‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.

Returns:



22
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 22

optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride }

#android_push_credential_idString?

The uuid of the push credential for Android

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 28

optional :android_push_credential_id, String, nil?: true

#call_cost_in_webhooksBoolean?

Specifies if call cost webhooks should be sent for this connection.

Returns:

  • (Boolean, nil)


34
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 34

optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean

#connection_nameString?

A user-assigned name to help manage the connection.

Returns:

  • (String, nil)


40
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 40

optional :connection_name, String

#default_on_hold_comfort_noise_enabledBoolean?

When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.

Returns:

  • (Boolean, nil)


48
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 48

optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean

#dtmf_typeSymbol, ...

Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.

Returns:



55
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 55

optional :dtmf_type, enum: -> { Telnyx::DtmfType }

#encode_contact_header_enabledBoolean?

Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.

Returns:

  • (Boolean, nil)


62
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 62

optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean

#encrypted_mediaSymbol, ...

Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.

Returns:



69
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 69

optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true

#inboundTelnyx::Models::InboundFqdn?

Returns:



74
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 74

optional :inbound, -> { Telnyx::InboundFqdn }

#ios_push_credential_idString?

The uuid of the push credential for Ios

Returns:

  • (String, nil)


80
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 80

optional :ios_push_credential_id, String, nil?: true

#jitter_bufferTelnyx::Models::FqdnConnectionUpdateParams::JitterBuffer?

Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.



90
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 90

optional :jitter_buffer, -> { Telnyx::FqdnConnectionUpdateParams::JitterBuffer }

#noise_suppressionSymbol, ...

Controls when noise suppression is applied to calls. When set to ‘inbound’, noise suppression is applied to incoming audio. When set to ‘outbound’, it’s applied to outgoing audio. When set to ‘both’, it’s applied in both directions. When set to ‘disabled’, noise suppression is turned off.



99
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 99

optional :noise_suppression, enum: -> { Telnyx::FqdnConnectionUpdateParams::NoiseSuppression }

#noise_suppression_detailsTelnyx::Models::ConnectionNoiseSuppressionDetails?

Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not ‘disabled’. If you disable noise suppression and later re-enable it, the previously configured settings will be used.



108
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 108

optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails }

#onnet_t38_passthrough_enabledBoolean?

Enable on-net T38 if you prefer that the sender and receiver negotiate T38 directly when both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call according to each leg’s settings.

Returns:

  • (Boolean, nil)


116
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 116

optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean

#outboundTelnyx::Models::OutboundFqdn?



121
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 121

optional :outbound, -> { Telnyx::OutboundFqdn }

#rtcp_settingsTelnyx::Models::ConnectionRtcpSettings?



126
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 126

optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings }

#tagsArray<String>?

Tags associated with the connection.

Returns:

  • (Array<String>, nil)


132
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 132

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

#transport_protocolSymbol, ...

One of UDP, TLS, or TCP. Applies only to connections with IP authentication or FQDN authentication.

Returns:



139
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 139

optional :transport_protocol, enum: -> { Telnyx::TransportProtocol }

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1 or v2.

Returns:



145
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 145

optional :webhook_api_version, enum: -> { Telnyx::WebhookAPIVersion }

#webhook_event_failover_urlString?

The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


152
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 152

optional :webhook_event_failover_url, String, nil?: true

#webhook_event_urlString?

The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.

Returns:

  • (String, nil)


159
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 159

optional :webhook_event_url, String

#webhook_timeout_secsInteger?

Specifies how many seconds to wait before timing out a webhook.

Returns:

  • (Integer, nil)


165
# File 'lib/telnyx/models/fqdn_connection_update_params.rb', line 165

optional :webhook_timeout_secs, Integer, nil?: true