Class: Telnyx::Models::FqdnCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FqdnCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/fqdn_create_params.rb
Overview
Instance Attribute Summary collapse
-
#connection_id ⇒ String
ID of the FQDN connection to which this IP should be attached.
-
#dns_record_type ⇒ String
The DNS record type for the FQDN.
-
#fqdn ⇒ String
FQDN represented by this resource.
-
#port ⇒ Integer?
Port to use when connecting to this FQDN.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(connection_id:, dns_record_type:, fqdn:, port: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FqdnCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_id:, dns_record_type:, fqdn:, port: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::FqdnCreateParams for more details.
|
|
# File 'lib/telnyx/models/fqdn_create_params.rb', line 37
|
Instance Attribute Details
#connection_id ⇒ String
ID of the FQDN connection to which this IP should be attached.
14 |
# File 'lib/telnyx/models/fqdn_create_params.rb', line 14 required :connection_id, String |
#dns_record_type ⇒ String
The DNS record type for the FQDN. For cases where a port is not set, the DNS record type must be ‘srv’. For cases where a port is set, the DNS record type must be ‘a’. If the DNS record type is ‘a’ and a port is not specified, 5060 will be used.
23 |
# File 'lib/telnyx/models/fqdn_create_params.rb', line 23 required :dns_record_type, String |
#fqdn ⇒ String
FQDN represented by this resource.
29 |
# File 'lib/telnyx/models/fqdn_create_params.rb', line 29 required :fqdn, String |
#port ⇒ Integer?
Port to use when connecting to this FQDN.
35 |
# File 'lib/telnyx/models/fqdn_create_params.rb', line 35 optional :port, Integer, nil?: true |