Class: Telnyx::Models::FqdnUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::FqdnUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/fqdn_update_params.rb
Overview
Instance Attribute Summary collapse
-
#connection_id ⇒ String?
ID of the FQDN connection to which this IP should be attached.
-
#dns_record_type ⇒ String?
The DNS record type for the FQDN.
-
#fqdn ⇒ String?
FQDN represented by this resource.
- #id ⇒ String
-
#port ⇒ Integer?
Port to use when connecting to this FQDN.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, connection_id: nil, dns_record_type: nil, fqdn: nil, port: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FqdnUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, connection_id: nil, dns_record_type: nil, fqdn: nil, port: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::FqdnUpdateParams for more details.
|
|
# File 'lib/telnyx/models/fqdn_update_params.rb', line 42
|
Instance Attribute Details
#connection_id ⇒ String?
ID of the FQDN connection to which this IP should be attached.
19 |
# File 'lib/telnyx/models/fqdn_update_params.rb', line 19 optional :connection_id, String |
#dns_record_type ⇒ String?
The DNS record type for the FQDN. For cases where a port is not set, the DNS record type must be ‘srv’. For cases where a port is set, the DNS record type must be ‘a’. If the DNS record type is ‘a’ and a port is not specified, 5060 will be used.
28 |
# File 'lib/telnyx/models/fqdn_update_params.rb', line 28 optional :dns_record_type, String |
#fqdn ⇒ String?
FQDN represented by this resource.
34 |
# File 'lib/telnyx/models/fqdn_update_params.rb', line 34 optional :fqdn, String |
#id ⇒ String
13 |
# File 'lib/telnyx/models/fqdn_update_params.rb', line 13 required :id, String |
#port ⇒ Integer?
Port to use when connecting to this FQDN.
40 |
# File 'lib/telnyx/models/fqdn_update_params.rb', line 40 optional :port, Integer, nil?: true |