Class: Telnyx::Models::HostedNumberOrderEventWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/hosted_number_order_event_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Modules: EventType, RecordType Classes: Payload

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, event_type: nil, occurred_at: nil, payload: nil, record_type: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::HostedNumberOrderEventWebhookEvent::Data for more details.

‘approval*

Parameters:



# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 49

Instance Attribute Details

#event_typeSymbol, ...

The type of event being delivered. Internal transfer events are only emitted for orders where the numbers are already active on another Telnyx account.



27
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 27

optional :event_type, enum: -> { Telnyx::HostedNumberOrderEventWebhookEvent::Data::EventType }

#idString?

Unique identifier for the event.

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 20

optional :id, String

#occurred_atTime?

ISO 8601 formatted date indicating when the event was generated.

Returns:

  • (Time, nil)


33
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 33

optional :occurred_at, Time

#payloadTelnyx::Models::HostedNumberOrderEventWebhookEvent::Data::Payload?

Payload delivered with every messaging*hosted_numbers_orders.* event. ‘approval_deadline` and `decision` are meaningful only for `internal_transfer**` events.



41
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 41

optional :payload, -> { Telnyx::HostedNumberOrderEventWebhookEvent::Data::Payload }

#record_typeSymbol, ...

Identifies the type of the resource.



47
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 47

optional :record_type, enum: -> { Telnyx::HostedNumberOrderEventWebhookEvent::Data::RecordType }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 85