Class: Telnyx::Models::HostedNumberOrderEventWebhookEvent::Data::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::HostedNumberOrderEventWebhookEvent::Data::Payload
- Defined in:
- lib/telnyx/models/hosted_number_order_event_webhook_event.rb
Overview
Defined Under Namespace
Modules: Decision, OrderStatus Classes: Number
Instance Attribute Summary collapse
-
#approval_deadline ⇒ Integer?
Unix timestamp (seconds) by which the losing organization must respond before auto-approval.
-
#decision ⇒ Symbol, ...
Approval decision for the internal transfer.
- #numbers ⇒ Array<Telnyx::Models::HostedNumberOrderEventWebhookEvent::Data::Payload::Number>?
-
#order_id ⇒ String?
The ID of the hosted number order.
-
#order_status ⇒ Symbol, ...
Current status of the order.
-
#profile_id ⇒ String?
The messaging profile associated with the order.
-
#user_id ⇒ String?
The organization that owns the order.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(approval_deadline: nil, decision: nil, numbers: nil, order_id: nil, order_status: nil, profile_id: nil, user_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(approval_deadline: nil, decision: nil, numbers: nil, order_id: nil, order_status: nil, profile_id: nil, user_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::HostedNumberOrderEventWebhookEvent::Data::Payload for more details.
Payload delivered with every messaging*hosted_numbers_orders.* event. ‘approval_deadline` and `decision` are meaningful only for `internal_transfer**` events.
|
|
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 137
|
Instance Attribute Details
#approval_deadline ⇒ Integer?
Unix timestamp (seconds) by which the losing organization must respond before auto-approval. Populated on internal-transfer events once an approval window has been issued.
97 |
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 97 optional :approval_deadline, Integer, nil?: true |
#decision ⇒ Symbol, ...
Approval decision for the internal transfer. Defaults to ‘pending` for non-internal-transfer events.
104 |
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 104 optional :decision, enum: -> { Telnyx::HostedNumberOrderEventWebhookEvent::Data::Payload::Decision } |
#numbers ⇒ Array<Telnyx::Models::HostedNumberOrderEventWebhookEvent::Data::Payload::Number>?
109 110 |
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 109 optional :numbers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::HostedNumberOrderEventWebhookEvent::Data::Payload::Number] } |
#order_id ⇒ String?
The ID of the hosted number order.
116 |
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 116 optional :order_id, String |
#order_status ⇒ Symbol, ...
Current status of the order.
122 123 |
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 122 optional :order_status, enum: -> { Telnyx::HostedNumberOrderEventWebhookEvent::Data::Payload::OrderStatus } |
#profile_id ⇒ String?
The messaging profile associated with the order.
129 |
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 129 optional :profile_id, String |
#user_id ⇒ String?
The organization that owns the order.
135 |
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 135 optional :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/hosted_number_order_event_webhook_event.rb', line 171
|