Class: Telnyx::Models::InboundIP
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::InboundIP
- Defined in:
- lib/telnyx/models/inbound_ip.rb
Defined Under Namespace
Modules: AniNumberFormat, DefaultRoutingMethod, DnisNumberFormat, SipRegion, SipSubdomainReceiveSettings
Instance Attribute Summary collapse
-
#ani_number_format ⇒ Symbol, ...
This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.
-
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
-
#codecs ⇒ Array<String>?
Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order.
-
#default_primary_ip_id ⇒ String?
The default primary IP to use for the number.
-
#default_routing_method ⇒ Symbol, ...
Default routing method to be used when a number is associated with the connection.
-
#default_secondary_ip_id ⇒ String?
The default secondary IP to use for the number.
-
#default_tertiary_ip_id ⇒ String?
The default tertiary IP to use for the number.
- #dnis_number_format ⇒ Symbol, ...
-
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
-
#isup_headers_enabled ⇒ Boolean?
When set, inbound phone calls will receive ISUP parameters via SIP headers.
-
#prack_enabled ⇒ Boolean?
Enable PRACK messages as defined in RFC3262.
-
#shaken_stir_enabled ⇒ Boolean?
When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.
-
#sip_compact_headers_enabled ⇒ Boolean?
Defaults to true.
-
#sip_region ⇒ Symbol, ...
Selects which ‘sip_region` to receive inbound calls from.
-
#sip_subdomain ⇒ String?
Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint.
-
#sip_subdomain_receive_settings ⇒ Symbol, ...
This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).
-
#timeout_1xx_secs ⇒ Integer?
Time(sec) before aborting if connection is not made.
-
#timeout_2xx_secs ⇒ Integer?
Time(sec) before aborting if call is unanswered (min: 1, max: 600).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_primary_ip_id: nil, default_routing_method: nil, default_secondary_ip_id: nil, default_tertiary_ip_id: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, sip_compact_headers_enabled: nil, sip_region: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see InboundIP for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_primary_ip_id: nil, default_routing_method: nil, default_secondary_ip_id: nil, default_tertiary_ip_id: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, sip_compact_headers_enabled: nil, sip_region: nil, sip_subdomain: nil, sip_subdomain_receive_settings: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::InboundIP for more details.
|
|
# File 'lib/telnyx/models/inbound_ip.rb', line 137
|
Instance Attribute Details
#ani_number_format ⇒ Symbol, ...
This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.
11 |
# File 'lib/telnyx/models/inbound_ip.rb', line 11 optional :ani_number_format, enum: -> { Telnyx::InboundIP::AniNumberFormat } |
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
18 |
# File 'lib/telnyx/models/inbound_ip.rb', line 18 optional :channel_limit, Integer |
#codecs ⇒ Array<String>?
Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order. This only works when the Connection the number is assigned to uses Media Handling mode: default. OPUS and H.264 codecs are available only when using TCP or TLS transport for SIP.
27 |
# File 'lib/telnyx/models/inbound_ip.rb', line 27 optional :codecs, Telnyx::Internal::Type::ArrayOf[String] |
#default_primary_ip_id ⇒ String?
The default primary IP to use for the number. Only settable if the connection is of IP authentication type. Value must be the ID of an authorized IP set on the connection.
35 |
# File 'lib/telnyx/models/inbound_ip.rb', line 35 optional :default_primary_ip_id, String |
#default_routing_method ⇒ Symbol, ...
Default routing method to be used when a number is associated with the connection. Must be one of the routing method types or left blank, other values are not allowed.
43 |
# File 'lib/telnyx/models/inbound_ip.rb', line 43 optional :default_routing_method, enum: -> { Telnyx::InboundIP::DefaultRoutingMethod } |
#default_secondary_ip_id ⇒ String?
The default secondary IP to use for the number. Only settable if the connection is of IP authentication type. Value must be the ID of an authorized IP set on the connection.
51 |
# File 'lib/telnyx/models/inbound_ip.rb', line 51 optional :default_secondary_ip_id, String |
#default_tertiary_ip_id ⇒ String?
The default tertiary IP to use for the number. Only settable if the connection is of IP authentication type. Value must be the ID of an authorized IP set on the connection.
59 |
# File 'lib/telnyx/models/inbound_ip.rb', line 59 optional :default_tertiary_ip_id, String |
#dnis_number_format ⇒ Symbol, ...
64 |
# File 'lib/telnyx/models/inbound_ip.rb', line 64 optional :dnis_number_format, enum: -> { Telnyx::InboundIP::DnisNumberFormat } |
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
70 |
# File 'lib/telnyx/models/inbound_ip.rb', line 70 optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean |
#isup_headers_enabled ⇒ Boolean?
When set, inbound phone calls will receive ISUP parameters via SIP headers. (Only when available and only when using TCP or TLS transport.)
77 |
# File 'lib/telnyx/models/inbound_ip.rb', line 77 optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean |
#prack_enabled ⇒ Boolean?
Enable PRACK messages as defined in RFC3262.
83 |
# File 'lib/telnyx/models/inbound_ip.rb', line 83 optional :prack_enabled, Telnyx::Internal::Type::Boolean |
#shaken_stir_enabled ⇒ Boolean?
When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.
91 |
# File 'lib/telnyx/models/inbound_ip.rb', line 91 optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean |
#sip_compact_headers_enabled ⇒ Boolean?
Defaults to true.
97 |
# File 'lib/telnyx/models/inbound_ip.rb', line 97 optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean |
#sip_region ⇒ Symbol, ...
Selects which ‘sip_region` to receive inbound calls from. If null, the default region (US) will be used.
104 |
# File 'lib/telnyx/models/inbound_ip.rb', line 104 optional :sip_region, enum: -> { Telnyx::InboundIP::SipRegion } |
#sip_subdomain ⇒ String?
Specifies a subdomain that can be used to receive Inbound calls to a Connection, in the same way a phone number is used, from a SIP endpoint. Example: the subdomain “example.sip.telnyx.com” can be called from any SIP endpoint by using the SIP URI “sip:@example.sip.telnyx.com” where the user part can be any alphanumeric value. Please note TLS encrypted calls are not allowed for subdomain calls.
115 |
# File 'lib/telnyx/models/inbound_ip.rb', line 115 optional :sip_subdomain, String |
#sip_subdomain_receive_settings ⇒ Symbol, ...
This option can be enabled to receive calls from: “Anyone” (any SIP endpoint in the public Internet) or “Only my connections” (any connection assigned to the same Telnyx user).
123 |
# File 'lib/telnyx/models/inbound_ip.rb', line 123 optional :sip_subdomain_receive_settings, enum: -> { Telnyx::InboundIP::SipSubdomainReceiveSettings } |
#timeout_1xx_secs ⇒ Integer?
Time(sec) before aborting if connection is not made.
129 |
# File 'lib/telnyx/models/inbound_ip.rb', line 129 optional :timeout_1xx_secs, Integer |
#timeout_2xx_secs ⇒ Integer?
Time(sec) before aborting if call is unanswered (min: 1, max: 600).
135 |
# File 'lib/telnyx/models/inbound_ip.rb', line 135 optional :timeout_2xx_secs, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/inbound_ip.rb', line 189
|