Class: Telnyx::Models::InboundMessageWebhookEvent::Data::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::InboundMessageWebhookEvent::Data::Payload
- Defined in:
- lib/telnyx/models/inbound_message_webhook_event.rb,
sig/telnyx/models/inbound_message_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Direction, RecordType, Type Classes: Cc, Cost, CostBreakdown, From, Media, To
Instance Attribute Summary collapse
- #cc ⇒ Array<Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::Cc>?
-
#completed_at ⇒ Time?
Not used for inbound messages.
- #cost ⇒ Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::Cost?
-
#cost_breakdown ⇒ Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::CostBreakdown?
Detailed breakdown of the message cost components.
-
#direction ⇒ Symbol, ...
The direction of the message.
-
#encoding ⇒ String?
Encoding scheme used for the message body.
-
#errors ⇒ Array<Telnyx::Models::MessagingError0b38e7044b>?
These errors may point at addressees when referring to unsuccessful/unconfirmed delivery statuses.
- #from ⇒ Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::From?
-
#id ⇒ String?
Identifies the type of resource.
- #media ⇒ Array<Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::Media>?
-
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
-
#num_chars ⇒ Integer?
The number of characters in the message text.
-
#organization_id ⇒ String?
Unique identifier for a messaging profile.
-
#parts ⇒ Integer?
Number of parts into which the message's body must be split.
-
#received_at ⇒ Time?
ISO 8601 formatted date indicating when the message request was received.
-
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
-
#sent_at ⇒ Time?
Not used for inbound messages.
-
#subject ⇒ String?
Message subject.
-
#tags ⇒ Array<String>?
Tags associated with the resource.
-
#tcr_campaign_billable ⇒ Boolean?
Indicates whether the TCR campaign is billable.
-
#tcr_campaign_id ⇒ String?
The Campaign Registry (TCR) campaign ID associated with the message.
-
#tcr_campaign_registered ⇒ String?
The registration status of the TCR campaign.
-
#text ⇒ String?
Message body (i.e., content) as a non-empty string.
- #to ⇒ Array<Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::To>?
-
#type ⇒ Symbol, ...
The type of message.
-
#valid_until ⇒ Time?
Not used for inbound messages.
-
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.
-
#webhook_url ⇒ String?
The URL where webhooks related to this message will be sent.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(content_type: nil, hash_sha256: nil, size: nil, url: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_type: nil, hash_sha256: nil, size: nil, url: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 384
|
Instance Attribute Details
#cc ⇒ Array<Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::Cc>?
79 80 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 79 optional :cc, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::InboundMessageWebhookEvent::Data::Payload::Cc] } |
#completed_at ⇒ Time?
Not used for inbound messages.
86 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 86 optional :completed_at, Time, nil?: true |
#cost ⇒ Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::Cost?
91 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 91 optional :cost, -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::Cost }, nil?: true |
#cost_breakdown ⇒ Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::CostBreakdown?
Detailed breakdown of the message cost components.
97 98 99 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 97 optional :cost_breakdown, -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::CostBreakdown }, nil?: true |
#direction ⇒ Symbol, ...
The direction of the message. Inbound messages are sent to you whereas outbound messages are sent from you.
106 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 106 optional :direction, enum: -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::Direction } |
#encoding ⇒ String?
Encoding scheme used for the message body.
112 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 112 optional :encoding, String |
#errors ⇒ Array<Telnyx::Models::MessagingError0b38e7044b>?
These errors may point at addressees when referring to unsuccessful/unconfirmed delivery statuses.
119 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 119 optional :errors, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::MessagingError0b38e7044b] } |
#from ⇒ Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::From?
124 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 124 optional :from, -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::From } |
#id ⇒ String?
Identifies the type of resource.
74 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 74 optional :id, String |
#media ⇒ Array<Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::Media>?
129 130 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 129 optional :media, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::InboundMessageWebhookEvent::Data::Payload::Media] } |
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
136 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 136 optional :messaging_profile_id, String |
#num_chars ⇒ Integer?
The number of characters in the message text
142 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 142 optional :num_chars, Integer |
#organization_id ⇒ String?
Unique identifier for a messaging profile.
148 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 148 optional :organization_id, String |
#parts ⇒ Integer?
Number of parts into which the message's body must be split.
154 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 154 optional :parts, Integer |
#received_at ⇒ Time?
ISO 8601 formatted date indicating when the message request was received.
160 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 160 optional :received_at, Time |
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
166 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 166 optional :record_type, enum: -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::RecordType } |
#sent_at ⇒ Time?
Not used for inbound messages.
172 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 172 optional :sent_at, Time, nil?: true |
#subject ⇒ String?
Message subject.
178 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 178 optional :subject, String, nil?: true |
#tags ⇒ Array<String>?
Tags associated with the resource.
184 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 184 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#tcr_campaign_billable ⇒ Boolean?
Indicates whether the TCR campaign is billable.
190 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 190 optional :tcr_campaign_billable, Telnyx::Internal::Type::Boolean |
#tcr_campaign_id ⇒ String?
The Campaign Registry (TCR) campaign ID associated with the message.
196 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 196 optional :tcr_campaign_id, String, nil?: true |
#tcr_campaign_registered ⇒ String?
The registration status of the TCR campaign.
202 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 202 optional :tcr_campaign_registered, String, nil?: true |
#text ⇒ String?
Message body (i.e., content) as a non-empty string.
Required for SMS
210 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 210 optional :text, String |
#to ⇒ Array<Telnyx::Models::InboundMessageWebhookEvent::Data::Payload::To>?
215 216 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 215 optional :to, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::InboundMessageWebhookEvent::Data::Payload::To] } |
#type ⇒ Symbol, ...
The type of message. This value can be either 'sms' or 'mms'.
222 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 222 optional :type, enum: -> { Telnyx::InboundMessageWebhookEvent::Data::Payload::Type } |
#valid_until ⇒ Time?
Not used for inbound messages.
228 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 228 optional :valid_until, Time, nil?: true |
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.
235 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 235 optional :webhook_failover_url, String, nil?: true |
#webhook_url ⇒ String?
The URL where webhooks related to this message will be sent.
241 |
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 241 optional :webhook_url, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/inbound_message_webhook_event.rb', line 365
|
Instance Method Details
#to_hash ⇒ {
251 |
# File 'sig/telnyx/models/inbound_message_webhook_event.rbs', line 251
def to_hash: -> {
|