Class: Telnyx::Models::InexplicitNumberOrderCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::InexplicitNumberOrderCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/inexplicit_number_order_create_params.rb
Overview
Defined Under Namespace
Classes: OrderingGroup
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Billing group id to apply to phone numbers that are purchased.
-
#connection_id ⇒ String?
Connection id to apply to phone numbers that are purchased.
-
#customer_reference ⇒ String?
Reference label for the customer.
-
#messaging_profile_id ⇒ String?
Messaging profile id to apply to phone numbers that are purchased.
-
#ordering_groups ⇒ Array<Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup>
Group(s) of numbers to order.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#billing_group_id ⇒ String?
Billing group id to apply to phone numbers that are purchased
22 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 22 optional :billing_group_id, String |
#connection_id ⇒ String?
Connection id to apply to phone numbers that are purchased
28 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 28 optional :connection_id, String |
#customer_reference ⇒ String?
Reference label for the customer
34 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 34 optional :customer_reference, String |
#messaging_profile_id ⇒ String?
Messaging profile id to apply to phone numbers that are purchased
40 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 40 optional :messaging_profile_id, String |
#ordering_groups ⇒ Array<Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup>
Group(s) of numbers to order. You can have multiple ordering_groups objects added to a single request.
15 16 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 15 required :ordering_groups, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::InexplicitNumberOrderCreateParams::OrderingGroup] } |