Class: Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup
- Defined in:
- lib/telnyx/models/inexplicit_number_order_create_params.rb
Defined Under Namespace
Modules: CountryISO, Strategy Classes: PhoneNumber
Instance Attribute Summary collapse
-
#administrative_area ⇒ String?
Filter for phone numbers in a given state / province.
-
#count_requested ⇒ String
Quantity of phone numbers to order.
-
#country_iso ⇒ Symbol, Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::CountryISO
Country where you would like to purchase phone numbers.
-
#exclude_held_numbers ⇒ Boolean?
Filter to exclude phone numbers that are currently on hold/reserved for your account.
-
#features ⇒ Array<String>?
Filter for phone numbers that have the features to satisfy your use case (e.g., [“voice”]).
-
#locality ⇒ String?
Filter for phone numbers in a given city / region / rate center.
-
#national_destination_code ⇒ String?
Filter by area code.
-
#phone_number ⇒ Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::PhoneNumber?
Phone number search criteria.
-
#phone_number_type ⇒ String
Number type (local, toll-free, etc.).
-
#quickship ⇒ Boolean?
Filter to exclude phone numbers that need additional time after to purchase to activate.
-
#strategy ⇒ Symbol, ...
Ordering strategy.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(contains: nil, ends_with: nil, starts_with: nil) ⇒ Object
constructor
Phone number search criteria.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(contains: nil, ends_with: nil, starts_with: nil) ⇒ Object
Phone number search criteria
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 58 class OrderingGroup < Telnyx::Internal::Type::BaseModel # @!attribute count_requested # Quantity of phone numbers to order # # @return [String] required :count_requested, String # @!attribute country_iso # Country where you would like to purchase phone numbers. Allowable values: US, CA # # @return [Symbol, Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::CountryISO] required :country_iso, enum: -> { Telnyx::InexplicitNumberOrderCreateParams::OrderingGroup::CountryISO } # @!attribute phone_number_type # Number type (local, toll-free, etc.) # # @return [String] required :phone_number_type, String # @!attribute administrative_area # Filter for phone numbers in a given state / province # # @return [String, nil] optional :administrative_area, String # @!attribute exclude_held_numbers # Filter to exclude phone numbers that are currently on hold/reserved for your # account. # # @return [Boolean, nil] optional :exclude_held_numbers, Telnyx::Internal::Type::Boolean # @!attribute features # Filter for phone numbers that have the features to satisfy your use case (e.g., # ["voice"]) # # @return [Array<String>, nil] optional :features, Telnyx::Internal::Type::ArrayOf[String] # @!attribute locality # Filter for phone numbers in a given city / region / rate center # # @return [String, nil] optional :locality, String # @!attribute national_destination_code # Filter by area code # # @return [String, nil] optional :national_destination_code, String # @!attribute phone_number # Phone number search criteria # # @return [Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::PhoneNumber, nil] optional :phone_number, -> { Telnyx::InexplicitNumberOrderCreateParams::OrderingGroup::PhoneNumber } # @!attribute quickship # Filter to exclude phone numbers that need additional time after to purchase to # activate. Only applicable for +1 toll_free numbers. # # @return [Boolean, nil] optional :quickship, Telnyx::Internal::Type::Boolean # @!attribute strategy # Ordering strategy. Define what action should be taken if we don't have enough # phone numbers to fulfill your request. Allowable values are: always = proceed # with ordering phone numbers, regardless of current inventory levels; never = do # not place any orders unless there are enough phone numbers to satisfy the # request. If not specified, the always strategy will be enforced. # # @return [Symbol, Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::Strategy, nil] optional :strategy, enum: -> { Telnyx::InexplicitNumberOrderCreateParams::OrderingGroup::Strategy } # @!method initialize(count_requested:, country_iso:, phone_number_type:, administrative_area: nil, exclude_held_numbers: nil, features: nil, locality: nil, national_destination_code: nil, phone_number: nil, quickship: nil, strategy: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup} for more # details. # # @param count_requested [String] Quantity of phone numbers to order # # @param country_iso [Symbol, Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::CountryISO] Country where you would like to purchase phone numbers. Allowable values: US, CA # # @param phone_number_type [String] Number type (local, toll-free, etc.) # # @param administrative_area [String] Filter for phone numbers in a given state / province # # @param exclude_held_numbers [Boolean] Filter to exclude phone numbers that are currently on hold/reserved for your acc # # @param features [Array<String>] Filter for phone numbers that have the features to satisfy your use case (e.g., # # @param locality [String] Filter for phone numbers in a given city / region / rate center # # @param national_destination_code [String] Filter by area code # # @param phone_number [Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::PhoneNumber] Phone number search criteria # # @param quickship [Boolean] Filter to exclude phone numbers that need additional time after to purchase to a # # @param strategy [Symbol, Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::Strategy] Ordering strategy. Define what action should be taken if we don't have enough ph # Country where you would like to purchase phone numbers. Allowable values: US, CA # # @see Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup#country_iso module CountryISO extend Telnyx::Internal::Type::Enum US = :US CA = :CA # @!method self.values # @return [Array<Symbol>] end # @see Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup#phone_number class PhoneNumber < Telnyx::Internal::Type::BaseModel # @!attribute contains # Filter for phone numbers that contain the digits specified # # @return [String, nil] optional :contains, String # @!attribute ends_with # Filter by the ending digits of the phone number # # @return [String, nil] optional :ends_with, String # @!attribute starts_with # Filter by the starting digits of the phone number # # @return [String, nil] optional :starts_with, String # @!method initialize(contains: nil, ends_with: nil, starts_with: nil) # Phone number search criteria # # @param contains [String] Filter for phone numbers that contain the digits specified # # @param ends_with [String] Filter by the ending digits of the phone number # # @param starts_with [String] Filter by the starting digits of the phone number end # Ordering strategy. Define what action should be taken if we don't have enough # phone numbers to fulfill your request. Allowable values are: always = proceed # with ordering phone numbers, regardless of current inventory levels; never = do # not place any orders unless there are enough phone numbers to satisfy the # request. If not specified, the always strategy will be enforced. # # @see Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup#strategy module Strategy extend Telnyx::Internal::Type::Enum ALWAYS = :always NEVER = :never # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#administrative_area ⇒ String?
Filter for phone numbers in a given state / province
81 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 81 optional :administrative_area, String |
#count_requested ⇒ String
Quantity of phone numbers to order
63 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 63 required :count_requested, String |
#country_iso ⇒ Symbol, Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::CountryISO
Country where you would like to purchase phone numbers. Allowable values: US, CA
69 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 69 required :country_iso, enum: -> { Telnyx::InexplicitNumberOrderCreateParams::OrderingGroup::CountryISO } |
#exclude_held_numbers ⇒ Boolean?
Filter to exclude phone numbers that are currently on hold/reserved for your account.
88 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 88 optional :exclude_held_numbers, Telnyx::Internal::Type::Boolean |
#features ⇒ Array<String>?
Filter for phone numbers that have the features to satisfy your use case (e.g., [“voice”])
95 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 95 optional :features, Telnyx::Internal::Type::ArrayOf[String] |
#locality ⇒ String?
Filter for phone numbers in a given city / region / rate center
101 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 101 optional :locality, String |
#national_destination_code ⇒ String?
Filter by area code
107 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 107 optional :national_destination_code, String |
#phone_number ⇒ Telnyx::Models::InexplicitNumberOrderCreateParams::OrderingGroup::PhoneNumber?
Phone number search criteria
113 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 113 optional :phone_number, -> { Telnyx::InexplicitNumberOrderCreateParams::OrderingGroup::PhoneNumber } |
#phone_number_type ⇒ String
Number type (local, toll-free, etc.)
75 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 75 required :phone_number_type, String |
#quickship ⇒ Boolean?
Filter to exclude phone numbers that need additional time after to purchase to activate. Only applicable for +1 toll_free numbers.
120 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 120 optional :quickship, Telnyx::Internal::Type::Boolean |
#strategy ⇒ Symbol, ...
Ordering strategy. Define what action should be taken if we don’t have enough phone numbers to fulfill your request. Allowable values are: always = proceed with ordering phone numbers, regardless of current inventory levels; never = do not place any orders unless there are enough phone numbers to satisfy the request. If not specified, the always strategy will be enforced.
130 |
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 130 optional :strategy, enum: -> { Telnyx::InexplicitNumberOrderCreateParams::OrderingGroup::Strategy } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/inexplicit_number_order_create_params.rb', line 168
|