Class: Telnyx::Models::InexplicitNumberOrderResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::InexplicitNumberOrderResponse
- Defined in:
- lib/telnyx/models/inexplicit_number_order_response.rb
Overview
Defined Under Namespace
Classes: OrderingGroup
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Billing group id to apply to phone numbers that are purchased.
-
#connection_id ⇒ String?
Connection id to apply to phone numbers that are purchased.
-
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
-
#customer_reference ⇒ String?
Reference label for the customer.
-
#id ⇒ String?
Unique identifier for the inexplicit number order.
-
#messaging_profile_id ⇒ String?
Messaging profile id to apply to phone numbers that are purchased.
- #ordering_groups ⇒ Array<Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup>?
-
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#billing_group_id ⇒ String?
Billing group id to apply to phone numbers that are purchased
17 |
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 17 optional :billing_group_id, String |
#connection_id ⇒ String?
Connection id to apply to phone numbers that are purchased
23 |
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 23 optional :connection_id, String |
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created
29 |
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 29 optional :created_at, Time |
#customer_reference ⇒ String?
Reference label for the customer
35 |
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 35 optional :customer_reference, String |
#id ⇒ String?
Unique identifier for the inexplicit number order
11 |
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 11 optional :id, String |
#messaging_profile_id ⇒ String?
Messaging profile id to apply to phone numbers that are purchased
41 |
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 41 optional :messaging_profile_id, String |
#ordering_groups ⇒ Array<Telnyx::Models::InexplicitNumberOrderResponse::OrderingGroup>?
46 47 |
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 46 optional :ordering_groups, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::InexplicitNumberOrderResponse::OrderingGroup] } |
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated
53 |
# File 'lib/telnyx/models/inexplicit_number_order_response.rb', line 53 optional :updated_at, Time |