Class: Telnyx::Models::InfringementClaim
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::InfringementClaim
- Defined in:
- lib/telnyx/models/infringement_claim.rb,
sig/telnyx/models/infringement_claim.rbs
Defined Under Namespace
Modules: ClaimType, Resolution, Status Classes: ContestHistory, Dir
Instance Attribute Summary collapse
-
#claim_date ⇒ Time?
readonly
Returns the value of attribute claim_date.
- #claim_description ⇒ String?
-
#claim_type ⇒ Symbol, ...
Category of infringement being claimed.
- #claimant_contact ⇒ String?
- #claimant_name ⇒ String?
-
#contest_documents ⇒ Array<Telnyx::Models::Document>?
Aggregated across all customer contest submissions on this claim.
-
#contest_history ⇒ ::Array[Telnyx::InfringementClaim::ContestHistory]?
readonly
Returns the value of attribute contest_history.
-
#created_at ⇒ Time?
readonly
Returns the value of attribute created_at.
-
#dir ⇒ Telnyx::Models::InfringementClaim::Dir?
Snapshot of the DIR the claim is filed against, embedded for convenience.
- #dir_id ⇒ String?
- #enterprise_id ⇒ String?
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#resolution ⇒ Symbol, ...
Set only when
statusisresolved. -
#resolution_date ⇒ Time?
Returns the value of attribute resolution_date.
-
#resolution_notes ⇒ String?
Returns the value of attribute resolution_notes.
-
#status ⇒ Symbol, ...
Lifecycle status.
-
#updated_at ⇒ Time?
readonly
Returns the value of attribute updated_at.
Class Method Summary collapse
Instance Method Summary collapse
- #claim_date ⇒ Time readonly
- #contest_history ⇒ Object readonly
- #created_at ⇒ Time readonly
- #id ⇒ String readonly
-
#initialize(id: nil, display_name: nil, enterprise_id: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Dir for more details.
- #to_hash ⇒ {
- #updated_at ⇒ Time readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, display_name: nil, enterprise_id: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see Dir for more details.
Snapshot of the DIR the claim is filed against, embedded for convenience.
|
|
# File 'lib/telnyx/models/infringement_claim.rb', line 105
|
Instance Attribute Details
#claim_date ⇒ Time? (readonly)
Returns the value of attribute claim_date.
75 76 77 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 75 def claim_date @claim_date end |
#claim_description ⇒ String?
9 |
# File 'lib/telnyx/models/infringement_claim.rb', line 9 optional :claim_description, String |
#claim_type ⇒ Symbol, ...
Category of infringement being claimed.
15 |
# File 'lib/telnyx/models/infringement_claim.rb', line 15 optional :claim_type, enum: -> { Telnyx::InfringementClaim::ClaimType } |
#claimant_contact ⇒ String?
20 |
# File 'lib/telnyx/models/infringement_claim.rb', line 20 optional :claimant_contact, String |
#claimant_name ⇒ String?
25 |
# File 'lib/telnyx/models/infringement_claim.rb', line 25 optional :claimant_name, String |
#contest_documents ⇒ Array<Telnyx::Models::Document>?
Aggregated across all customer contest submissions on this claim.
31 |
# File 'lib/telnyx/models/infringement_claim.rb', line 31 optional :contest_documents, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Document] } |
#contest_history ⇒ ::Array[Telnyx::InfringementClaim::ContestHistory]? (readonly)
Returns the value of attribute contest_history.
79 80 81 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 79 def contest_history @contest_history end |
#created_at ⇒ Time? (readonly)
Returns the value of attribute created_at.
85 86 87 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 85 def created_at @created_at end |
#dir ⇒ Telnyx::Models::InfringementClaim::Dir?
Snapshot of the DIR the claim is filed against, embedded for convenience.
37 |
# File 'lib/telnyx/models/infringement_claim.rb', line 37 optional :dir, -> { Telnyx::InfringementClaim::Dir } |
#dir_id ⇒ String?
42 |
# File 'lib/telnyx/models/infringement_claim.rb', line 42 optional :dir_id, String |
#enterprise_id ⇒ String?
47 |
# File 'lib/telnyx/models/infringement_claim.rb', line 47 optional :enterprise_id, String |
#id ⇒ String? (readonly)
Returns the value of attribute id.
71 72 73 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 71 def id @id end |
#resolution ⇒ Symbol, ...
Set only when status is resolved.
53 |
# File 'lib/telnyx/models/infringement_claim.rb', line 53 optional :resolution, enum: -> { Telnyx::InfringementClaim::Resolution }, nil?: true |
#resolution_date ⇒ Time?
Returns the value of attribute resolution_date.
89 90 91 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 89 def resolution_date @resolution_date end |
#resolution_notes ⇒ String?
Returns the value of attribute resolution_notes.
91 92 93 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 91 def resolution_notes @resolution_notes end |
#status ⇒ Symbol, ...
Lifecycle status. pending - newly filed; the DIR is auto-suspended.
contested - you have submitted contest evidence; awaiting Telnyx review.
resolved - final.
61 |
# File 'lib/telnyx/models/infringement_claim.rb', line 61 optional :status, enum: -> { Telnyx::InfringementClaim::Status } |
#updated_at ⇒ Time? (readonly)
Returns the value of attribute updated_at.
93 94 95 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 93 def updated_at @updated_at end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/infringement_claim.rb', line 152
|
Instance Method Details
#claim_date= ⇒ Time (readonly)
77 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 77
def claim_date=: (Time) -> Time
|
#contest_history= ⇒ Object (readonly)
81 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 81
def contest_history=: (
|
#created_at= ⇒ Time (readonly)
87 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 87
def created_at=: (Time) -> Time
|
#id= ⇒ String (readonly)
73 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 73
def id=: (String) -> String
|
#to_hash ⇒ {
117 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 117
def to_hash: -> {
|
#updated_at= ⇒ Time (readonly)
95 |
# File 'sig/telnyx/models/infringement_claim.rbs', line 95
def updated_at=: (Time) -> Time
|