Class: Telnyx::Models::LedgerBillingGroupReport
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::LedgerBillingGroupReport
- Defined in:
- lib/telnyx/models/ledger_billing_group_report.rb
Defined Under Namespace
Modules: RecordType, Status
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
-
#id ⇒ String?
Identifies the type of resource.
-
#organization_id ⇒ String?
Uniquely identifies the organization that owns the resource.
-
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
-
#report_url ⇒ String?
External url of the ledger billing group report, if the status is complete.
-
#status ⇒ Symbol, ...
Status of the ledger billing group report.
-
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, organization_id: nil, record_type: nil, report_url: nil, status: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 48
|
Instance Attribute Details
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
16 |
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 16 optional :created_at, Time |
#id ⇒ String?
Identifies the type of resource.
10 |
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 10 optional :id, String |
#organization_id ⇒ String?
Uniquely identifies the organization that owns the resource.
22 |
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 22 optional :organization_id, String |
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
28 |
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 28 optional :record_type, enum: -> { Telnyx::LedgerBillingGroupReport::RecordType } |
#report_url ⇒ String?
External url of the ledger billing group report, if the status is complete
34 |
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 34 optional :report_url, String, nil?: true |
#status ⇒ Symbol, ...
Status of the ledger billing group report
40 |
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 40 optional :status, enum: -> { Telnyx::LedgerBillingGroupReport::Status } |
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
46 |
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 46 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ledger_billing_group_report.rb', line 71
|