Class: Telnyx::Models::Legacy::Reporting::BatchDetailRecords::VoiceRetrieveFieldsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Legacy::Reporting::BatchDetailRecords::VoiceRetrieveFieldsResponse
- Defined in:
- lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb
Overview
Instance Attribute Summary collapse
-
#billing ⇒ Array<String>?
Cost and billing related information.
-
#interaction_data ⇒ Array<String>?
Fields related to call interaction and basic call information.
-
#number_information ⇒ Array<String>?
Geographic and routing information for phone numbers.
-
#telephony_data ⇒ Array<String>?
Technical telephony and call control information.
Instance Method Summary collapse
-
#initialize(billing: nil, interaction_data: nil, number_information: nil, telephony_data: nil) ⇒ Object
constructor
Available CDR report fields grouped by category.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing: nil, interaction_data: nil, number_information: nil, telephony_data: nil) ⇒ Object
Available CDR report fields grouped by category
|
|
# File 'lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb', line 36
|
Instance Attribute Details
#billing ⇒ Array<String>?
Cost and billing related information
14 |
# File 'lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb', line 14 optional :billing, Telnyx::Internal::Type::ArrayOf[String], api_name: :Billing |
#interaction_data ⇒ Array<String>?
Fields related to call interaction and basic call information
20 |
# File 'lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb', line 20 optional :interaction_data, Telnyx::Internal::Type::ArrayOf[String], api_name: :"Interaction Data" |
#number_information ⇒ Array<String>?
Geographic and routing information for phone numbers
26 27 28 |
# File 'lib/telnyx/models/legacy/reporting/batch_detail_records/voice_retrieve_fields_response.rb', line 26 optional :number_information, Telnyx::Internal::Type::ArrayOf[String], api_name: :"Number Information" |