Class: Telnyx::Models::ManagedAccountCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ManagedAccountCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/managed_account_create_params.rb
Overview
Instance Attribute Summary collapse
-
#business_name ⇒ String
The name of the business for which the new managed account is being created, that will be used as the managed accounts’s organization’s name.
-
#email ⇒ String?
The email address for the managed account.
-
#managed_account_allow_custom_pricing ⇒ Boolean?
Boolean value that indicates if the managed account is able to have custom pricing set for it or not.
-
#password ⇒ String?
Password for the managed account.
-
#rollup_billing ⇒ Boolean?
Boolean value that indicates if the billing information and charges to the managed account “roll up” to the manager account.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(business_name:, email: nil, managed_account_allow_custom_pricing: nil, password: nil, rollup_billing: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ManagedAccountCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(business_name:, email: nil, managed_account_allow_custom_pricing: nil, password: nil, rollup_billing: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ManagedAccountCreateParams for more details.
|
|
# File 'lib/telnyx/models/managed_account_create_params.rb', line 52
|
Instance Attribute Details
#business_name ⇒ String
The name of the business for which the new managed account is being created, that will be used as the managed accounts’s organization’s name.
15 |
# File 'lib/telnyx/models/managed_account_create_params.rb', line 15 required :business_name, String |
#email ⇒ String?
The email address for the managed account. If not provided, the email address will be generated based on the email address of the manager account.
22 |
# File 'lib/telnyx/models/managed_account_create_params.rb', line 22 optional :email, String |
#managed_account_allow_custom_pricing ⇒ Boolean?
Boolean value that indicates if the managed account is able to have custom pricing set for it or not. If false, uses the pricing of the manager account. Defaults to false. This value may be changed after creation, but there may be time lag between when the value is changed and pricing changes take effect.
31 |
# File 'lib/telnyx/models/managed_account_create_params.rb', line 31 optional :managed_account_allow_custom_pricing, Telnyx::Internal::Type::Boolean |
#password ⇒ String?
Password for the managed account. If a password is not supplied, the account will not be able to be signed into directly. (A password reset may still be performed later to enable sign-in via password.)
39 |
# File 'lib/telnyx/models/managed_account_create_params.rb', line 39 optional :password, String |
#rollup_billing ⇒ Boolean?
Boolean value that indicates if the billing information and charges to the managed account “roll up” to the manager account. If true, the managed account will not have its own balance and will use the shared balance with the manager account. This value cannot be changed after account creation without going through Telnyx support as changes require manual updates to the account ledger. Defaults to false.
50 |
# File 'lib/telnyx/models/managed_account_create_params.rb', line 50 optional :rollup_billing, Telnyx::Internal::Type::Boolean |