Class: Telnyx::Models::ManagedAccountGetAllocatableGlobalOutboundChannelsResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ManagedAccountGetAllocatableGlobalOutboundChannelsResponse::Data
- Defined in:
- lib/telnyx/models/managed_account_get_allocatable_global_outbound_channels_response.rb
Overview
Instance Attribute Summary collapse
-
#allocatable_global_outbound_channels ⇒ Integer?
The total amount of allocatable global outbound channels available to the authenticated manager.
-
#managed_account_allow_custom_pricing ⇒ Boolean?
Boolean value that indicates if the managed account is able to have custom pricing set for it or not.
-
#record_type ⇒ String?
The type of the data contained in this record.
-
#total_global_channels_allocated ⇒ Integer?
The total number of allocatable global outbound channels currently allocated across all managed accounts for the authenticated user.
Instance Method Summary collapse
-
#initialize(allocatable_global_outbound_channels: nil, managed_account_allow_custom_pricing: nil, record_type: nil, total_global_channels_allocated: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocatable_global_outbound_channels: nil, managed_account_allow_custom_pricing: nil, record_type: nil, total_global_channels_allocated: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ManagedAccountGetAllocatableGlobalOutboundChannelsResponse::Data for more details.
|
|
# File 'lib/telnyx/models/managed_account_get_allocatable_global_outbound_channels_response.rb', line 49
|
Instance Attribute Details
#allocatable_global_outbound_channels ⇒ Integer?
The total amount of allocatable global outbound channels available to the authenticated manager. Will be 0 if the feature is not enabled for their account.
23 |
# File 'lib/telnyx/models/managed_account_get_allocatable_global_outbound_channels_response.rb', line 23 optional :allocatable_global_outbound_channels, Integer |
#managed_account_allow_custom_pricing ⇒ Boolean?
Boolean value that indicates if the managed account is able to have custom pricing set for it or not. If false, uses the pricing of the manager account. Defaults to false. This value may be changed, but there may be time lag between when the value is changed and pricing changes take effect.
32 |
# File 'lib/telnyx/models/managed_account_get_allocatable_global_outbound_channels_response.rb', line 32 optional :managed_account_allow_custom_pricing, Telnyx::Internal::Type::Boolean |
#record_type ⇒ String?
The type of the data contained in this record.
38 |
# File 'lib/telnyx/models/managed_account_get_allocatable_global_outbound_channels_response.rb', line 38 optional :record_type, String |
#total_global_channels_allocated ⇒ Integer?
The total number of allocatable global outbound channels currently allocated across all managed accounts for the authenticated user. This includes any amount of channels allocated by default at managed account creation time. Will be 0 if the feature is not enabled for their account.
47 |
# File 'lib/telnyx/models/managed_account_get_allocatable_global_outbound_channels_response.rb', line 47 optional :total_global_channels_allocated, Integer |