Class: Telnyx::Models::ManagedAccountListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ManagedAccountListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/managed_account_list_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#filter ⇒ Telnyx::Models::ManagedAccountListParams::Filter?
Consolidated filter parameter (deepObject style).
-
#include_cancelled_accounts ⇒ Boolean?
Specifies if cancelled accounts should be included in the results.
- #page_number ⇒ Integer?
- #page_size ⇒ Integer?
-
#sort ⇒ Symbol, ...
Specifies the sort order for results.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(contains: nil, eq: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Filter::OrganizationName for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(contains: nil, eq: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ManagedAccountListParams::Filter::OrganizationName for more details.
|
|
# File 'lib/telnyx/models/managed_account_list_params.rb', line 130
|
Instance Attribute Details
#filter ⇒ Telnyx::Models::ManagedAccountListParams::Filter?
16 |
# File 'lib/telnyx/models/managed_account_list_params.rb', line 16 optional :filter, -> { Telnyx::ManagedAccountListParams::Filter } |
#include_cancelled_accounts ⇒ Boolean?
Specifies if cancelled accounts should be included in the results.
22 |
# File 'lib/telnyx/models/managed_account_list_params.rb', line 22 optional :include_cancelled_accounts, Telnyx::Internal::Type::Boolean |
#page_number ⇒ Integer?
27 |
# File 'lib/telnyx/models/managed_account_list_params.rb', line 27 optional :page_number, Integer |
#page_size ⇒ Integer?
32 |
# File 'lib/telnyx/models/managed_account_list_params.rb', line 32 optional :page_size, Integer |
#sort ⇒ Symbol, ...
Specifies the sort order for results. By default sorting direction is ascending. To have the results sorted in descending order add the - prefix.<br/><br/> That is: <ul>
<li>
<code>email</code>: sorts the result by the
<code>email</code> field in ascending order.
</li>
<li>
<code>-email</code>: sorts the result by the
<code>email</code> field in descending order.
</li>
</ul> <br/> If not given, results are sorted by created_at in descending order.
51 |
# File 'lib/telnyx/models/managed_account_list_params.rb', line 51 optional :sort, enum: -> { Telnyx::ManagedAccountListParams::Sort } |