Class: Telnyx::Models::ManagedAccountListParams::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ManagedAccountListParams::Filter
- Defined in:
- lib/telnyx/models/managed_account_list_params.rb,
sig/telnyx/models/managed_account_list_params.rbs
Defined Under Namespace
Classes: Email, OrganizationName, Status
Instance Attribute Summary collapse
- #email ⇒ Telnyx::Models::ManagedAccountListParams::Filter::Email?
- #organization_name ⇒ Telnyx::Models::ManagedAccountListParams::Filter::OrganizationName?
- #status ⇒ Telnyx::Models::ManagedAccountListParams::Filter::Status?
Instance Method Summary collapse
-
#initialize(contains: nil, eq: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see OrganizationName for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(contains: nil, eq: nil) ⇒ Object
Some parameter documentations has been truncated, see OrganizationName for more details.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/telnyx/models/managed_account_list_params.rb', line 69 class Filter < Telnyx::Internal::Type::BaseModel # @!attribute email # # @return [Telnyx::Models::ManagedAccountListParams::Filter::Email, nil] optional :email, -> { Telnyx::ManagedAccountListParams::Filter::Email } # @!attribute organization_name # # @return [Telnyx::Models::ManagedAccountListParams::Filter::OrganizationName, nil] optional :organization_name, -> { Telnyx::ManagedAccountListParams::Filter::OrganizationName } # @!attribute status # # @return [Telnyx::Models::ManagedAccountListParams::Filter::Status, nil] optional :status, -> { Telnyx::ManagedAccountListParams::Filter::Status } # @!method initialize(email: nil, organization_name: nil, status: nil) # Consolidated filter parameter (deepObject style). Originally: # filter[email][contains], filter[email][eq], filter[organization_name][contains], # filter[organization_name][eq], filter[status][eq] # # @param email [Telnyx::Models::ManagedAccountListParams::Filter::Email] # @param organization_name [Telnyx::Models::ManagedAccountListParams::Filter::OrganizationName] # @param status [Telnyx::Models::ManagedAccountListParams::Filter::Status] # @see Telnyx::Models::ManagedAccountListParams::Filter#email class Email < Telnyx::Internal::Type::BaseModel # @!attribute contains # If present, email containing the given value will be returned. Matching is not # case-sensitive. Requires at least three characters. # # @return [String, nil] optional :contains, String # @!attribute eq # If present, only returns results with the <code>email</code> matching exactly # the value given. # # @return [String, nil] optional :eq, String # @!method initialize(contains: nil, eq: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::ManagedAccountListParams::Filter::Email} for more details. # # @param contains [String] If present, email containing the given value will be returned. Matching is not c # # @param eq [String] If present, only returns results with the <code>email</code> matching exactly th end # @see Telnyx::Models::ManagedAccountListParams::Filter#organization_name class OrganizationName < Telnyx::Internal::Type::BaseModel # @!attribute contains # If present, only returns results with the <code>organization_name</code> # containing the given value. Matching is not case-sensitive. Requires at least # three characters. # # @return [String, nil] optional :contains, String # @!attribute eq # If present, only returns results with the <code>organization_name</code> # matching exactly the value given. # # @return [String, nil] optional :eq, String # @!method initialize(contains: nil, eq: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::ManagedAccountListParams::Filter::OrganizationName} for more # details. # # @param contains [String] If present, only returns results with the <code>organization_name</code> contain # # @param eq [String] If present, only returns results with the <code>organization_name</code> matchin end # @see Telnyx::Models::ManagedAccountListParams::Filter#status class Status < Telnyx::Internal::Type::BaseModel # @!attribute eq # If present, only returns managed accounts with the <code>status</code> matching # exactly the value given. Use <code>enabled</code> or <code>disabled</code> to # filter accounts by whether they are currently able to use Telnyx services. # # @return [Symbol, Telnyx::Models::ManagedAccountListParams::Filter::Status::Eq, nil] optional :eq, enum: -> { Telnyx::ManagedAccountListParams::Filter::Status::Eq } # @!method initialize(eq: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::ManagedAccountListParams::Filter::Status} for more details. # # @param eq [Symbol, Telnyx::Models::ManagedAccountListParams::Filter::Status::Eq] If present, only returns managed accounts with the <code>status</code> matching # If present, only returns managed accounts with the <code>status</code> matching # exactly the value given. Use <code>enabled</code> or <code>disabled</code> to # filter accounts by whether they are currently able to use Telnyx services. # # @see Telnyx::Models::ManagedAccountListParams::Filter::Status#eq module Eq extend Telnyx::Internal::Type::Enum ALL = :all ACTIVE = :active ENABLED = :enabled CANCELLED = :cancelled DISABLED = :disabled BLOCKED = :blocked # @!method self.values # @return [Array<Symbol>] end end end |
Instance Attribute Details
#email ⇒ Telnyx::Models::ManagedAccountListParams::Filter::Email?
73 |
# File 'lib/telnyx/models/managed_account_list_params.rb', line 73 optional :email, -> { Telnyx::ManagedAccountListParams::Filter::Email } |
#organization_name ⇒ Telnyx::Models::ManagedAccountListParams::Filter::OrganizationName?
78 |
# File 'lib/telnyx/models/managed_account_list_params.rb', line 78 optional :organization_name, -> { Telnyx::ManagedAccountListParams::Filter::OrganizationName } |
#status ⇒ Telnyx::Models::ManagedAccountListParams::Filter::Status?
83 |
# File 'lib/telnyx/models/managed_account_list_params.rb', line 83 optional :status, -> { Telnyx::ManagedAccountListParams::Filter::Status } |
Instance Method Details
#to_hash ⇒ {
91 |
# File 'sig/telnyx/models/managed_account_list_params.rbs', line 91
def to_hash: -> {
|