Class: Telnyx::Models::ManagedAccountListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ManagedAccountListResponse
- Defined in:
- lib/telnyx/models/managed_account_list_response.rb
Overview
Defined Under Namespace
Modules: RecordType
Instance Attribute Summary collapse
-
#api_user ⇒ String
The manager account’s email, which serves as the V1 API user identifier.
-
#created_at ⇒ String
ISO 8601 formatted date indicating when the resource was created.
-
#email ⇒ String
The managed account’s email.
-
#id ⇒ String
Uniquely identifies the managed account.
-
#managed_account_allow_custom_pricing ⇒ Boolean?
Boolean value that indicates if the managed account is able to have custom pricing set for it or not.
-
#manager_account_id ⇒ String
The ID of the manager account associated with the managed account.
-
#organization_name ⇒ String?
The organization the managed account is associated with.
-
#record_type ⇒ Symbol, Telnyx::Models::ManagedAccountListResponse::RecordType
Identifies the type of the resource.
-
#rollup_billing ⇒ Boolean?
Boolean value that indicates if the billing information and charges to the managed account “roll up” to the manager account.
-
#updated_at ⇒ String
ISO 8601 formatted date indicating when the resource was updated.
Instance Method Summary collapse
-
#initialize(id:, api_user:, created_at:, email:, manager_account_id:, record_type:, updated_at:, managed_account_allow_custom_pricing: nil, organization_name: nil, rollup_billing: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ManagedAccountListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, api_user:, created_at:, email:, manager_account_id:, record_type:, updated_at:, managed_account_allow_custom_pricing: nil, organization_name: nil, rollup_billing: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ManagedAccountListResponse for more details.
|
|
# File 'lib/telnyx/models/managed_account_list_response.rb', line 75
|
Instance Attribute Details
#api_user ⇒ String
The manager account’s email, which serves as the V1 API user identifier
17 |
# File 'lib/telnyx/models/managed_account_list_response.rb', line 17 required :api_user, String |
#created_at ⇒ String
ISO 8601 formatted date indicating when the resource was created.
23 |
# File 'lib/telnyx/models/managed_account_list_response.rb', line 23 required :created_at, String |
#email ⇒ String
The managed account’s email.
29 |
# File 'lib/telnyx/models/managed_account_list_response.rb', line 29 required :email, String |
#id ⇒ String
Uniquely identifies the managed account.
11 |
# File 'lib/telnyx/models/managed_account_list_response.rb', line 11 required :id, String |
#managed_account_allow_custom_pricing ⇒ Boolean?
Boolean value that indicates if the managed account is able to have custom pricing set for it or not. If false, uses the pricing of the manager account. Defaults to false. There may be time lag between when the value is changed and pricing changes take effect.
56 |
# File 'lib/telnyx/models/managed_account_list_response.rb', line 56 optional :managed_account_allow_custom_pricing, Telnyx::Internal::Type::Boolean |
#manager_account_id ⇒ String
The ID of the manager account associated with the managed account.
35 |
# File 'lib/telnyx/models/managed_account_list_response.rb', line 35 required :manager_account_id, String |
#organization_name ⇒ String?
The organization the managed account is associated with.
62 |
# File 'lib/telnyx/models/managed_account_list_response.rb', line 62 optional :organization_name, String |
#record_type ⇒ Symbol, Telnyx::Models::ManagedAccountListResponse::RecordType
Identifies the type of the resource.
41 |
# File 'lib/telnyx/models/managed_account_list_response.rb', line 41 required :record_type, enum: -> { Telnyx::Models::ManagedAccountListResponse::RecordType } |
#rollup_billing ⇒ Boolean?
Boolean value that indicates if the billing information and charges to the managed account “roll up” to the manager account. If true, the managed account will not have its own balance and will use the shared balance with the manager account. This value cannot be changed after account creation without going through Telnyx support as changes require manual updates to the account ledger. Defaults to false.
73 |
# File 'lib/telnyx/models/managed_account_list_response.rb', line 73 optional :rollup_billing, Telnyx::Internal::Type::Boolean |
#updated_at ⇒ String
ISO 8601 formatted date indicating when the resource was updated.
47 |
# File 'lib/telnyx/models/managed_account_list_response.rb', line 47 required :updated_at, String |