Class: Telnyx::Models::ManagedAccountUpdateGlobalChannelLimitResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ManagedAccountUpdateGlobalChannelLimitResponse::Data
- Defined in:
- lib/telnyx/models/managed_account_update_global_channel_limit_response.rb
Overview
Instance Attribute Summary collapse
-
#channel_limit ⇒ Integer?
Integer value that indicates the number of allocatable global outbound channels that are allocated to the managed account.
-
#email ⇒ String?
The email of the managed account.
-
#id ⇒ String?
The user ID of the managed account.
-
#manager_account_id ⇒ String?
The user ID of the manager of the account.
-
#record_type ⇒ String?
The name of the type of data in the response.
Instance Method Summary collapse
-
#initialize(id: nil, channel_limit: nil, email: nil, manager_account_id: nil, record_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, channel_limit: nil, email: nil, manager_account_id: nil, record_type: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ManagedAccountUpdateGlobalChannelLimitResponse::Data for more details.
|
|
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 49
|
Instance Attribute Details
#channel_limit ⇒ Integer?
Integer value that indicates the number of allocatable global outbound channels that are allocated to the managed account. If the value is 0 then the account will have no usable channels and will not be able to perform outbound calling.
29 |
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 29 optional :channel_limit, Integer |
#email ⇒ String?
The email of the managed account.
35 |
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 35 optional :email, String |
#id ⇒ String?
The user ID of the managed account.
21 |
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 21 optional :id, String |
#manager_account_id ⇒ String?
The user ID of the manager of the account.
41 |
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 41 optional :manager_account_id, String |
#record_type ⇒ String?
The name of the type of data in the response.
47 |
# File 'lib/telnyx/models/managed_account_update_global_channel_limit_response.rb', line 47 optional :record_type, String |