Class: Telnyx::Models::ManagedAccountUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ManagedAccountUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/managed_account_update_params.rb
Overview
Instance Attribute Summary collapse
- #id ⇒ String
-
#managed_account_allow_custom_pricing ⇒ Boolean?
Boolean value that indicates if the managed account is able to have custom pricing set for it or not.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, managed_account_allow_custom_pricing: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ManagedAccountUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, managed_account_allow_custom_pricing: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ManagedAccountUpdateParams for more details.
|
|
# File 'lib/telnyx/models/managed_account_update_params.rb', line 24
|
Instance Attribute Details
#id ⇒ String
13 |
# File 'lib/telnyx/models/managed_account_update_params.rb', line 13 required :id, String |
#managed_account_allow_custom_pricing ⇒ Boolean?
Boolean value that indicates if the managed account is able to have custom pricing set for it or not. If false, uses the pricing of the manager account. Defaults to false. This value may be changed, but there may be time lag between when the value is changed and pricing changes take effect.
22 |
# File 'lib/telnyx/models/managed_account_update_params.rb', line 22 optional :managed_account_allow_custom_pricing, Telnyx::Internal::Type::Boolean |