Class: Telnyx::Models::MediaUploadParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MediaUploadParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/media_upload_params.rb
Overview
Instance Attribute Summary collapse
-
#media_name ⇒ String?
The unique identifier of a file.
-
#media_url ⇒ String
The URL where the media to be stored in Telnyx network is currently hosted.
-
#ttl_secs ⇒ Integer?
The number of seconds after which the media resource will be deleted, defaults to 2 days.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(media_url:, media_name: nil, ttl_secs: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MediaUploadParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(media_url:, media_name: nil, ttl_secs: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::MediaUploadParams for more details.
|
|
# File 'lib/telnyx/models/media_upload_params.rb', line 30
|
Instance Attribute Details
#media_name ⇒ String?
The unique identifier of a file.
21 |
# File 'lib/telnyx/models/media_upload_params.rb', line 21 optional :media_name, String |
#media_url ⇒ String
The URL where the media to be stored in Telnyx network is currently hosted. The maximum allowed size is 20 MB.
15 |
# File 'lib/telnyx/models/media_upload_params.rb', line 15 required :media_url, String |
#ttl_secs ⇒ Integer?
The number of seconds after which the media resource will be deleted, defaults to 2 days. The maximum allowed vale is 630720000, which translates to 20 years.
28 |
# File 'lib/telnyx/models/media_upload_params.rb', line 28 optional :ttl_secs, Integer |