Class: Telnyx::Models::MeetingSessionCreateParams::CameraImage::MeetingSessionCameraImageURLSource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MeetingSessionCreateParams::CameraImage::MeetingSessionCameraImageURLSource
- Defined in:
- lib/telnyx/models/meeting_session_create_params.rb,
sig/telnyx/models/meeting_session_create_params.rbs
Instance Attribute Summary collapse
-
#format_ ⇒ Symbol, :jpeg
Only JPEG images are accepted.
-
#url ⇒ String
Public HTTPS JPEG URL with at most 2,048 characters and no credentials, fragment, surrounding whitespace, raw control characters, or explicit non-default port.
Instance Method Summary collapse
-
#initialize(url:, format_: :jpeg) ⇒ MeetingSessionCameraImageURLSource
constructor
Some parameter documentations has been truncated, see MeetingSessionCameraImageURLSource for more details.
- #to_hash ⇒ { format_: :jpeg, url: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url:, format_: :jpeg) ⇒ MeetingSessionCameraImageURLSource
Some parameter documentations has been truncated, see Telnyx::Models::MeetingSessionCreateParams::CameraImage::MeetingSessionCameraImageURLSource for more details.
|
|
# File 'lib/telnyx/models/meeting_session_create_params.rb', line 294
|
Instance Attribute Details
#format_ ⇒ Symbol, :jpeg
Only JPEG images are accepted.
279 |
# File 'lib/telnyx/models/meeting_session_create_params.rb', line 279 required :format_, const: :jpeg, api_name: :format |
#url ⇒ String
Public HTTPS JPEG URL with at most 2,048 characters and no credentials, fragment, surrounding whitespace, raw control characters, or explicit non-default port. Signed queries are allowed but must be treated as credentials. Fetching is limited to public network destinations, a five-second timeout, no redirects, a 2xx image/jpeg response with identity or no content encoding, and a 1,363,148-byte limit enforced against both declared and streamed content. The service resolves the URL before bot creation and does not persist, return, or log the URL or image bytes.
292 |
# File 'lib/telnyx/models/meeting_session_create_params.rb', line 292 required :url, String |
Instance Method Details
#to_hash ⇒ { format_: :jpeg, url: String }
215 |
# File 'sig/telnyx/models/meeting_session_create_params.rbs', line 215
def to_hash: -> { format_: :jpeg, url: String }
|