Class: Telnyx::Models::MeetingSessionRetrieveRecordingsResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MeetingSessionRetrieveRecordingsResponse::Data
- Defined in:
- lib/telnyx/models/meeting_session_retrieve_recordings_response.rb,
sig/telnyx/models/meeting_session_retrieve_recordings_response.rbs
Instance Attribute Summary collapse
-
#expires_at ⇒ String?
Expiry timestamp when supplied by the provider, or null.
- #type ⇒ String
-
#url ⇒ String
Current provider download URL.
Instance Method Summary collapse
-
#initialize(expires_at:, type:, url:) ⇒ Data
constructor
Some parameter documentations has been truncated, see Data for more details.
- #to_hash ⇒ { expires_at: String?, type: String, url: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(expires_at:, type:, url:) ⇒ Data
Some parameter documentations has been truncated, see Telnyx::Models::MeetingSessionRetrieveRecordingsResponse::Data for more details.
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/telnyx/models/meeting_session_retrieve_recordings_response.rb', line 16 class Data < Telnyx::Internal::Type::BaseModel # @!attribute expires_at # Expiry timestamp when supplied by the provider, or null. The current adapter # returns null. # # @return [String, nil] required :expires_at, String, nil?: true # @!attribute type # # @return [String] required :type, String # @!attribute url # Current provider download URL. The API does not guarantee URL lifetime or # refresh behavior. # # @return [String] required :url, String # @!method initialize(expires_at:, type:, url:) # Some parameter documentations has been truncated, see # {Telnyx::Models::MeetingSessionRetrieveRecordingsResponse::Data} for more # details. # # @param expires_at [String, nil] Expiry timestamp when supplied by the provider, or null. The current adapter ret # # @param type [String] # # @param url [String] Current provider download URL. The API does not guarantee URL lifetime or refres end |
Instance Attribute Details
#expires_at ⇒ String?
Expiry timestamp when supplied by the provider, or null. The current adapter returns null.
22 |
# File 'lib/telnyx/models/meeting_session_retrieve_recordings_response.rb', line 22 required :expires_at, String, nil?: true |
#type ⇒ String
27 |
# File 'lib/telnyx/models/meeting_session_retrieve_recordings_response.rb', line 27 required :type, String |
#url ⇒ String
Current provider download URL. The API does not guarantee URL lifetime or refresh behavior.
34 |
# File 'lib/telnyx/models/meeting_session_retrieve_recordings_response.rb', line 34 required :url, String |
Instance Method Details
#to_hash ⇒ { expires_at: String?, type: String, url: String }
30 |
# File 'sig/telnyx/models/meeting_session_retrieve_recordings_response.rbs', line 30
def to_hash: -> { expires_at: String?, type: String, url: String }
|