Class: Telnyx::Models::MessageSendLongCodeParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/message_send_long_code_params.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(from:, to:, auto_detect: nil, media_urls: nil, subject: nil, text: nil, type: nil, use_profile_webhooks: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessageSendLongCodeParams for more details.

Parameters:

  • from (String)

    Phone number, in +E.164 format, used to send the message.

  • to (String)

    Receiving address (+E.164 formatted phone number or short code).

  • auto_detect (Boolean) (defaults to: nil)

    Automatically detect if an SMS message is unusually long and exceeds a recommend

  • media_urls (Array<String>) (defaults to: nil)

    A list of media URLs. The total media size must be less than 1 MB.

  • subject (String) (defaults to: nil)

    Subject of multimedia message

  • text (String) (defaults to: nil)

    Message body (i.e., content) as a non-empty string.

  • type (Symbol, Telnyx::Models::MessageSendLongCodeParams::Type) (defaults to: nil)

    The protocol for sending the message, either SMS or MMS.

  • use_profile_webhooks (Boolean) (defaults to: nil)

    If the profile this number is associated with has webhooks, use them for deliver

  • webhook_failover_url (String) (defaults to: nil)

    The failover URL where webhooks related to this message will be sent if sending

  • webhook_url (String) (defaults to: nil)

    The URL where webhooks related to this message will be sent.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/message_send_long_code_params.rb', line 78

Instance Attribute Details

#auto_detectBoolean?

Automatically detect if an SMS message is unusually long and exceeds a recommended limit of message parts.

Returns:

  • (Boolean, nil)


27
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 27

optional :auto_detect, Telnyx::Internal::Type::Boolean

#fromString

Phone number, in +E.164 format, used to send the message.

Returns:

  • (String)


14
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 14

required :from, String

#media_urlsArray<String>?

A list of media URLs. The total media size must be less than 1 MB.

**Required for MMS**

Returns:

  • (Array<String>, nil)


35
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 35

optional :media_urls, Telnyx::Internal::Type::ArrayOf[String]

#subjectString?

Subject of multimedia message

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 41

optional :subject, String

#textString?

Message body (i.e., content) as a non-empty string.

**Required for SMS**

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 49

optional :text, String

#toString

Receiving address (+E.164 formatted phone number or short code).

Returns:

  • (String)


20
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 20

required :to, String

#typeSymbol, ...

The protocol for sending the message, either SMS or MMS.



55
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 55

optional :type, enum: -> { Telnyx::MessageSendLongCodeParams::Type }

#use_profile_webhooksBoolean?

If the profile this number is associated with has webhooks, use them for delivery notifications. If webhooks are also specified on the message itself, they will be attempted first, then those on the profile.

Returns:

  • (Boolean, nil)


63
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 63

optional :use_profile_webhooks, Telnyx::Internal::Type::Boolean

#webhook_failover_urlString?

The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.

Returns:

  • (String, nil)


70
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 70

optional :webhook_failover_url, String

#webhook_urlString?

The URL where webhooks related to this message will be sent.

Returns:

  • (String, nil)


76
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 76

optional :webhook_url, String