Class: Telnyx::Models::MessageSendLongCodeParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MessageSendLongCodeParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/message_send_long_code_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#auto_detect ⇒ Boolean?
Automatically detect if an SMS message is unusually long and exceeds a recommended limit of message parts.
-
#encoding ⇒ Symbol, ...
Encoding to use for the message.
-
#from ⇒ String
Phone number, in +E.164 format, used to send the message.
-
#media_urls ⇒ Array<String>?
A list of media URLs.
-
#subject ⇒ String?
Subject of multimedia message.
-
#text ⇒ String?
Message body (i.e., content) as a non-empty string.
-
#to ⇒ String
Receiving address (+E.164 formatted phone number or short code).
-
#type ⇒ Symbol, ...
The protocol for sending the message, either SMS or MMS.
-
#use_profile_webhooks ⇒ Boolean?
If the profile this number is associated with has webhooks, use them for delivery notifications.
-
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.
-
#webhook_url ⇒ String?
The URL where webhooks related to this message will be sent.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(from:, to:, auto_detect: nil, encoding: nil, media_urls: nil, subject: nil, text: nil, type: nil, use_profile_webhooks: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessageSendLongCodeParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(from:, to:, auto_detect: nil, encoding: nil, media_urls: nil, subject: nil, text: nil, type: nil, use_profile_webhooks: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::MessageSendLongCodeParams for more details.
|
|
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 88
|
Instance Attribute Details
#auto_detect ⇒ Boolean?
Automatically detect if an SMS message is unusually long and exceeds a recommended limit of message parts.
27 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 27 optional :auto_detect, Telnyx::Internal::Type::Boolean |
#encoding ⇒ Symbol, ...
Encoding to use for the message. auto (default) uses smart encoding to
automatically select the most efficient encoding. gsm7 forces GSM-7 encoding
(returns 400 if message contains characters that cannot be encoded). ucs2
forces UCS-2 encoding and disables smart encoding. When set, this overrides the
messaging profile's smart_encoding setting.
37 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 37 optional :encoding, enum: -> { Telnyx::MessageSendLongCodeParams::Encoding } |
#from ⇒ String
Phone number, in +E.164 format, used to send the message.
14 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 14 required :from, String |
#media_urls ⇒ Array<String>?
A list of media URLs. The total media size must be less than 1 MB.
Required for MMS
45 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 45 optional :media_urls, Telnyx::Internal::Type::ArrayOf[String] |
#subject ⇒ String?
Subject of multimedia message
51 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 51 optional :subject, String |
#text ⇒ String?
Message body (i.e., content) as a non-empty string.
Required for SMS
59 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 59 optional :text, String |
#to ⇒ String
Receiving address (+E.164 formatted phone number or short code).
20 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 20 required :to, String |
#type ⇒ Symbol, ...
The protocol for sending the message, either SMS or MMS.
65 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 65 optional :type, enum: -> { Telnyx::MessageSendLongCodeParams::Type } |
#use_profile_webhooks ⇒ Boolean?
If the profile this number is associated with has webhooks, use them for delivery notifications. If webhooks are also specified on the message itself, they will be attempted first, then those on the profile.
73 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 73 optional :use_profile_webhooks, Telnyx::Internal::Type::Boolean |
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this message will be sent if sending to the primary URL fails.
80 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 80 optional :webhook_failover_url, String |
#webhook_url ⇒ String?
The URL where webhooks related to this message will be sent.
86 |
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 86 optional :webhook_url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/message_send_long_code_params.rb', line 128
|