Class: Telnyx::Models::MessageSendWhatsappResponse::Data
Overview
Defined Under Namespace
Classes: From
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(id: nil, body: nil, direction: nil, encoding: nil, from: nil, messaging_profile_id: nil, organization_id: nil, received_at: nil, record_type: nil, to: nil, type: nil, wait_seconds: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, body: nil, direction: nil, encoding: nil, from: nil, messaging_profile_id: nil, organization_id: nil, received_at: nil, record_type: nil, to: nil, type: nil, wait_seconds: nil) ⇒ Object
|
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 81
|
Instance Attribute Details
#direction ⇒ String?
31
|
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 31
optional :direction, String
|
#encoding ⇒ String?
36
|
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 36
optional :encoding, String
|
#id ⇒ String?
21
|
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 21
optional :id, String
|
#messaging_profile_id ⇒ String?
46
|
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 46
optional :messaging_profile_id, String
|
#organization_id ⇒ String?
51
|
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 51
optional :organization_id, String
|
#received_at ⇒ Time?
56
|
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 56
optional :received_at, Time
|
#record_type ⇒ String?
61
|
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 61
optional :record_type, String
|
#type ⇒ String?
71
|
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 71
optional :type, String
|
#wait_seconds ⇒ Float?
Seconds the message is queued due to rate limiting before being sent to the carrier. Represents the maximum wait across all applicable rate limits (account, carrier, campaign). 0.0 = no queuing delay.
79
|
# File 'lib/telnyx/models/message_send_whatsapp_response.rb', line 79
optional :wait_seconds, Float, nil?: true
|