Class: Telnyx::Models::Messaging10dlc::BrandCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::BrandCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/messaging_10dlc/brand_create_params.rb
Overview
Instance Attribute Summary collapse
-
#business_contact_email ⇒ String?
Business contact email.
-
#city ⇒ String?
City name.
-
#company_name ⇒ String?
(Required for Non-profit/private/public) Legal company name.
-
#country ⇒ String
ISO2 2 characters country code.
-
#display_name ⇒ String
Display name, marketing name, or DBA name of the brand.
-
#ein ⇒ String?
(Required for Non-profit) Government assigned corporate tax ID.
-
#email ⇒ String
Valid email address of brand support contact.
-
#entity_type ⇒ Symbol, Telnyx::Models::Messaging10dlc::EntityType
Entity type behind the brand.
-
#first_name ⇒ String?
First name of business contact.
-
#ip_address ⇒ String?
IP address of the browser requesting to create brand identity.
- #is_reseller ⇒ Boolean?
-
#last_name ⇒ String?
Last name of business contact.
-
#mobile_phone ⇒ String?
Valid mobile phone number in e.164 international format.
-
#mock ⇒ Boolean?
Mock brand for testing purposes.
-
#phone ⇒ String?
Valid phone number in e.164 international format.
-
#postal_code ⇒ String?
Postal codes.
-
#state ⇒ String?
State.
-
#stock_exchange ⇒ Symbol, ...
(Required for public company) stock exchange.
-
#stock_symbol ⇒ String?
(Required for public company) stock symbol.
-
#street ⇒ String?
Street number and name.
-
#vertical ⇒ Symbol, Telnyx::Models::Messaging10dlc::Vertical
Vertical or industry segment of the brand or campaign.
-
#webhook_failover_url ⇒ String?
Webhook failover URL for brand status updates.
-
#webhook_url ⇒ String?
Webhook URL for brand status updates.
-
#website ⇒ String?
Brand website URL.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(country:, display_name:, email:, entity_type:, vertical:, business_contact_email: nil, city: nil, company_name: nil, ein: nil, first_name: nil, ip_address: nil, is_reseller: nil, last_name: nil, mobile_phone: nil, mock: nil, phone: nil, postal_code: nil, state: nil, stock_exchange: nil, stock_symbol: nil, street: nil, webhook_failover_url: nil, webhook_url: nil, website: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BrandCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, display_name:, email:, entity_type:, vertical:, business_contact_email: nil, city: nil, company_name: nil, ein: nil, first_name: nil, ip_address: nil, is_reseller: nil, last_name: nil, mobile_phone: nil, mock: nil, phone: nil, postal_code: nil, state: nil, stock_exchange: nil, stock_symbol: nil, street: nil, webhook_failover_url: nil, webhook_url: nil, website: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::BrandCreateParams for more details.
|
|
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 158
|
Instance Attribute Details
#business_contact_email ⇒ String?
Business contact email.
Required if ‘entityType` is `PUBLIC_PROFIT`. Otherwise, it is recommended to either omit this field or set it to `null`.
48 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 48 optional :business_contact_email, String, api_name: :businessContactEmail |
#city ⇒ String?
City name
54 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 54 optional :city, String |
#company_name ⇒ String?
(Required for Non-profit/private/public) Legal company name.
60 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 60 optional :company_name, String, api_name: :companyName |
#country ⇒ String
ISO2 2 characters country code. Example: US - United States
15 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 15 required :country, String |
#display_name ⇒ String
Display name, marketing name, or DBA name of the brand.
21 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 21 required :display_name, String, api_name: :displayName |
#ein ⇒ String?
(Required for Non-profit) Government assigned corporate tax ID. EIN is 9-digits in U.S.
67 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 67 optional :ein, String |
#email ⇒ String
Valid email address of brand support contact.
27 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 27 required :email, String |
#entity_type ⇒ Symbol, Telnyx::Models::Messaging10dlc::EntityType
Entity type behind the brand. This is the form of business establishment.
33 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 33 required :entity_type, enum: -> { Telnyx::Messaging10dlc::EntityType }, api_name: :entityType |
#first_name ⇒ String?
First name of business contact.
73 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 73 optional :first_name, String, api_name: :firstName |
#ip_address ⇒ String?
IP address of the browser requesting to create brand identity.
79 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 79 optional :ip_address, String, api_name: :ipAddress |
#is_reseller ⇒ Boolean?
84 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 84 optional :is_reseller, Telnyx::Internal::Type::Boolean, api_name: :isReseller |
#last_name ⇒ String?
Last name of business contact.
90 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 90 optional :last_name, String, api_name: :lastName |
#mobile_phone ⇒ String?
Valid mobile phone number in e.164 international format.
96 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 96 optional :mobile_phone, String, api_name: :mobilePhone |
#mock ⇒ Boolean?
Mock brand for testing purposes. Defaults to false.
102 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 102 optional :mock, Telnyx::Internal::Type::Boolean |
#phone ⇒ String?
Valid phone number in e.164 international format.
108 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 108 optional :phone, String |
#postal_code ⇒ String?
Postal codes. Use 5 digit zipcode for United States
114 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 114 optional :postal_code, String, api_name: :postalCode |
#state ⇒ String?
State. Must be 2 letters code for United States.
120 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 120 optional :state, String |
#stock_exchange ⇒ Symbol, ...
(Required for public company) stock exchange.
126 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 126 optional :stock_exchange, enum: -> { Telnyx::Messaging10dlc::StockExchange }, api_name: :stockExchange |
#stock_symbol ⇒ String?
(Required for public company) stock symbol.
132 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 132 optional :stock_symbol, String, api_name: :stockSymbol |
#street ⇒ String?
Street number and name.
138 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 138 optional :street, String |
#vertical ⇒ Symbol, Telnyx::Models::Messaging10dlc::Vertical
Vertical or industry segment of the brand or campaign.
39 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 39 required :vertical, enum: -> { Telnyx::Messaging10dlc::Vertical } |
#webhook_failover_url ⇒ String?
Webhook failover URL for brand status updates.
144 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 144 optional :webhook_failover_url, String, api_name: :webhookFailoverURL |
#webhook_url ⇒ String?
Webhook URL for brand status updates.
150 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 150 optional :webhook_url, String, api_name: :webhookURL |
#website ⇒ String?
Brand website URL.
156 |
# File 'lib/telnyx/models/messaging_10dlc/brand_create_params.rb', line 156 optional :website, String |