Class: Telnyx::Models::Messaging10dlc::BrandListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::BrandListResponse
- Defined in:
- lib/telnyx/models/messaging_10dlc/brand_list_response.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#assigned_campaings_count ⇒ Integer?
Number of campaigns associated with the brand.
-
#brand_id ⇒ String?
Unique identifier assigned to the brand.
-
#company_name ⇒ String?
(Required for Non-profit/private/public) Legal company name.
-
#created_at ⇒ String?
Date and time that the brand was created at.
-
#display_name ⇒ String?
Display or marketing name of the brand.
-
#email ⇒ String?
Valid email address of brand support contact.
-
#entity_type ⇒ Symbol, ...
Entity type behind the brand.
-
#failure_reasons ⇒ String?
Failure reasons for brand.
-
#identity_status ⇒ Symbol, ...
The verification status of an active brand.
-
#status ⇒ Symbol, ...
Status of the brand.
-
#tcr_brand_id ⇒ String?
Unique identifier assigned to the brand by the registry.
-
#updated_at ⇒ String?
Date and time that the brand was last updated at.
-
#website ⇒ String?
Brand website URL.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assigned_campaings_count: nil, brand_id: nil, company_name: nil, created_at: nil, display_name: nil, email: nil, entity_type: nil, failure_reasons: nil, identity_status: nil, status: nil, tcr_brand_id: nil, updated_at: nil, website: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 88
|
Instance Attribute Details
#assigned_campaings_count ⇒ Integer?
Number of campaigns associated with the brand
12 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 12 optional :assigned_campaings_count, Integer, api_name: :assignedCampaingsCount |
#brand_id ⇒ String?
Unique identifier assigned to the brand.
18 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 18 optional :brand_id, String, api_name: :brandId |
#company_name ⇒ String?
(Required for Non-profit/private/public) Legal company name.
24 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 24 optional :company_name, String, api_name: :companyName |
#created_at ⇒ String?
Date and time that the brand was created at.
30 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 30 optional :created_at, String, api_name: :createdAt |
#display_name ⇒ String?
Display or marketing name of the brand.
36 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 36 optional :display_name, String, api_name: :displayName |
#email ⇒ String?
Valid email address of brand support contact.
42 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 42 optional :email, String |
#entity_type ⇒ Symbol, ...
Entity type behind the brand. This is the form of business establishment.
48 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 48 optional :entity_type, enum: -> { Telnyx::Messaging10dlc::EntityType }, api_name: :entityType |
#failure_reasons ⇒ String?
Failure reasons for brand
54 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 54 optional :failure_reasons, String, api_name: :failureReasons |
#identity_status ⇒ Symbol, ...
The verification status of an active brand
60 61 62 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 60 optional :identity_status, enum: -> { Telnyx::Messaging10dlc::BrandIdentityStatus }, api_name: :identityStatus |
#status ⇒ Symbol, ...
Status of the brand
68 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 68 optional :status, enum: -> { Telnyx::Models::Messaging10dlc::BrandListResponse::Status } |
#tcr_brand_id ⇒ String?
Unique identifier assigned to the brand by the registry.
74 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 74 optional :tcr_brand_id, String, api_name: :tcrBrandId |
#updated_at ⇒ String?
Date and time that the brand was last updated at.
80 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 80 optional :updated_at, String, api_name: :updatedAt |
#website ⇒ String?
Brand website URL.
86 |
# File 'lib/telnyx/models/messaging_10dlc/brand_list_response.rb', line 86 optional :website, String |