Class: Telnyx::Models::Messaging10dlc::BrandRetrieveSMSOtpStatusResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::BrandRetrieveSMSOtpStatusResponse
- Defined in:
- lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb
Overview
Instance Attribute Summary collapse
-
#brand_id ⇒ String
The Brand ID associated with this OTP request.
-
#delivery_status ⇒ String
The current delivery status of the OTP SMS message.
-
#delivery_status_date ⇒ Time?
The timestamp when the delivery status was last updated.
-
#delivery_status_details ⇒ String?
Additional details about the delivery status.
-
#mobile_phone ⇒ String
The mobile phone number where the OTP was sent, in E.164 format.
-
#reference_id ⇒ String
The reference ID for this OTP request, used for status queries.
-
#request_date ⇒ Time
The timestamp when the OTP request was initiated.
-
#verify_date ⇒ Time?
The timestamp when the OTP was successfully verified (if applicable).
Instance Method Summary collapse
-
#initialize(brand_id:, delivery_status:, mobile_phone:, reference_id:, request_date:, delivery_status_date: nil, delivery_status_details: nil, verify_date: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BrandRetrieveSMSOtpStatusResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(brand_id:, delivery_status:, mobile_phone:, reference_id:, request_date:, delivery_status_date: nil, delivery_status_details: nil, verify_date: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::BrandRetrieveSMSOtpStatusResponse for more details.
Status information for an SMS OTP sent during Sole Proprietor brand verification
|
|
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 57
|
Instance Attribute Details
#brand_id ⇒ String
The Brand ID associated with this OTP request
12 |
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 12 required :brand_id, String, api_name: :brandId |
#delivery_status ⇒ String
The current delivery status of the OTP SMS message. Common values include: ‘DELIVERED_HANDSET`, `PENDING`, `FAILED`, `EXPIRED`
19 |
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 19 required :delivery_status, String, api_name: :deliveryStatus |
#delivery_status_date ⇒ Time?
The timestamp when the delivery status was last updated
43 |
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 43 optional :delivery_status_date, Time, api_name: :deliveryStatusDate |
#delivery_status_details ⇒ String?
Additional details about the delivery status
49 |
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 49 optional :delivery_status_details, String, api_name: :deliveryStatusDetails |
#mobile_phone ⇒ String
The mobile phone number where the OTP was sent, in E.164 format
25 |
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 25 required :mobile_phone, String, api_name: :mobilePhone |
#reference_id ⇒ String
The reference ID for this OTP request, used for status queries
31 |
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 31 required :reference_id, String, api_name: :referenceId |
#request_date ⇒ Time
The timestamp when the OTP request was initiated
37 |
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 37 required :request_date, Time, api_name: :requestDate |
#verify_date ⇒ Time?
The timestamp when the OTP was successfully verified (if applicable)
55 |
# File 'lib/telnyx/models/messaging_10dlc/brand_retrieve_sms_otp_status_response.rb', line 55 optional :verify_date, Time, api_name: :verifyDate |