Class: Telnyx::Models::Messaging10dlc::CampaignListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::CampaignListResponse
- Defined in:
- lib/telnyx/models/messaging_10dlc/campaign_list_response.rb
Overview
Defined Under Namespace
Modules: CampaignStatus, SubmissionStatus
Instance Attribute Summary collapse
-
#age_gated ⇒ Boolean?
Age gated content in campaign.
-
#assigned_phone_numbers_count ⇒ Float?
Number of phone numbers associated with the campaign.
-
#auto_renewal ⇒ Boolean?
Campaign subscription auto-renewal status.
-
#billed_date ⇒ String?
Campaign recent billed date.
-
#brand_display_name ⇒ String?
Display or marketing name of the brand.
-
#brand_id ⇒ String?
Unique identifier assigned to the brand.
-
#campaign_id ⇒ String?
Unique identifier for a campaign.
-
#campaign_status ⇒ Symbol, ...
Campaign status.
-
#create_date ⇒ String?
Unix timestamp when campaign was created.
-
#csp_id ⇒ String?
Alphanumeric identifier of the CSP associated with this campaign.
-
#description ⇒ String?
Summary description of this campaign.
- #direct_lending ⇒ Boolean?
-
#embedded_link ⇒ Boolean?
Does message generated by the campaign include URL link in SMS?.
-
#embedded_link_sample ⇒ String?
Sample of an embedded link that will be sent to subscribers.
-
#embedded_phone ⇒ Boolean?
Does message generated by the campaign include phone number in SMS?.
-
#failure_reasons ⇒ String?
Failure reasons if campaign submission failed.
-
#help_keywords ⇒ String?
Subscriber help keywords.
-
#help_message ⇒ String?
Help message of the campaign.
-
#is_t_mobile_number_pooling_enabled ⇒ Boolean?
Indicates whether the campaign has a T-Mobile number pool ID associated with it.
-
#is_t_mobile_registered ⇒ Boolean?
Indicates whether the campaign is registered with T-Mobile.
-
#is_t_mobile_suspended ⇒ Boolean?
Indicates whether the campaign is suspended with T-Mobile.
-
#message_flow ⇒ String?
Message flow description.
-
#mock ⇒ Boolean?
Campaign created from mock brand.
-
#next_renewal_or_expiration_date ⇒ String?
When the campaign would be due for its next renew/bill date.
-
#number_pool ⇒ Boolean?
Does campaign utilize pool of phone numbers?.
-
#optin_keywords ⇒ String?
Subscriber opt-in keywords.
-
#optin_message ⇒ String?
Subscriber opt-in message.
-
#optout_keywords ⇒ String?
Subscriber opt-out keywords.
-
#optout_message ⇒ String?
Subscriber opt-out message.
-
#privacy_policy_link ⇒ String?
Link to the campaign’s privacy policy.
-
#reference_id ⇒ String?
Caller supplied campaign reference ID.
-
#reseller_id ⇒ String?
Alphanumeric identifier of the reseller that you want to associate with this campaign.
-
#sample1 ⇒ String?
Message sample.
-
#sample2 ⇒ String?
Message sample.
-
#sample3 ⇒ String?
Message sample.
-
#sample4 ⇒ String?
Message sample.
-
#sample5 ⇒ String?
Message sample.
-
#status ⇒ String?
Current campaign status.
-
#sub_usecases ⇒ Array<String>?
Campaign sub-usecases.
-
#submission_status ⇒ Symbol, ...
Campaign submission status.
-
#subscriber_help ⇒ Boolean?
Does campaign responds to help keyword(s)?.
-
#subscriber_optin ⇒ Boolean?
Does campaign require subscriber to opt-in before SMS is sent to subscriber?.
-
#subscriber_optout ⇒ Boolean?
Does campaign support subscriber opt-out keyword(s)?.
-
#tcr_brand_id ⇒ String?
Unique identifier assigned to the brand by the registry.
-
#tcr_campaign_id ⇒ String?
Unique identifier assigned to the campaign by the registry.
-
#terms_and_conditions ⇒ Boolean?
Is terms & conditions accepted?.
-
#terms_and_conditions_link ⇒ String?
Link to the campaign’s terms and conditions.
-
#usecase ⇒ String?
Campaign usecase.
-
#vertical ⇒ String?
deprecated
Deprecated.
This field is deprecated and will be removed soon
-
#webhook_failover_url ⇒ String?
Failover webhook to which campaign status updates are sent.
-
#webhook_url ⇒ String?
Webhook to which campaign status updates are sent.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(age_gated: nil, assigned_phone_numbers_count: nil, auto_renewal: nil, billed_date: nil, brand_display_name: nil, brand_id: nil, campaign_id: nil, campaign_status: nil, create_date: nil, csp_id: nil, description: nil, direct_lending: nil, embedded_link: nil, embedded_link_sample: nil, embedded_phone: nil, failure_reasons: nil, help_keywords: nil, help_message: nil, is_t_mobile_number_pooling_enabled: nil, is_t_mobile_registered: nil, is_t_mobile_suspended: nil, message_flow: nil, mock: nil, next_renewal_or_expiration_date: nil, number_pool: nil, optin_keywords: nil, optin_message: nil, optout_keywords: nil, optout_message: nil, privacy_policy_link: nil, reference_id: nil, reseller_id: nil, sample1: nil, sample2: nil, sample3: nil, sample4: nil, sample5: nil, status: nil, submission_status: nil, subscriber_help: nil, subscriber_optin: nil, subscriber_optout: nil, sub_usecases: nil, tcr_brand_id: nil, tcr_campaign_id: nil, terms_and_conditions: nil, terms_and_conditions_link: nil, usecase: nil, vertical: nil, webhook_failover_url: nil, webhook_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CampaignListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(age_gated: nil, assigned_phone_numbers_count: nil, auto_renewal: nil, billed_date: nil, brand_display_name: nil, brand_id: nil, campaign_id: nil, campaign_status: nil, create_date: nil, csp_id: nil, description: nil, direct_lending: nil, embedded_link: nil, embedded_link_sample: nil, embedded_phone: nil, failure_reasons: nil, help_keywords: nil, help_message: nil, is_t_mobile_number_pooling_enabled: nil, is_t_mobile_registered: nil, is_t_mobile_suspended: nil, message_flow: nil, mock: nil, next_renewal_or_expiration_date: nil, number_pool: nil, optin_keywords: nil, optin_message: nil, optout_keywords: nil, optout_message: nil, privacy_policy_link: nil, reference_id: nil, reseller_id: nil, sample1: nil, sample2: nil, sample3: nil, sample4: nil, sample5: nil, status: nil, submission_status: nil, subscriber_help: nil, subscriber_optin: nil, subscriber_optout: nil, sub_usecases: nil, tcr_brand_id: nil, tcr_campaign_id: nil, terms_and_conditions: nil, terms_and_conditions_link: nil, usecase: nil, vertical: nil, webhook_failover_url: nil, webhook_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::CampaignListResponse for more details.
|
|
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 333
|
Instance Attribute Details
#age_gated ⇒ Boolean?
Age gated content in campaign.
12 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 12 optional :age_gated, Telnyx::Internal::Type::Boolean, api_name: :ageGated |
#assigned_phone_numbers_count ⇒ Float?
Number of phone numbers associated with the campaign
18 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 18 optional :assigned_phone_numbers_count, Float, api_name: :assignedPhoneNumbersCount |
#auto_renewal ⇒ Boolean?
Campaign subscription auto-renewal status.
24 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 24 optional :auto_renewal, Telnyx::Internal::Type::Boolean, api_name: :autoRenewal |
#billed_date ⇒ String?
Campaign recent billed date.
30 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 30 optional :billed_date, String, api_name: :billedDate |
#brand_display_name ⇒ String?
Display or marketing name of the brand.
36 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 36 optional :brand_display_name, String, api_name: :brandDisplayName |
#brand_id ⇒ String?
Unique identifier assigned to the brand.
42 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 42 optional :brand_id, String, api_name: :brandId |
#campaign_id ⇒ String?
Unique identifier for a campaign.
48 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 48 optional :campaign_id, String, api_name: :campaignId |
#campaign_status ⇒ Symbol, ...
Campaign status
54 55 56 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 54 optional :campaign_status, enum: -> { Telnyx::Models::Messaging10dlc::CampaignListResponse::CampaignStatus }, api_name: :campaignStatus |
#create_date ⇒ String?
Unix timestamp when campaign was created.
62 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 62 optional :create_date, String, api_name: :createDate |
#csp_id ⇒ String?
Alphanumeric identifier of the CSP associated with this campaign.
68 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 68 optional :csp_id, String, api_name: :cspId |
#description ⇒ String?
Summary description of this campaign.
74 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 74 optional :description, String |
#direct_lending ⇒ Boolean?
79 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 79 optional :direct_lending, Telnyx::Internal::Type::Boolean, api_name: :directLending |
#embedded_link ⇒ Boolean?
Does message generated by the campaign include URL link in SMS?
85 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 85 optional :embedded_link, Telnyx::Internal::Type::Boolean, api_name: :embeddedLink |
#embedded_link_sample ⇒ String?
Sample of an embedded link that will be sent to subscribers.
91 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 91 optional :embedded_link_sample, String, api_name: :embeddedLinkSample |
#embedded_phone ⇒ Boolean?
Does message generated by the campaign include phone number in SMS?
97 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 97 optional :embedded_phone, Telnyx::Internal::Type::Boolean, api_name: :embeddedPhone |
#failure_reasons ⇒ String?
Failure reasons if campaign submission failed
103 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 103 optional :failure_reasons, String, api_name: :failureReasons |
#help_keywords ⇒ String?
Subscriber help keywords. Multiple keywords are comma separated without space.
109 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 109 optional :help_keywords, String, api_name: :helpKeywords |
#help_message ⇒ String?
Help message of the campaign.
115 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 115 optional :help_message, String, api_name: :helpMessage |
#is_t_mobile_number_pooling_enabled ⇒ Boolean?
Indicates whether the campaign has a T-Mobile number pool ID associated with it.
121 122 123 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 121 optional :is_t_mobile_number_pooling_enabled, Telnyx::Internal::Type::Boolean, api_name: :isTMobileNumberPoolingEnabled |
#is_t_mobile_registered ⇒ Boolean?
Indicates whether the campaign is registered with T-Mobile.
129 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 129 optional :is_t_mobile_registered, Telnyx::Internal::Type::Boolean, api_name: :isTMobileRegistered |
#is_t_mobile_suspended ⇒ Boolean?
Indicates whether the campaign is suspended with T-Mobile.
135 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 135 optional :is_t_mobile_suspended, Telnyx::Internal::Type::Boolean, api_name: :isTMobileSuspended |
#message_flow ⇒ String?
Message flow description.
141 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 141 optional :message_flow, String, api_name: :messageFlow |
#mock ⇒ Boolean?
Campaign created from mock brand. Mocked campaign cannot be shared with an upstream CNP.
148 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 148 optional :mock, Telnyx::Internal::Type::Boolean |
#next_renewal_or_expiration_date ⇒ String?
When the campaign would be due for its next renew/bill date.
154 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 154 optional :next_renewal_or_expiration_date, String, api_name: :nextRenewalOrExpirationDate |
#number_pool ⇒ Boolean?
Does campaign utilize pool of phone numbers?
160 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 160 optional :number_pool, Telnyx::Internal::Type::Boolean, api_name: :numberPool |
#optin_keywords ⇒ String?
Subscriber opt-in keywords. Multiple keywords are comma separated without space.
166 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 166 optional :optin_keywords, String, api_name: :optinKeywords |
#optin_message ⇒ String?
Subscriber opt-in message.
172 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 172 optional :optin_message, String, api_name: :optinMessage |
#optout_keywords ⇒ String?
Subscriber opt-out keywords. Multiple keywords are comma separated without space.
179 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 179 optional :optout_keywords, String, api_name: :optoutKeywords |
#optout_message ⇒ String?
Subscriber opt-out message.
185 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 185 optional :optout_message, String, api_name: :optoutMessage |
#privacy_policy_link ⇒ String?
Link to the campaign’s privacy policy.
191 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 191 optional :privacy_policy_link, String, api_name: :privacyPolicyLink |
#reference_id ⇒ String?
Caller supplied campaign reference ID. If supplied, the value must be unique across all submitted campaigns. Can be used to prevent duplicate campaign registrations.
199 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 199 optional :reference_id, String, api_name: :referenceId |
#reseller_id ⇒ String?
Alphanumeric identifier of the reseller that you want to associate with this campaign.
206 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 206 optional :reseller_id, String, api_name: :resellerId |
#sample1 ⇒ String?
Message sample. Some campaign tiers require 1 or more message samples.
212 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 212 optional :sample1, String |
#sample2 ⇒ String?
Message sample. Some campaign tiers require 2 or more message samples.
218 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 218 optional :sample2, String |
#sample3 ⇒ String?
Message sample. Some campaign tiers require 3 or more message samples.
224 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 224 optional :sample3, String |
#sample4 ⇒ String?
Message sample. Some campaign tiers require 4 or more message samples.
230 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 230 optional :sample4, String |
#sample5 ⇒ String?
Message sample. Some campaign tiers require 5 or more message samples.
236 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 236 optional :sample5, String |
#status ⇒ String?
Current campaign status. Possible values: ACTIVE, EXPIRED. A newly created campaign defaults to ACTIVE status.
243 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 243 optional :status, String |
#sub_usecases ⇒ Array<String>?
Campaign sub-usecases. Must be of defined valid sub-usecase types. Use ‘/10dlc/enum/usecase` operation to retrieve list of valid sub-usecases
276 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 276 optional :sub_usecases, Telnyx::Internal::Type::ArrayOf[String], api_name: :subUsecases |
#submission_status ⇒ Symbol, ...
Campaign submission status
249 250 251 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 249 optional :submission_status, enum: -> { Telnyx::Models::Messaging10dlc::CampaignListResponse::SubmissionStatus }, api_name: :submissionStatus |
#subscriber_help ⇒ Boolean?
Does campaign responds to help keyword(s)?
257 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 257 optional :subscriber_help, Telnyx::Internal::Type::Boolean, api_name: :subscriberHelp |
#subscriber_optin ⇒ Boolean?
Does campaign require subscriber to opt-in before SMS is sent to subscriber?
263 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 263 optional :subscriber_optin, Telnyx::Internal::Type::Boolean, api_name: :subscriberOptin |
#subscriber_optout ⇒ Boolean?
Does campaign support subscriber opt-out keyword(s)?
269 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 269 optional :subscriber_optout, Telnyx::Internal::Type::Boolean, api_name: :subscriberOptout |
#tcr_brand_id ⇒ String?
Unique identifier assigned to the brand by the registry.
282 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 282 optional :tcr_brand_id, String, api_name: :tcrBrandId |
#tcr_campaign_id ⇒ String?
Unique identifier assigned to the campaign by the registry.
288 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 288 optional :tcr_campaign_id, String, api_name: :tcrCampaignId |
#terms_and_conditions ⇒ Boolean?
Is terms & conditions accepted?
294 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 294 optional :terms_and_conditions, Telnyx::Internal::Type::Boolean, api_name: :termsAndConditions |
#terms_and_conditions_link ⇒ String?
Link to the campaign’s terms and conditions.
300 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 300 optional :terms_and_conditions_link, String, api_name: :termsAndConditionsLink |
#usecase ⇒ String?
Campaign usecase. Must be of defined valid types. Use ‘/10dlc/enum/usecase` operation to retrieve usecases available for given brand.
307 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 307 optional :usecase, String |
#vertical ⇒ String?
This field is deprecated and will be removed soon
Business/industry segment of this campaign (Deprecated). Must be of defined valid types. Use ‘/registry/enum/vertical` operation to retrieve verticals available for given brand, vertical combination.
This field is deprecated.
319 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 319 optional :vertical, String |
#webhook_failover_url ⇒ String?
Failover webhook to which campaign status updates are sent.
325 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 325 optional :webhook_failover_url, String, api_name: :webhookFailoverURL |
#webhook_url ⇒ String?
Webhook to which campaign status updates are sent.
331 |
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 331 optional :webhook_url, String, api_name: :webhookURL |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/messaging_10dlc/campaign_list_response.rb', line 458
|