Class: Telnyx::Models::Messaging10dlc::PartnerCampaignListSharedByMeResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::PartnerCampaignListSharedByMeResponse
- Defined in:
- lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_response.rb
Overview
Instance Attribute Summary collapse
-
#brand_id ⇒ String
Alphanumeric identifier of the brand associated with this campaign.
-
#campaign_id ⇒ String
Alphanumeric identifier assigned by the registry for a campaign.
-
#create_date ⇒ String?
Unix timestamp when campaign was created.
-
#status ⇒ String?
Current campaign status.
-
#usecase ⇒ String
Campaign usecase.
Instance Method Summary collapse
-
#initialize(brand_id:, campaign_id:, usecase:, create_date: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PartnerCampaignListSharedByMeResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(brand_id:, campaign_id:, usecase:, create_date: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::PartnerCampaignListSharedByMeResponse for more details.
Campaign is generated by the 10DLC registry once the corresponding campaign request is approved. Each campaign is assigned a unique identifier - campaignId. Once a campaign is activated, limited information is published to the NetNumber OSR service for consumption by members of the ecosystem. When a campaign is suspended(reversible) or expired(non-reversible), campaign data is deleted from the OSR service. Most attributes of campaignare immutable, including usecase, vertical, brandId and cspId.
|
|
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_response.rb', line 41
|
Instance Attribute Details
#brand_id ⇒ String
Alphanumeric identifier of the brand associated with this campaign.
12 |
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_response.rb', line 12 required :brand_id, String, api_name: :brandId |
#campaign_id ⇒ String
Alphanumeric identifier assigned by the registry for a campaign. This identifier is required by the NetNumber OSR SMS enabling process of 10DLC.
19 |
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_response.rb', line 19 required :campaign_id, String, api_name: :campaignId |
#create_date ⇒ String?
Unix timestamp when campaign was created.
32 |
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_response.rb', line 32 optional :create_date, String, api_name: :createDate |
#status ⇒ String?
Current campaign status. Possible values: ACTIVE, EXPIRED. A newly created campaign defaults to ACTIVE status.
39 |
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_response.rb', line 39 optional :status, String |
#usecase ⇒ String
Campaign usecase. Must be of defined valid types. Use ‘/10dlc/enum/usecase` operation to retrieve usecases available for given brand.
26 |
# File 'lib/telnyx/models/messaging_10dlc/partner_campaign_list_shared_by_me_response.rb', line 26 required :usecase, String |