Class: Telnyx::Models::Messaging10dlc::PhoneNumberAssignmentByProfileAssignResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::PhoneNumberAssignmentByProfileAssignResponse
- Defined in:
- lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_assign_response.rb
Overview
Instance Attribute Summary collapse
-
#campaign_id ⇒ String?
The ID of the campaign you want to link to the specified messaging profile.
-
#messaging_profile_id ⇒ String
The ID of the messaging profile that you want to link to the specified campaign.
-
#task_id ⇒ String
The ID of the task associated with assigning a messaging profile to a campaign.
-
#tcr_campaign_id ⇒ String?
The TCR ID of the shared campaign you want to link to the specified messaging profile (for campaigns not created using Telnyx 10DLC services only).
Instance Method Summary collapse
-
#initialize(messaging_profile_id:, task_id:, campaign_id: nil, tcr_campaign_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberAssignmentByProfileAssignResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(messaging_profile_id:, task_id:, campaign_id: nil, tcr_campaign_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::PhoneNumberAssignmentByProfileAssignResponse for more details.
|
|
# File 'lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_assign_response.rb', line 35
|
Instance Attribute Details
#campaign_id ⇒ String?
The ID of the campaign you want to link to the specified messaging profile. If you supply this ID in the request, do not also include a tcrCampaignId.
25 |
# File 'lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_assign_response.rb', line 25 optional :campaign_id, String, api_name: :campaignId |
#messaging_profile_id ⇒ String
The ID of the messaging profile that you want to link to the specified campaign.
12 |
# File 'lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_assign_response.rb', line 12 required :messaging_profile_id, String, api_name: :messagingProfileId |
#task_id ⇒ String
The ID of the task associated with assigning a messaging profile to a campaign.
18 |
# File 'lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_assign_response.rb', line 18 required :task_id, String, api_name: :taskId |
#tcr_campaign_id ⇒ String?
The TCR ID of the shared campaign you want to link to the specified messaging profile (for campaigns not created using Telnyx 10DLC services only). If you supply this ID in the request, do not also include a campaignId.
33 |
# File 'lib/telnyx/models/messaging_10dlc/phone_number_assignment_by_profile_assign_response.rb', line 33 optional :tcr_campaign_id, String, api_name: :tcrCampaignId |