Class: Telnyx::Models::Messaging10dlc::TelnyxBrand
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Messaging10dlc::TelnyxBrand
- Defined in:
- lib/telnyx/models/messaging_10dlc/telnyx_brand.rb
Overview
Direct Known Subclasses
Defined Under Namespace
Modules: BrandRelationship, Status
Instance Attribute Summary collapse
-
#alt_business_id ⇒ String?
Alternate business identifier such as DUNS, LEI, or GIIN.
-
#alt_business_id_type ⇒ Symbol, ...
An enumeration.
-
#brand_id ⇒ String?
Unique identifier assigned to the brand.
-
#brand_relationship ⇒ Symbol, Telnyx::Models::Messaging10dlc::TelnyxBrand::BrandRelationship
Brand relationship to the CSP.
-
#business_contact_email ⇒ String?
Business contact email.
-
#city ⇒ String?
City name.
-
#company_name ⇒ String?
(Required for Non-profit/private/public) Legal company name.
-
#country ⇒ String
ISO2 2 characters country code.
-
#created_at ⇒ String?
Date and time that the brand was created at.
-
#csp_id ⇒ String?
Unique identifier assigned to the csp by the registry.
-
#display_name ⇒ String
Display or marketing name of the brand.
-
#ein ⇒ String?
(Required for Non-profit) Government assigned corporate tax ID.
-
#email ⇒ String
Valid email address of brand support contact.
-
#entity_type ⇒ Symbol, Telnyx::Models::Messaging10dlc::EntityType
Entity type behind the brand.
-
#failure_reasons ⇒ String?
Failure reasons for brand.
-
#first_name ⇒ String?
First name of business contact.
-
#identity_status ⇒ Symbol, ...
The verification status of an active brand.
-
#ip_address ⇒ String?
IP address of the browser requesting to create brand identity.
-
#is_reseller ⇒ Boolean?
Indicates whether this brand is known to be a reseller.
-
#last_name ⇒ String?
Last name of business contact.
-
#mobile_phone ⇒ String?
Valid mobile phone number in e.164 international format.
-
#mock ⇒ Boolean?
Mock brand for testing purposes.
- #optional_attributes ⇒ Telnyx::Models::Messaging10dlc::BrandOptionalAttributes?
-
#phone ⇒ String?
Valid phone number in e.164 international format.
-
#postal_code ⇒ String?
Postal codes.
-
#reference_id ⇒ String?
Unique identifier Telnyx assigned to the brand - the brandId.
-
#state ⇒ String?
State.
-
#status ⇒ Symbol, ...
Status of the brand.
-
#stock_exchange ⇒ Symbol, ...
(Required for public company) stock exchange.
-
#stock_symbol ⇒ String?
(Required for public company) stock symbol.
-
#street ⇒ String?
Street number and name.
-
#tcr_brand_id ⇒ String?
Unique identifier assigned to the brand by the registry.
-
#universal_ein ⇒ String?
Universal EIN of Brand, Read Only.
-
#updated_at ⇒ String?
Date and time that the brand was last updated at.
-
#vertical ⇒ String
Vertical or industry segment of the brand.
-
#webhook_failover_url ⇒ String?
Failover webhook to which brand status updates are sent.
-
#webhook_url ⇒ String?
Webhook to which brand status updates are sent.
-
#website ⇒ String?
Brand website URL.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(brand_relationship:, country:, display_name:, email:, entity_type:, vertical:, alt_business_id: nil, alt_business_id_type: nil, brand_id: nil, business_contact_email: nil, city: nil, company_name: nil, created_at: nil, csp_id: nil, ein: nil, failure_reasons: nil, first_name: nil, identity_status: nil, ip_address: nil, is_reseller: nil, last_name: nil, mobile_phone: nil, mock: nil, optional_attributes: nil, phone: nil, postal_code: nil, reference_id: nil, state: nil, status: nil, stock_exchange: nil, stock_symbol: nil, street: nil, tcr_brand_id: nil, universal_ein: nil, updated_at: nil, webhook_failover_url: nil, webhook_url: nil, website: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TelnyxBrand for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(brand_relationship:, country:, display_name:, email:, entity_type:, vertical:, alt_business_id: nil, alt_business_id_type: nil, brand_id: nil, business_contact_email: nil, city: nil, company_name: nil, created_at: nil, csp_id: nil, ein: nil, failure_reasons: nil, first_name: nil, identity_status: nil, ip_address: nil, is_reseller: nil, last_name: nil, mobile_phone: nil, mock: nil, optional_attributes: nil, phone: nil, postal_code: nil, reference_id: nil, state: nil, status: nil, stock_exchange: nil, stock_symbol: nil, street: nil, tcr_brand_id: nil, universal_ein: nil, updated_at: nil, webhook_failover_url: nil, webhook_url: nil, website: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Messaging10dlc::TelnyxBrand for more details.
Telnyx-specific extensions to The Campaign Registry’s ‘Brand` type
|
|
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 246
|
Instance Attribute Details
#alt_business_id ⇒ String?
Alternate business identifier such as DUNS, LEI, or GIIN
50 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 50 optional :alt_business_id, String, api_name: :altBusinessId |
#alt_business_id_type ⇒ Symbol, ...
An enumeration.
56 57 58 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 56 optional :alt_business_id_type, enum: -> { Telnyx::Messaging10dlc::AltBusinessIDType }, api_name: :altBusinessIdType |
#brand_id ⇒ String?
Unique identifier assigned to the brand.
64 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 64 optional :brand_id, String, api_name: :brandId |
#brand_relationship ⇒ Symbol, Telnyx::Models::Messaging10dlc::TelnyxBrand::BrandRelationship
Brand relationship to the CSP.
12 13 14 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 12 required :brand_relationship, enum: -> { Telnyx::Messaging10dlc::TelnyxBrand::BrandRelationship }, api_name: :brandRelationship |
#business_contact_email ⇒ String?
Business contact email.
Required if ‘entityType` is `PUBLIC_PROFIT`.
72 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 72 optional :business_contact_email, String, api_name: :businessContactEmail |
#city ⇒ String?
City name
78 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 78 optional :city, String |
#company_name ⇒ String?
(Required for Non-profit/private/public) Legal company name.
84 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 84 optional :company_name, String, api_name: :companyName |
#country ⇒ String
ISO2 2 characters country code. Example: US - United States
20 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 20 required :country, String |
#created_at ⇒ String?
Date and time that the brand was created at.
90 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 90 optional :created_at, String, api_name: :createdAt |
#csp_id ⇒ String?
Unique identifier assigned to the csp by the registry.
96 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 96 optional :csp_id, String, api_name: :cspId |
#display_name ⇒ String
Display or marketing name of the brand.
26 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 26 required :display_name, String, api_name: :displayName |
#ein ⇒ String?
(Required for Non-profit) Government assigned corporate tax ID. EIN is 9-digits in U.S.
103 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 103 optional :ein, String |
#email ⇒ String
Valid email address of brand support contact.
32 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 32 required :email, String |
#entity_type ⇒ Symbol, Telnyx::Models::Messaging10dlc::EntityType
Entity type behind the brand. This is the form of business establishment.
38 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 38 required :entity_type, enum: -> { Telnyx::Messaging10dlc::EntityType }, api_name: :entityType |
#failure_reasons ⇒ String?
Failure reasons for brand
109 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 109 optional :failure_reasons, String, api_name: :failureReasons |
#first_name ⇒ String?
First name of business contact.
115 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 115 optional :first_name, String, api_name: :firstName |
#identity_status ⇒ Symbol, ...
The verification status of an active brand
121 122 123 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 121 optional :identity_status, enum: -> { Telnyx::Messaging10dlc::BrandIdentityStatus }, api_name: :identityStatus |
#ip_address ⇒ String?
IP address of the browser requesting to create brand identity.
129 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 129 optional :ip_address, String, api_name: :ipAddress |
#is_reseller ⇒ Boolean?
Indicates whether this brand is known to be a reseller
135 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 135 optional :is_reseller, Telnyx::Internal::Type::Boolean, api_name: :isReseller |
#last_name ⇒ String?
Last name of business contact.
141 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 141 optional :last_name, String, api_name: :lastName |
#mobile_phone ⇒ String?
Valid mobile phone number in e.164 international format.
147 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 147 optional :mobile_phone, String, api_name: :mobilePhone |
#mock ⇒ Boolean?
Mock brand for testing purposes
153 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 153 optional :mock, Telnyx::Internal::Type::Boolean |
#optional_attributes ⇒ Telnyx::Models::Messaging10dlc::BrandOptionalAttributes?
158 159 160 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 158 optional :optional_attributes, -> { Telnyx::Messaging10dlc::BrandOptionalAttributes }, api_name: :optionalAttributes |
#phone ⇒ String?
Valid phone number in e.164 international format.
166 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 166 optional :phone, String |
#postal_code ⇒ String?
Postal codes. Use 5 digit zipcode for United States
172 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 172 optional :postal_code, String, api_name: :postalCode |
#reference_id ⇒ String?
Unique identifier Telnyx assigned to the brand - the brandId
178 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 178 optional :reference_id, String, api_name: :referenceId |
#state ⇒ String?
State. Must be 2 letters code for United States.
184 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 184 optional :state, String |
#status ⇒ Symbol, ...
Status of the brand
190 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 190 optional :status, enum: -> { Telnyx::Messaging10dlc::TelnyxBrand::Status } |
#stock_exchange ⇒ Symbol, ...
(Required for public company) stock exchange.
196 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 196 optional :stock_exchange, enum: -> { Telnyx::Messaging10dlc::StockExchange }, api_name: :stockExchange |
#stock_symbol ⇒ String?
(Required for public company) stock symbol.
202 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 202 optional :stock_symbol, String, api_name: :stockSymbol |
#street ⇒ String?
Street number and name.
208 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 208 optional :street, String |
#tcr_brand_id ⇒ String?
Unique identifier assigned to the brand by the registry.
214 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 214 optional :tcr_brand_id, String, api_name: :tcrBrandId |
#universal_ein ⇒ String?
Universal EIN of Brand, Read Only.
220 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 220 optional :universal_ein, String, api_name: :universalEin |
#updated_at ⇒ String?
Date and time that the brand was last updated at.
226 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 226 optional :updated_at, String, api_name: :updatedAt |
#vertical ⇒ String
Vertical or industry segment of the brand.
44 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 44 required :vertical, String |
#webhook_failover_url ⇒ String?
Failover webhook to which brand status updates are sent.
232 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 232 optional :webhook_failover_url, String, api_name: :webhookFailoverURL |
#webhook_url ⇒ String?
Webhook to which brand status updates are sent.
238 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 238 optional :webhook_url, String, api_name: :webhookURL |
#website ⇒ String?
Brand website URL.
244 |
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 244 optional :website, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/messaging_10dlc/telnyx_brand.rb', line 340
|