Class: Telnyx::Models::MessagingHostedNumberOrder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/messaging_hosted_number_order.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, messaging_profile_id: nil, phone_numbers: nil, record_type: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessagingHostedNumberOrder for more details.

Parameters:

  • id (String) (defaults to: nil)

    Resource unique identifier.

  • messaging_profile_id (String, nil) (defaults to: nil)

    Automatically associate the number with this messaging profile ID when the order

  • phone_numbers (Array<Telnyx::Models::HostedNumber>) (defaults to: nil)
  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • status (Symbol, Telnyx::Models::MessagingHostedNumberOrder::Status) (defaults to: nil)


# File 'lib/telnyx/models/messaging_hosted_number_order.rb', line 37

Instance Attribute Details

#messaging_profile_idString?

Automatically associate the number with this messaging profile ID when the order is complete.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/messaging_hosted_number_order.rb', line 11

optional :messaging_profile_id, String, nil?: true

#phone_numbersArray<Telnyx::Models::HostedNumber>?

Returns:



16
# File 'lib/telnyx/models/messaging_hosted_number_order.rb', line 16

optional :phone_numbers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::HostedNumber] }

#statusSymbol, ...



21
# File 'lib/telnyx/models/messaging_hosted_number_order.rb', line 21

optional :status, enum: -> { Telnyx::MessagingHostedNumberOrder::Status }