Class: Telnyx::Models::MessagingNumbersBulkUpdateCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MessagingNumbersBulkUpdateCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/messaging_numbers_bulk_update_create_params.rb
Overview
Instance Attribute Summary collapse
-
#assign_only ⇒ Boolean?
If true, only assign numbers to the profile without changing other settings.
-
#messaging_profile_id ⇒ String
Configure the messaging profile these phone numbers are assigned to:.
-
#numbers ⇒ Array<String>
The list of phone numbers to update.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(messaging_profile_id:, numbers:, assign_only: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessagingNumbersBulkUpdateCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(messaging_profile_id:, numbers:, assign_only: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::MessagingNumbersBulkUpdateCreateParams for more details.
|
|
# File 'lib/telnyx/models/messaging_numbers_bulk_update_create_params.rb', line 33
|
Instance Attribute Details
#assign_only ⇒ Boolean?
If true, only assign numbers to the profile without changing other settings.
31 |
# File 'lib/telnyx/models/messaging_numbers_bulk_update_create_params.rb', line 31 optional :assign_only, Telnyx::Internal::Type::Boolean |
#messaging_profile_id ⇒ String
Configure the messaging profile these phone numbers are assigned to:
-
Set this field to ‘“”` to unassign each number from their respective messaging profile
-
Set this field to a quoted UUID of a messaging profile to assign these numbers to that messaging profile
19 |
# File 'lib/telnyx/models/messaging_numbers_bulk_update_create_params.rb', line 19 required :messaging_profile_id, String |