Class: Telnyx::Models::MessagingProfile
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MessagingProfile
- Defined in:
- lib/telnyx/models/messaging_profile.rb,
sig/telnyx/models/messaging_profile.rbs
Overview
Defined Under Namespace
Modules: RecordType, WebhookAPIVersion
Instance Attribute Summary collapse
-
#ai_assistant_id ⇒ String?
The AI assistant ID associated with this messaging profile.
-
#alpha_sender ⇒ String?
The alphanumeric sender ID to use when sending to destinations that require an alphanumeric sender ID.
-
#created_at ⇒ Time?
readonly
Returns the value of attribute created_at.
-
#daily_spend_limit ⇒ String?
The maximum amount of money (in USD) that can be spent by this profile before midnight UTC.
-
#daily_spend_limit_enabled ⇒ Boolean?
Whether to enforce the value configured by
daily_spend_limit. -
#enabled ⇒ Boolean?
Specifies whether the messaging profile is enabled or not.
-
#health_webhook_url ⇒ String?
DEPRECATED: health check url service checking.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#mms_fall_back_to_sms ⇒ Boolean?
enables SMS fallback for MMS messages.
-
#mms_transcoding ⇒ Boolean?
enables automated resizing of MMS media.
-
#mobile_only ⇒ Boolean?
Send messages only to mobile phone numbers.
-
#name ⇒ String?
A user friendly name for the messaging profile.
-
#number_pool_settings ⇒ Telnyx::Models::NumberPoolSettings?
Number Pool allows you to send messages from a pool of numbers of different types, assigning weights to each type.
-
#organization_id ⇒ String?
The organization that owns this messaging profile.
-
#record_type ⇒ Telnyx::Models::MessagingProfile::record_type?
readonly
Returns the value of attribute record_type.
-
#redaction_enabled ⇒ Boolean?
Indicates whether message content redaction is enabled for this profile.
-
#redaction_level ⇒ Integer?
Determines how much information is redacted in messages for privacy or compliance purposes.
-
#resource_group_id ⇒ String?
The resource group ID associated with this messaging profile.
-
#smart_encoding ⇒ Boolean?
Enables automatic character encoding optimization for SMS messages.
-
#updated_at ⇒ Time?
readonly
Returns the value of attribute updated_at.
-
#url_shortener_settings ⇒ Telnyx::Models::URLShortenerSettings?
The URL shortener feature allows automatic replacement of URLs that were generated using a public URL shortener service.
-
#v1_secret ⇒ String?
Secret used to authenticate with v1 endpoints.
-
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1, v2, or a legacy 2010-04-01 format.
-
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this messaging profile will be sent if sending to the primary URL fails.
-
#webhook_url ⇒ String?
The URL where webhooks related to this messaging profile will be sent.
-
#whitelisted_destinations ⇒ Array<String>?
Destinations to which the messaging profile is allowed to send.
Class Method Summary collapse
Instance Method Summary collapse
- #created_at ⇒ Time readonly
- #id ⇒ String readonly
-
#initialize(id: nil, ai_assistant_id: nil, alpha_sender: nil, created_at: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, enabled: nil, health_webhook_url: nil, mms_fall_back_to_sms: nil, mms_transcoding: nil, mobile_only: nil, name: nil, number_pool_settings: nil, organization_id: nil, record_type: nil, redaction_enabled: nil, redaction_level: nil, resource_group_id: nil, smart_encoding: nil, updated_at: nil, url_shortener_settings: nil, v1_secret: nil, webhook_api_version: nil, webhook_failover_url: nil, webhook_url: nil, whitelisted_destinations: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessagingProfile for more details.
- #record_type ⇒ Object readonly
- #to_hash ⇒ {
- #updated_at ⇒ Time readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, ai_assistant_id: nil, alpha_sender: nil, created_at: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, enabled: nil, health_webhook_url: nil, mms_fall_back_to_sms: nil, mms_transcoding: nil, mobile_only: nil, name: nil, number_pool_settings: nil, organization_id: nil, record_type: nil, redaction_enabled: nil, redaction_level: nil, resource_group_id: nil, smart_encoding: nil, updated_at: nil, url_shortener_settings: nil, v1_secret: nil, webhook_api_version: nil, webhook_failover_url: nil, webhook_url: nil, whitelisted_destinations: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::MessagingProfile for more details.
|
|
# File 'lib/telnyx/models/messaging_profile.rb', line 184
|
Instance Attribute Details
#ai_assistant_id ⇒ String?
The AI assistant ID associated with this messaging profile.
11 |
# File 'lib/telnyx/models/messaging_profile.rb', line 11 optional :ai_assistant_id, String, nil?: true |
#alpha_sender ⇒ String?
The alphanumeric sender ID to use when sending to destinations that require an alphanumeric sender ID.
18 |
# File 'lib/telnyx/models/messaging_profile.rb', line 18 optional :alpha_sender, String, nil?: true |
#created_at ⇒ Time? (readonly)
Returns the value of attribute created_at.
112 113 114 |
# File 'sig/telnyx/models/messaging_profile.rbs', line 112 def created_at @created_at end |
#daily_spend_limit ⇒ String?
The maximum amount of money (in USD) that can be spent by this profile before midnight UTC.
25 |
# File 'lib/telnyx/models/messaging_profile.rb', line 25 optional :daily_spend_limit, String |
#daily_spend_limit_enabled ⇒ Boolean?
Whether to enforce the value configured by daily_spend_limit.
31 |
# File 'lib/telnyx/models/messaging_profile.rb', line 31 optional :daily_spend_limit_enabled, Telnyx::Internal::Type::Boolean |
#enabled ⇒ Boolean?
Specifies whether the messaging profile is enabled or not.
37 |
# File 'lib/telnyx/models/messaging_profile.rb', line 37 optional :enabled, Telnyx::Internal::Type::Boolean |
#health_webhook_url ⇒ String?
DEPRECATED: health check url service checking
43 |
# File 'lib/telnyx/models/messaging_profile.rb', line 43 optional :health_webhook_url, String, nil?: true |
#id ⇒ String? (readonly)
Returns the value of attribute id.
108 109 110 |
# File 'sig/telnyx/models/messaging_profile.rbs', line 108 def id @id end |
#mms_fall_back_to_sms ⇒ Boolean?
enables SMS fallback for MMS messages.
49 |
# File 'lib/telnyx/models/messaging_profile.rb', line 49 optional :mms_fall_back_to_sms, Telnyx::Internal::Type::Boolean |
#mms_transcoding ⇒ Boolean?
enables automated resizing of MMS media.
55 |
# File 'lib/telnyx/models/messaging_profile.rb', line 55 optional :mms_transcoding, Telnyx::Internal::Type::Boolean |
#mobile_only ⇒ Boolean?
Send messages only to mobile phone numbers.
61 |
# File 'lib/telnyx/models/messaging_profile.rb', line 61 optional :mobile_only, Telnyx::Internal::Type::Boolean |
#name ⇒ String?
A user friendly name for the messaging profile.
67 |
# File 'lib/telnyx/models/messaging_profile.rb', line 67 optional :name, String |
#number_pool_settings ⇒ Telnyx::Models::NumberPoolSettings?
Number Pool allows you to send messages from a pool of numbers of different types, assigning weights to each type. The pool consists of all the long code and toll free numbers assigned to the messaging profile.
To disable this feature, set the object field to null.
77 |
# File 'lib/telnyx/models/messaging_profile.rb', line 77 optional :number_pool_settings, -> { Telnyx::NumberPoolSettings }, nil?: true |
#organization_id ⇒ String?
The organization that owns this messaging profile.
83 |
# File 'lib/telnyx/models/messaging_profile.rb', line 83 optional :organization_id, String |
#record_type ⇒ Telnyx::Models::MessagingProfile::record_type? (readonly)
Returns the value of attribute record_type.
116 117 118 |
# File 'sig/telnyx/models/messaging_profile.rbs', line 116 def record_type @record_type end |
#redaction_enabled ⇒ Boolean?
Indicates whether message content redaction is enabled for this profile.
89 |
# File 'lib/telnyx/models/messaging_profile.rb', line 89 optional :redaction_enabled, Telnyx::Internal::Type::Boolean |
#redaction_level ⇒ Integer?
Determines how much information is redacted in messages for privacy or compliance purposes.
96 |
# File 'lib/telnyx/models/messaging_profile.rb', line 96 optional :redaction_level, Integer |
#resource_group_id ⇒ String?
The resource group ID associated with this messaging profile.
102 |
# File 'lib/telnyx/models/messaging_profile.rb', line 102 optional :resource_group_id, String, nil?: true |
#smart_encoding ⇒ Boolean?
Enables automatic character encoding optimization for SMS messages. When enabled, the system automatically selects the most efficient encoding (GSM-7 or UCS-2) based on message content to maximize character limits and minimize costs.
110 |
# File 'lib/telnyx/models/messaging_profile.rb', line 110 optional :smart_encoding, Telnyx::Internal::Type::Boolean |
#updated_at ⇒ Time? (readonly)
Returns the value of attribute updated_at.
122 123 124 |
# File 'sig/telnyx/models/messaging_profile.rbs', line 122 def updated_at @updated_at end |
#url_shortener_settings ⇒ Telnyx::Models::URLShortenerSettings?
The URL shortener feature allows automatic replacement of URLs that were generated using a public URL shortener service. Some examples include bit.do, bit.ly, goo.gl, ht.ly, is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com. Such URLs are replaced with with links generated by Telnyx. The use of custom links can improve branding and message deliverability.
To disable this feature, set the object field to null.
122 |
# File 'lib/telnyx/models/messaging_profile.rb', line 122 optional :url_shortener_settings, -> { Telnyx::URLShortenerSettings }, nil?: true |
#v1_secret ⇒ String?
Secret used to authenticate with v1 endpoints.
128 |
# File 'lib/telnyx/models/messaging_profile.rb', line 128 optional :v1_secret, String |
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1, v2, or a legacy 2010-04-01 format.
135 |
# File 'lib/telnyx/models/messaging_profile.rb', line 135 optional :webhook_api_version, enum: -> { Telnyx::MessagingProfile::WebhookAPIVersion } |
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this messaging profile will be sent if sending to the primary URL fails.
142 |
# File 'lib/telnyx/models/messaging_profile.rb', line 142 optional :webhook_failover_url, String, nil?: true |
#webhook_url ⇒ String?
The URL where webhooks related to this messaging profile will be sent.
148 |
# File 'lib/telnyx/models/messaging_profile.rb', line 148 optional :webhook_url, String, nil?: true |
#whitelisted_destinations ⇒ Array<String>?
Destinations to which the messaging profile is allowed to send. The elements in
the list must be valid ISO 3166-1 alpha-2 country codes. If set to ["*"], all
destinations will be allowed.
156 |
# File 'lib/telnyx/models/messaging_profile.rb', line 156 optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/messaging_profile.rb', line 248
|
Instance Method Details
#created_at= ⇒ Time (readonly)
114 |
# File 'sig/telnyx/models/messaging_profile.rbs', line 114
def created_at=: (Time) -> Time
|
#id= ⇒ String (readonly)
110 |
# File 'sig/telnyx/models/messaging_profile.rbs', line 110
def id=: (String) -> String
|
#record_type= ⇒ Object (readonly)
118 |
# File 'sig/telnyx/models/messaging_profile.rbs', line 118
def record_type=: (
|
#to_hash ⇒ {
155 |
# File 'sig/telnyx/models/messaging_profile.rbs', line 155
def to_hash: -> {
|
#updated_at= ⇒ Time (readonly)
124 |
# File 'sig/telnyx/models/messaging_profile.rbs', line 124
def updated_at=: (Time) -> Time
|