Class: Telnyx::Models::MessagingProfileUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MessagingProfileUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/messaging_profile_update_params.rb
Overview
Defined Under Namespace
Modules: WebhookAPIVersion
Instance Attribute Summary collapse
-
#alpha_sender ⇒ String?
The alphanumeric sender ID to use when sending to destinations that require an alphanumeric sender ID.
-
#daily_spend_limit ⇒ String?
The maximum amount of money (in USD) that can be spent by this profile before midnight UTC.
-
#daily_spend_limit_enabled ⇒ Boolean?
Whether to enforce the value configured by ‘daily_spend_limit`.
-
#enabled ⇒ Boolean?
Specifies whether the messaging profile is enabled or not.
- #messaging_profile_id ⇒ String
-
#mms_fall_back_to_sms ⇒ Boolean?
enables SMS fallback for MMS messages.
-
#mms_transcoding ⇒ Boolean?
enables automated resizing of MMS media.
-
#mobile_only ⇒ Boolean?
Send messages only to mobile phone numbers.
-
#name ⇒ String?
A user friendly name for the messaging profile.
-
#number_pool_settings ⇒ Telnyx::Models::NumberPoolSettings?
Number Pool allows you to send messages from a pool of numbers of different types, assigning weights to each type.
-
#smart_encoding ⇒ Boolean?
Enables automatic character encoding optimization for SMS messages.
-
#url_shortener_settings ⇒ Telnyx::Models::URLShortenerSettings?
The URL shortener feature allows automatic replacement of URLs that were generated using a public URL shortener service.
-
#v1_secret ⇒ String?
Secret used to authenticate with v1 endpoints.
-
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1, v2, or a legacy 2010-04-01 format.
-
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this messaging profile will be sent if sending to the primary URL fails.
-
#webhook_url ⇒ String?
The URL where webhooks related to this messaging profile will be sent.
-
#whitelisted_destinations ⇒ Array<String>?
Destinations to which the messaging profile is allowed to send.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(messaging_profile_id:, alpha_sender: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, enabled: nil, mms_fall_back_to_sms: nil, mms_transcoding: nil, mobile_only: nil, name: nil, number_pool_settings: nil, smart_encoding: nil, url_shortener_settings: nil, v1_secret: nil, webhook_api_version: nil, webhook_failover_url: nil, webhook_url: nil, whitelisted_destinations: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessagingProfileUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(messaging_profile_id:, alpha_sender: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, enabled: nil, mms_fall_back_to_sms: nil, mms_transcoding: nil, mobile_only: nil, name: nil, number_pool_settings: nil, smart_encoding: nil, url_shortener_settings: nil, v1_secret: nil, webhook_api_version: nil, webhook_failover_url: nil, webhook_url: nil, whitelisted_destinations: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::MessagingProfileUpdateParams for more details.
|
|
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 131
|
Instance Attribute Details
#alpha_sender ⇒ String?
The alphanumeric sender ID to use when sending to destinations that require an alphanumeric sender ID.
20 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 20 optional :alpha_sender, String, nil?: true |
#daily_spend_limit ⇒ String?
The maximum amount of money (in USD) that can be spent by this profile before midnight UTC.
27 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 27 optional :daily_spend_limit, String |
#daily_spend_limit_enabled ⇒ Boolean?
Whether to enforce the value configured by ‘daily_spend_limit`.
33 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 33 optional :daily_spend_limit_enabled, Telnyx::Internal::Type::Boolean |
#enabled ⇒ Boolean?
Specifies whether the messaging profile is enabled or not.
39 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 39 optional :enabled, Telnyx::Internal::Type::Boolean |
#messaging_profile_id ⇒ String
13 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 13 required :messaging_profile_id, String |
#mms_fall_back_to_sms ⇒ Boolean?
enables SMS fallback for MMS messages.
45 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 45 optional :mms_fall_back_to_sms, Telnyx::Internal::Type::Boolean |
#mms_transcoding ⇒ Boolean?
enables automated resizing of MMS media.
51 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 51 optional :mms_transcoding, Telnyx::Internal::Type::Boolean |
#mobile_only ⇒ Boolean?
Send messages only to mobile phone numbers.
57 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 57 optional :mobile_only, Telnyx::Internal::Type::Boolean |
#name ⇒ String?
A user friendly name for the messaging profile.
63 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 63 optional :name, String |
#number_pool_settings ⇒ Telnyx::Models::NumberPoolSettings?
Number Pool allows you to send messages from a pool of numbers of different types, assigning weights to each type. The pool consists of all the long code and toll free numbers assigned to the messaging profile.
To disable this feature, set the object field to ‘null`.
73 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 73 optional :number_pool_settings, -> { Telnyx::NumberPoolSettings }, nil?: true |
#smart_encoding ⇒ Boolean?
Enables automatic character encoding optimization for SMS messages. When enabled, the system automatically selects the most efficient encoding (GSM-7 or UCS-2) based on message content to maximize character limits and minimize costs.
81 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 81 optional :smart_encoding, Telnyx::Internal::Type::Boolean |
#url_shortener_settings ⇒ Telnyx::Models::URLShortenerSettings?
The URL shortener feature allows automatic replacement of URLs that were generated using a public URL shortener service. Some examples include bit.do, bit.ly, goo.gl, ht.ly, is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com. Such URLs are replaced with with links generated by Telnyx. The use of custom links can improve branding and message deliverability.
To disable this feature, set the object field to ‘null`.
93 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 93 optional :url_shortener_settings, -> { Telnyx::URLShortenerSettings }, nil?: true |
#v1_secret ⇒ String?
Secret used to authenticate with v1 endpoints.
99 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 99 optional :v1_secret, String |
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1, v2, or a legacy 2010-04-01 format.
106 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 106 optional :webhook_api_version, enum: -> { Telnyx::MessagingProfileUpdateParams::WebhookAPIVersion } |
#webhook_failover_url ⇒ String?
The failover URL where webhooks related to this messaging profile will be sent if sending to the primary URL fails.
113 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 113 optional :webhook_failover_url, String, nil?: true |
#webhook_url ⇒ String?
The URL where webhooks related to this messaging profile will be sent.
119 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 119 optional :webhook_url, String, nil?: true |
#whitelisted_destinations ⇒ Array<String>?
Destinations to which the messaging profile is allowed to send. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ‘[“*”]`, all destinations will be allowed.
This field is required if the messaging profile doesn’t have it defined yet.
129 |
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 129 optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String] |