Class: Telnyx::Models::MessagingProfileUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/messaging_profile_update_params.rb

Overview

Defined Under Namespace

Modules: WebhookAPIVersion

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(alpha_sender: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, enabled: nil, mms_fall_back_to_sms: nil, mms_transcoding: nil, mobile_only: nil, name: nil, number_pool_settings: nil, smart_encoding: nil, url_shortener_settings: nil, v1_secret: nil, webhook_api_version: nil, webhook_failover_url: nil, webhook_url: nil, whitelisted_destinations: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MessagingProfileUpdateParams for more details.

Parameters:

  • alpha_sender (String, nil) (defaults to: nil)

    The alphanumeric sender ID to use when sending to destinations that require an a

  • daily_spend_limit (String) (defaults to: nil)

    The maximum amount of money (in USD) that can be spent by this profile before mi

  • daily_spend_limit_enabled (Boolean) (defaults to: nil)

    Whether to enforce the value configured by ‘daily_spend_limit`.

  • enabled (Boolean) (defaults to: nil)

    Specifies whether the messaging profile is enabled or not.

  • mms_fall_back_to_sms (Boolean) (defaults to: nil)

    enables SMS fallback for MMS messages.

  • mms_transcoding (Boolean) (defaults to: nil)

    enables automated resizing of MMS media.

  • mobile_only (Boolean) (defaults to: nil)

    Send messages only to mobile phone numbers.

  • name (String) (defaults to: nil)

    A user friendly name for the messaging profile.

  • number_pool_settings (Telnyx::Models::NumberPoolSettings, nil) (defaults to: nil)

    Number Pool allows you to send messages from a pool of numbers of different type

  • smart_encoding (Boolean) (defaults to: nil)

    Enables automatic character encoding optimization for SMS messages. When enabled

  • url_shortener_settings (Telnyx::Models::URLShortenerSettings, nil) (defaults to: nil)

    The URL shortener feature allows automatic replacement of URLs that were generat

  • v1_secret (String) (defaults to: nil)

    Secret used to authenticate with v1 endpoints.

  • webhook_api_version (Symbol, Telnyx::Models::MessagingProfileUpdateParams::WebhookAPIVersion) (defaults to: nil)

    Determines which webhook format will be used, Telnyx API v1, v2, or a legacy 201

  • webhook_failover_url (String, nil) (defaults to: nil)

    The failover URL where webhooks related to this messaging profile will be sent i

  • webhook_url (String, nil) (defaults to: nil)

    The URL where webhooks related to this messaging profile will be sent.

  • whitelisted_destinations (Array<String>) (defaults to: nil)

    Destinations to which the messaging profile is allowed to send. The elements in

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 126

Instance Attribute Details

#alpha_senderString?

The alphanumeric sender ID to use when sending to destinations that require an alphanumeric sender ID.

Returns:

  • (String, nil)


15
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 15

optional :alpha_sender, String, nil?: true

#daily_spend_limitString?

The maximum amount of money (in USD) that can be spent by this profile before midnight UTC.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 22

optional :daily_spend_limit, String

#daily_spend_limit_enabledBoolean?

Whether to enforce the value configured by ‘daily_spend_limit`.

Returns:

  • (Boolean, nil)


28
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 28

optional :daily_spend_limit_enabled, Telnyx::Internal::Type::Boolean

#enabledBoolean?

Specifies whether the messaging profile is enabled or not.

Returns:

  • (Boolean, nil)


34
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 34

optional :enabled, Telnyx::Internal::Type::Boolean

#mms_fall_back_to_smsBoolean?

enables SMS fallback for MMS messages.

Returns:

  • (Boolean, nil)


40
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 40

optional :mms_fall_back_to_sms, Telnyx::Internal::Type::Boolean

#mms_transcodingBoolean?

enables automated resizing of MMS media.

Returns:

  • (Boolean, nil)


46
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 46

optional :mms_transcoding, Telnyx::Internal::Type::Boolean

#mobile_onlyBoolean?

Send messages only to mobile phone numbers.

Returns:

  • (Boolean, nil)


52
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 52

optional :mobile_only, Telnyx::Internal::Type::Boolean

#nameString?

A user friendly name for the messaging profile.

Returns:

  • (String, nil)


58
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 58

optional :name, String

#number_pool_settingsTelnyx::Models::NumberPoolSettings?

Number Pool allows you to send messages from a pool of numbers of different types, assigning weights to each type. The pool consists of all the long code and toll free numbers assigned to the messaging profile.

To disable this feature, set the object field to ‘null`.



68
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 68

optional :number_pool_settings, -> { Telnyx::NumberPoolSettings }, nil?: true

#smart_encodingBoolean?

Enables automatic character encoding optimization for SMS messages. When enabled, the system automatically selects the most efficient encoding (GSM-7 or UCS-2) based on message content to maximize character limits and minimize costs.

Returns:

  • (Boolean, nil)


76
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 76

optional :smart_encoding, Telnyx::Internal::Type::Boolean

#url_shortener_settingsTelnyx::Models::URLShortenerSettings?

The URL shortener feature allows automatic replacement of URLs that were generated using a public URL shortener service. Some examples include bit.do, bit.ly, goo.gl, ht.ly, is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com. Such URLs are replaced with with links generated by Telnyx. The use of custom links can improve branding and message deliverability.

To disable this feature, set the object field to ‘null`.



88
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 88

optional :url_shortener_settings, -> { Telnyx::URLShortenerSettings }, nil?: true

#v1_secretString?

Secret used to authenticate with v1 endpoints.

Returns:

  • (String, nil)


94
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 94

optional :v1_secret, String

#webhook_api_versionSymbol, ...

Determines which webhook format will be used, Telnyx API v1, v2, or a legacy 2010-04-01 format.



101
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 101

optional :webhook_api_version, enum: -> { Telnyx::MessagingProfileUpdateParams::WebhookAPIVersion }

#webhook_failover_urlString?

The failover URL where webhooks related to this messaging profile will be sent if sending to the primary URL fails.

Returns:

  • (String, nil)


108
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 108

optional :webhook_failover_url, String, nil?: true

#webhook_urlString?

The URL where webhooks related to this messaging profile will be sent.

Returns:

  • (String, nil)


114
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 114

optional :webhook_url, String, nil?: true

#whitelisted_destinationsArray<String>?

Destinations to which the messaging profile is allowed to send. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ‘[“*”]`, all destinations will be allowed.

This field is required if the messaging profile doesn’t have it defined yet.

Returns:

  • (Array<String>, nil)


124
# File 'lib/telnyx/models/messaging_profile_update_params.rb', line 124

optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String]