Class: Telnyx::Models::MinimaxVoiceSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MinimaxVoiceSettings
- Defined in:
- lib/telnyx/models/minimax_voice_settings.rb
Defined Under Namespace
Modules: LanguageBoost, Type
Instance Attribute Summary collapse
-
#language_boost ⇒ Symbol, ...
Enhances recognition for specific languages and dialects during MiniMax TTS synthesis.
-
#pitch ⇒ Integer?
Voice pitch adjustment.
-
#speed ⇒ Float?
Speech speed multiplier.
-
#type ⇒ Symbol, Telnyx::Models::MinimaxVoiceSettings::Type
Voice settings provider type.
-
#vol ⇒ Float?
Speech volume multiplier.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type:, language_boost: nil, pitch: nil, speed: nil, vol: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MinimaxVoiceSettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, language_boost: nil, pitch: nil, speed: nil, vol: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::MinimaxVoiceSettings for more details.
|
|
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 38
|
Instance Attribute Details
#language_boost ⇒ Symbol, ...
Enhances recognition for specific languages and dialects during MiniMax TTS synthesis. Default is null (no boost). Set to ‘auto’ for automatic language detection.
18 |
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 18 optional :language_boost, enum: -> { Telnyx::MinimaxVoiceSettings::LanguageBoost }, nil?: true |
#pitch ⇒ Integer?
Voice pitch adjustment. Default is 0.
24 |
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 24 optional :pitch, Integer |
#speed ⇒ Float?
Speech speed multiplier. Default is 1.0.
30 |
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 30 optional :speed, Float |
#type ⇒ Symbol, Telnyx::Models::MinimaxVoiceSettings::Type
Voice settings provider type
10 |
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 10 required :type, enum: -> { Telnyx::MinimaxVoiceSettings::Type } |
#vol ⇒ Float?
Speech volume multiplier. Default is 1.0.
36 |
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 36 optional :vol, Float |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/minimax_voice_settings.rb', line 60
|