Class: Telnyx::Models::MobileNetworkOperatorListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/mobile_network_operator_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, country_code: nil, mcc: nil, mnc: nil, name: nil, network_preferences_enabled: nil, record_type: nil, tadig: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::MobileNetworkOperatorListResponse for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • country_code (String) (defaults to: nil)

    The mobile operator two-character (ISO 3166-1 alpha-2) origin country code.

  • mcc (String) (defaults to: nil)

    MCC stands for Mobile Country Code. It’s a three decimal digit that identifies a

  • mnc (String) (defaults to: nil)

    MNC stands for Mobile Network Code. It’s a two to three decimal digits that iden

  • name (String) (defaults to: nil)

    The network operator name.

  • network_preferences_enabled (Boolean) (defaults to: nil)

    Indicate whether the mobile network operator can be set as preferred in the Netw

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • tadig (String) (defaults to: nil)

    TADIG stands for Transferred Account Data Interchange Group. The TADIG code is a



# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 65

Instance Attribute Details

#country_codeString?

The mobile operator two-character (ISO 3166-1 alpha-2) origin country code.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 11

optional :country_code, String

#mccString?

MCC stands for Mobile Country Code. It’s a three decimal digit that identifies a country.<br/><br/> This code is commonly seen joined with a Mobile Network Code (MNC) in a tuple that allows identifying a carrier known as PLMN (Public Land Mobile Network) code.

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 20

optional :mcc, String

#mncString?

MNC stands for Mobile Network Code. It’s a two to three decimal digits that identify a network.<br/><br/> This code is commonly seen joined with a Mobile Country Code (MCC) in a tuple that allows identifying a carrier known as PLMN (Public Land Mobile Network) code.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 29

optional :mnc, String

#nameString?

The network operator name.

Returns:

  • (String, nil)


35
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 35

optional :name, String

#tadigString?

TADIG stands for Transferred Account Data Interchange Group. The TADIG code is a unique identifier for network operators in GSM mobile networks.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/mobile_network_operator_list_response.rb', line 42

optional :tadig, String