Class: Telnyx::Models::MobilePhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/mobile_phone_number.rb

Overview

Defined Under Namespace

Modules: InboundCallScreening, NoiseSuppression Classes: CallForwarding, CallRecording, CnamListing, Inbound, Outbound

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(interception_app_id: nil, interception_app_name: nil) ⇒ Object

Parameters:

  • interception_app_id (String, nil) (defaults to: nil)

    The ID of the app that will intercept inbound calls.

  • interception_app_name (String, nil) (defaults to: nil)

    The name of the app that will intercept inbound calls.



# File 'lib/telnyx/models/mobile_phone_number.rb', line 140

Instance Attribute Details

#call_forwardingTelnyx::Models::MobilePhoneNumber::CallForwarding?



10
# File 'lib/telnyx/models/mobile_phone_number.rb', line 10

optional :call_forwarding, -> { Telnyx::MobilePhoneNumber::CallForwarding }

#call_recordingTelnyx::Models::MobilePhoneNumber::CallRecording?



15
# File 'lib/telnyx/models/mobile_phone_number.rb', line 15

optional :call_recording, -> { Telnyx::MobilePhoneNumber::CallRecording }

#caller_id_name_enabledBoolean?

Indicates if caller ID name is enabled.

Returns:

  • (Boolean, nil)


21
# File 'lib/telnyx/models/mobile_phone_number.rb', line 21

optional :caller_id_name_enabled, Telnyx::Internal::Type::Boolean

#cnam_listingTelnyx::Models::MobilePhoneNumber::CnamListing?



26
# File 'lib/telnyx/models/mobile_phone_number.rb', line 26

optional :cnam_listing, -> { Telnyx::MobilePhoneNumber::CnamListing }

#connection_idString?

The ID of the connection associated with this number.

Returns:

  • (String, nil)


32
# File 'lib/telnyx/models/mobile_phone_number.rb', line 32

optional :connection_id, String, nil?: true

#customer_referenceString?

A customer reference string.

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/mobile_phone_number.rb', line 38

optional :customer_reference, String, nil?: true

#inboundTelnyx::Models::MobilePhoneNumber::Inbound?



43
# File 'lib/telnyx/models/mobile_phone_number.rb', line 43

optional :inbound, -> { Telnyx::MobilePhoneNumber::Inbound }

#inbound_call_screeningSymbol, ...

The inbound call screening setting.



49
50
51
52
53
# File 'lib/telnyx/models/mobile_phone_number.rb', line 49

optional :inbound_call_screening,
enum: -> {
  Telnyx::MobilePhoneNumber::InboundCallScreening
},
nil?: true

#noise_suppressionSymbol, ...

The noise suppression setting.



59
# File 'lib/telnyx/models/mobile_phone_number.rb', line 59

optional :noise_suppression, enum: -> { Telnyx::MobilePhoneNumber::NoiseSuppression }

#outboundTelnyx::Models::MobilePhoneNumber::Outbound?



64
# File 'lib/telnyx/models/mobile_phone_number.rb', line 64

optional :outbound, -> { Telnyx::MobilePhoneNumber::Outbound }

#tagsArray<String>?

A list of tags associated with the number.

Returns:

  • (Array<String>, nil)


70
# File 'lib/telnyx/models/mobile_phone_number.rb', line 70

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/mobile_phone_number.rb', line 216