Class: Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings
- Defined in:
- lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb,
sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs
Overview
Defined Under Namespace
Modules: RecordType, Type Classes: Features
Instance Attribute Summary collapse
-
#country_code ⇒ String?
readonly
Returns the value of attribute country_code.
-
#created_at ⇒ Time?
readonly
Returns the value of attribute created_at.
-
#features ⇒ Telnyx::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::Features?
readonly
Returns the value of attribute features.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#messaging_product ⇒ String?
The messaging product that the number is registered to use.
-
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
-
#organization_id ⇒ String?
The organization that owns this phone number.
-
#phone_number ⇒ String?
readonly
Returns the value of attribute phone_number.
-
#record_type ⇒ Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::record_type?
readonly
Returns the value of attribute record_type.
-
#tags ⇒ Array<String>?
Tags associated with this phone number.
-
#traffic_type ⇒ String?
readonly
Returns the value of attribute traffic_type.
-
#type ⇒ Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::type_?
readonly
Returns the value of attribute type.
-
#updated_at ⇒ Time?
readonly
Returns the value of attribute updated_at.
Class Method Summary collapse
Instance Method Summary collapse
- #country_code ⇒ String readonly
- #created_at ⇒ Time readonly
- #features ⇒ Object readonly
- #id ⇒ String readonly
-
#initialize(sms: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Features for more details.
- #phone_number ⇒ String readonly
- #record_type ⇒ Object readonly
- #to_hash ⇒ {
- #traffic_type ⇒ String readonly
- #type ⇒ Object readonly
- #updated_at ⇒ Time readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(sms: nil) ⇒ Object
Some parameter documentations has been truncated, see Features for more details.
|
|
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 88
|
Instance Attribute Details
#country_code ⇒ String? (readonly)
Returns the value of attribute country_code.
42 43 44 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 42 def country_code @country_code end |
#created_at ⇒ Time? (readonly)
Returns the value of attribute created_at.
46 47 48 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 46 def created_at @created_at end |
#features ⇒ Telnyx::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::Features? (readonly)
Returns the value of attribute features.
50 51 52 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 50 def features @features end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
38 39 40 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 38 def id @id end |
#messaging_product ⇒ String?
The messaging product that the number is registered to use
12 |
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 12 optional :messaging_product, String |
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
18 |
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 18 optional :messaging_profile_id, String, nil?: true |
#organization_id ⇒ String?
The organization that owns this phone number.
24 |
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 24 optional :organization_id, String |
#phone_number ⇒ String? (readonly)
Returns the value of attribute phone_number.
56 57 58 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 56 def phone_number @phone_number end |
#record_type ⇒ Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::record_type? (readonly)
Returns the value of attribute record_type.
60 61 62 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 60 def record_type @record_type end |
#tags ⇒ Array<String>?
Tags associated with this phone number.
30 |
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 30 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#traffic_type ⇒ String? (readonly)
Returns the value of attribute traffic_type.
66 67 68 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 66 def traffic_type @traffic_type end |
#type ⇒ Telnyx::Models::MobilePhoneNumbers::MobilePhoneNumberWithMessagingSettings::type_? (readonly)
Returns the value of attribute type.
70 71 72 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 70 def type @type end |
#updated_at ⇒ Time? (readonly)
Returns the value of attribute updated_at.
76 77 78 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 76 def updated_at @updated_at end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rb', line 142
|
Instance Method Details
#country_code= ⇒ String (readonly)
44 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 44
def country_code=: (String) -> String
|
#created_at= ⇒ Time (readonly)
48 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 48
def created_at=: (Time) -> Time
|
#features= ⇒ Object (readonly)
52 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 52
def features=: (
|
#id= ⇒ String (readonly)
40 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 40
def id=: (String) -> String
|
#phone_number= ⇒ String (readonly)
58 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 58
def phone_number=: (String) -> String
|
#record_type= ⇒ Object (readonly)
62 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 62
def record_type=: (
|
#to_hash ⇒ {
96 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 96
def to_hash: -> {
|
#traffic_type= ⇒ String (readonly)
68 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 68
def traffic_type=: (String) -> String
|
#type= ⇒ Object (readonly)
72 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 72
def type=: (
|
#updated_at= ⇒ Time (readonly)
78 |
# File 'sig/telnyx/models/mobile_phone_numbers/mobile_phone_number_with_messaging_settings.rbs', line 78
def updated_at=: (Time) -> Time
|