Class: Telnyx::Models::NetworkListInterfacesResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NetworkListInterfacesResponse
- Defined in:
- lib/telnyx/models/network_list_interfaces_response.rb,
sig/telnyx/models/network_list_interfaces_response.rbs
Overview
Defined Under Namespace
Classes: Region
Instance Attribute Summary collapse
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#name ⇒ String?
A user specified name for the interface.
-
#network_id ⇒ String?
The id of the network associated with the interface.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
- #region ⇒ Telnyx::Models::NetworkListInterfacesResponse::Region?
-
#region_code ⇒ String?
The region interface is deployed to.
-
#status ⇒ Telnyx::Models::interface_status?
readonly
Returns the value of attribute status.
-
#type ⇒ String?
readonly
Returns the value of attribute type.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Instance Method Summary collapse
- #created_at ⇒ String readonly
- #id ⇒ String readonly
- #initialize(id: nil, created_at: nil, name: nil, network_id: nil, record_type: nil, region: nil, region_code: nil, status: nil, type: nil, updated_at: nil) ⇒ Object constructor
- #record_type ⇒ String readonly
- #status ⇒ Object readonly
- #to_hash ⇒ {
- #type ⇒ String readonly
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, name: nil, network_id: nil, record_type: nil, region: nil, region_code: nil, status: nil, type: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/network_list_interfaces_response.rb', line 68
|
Instance Attribute Details
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
40 41 42 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 40 def created_at @created_at end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
36 37 38 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 36 def id @id end |
#name ⇒ String?
A user specified name for the interface.
11 |
# File 'lib/telnyx/models/network_list_interfaces_response.rb', line 11 optional :name, String |
#network_id ⇒ String?
The id of the network associated with the interface.
17 |
# File 'lib/telnyx/models/network_list_interfaces_response.rb', line 17 optional :network_id, String |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
44 45 46 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 44 def record_type @record_type end |
#region ⇒ Telnyx::Models::NetworkListInterfacesResponse::Region?
22 |
# File 'lib/telnyx/models/network_list_interfaces_response.rb', line 22 optional :region, -> { Telnyx::Models::NetworkListInterfacesResponse::Region } |
#region_code ⇒ String?
The region interface is deployed to.
28 |
# File 'lib/telnyx/models/network_list_interfaces_response.rb', line 28 optional :region_code, String |
#status ⇒ Telnyx::Models::interface_status? (readonly)
Returns the value of attribute status.
48 49 50 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 48 def status @status end |
#type ⇒ String? (readonly)
Returns the value of attribute type.
54 55 56 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 54 def type @type end |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
58 59 60 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 58 def updated_at @updated_at end |
Instance Method Details
#created_at= ⇒ String (readonly)
42 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 42
def created_at=: (String) -> String
|
#id= ⇒ String (readonly)
38 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 38
def id=: (String) -> String
|
#record_type= ⇒ String (readonly)
46 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 46
def record_type=: (String) -> String
|
#status= ⇒ Object (readonly)
50 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 50
def status=: (
|
#to_hash ⇒ {
75 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 75
def to_hash: -> {
|
#type= ⇒ String (readonly)
56 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 56
def type=: (String) -> String
|
#updated_at= ⇒ String (readonly)
60 |
# File 'sig/telnyx/models/network_list_interfaces_response.rbs', line 60
def updated_at=: (String) -> String
|