Class: Telnyx::Models::NotificationEventConditionListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NotificationEventConditionListResponse
- Defined in:
- lib/telnyx/models/notification_event_condition_list_response.rb
Overview
Defined Under Namespace
Modules: AssociatedRecordType Classes: Parameter
Instance Attribute Summary collapse
-
#allow_multiple_channels ⇒ Boolean?
Dictates whether a notification channel id needs to be provided when creating a notficiation setting.
- #associated_record_type ⇒ Symbol, ...
-
#asynchronous ⇒ Boolean?
Dictates whether a notification setting will take effect immediately.
-
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
- #description ⇒ String?
- #enabled ⇒ Boolean?
- #name ⇒ String?
- #notification_event_id ⇒ String?
- #parameters ⇒ Array<Telnyx::Models::NotificationEventConditionListResponse::Parameter>?
-
#supported_channels ⇒ Array<String>?
Dictates the supported notification channel types that can be emitted.
-
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, allow_multiple_channels: nil, associated_record_type: nil, asynchronous: nil, created_at: nil, description: nil, enabled: nil, name: nil, notification_event_id: nil, parameters: nil, supported_channels: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see NotificationEventConditionListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, allow_multiple_channels: nil, associated_record_type: nil, asynchronous: nil, created_at: nil, description: nil, enabled: nil, name: nil, notification_event_id: nil, parameters: nil, supported_channels: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::NotificationEventConditionListResponse for more details.
|
|
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 78
|
Instance Attribute Details
#allow_multiple_channels ⇒ Boolean?
Dictates whether a notification channel id needs to be provided when creating a notficiation setting.
12 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 12 optional :allow_multiple_channels, Telnyx::Internal::Type::Boolean |
#associated_record_type ⇒ Symbol, ...
17 18 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 17 optional :associated_record_type, enum: -> { Telnyx::Models::NotificationEventConditionListResponse::AssociatedRecordType } |
#asynchronous ⇒ Boolean?
Dictates whether a notification setting will take effect immediately.
24 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 24 optional :asynchronous, Telnyx::Internal::Type::Boolean |
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
30 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 30 optional :created_at, Time |
#description ⇒ String?
35 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 35 optional :description, String |
#enabled ⇒ Boolean?
40 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 40 optional :enabled, Telnyx::Internal::Type::Boolean |
#name ⇒ String?
45 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 45 optional :name, String |
#notification_event_id ⇒ String?
50 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 50 optional :notification_event_id, String |
#parameters ⇒ Array<Telnyx::Models::NotificationEventConditionListResponse::Parameter>?
55 56 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 55 optional :parameters, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::NotificationEventConditionListResponse::Parameter] } |
#supported_channels ⇒ Array<String>?
Dictates the supported notification channel types that can be emitted.
62 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 62 optional :supported_channels, Telnyx::Internal::Type::ArrayOf[String] |
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
68 |
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 68 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/notification_event_condition_list_response.rb', line 113
|