Class: Telnyx::Models::NumberBlockOrder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberBlockOrder
- Defined in:
- lib/telnyx/models/number_block_order.rb,
sig/telnyx/models/number_block_order.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#connection_id ⇒ String?
Identifies the connection associated to all numbers in the phone number block.
-
#created_at ⇒ Time?
readonly
Returns the value of attribute created_at.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated to all numbers in the phone number block.
-
#phone_numbers_count ⇒ Integer?
readonly
Returns the value of attribute phone_numbers_count.
-
#range ⇒ Integer?
The phone number range included in the block.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#requirements_met ⇒ Boolean?
readonly
Returns the value of attribute requirements_met.
-
#starting_number ⇒ String?
Starting phone number block.
-
#status ⇒ Telnyx::Models::NumberBlockOrder::status?
readonly
Returns the value of attribute status.
-
#updated_at ⇒ Time?
readonly
Returns the value of attribute updated_at.
Instance Method Summary collapse
- #created_at ⇒ Time readonly
- #id ⇒ String readonly
-
#initialize(id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers_count: nil, range: nil, record_type: nil, requirements_met: nil, starting_number: nil, status: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see NumberBlockOrder for more details.
- #phone_numbers_count ⇒ Integer readonly
- #record_type ⇒ String readonly
- #requirements_met ⇒ Boolean readonly
- #status ⇒ Object readonly
- #to_hash ⇒ {
- #updated_at ⇒ Time readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers_count: nil, range: nil, record_type: nil, requirements_met: nil, starting_number: nil, status: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::NumberBlockOrder for more details.
|
|
# File 'lib/telnyx/models/number_block_order.rb', line 80
|
Instance Attribute Details
#connection_id ⇒ String?
Identifies the connection associated to all numbers in the phone number block.
11 |
# File 'lib/telnyx/models/number_block_order.rb', line 11 optional :connection_id, String |
#created_at ⇒ Time? (readonly)
Returns the value of attribute created_at.
44 45 46 |
# File 'sig/telnyx/models/number_block_order.rbs', line 44 def created_at @created_at end |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
17 |
# File 'lib/telnyx/models/number_block_order.rb', line 17 optional :customer_reference, String |
#id ⇒ String? (readonly)
Returns the value of attribute id.
40 41 42 |
# File 'sig/telnyx/models/number_block_order.rbs', line 40 def id @id end |
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated to all numbers in the phone number block.
24 |
# File 'lib/telnyx/models/number_block_order.rb', line 24 optional :messaging_profile_id, String |
#phone_numbers_count ⇒ Integer? (readonly)
Returns the value of attribute phone_numbers_count.
48 49 50 |
# File 'sig/telnyx/models/number_block_order.rbs', line 48 def phone_numbers_count @phone_numbers_count end |
#range ⇒ Integer?
The phone number range included in the block.
30 |
# File 'lib/telnyx/models/number_block_order.rb', line 30 optional :range, Integer |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
52 53 54 |
# File 'sig/telnyx/models/number_block_order.rbs', line 52 def record_type @record_type end |
#requirements_met ⇒ Boolean? (readonly)
Returns the value of attribute requirements_met.
56 57 58 |
# File 'sig/telnyx/models/number_block_order.rbs', line 56 def requirements_met @requirements_met end |
#starting_number ⇒ String?
Starting phone number block
36 |
# File 'lib/telnyx/models/number_block_order.rb', line 36 optional :starting_number, String |
#status ⇒ Telnyx::Models::NumberBlockOrder::status? (readonly)
Returns the value of attribute status.
60 61 62 |
# File 'sig/telnyx/models/number_block_order.rbs', line 60 def status @status end |
#updated_at ⇒ Time? (readonly)
Returns the value of attribute updated_at.
66 67 68 |
# File 'sig/telnyx/models/number_block_order.rbs', line 66 def updated_at @updated_at end |
Instance Method Details
#created_at= ⇒ Time (readonly)
46 |
# File 'sig/telnyx/models/number_block_order.rbs', line 46
def created_at=: (Time) -> Time
|
#id= ⇒ String (readonly)
42 |
# File 'sig/telnyx/models/number_block_order.rbs', line 42
def id=: (String) -> String
|
#phone_numbers_count= ⇒ Integer (readonly)
50 |
# File 'sig/telnyx/models/number_block_order.rbs', line 50
def phone_numbers_count=: (Integer) -> Integer
|
#record_type= ⇒ String (readonly)
54 |
# File 'sig/telnyx/models/number_block_order.rbs', line 54
def record_type=: (String) -> String
|
#requirements_met= ⇒ Boolean (readonly)
58 |
# File 'sig/telnyx/models/number_block_order.rbs', line 58
def requirements_met=: (bool) -> bool
|
#status= ⇒ Object (readonly)
62 |
# File 'sig/telnyx/models/number_block_order.rbs', line 62
def status=: (
|
#to_hash ⇒ {
85 |
# File 'sig/telnyx/models/number_block_order.rbs', line 85
def to_hash: -> {
|
#updated_at= ⇒ Time (readonly)
68 |
# File 'sig/telnyx/models/number_block_order.rbs', line 68
def updated_at=: (Time) -> Time
|