Class: Telnyx::Models::NumberBlockOrder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/number_block_order.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers_count: nil, range: nil, record_type: nil, requirements_met: nil, starting_number: nil, status: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::NumberBlockOrder for more details.

Parameters:

  • id (String) (defaults to: nil)
  • connection_id (String) (defaults to: nil)

    Identifies the connection associated to all numbers in the phone number block.

  • created_at (Time) (defaults to: nil)

    An ISO 8901 datetime string denoting when the number order was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • messaging_profile_id (String) (defaults to: nil)

    Identifies the messaging profile associated to all numbers in the phone number b

  • phone_numbers_count (Integer) (defaults to: nil)

    The count of phone numbers in the number order.

  • range (Integer) (defaults to: nil)

    The phone number range included in the block.

  • record_type (String) (defaults to: nil)
  • requirements_met (Boolean) (defaults to: nil)

    True if all requirements are met for every phone number, false otherwise.

  • starting_number (String) (defaults to: nil)

    Starting phone number block

  • status (Symbol, Telnyx::Models::NumberBlockOrder::Status) (defaults to: nil)

    The status of the order.

  • updated_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the number order was updated.



# File 'lib/telnyx/models/number_block_order.rb', line 80

Instance Attribute Details

#connection_idString?

Identifies the connection associated to all numbers in the phone number block.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/number_block_order.rb', line 11

optional :connection_id, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/number_block_order.rb', line 17

optional :customer_reference, String

#messaging_profile_idString?

Identifies the messaging profile associated to all numbers in the phone number block.

Returns:

  • (String, nil)


24
# File 'lib/telnyx/models/number_block_order.rb', line 24

optional :messaging_profile_id, String

#rangeInteger?

The phone number range included in the block.

Returns:

  • (Integer, nil)


30
# File 'lib/telnyx/models/number_block_order.rb', line 30

optional :range, Integer

#starting_numberString?

Starting phone number block

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/number_block_order.rb', line 36

optional :starting_number, String