Class: Telnyx::Models::NumberBlockOrder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberBlockOrder
- Defined in:
- lib/telnyx/models/number_block_order.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#connection_id ⇒ String?
Identifies the connection associated to all numbers in the phone number block.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated to all numbers in the phone number block.
-
#range ⇒ Integer?
The phone number range included in the block.
-
#starting_number ⇒ String?
Starting phone number block.
Instance Method Summary collapse
-
#initialize(id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers_count: nil, range: nil, record_type: nil, requirements_met: nil, starting_number: nil, status: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see NumberBlockOrder for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers_count: nil, range: nil, record_type: nil, requirements_met: nil, starting_number: nil, status: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::NumberBlockOrder for more details.
|
|
# File 'lib/telnyx/models/number_block_order.rb', line 80
|
Instance Attribute Details
#connection_id ⇒ String?
Identifies the connection associated to all numbers in the phone number block.
11 |
# File 'lib/telnyx/models/number_block_order.rb', line 11 optional :connection_id, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
17 |
# File 'lib/telnyx/models/number_block_order.rb', line 17 optional :customer_reference, String |
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated to all numbers in the phone number block.
24 |
# File 'lib/telnyx/models/number_block_order.rb', line 24 optional :messaging_profile_id, String |
#range ⇒ Integer?
The phone number range included in the block.
30 |
# File 'lib/telnyx/models/number_block_order.rb', line 30 optional :range, Integer |
#starting_number ⇒ String?
Starting phone number block
36 |
# File 'lib/telnyx/models/number_block_order.rb', line 36 optional :starting_number, String |