Class: Telnyx::Models::NumberHealthMetrics
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberHealthMetrics
- Defined in:
- lib/telnyx/models/number_health_metrics.rb
Instance Attribute Summary collapse
-
#inbound_outbound_ratio ⇒ Float
The ratio of messages received to the number of messages sent.
-
#message_count ⇒ Integer
The number of messages analyzed for the health metrics.
-
#spam_ratio ⇒ Float
The ratio of messages blocked for spam to the number of messages attempted.
-
#success_ratio ⇒ Float
The ratio of messages sucessfully delivered to the number of messages attempted.
Instance Method Summary collapse
-
#initialize(inbound_outbound_ratio:, message_count:, spam_ratio:, success_ratio:) ⇒ Object
constructor
Some parameter documentations has been truncated, see NumberHealthMetrics for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(inbound_outbound_ratio:, message_count:, spam_ratio:, success_ratio:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::NumberHealthMetrics for more details.
High level health metrics about the number and it’s messaging sending patterns.
|
|
# File 'lib/telnyx/models/number_health_metrics.rb', line 30
|
Instance Attribute Details
#inbound_outbound_ratio ⇒ Float
The ratio of messages received to the number of messages sent.
10 |
# File 'lib/telnyx/models/number_health_metrics.rb', line 10 required :inbound_outbound_ratio, Float |
#message_count ⇒ Integer
The number of messages analyzed for the health metrics.
16 |
# File 'lib/telnyx/models/number_health_metrics.rb', line 16 required :message_count, Integer |
#spam_ratio ⇒ Float
The ratio of messages blocked for spam to the number of messages attempted.
22 |
# File 'lib/telnyx/models/number_health_metrics.rb', line 22 required :spam_ratio, Float |
#success_ratio ⇒ Float
The ratio of messages sucessfully delivered to the number of messages attempted.
28 |
# File 'lib/telnyx/models/number_health_metrics.rb', line 28 required :success_ratio, Float |