Class: Telnyx::Models::NumberLookupRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberLookupRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/number_lookup_retrieve_response.rb
Overview
Defined Under Namespace
Classes: CallerName, Carrier, Portability
Instance Attribute Summary collapse
- #caller_name ⇒ Telnyx::Models::NumberLookupRetrieveResponse::Data::CallerName?
- #carrier ⇒ Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier?
-
#country_code ⇒ String?
Region code that matches the specific country calling code.
-
#fraud ⇒ String?
Unused.
-
#national_format ⇒ String?
Hyphen-separated national number, preceded by the national destination code (NDC), with a 0 prefix, if an NDC is found.
-
#phone_number ⇒ String?
E164-formatted phone number.
- #portability ⇒ Telnyx::Models::NumberLookupRetrieveResponse::Data::Portability?
-
#record_type ⇒ String?
Identifies the type of record.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(caller_name: nil, error_code: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallerName for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_name: nil, error_code: nil) ⇒ Object
Some parameter documentations has been truncated, see CallerName for more details.
|
|
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 63
|
Instance Attribute Details
#caller_name ⇒ Telnyx::Models::NumberLookupRetrieveResponse::Data::CallerName?
20 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 20 optional :caller_name, -> { Telnyx::Models::NumberLookupRetrieveResponse::Data::CallerName } |
#carrier ⇒ Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier?
25 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 25 optional :carrier, -> { Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier } |
#country_code ⇒ String?
Region code that matches the specific country calling code
31 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 31 optional :country_code, String |
#fraud ⇒ String?
Unused
37 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 37 optional :fraud, String, nil?: true |
#national_format ⇒ String?
Hyphen-separated national number, preceded by the national destination code (NDC), with a 0 prefix, if an NDC is found
44 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 44 optional :national_format, String |
#phone_number ⇒ String?
E164-formatted phone number
50 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 50 optional :phone_number, String |
#portability ⇒ Telnyx::Models::NumberLookupRetrieveResponse::Data::Portability?
55 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 55 optional :portability, -> { Telnyx::Models::NumberLookupRetrieveResponse::Data::Portability } |
#record_type ⇒ String?
Identifies the type of record
61 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 61 optional :record_type, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 186
|