Class: Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier
- Defined in:
- lib/telnyx/models/number_lookup_retrieve_response.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#error_code ⇒ String?
Unused.
-
#mobile_country_code ⇒ String?
Region code that matches the specific country calling code if the requested phone number type is mobile.
-
#mobile_network_code ⇒ String?
National destination code (NDC), with a 0 prefix, if an NDC is found and the requested phone number type is mobile.
-
#name ⇒ String?
SPID (Service Provider ID) name, if the requested phone number has been ported; otherwise, the name of carrier who owns the phone number block.
-
#normalized_carrier ⇒ String?
If known to Telnyx and applicable, the primary network carrier.
-
#type ⇒ Symbol, ...
A phone number type that identifies the type of service associated with the requested phone number.
Instance Method Summary collapse
-
#initialize(error_code: nil, mobile_country_code: nil, mobile_network_code: nil, name: nil, normalized_carrier: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Carrier for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(error_code: nil, mobile_country_code: nil, mobile_network_code: nil, name: nil, normalized_carrier: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::NumberLookupRetrieveResponse::Data::Carrier for more details.
|
|
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 150
|
Instance Attribute Details
#error_code ⇒ String?
Unused
114 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 114 optional :error_code, String, nil?: true |
#mobile_country_code ⇒ String?
Region code that matches the specific country calling code if the requested phone number type is mobile
121 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 121 optional :mobile_country_code, String |
#mobile_network_code ⇒ String?
National destination code (NDC), with a 0 prefix, if an NDC is found and the requested phone number type is mobile
128 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 128 optional :mobile_network_code, String |
#name ⇒ String?
SPID (Service Provider ID) name, if the requested phone number has been ported; otherwise, the name of carrier who owns the phone number block
135 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 135 optional :name, String |
#normalized_carrier ⇒ String?
If known to Telnyx and applicable, the primary network carrier.
141 |
# File 'lib/telnyx/models/number_lookup_retrieve_response.rb', line 141 optional :normalized_carrier, String |