Class: Telnyx::Models::NumberOrderCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberOrderCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/number_order_create_params.rb
Overview
Defined Under Namespace
Classes: PhoneNumber
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
-
#connection_id ⇒ String?
Identifies the connection associated with this phone number.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
- #phone_numbers ⇒ Array<Telnyx::Models::NumberOrderCreateParams::PhoneNumber>?
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
14 |
# File 'lib/telnyx/models/number_order_create_params.rb', line 14 optional :billing_group_id, String |
#connection_id ⇒ String?
Identifies the connection associated with this phone number.
20 |
# File 'lib/telnyx/models/number_order_create_params.rb', line 20 optional :connection_id, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
26 |
# File 'lib/telnyx/models/number_order_create_params.rb', line 26 optional :customer_reference, String |
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
32 |
# File 'lib/telnyx/models/number_order_create_params.rb', line 32 optional :messaging_profile_id, String |
#phone_numbers ⇒ Array<Telnyx::Models::NumberOrderCreateParams::PhoneNumber>?
37 38 |
# File 'lib/telnyx/models/number_order_create_params.rb', line 37 optional :phone_numbers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::NumberOrderCreateParams::PhoneNumber] } |