Class: Telnyx::Models::NumberOrderListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/number_order_list_response.rb

Overview

Defined Under Namespace

Modules: Status Classes: PhoneNumber

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, phone_number: nil) ⇒ Object

The unique phone numbers given as arguments in the job creation.

Parameters:

  • id (String) (defaults to: nil)

    The phone number’s ID

  • phone_number (String) (defaults to: nil)

    The phone number in e164 format.



# File 'lib/telnyx/models/number_order_list_response.rb', line 124

Instance Attribute Details

#billing_group_idString?

Identifies the messaging profile associated with the phone number.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/number_order_list_response.rb', line 11

optional :billing_group_id, String

#connection_idString?

Identifies the connection associated with this phone number.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/number_order_list_response.rb', line 17

optional :connection_id, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/number_order_list_response.rb', line 23

optional :customer_reference, String

#messaging_profile_idString?

Identifies the messaging profile associated with the phone number.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/number_order_list_response.rb', line 29

optional :messaging_profile_id, String

#phone_numbersArray<Telnyx::Models::NumberOrderListResponse::PhoneNumber>?



34
35
# File 'lib/telnyx/models/number_order_list_response.rb', line 34

optional :phone_numbers,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::NumberOrderListResponse::PhoneNumber] }

#sub_number_orders_idsArray<String>?

Returns:

  • (Array<String>, nil)


40
# File 'lib/telnyx/models/number_order_list_response.rb', line 40

optional :sub_number_orders_ids, Telnyx::Internal::Type::ArrayOf[String]