Class: Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload
- Defined in:
- lib/telnyx/models/number_order_status_update_webhook_event.rb,
sig/telnyx/models/number_order_status_update_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Status Classes: PhoneNumber
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Identifies the messaging profile associated with the phone number.
-
#connection_id ⇒ String?
Identifies the connection associated with this phone number.
-
#created_at ⇒ Time?
An ISO 8901 datetime string denoting when the number order was created.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
- #id ⇒ String?
-
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
- #phone_numbers ⇒ Array<Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber>?
-
#phone_numbers_count ⇒ Integer?
The count of phone numbers in the number order.
- #record_type ⇒ String?
-
#requirements_met ⇒ Boolean?
True if all requirements are met for every phone number, false otherwise.
-
#status ⇒ Symbol, ...
The status of the order.
- #sub_number_orders_ids ⇒ Array<String>?
-
#updated_at ⇒ Time?
An ISO 8901 datetime string for when the number order was updated.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
134 |
# File 'sig/telnyx/models/number_order_status_update_webhook_event.rbs', line 134
def initialize: (
|
Instance Attribute Details
#billing_group_id ⇒ String?
Identifies the messaging profile associated with the phone number.
78 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 78 optional :billing_group_id, String |
#connection_id ⇒ String?
Identifies the connection associated with this phone number.
84 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 84 optional :connection_id, String |
#created_at ⇒ Time?
An ISO 8901 datetime string denoting when the number order was created.
90 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 90 optional :created_at, Time |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
96 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 96 optional :customer_reference, String |
#id ⇒ String?
72 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 72 optional :id, String |
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
102 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 102 optional :messaging_profile_id, String |
#phone_numbers ⇒ Array<Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber>?
107 108 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 107 optional :phone_numbers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber] } |
#phone_numbers_count ⇒ Integer?
The count of phone numbers in the number order.
114 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 114 optional :phone_numbers_count, Integer |
#record_type ⇒ String?
119 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 119 optional :record_type, String |
#requirements_met ⇒ Boolean?
True if all requirements are met for every phone number, false otherwise.
125 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 125 optional :requirements_met, Telnyx::Internal::Type::Boolean |
#status ⇒ Symbol, ...
The status of the order.
131 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 131 optional :status, enum: -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::Status } |
#sub_number_orders_ids ⇒ Array<String>?
136 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 136 optional :sub_number_orders_ids, Telnyx::Internal::Type::ArrayOf[String] |
#updated_at ⇒ Time?
An ISO 8901 datetime string for when the number order was updated.
142 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 142 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 363
|
Instance Method Details
#to_hash ⇒ {
150 |
# File 'sig/telnyx/models/number_order_status_update_webhook_event.rbs', line 150
def to_hash: -> {
|