Class: Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber
- Defined in:
- lib/telnyx/models/number_order_status_update_webhook_event.rb,
sig/telnyx/models/number_order_status_update_webhook_event.rbs
Defined Under Namespace
Modules: PhoneNumberType, RequirementsStatus, Status Classes: RegulatoryRequirement
Instance Attribute Summary collapse
- #bundle_id ⇒ String?
-
#country_code ⇒ String?
Country code of the phone number.
-
#country_iso_alpha2 ⇒ String?
The ISO 3166-1 alpha-2 country code of the phone number.
- #id ⇒ String?
- #phone_number ⇒ String?
-
#phone_number_type ⇒ Symbol, ...
Phone number type.
- #record_type ⇒ String?
- #regulatory_requirements ⇒ Array<Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement>?
-
#requirements_met ⇒ Boolean?
True if all requirements are met for a phone number, false otherwise.
-
#requirements_status ⇒ Symbol, ...
Status of document requirements (if applicable).
-
#status ⇒ Symbol, ...
The status of the phone number in the order.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, bundle_id: nil, country_code: nil, country_iso_alpha2: nil, phone_number: nil, phone_number_type: nil, record_type: nil, regulatory_requirements: nil, requirements_met: nil, requirements_status: nil, status: nil) ⇒ Object
constructor
The unique phone numbers given as arguments in the job creation.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, bundle_id: nil, country_code: nil, country_iso_alpha2: nil, phone_number: nil, phone_number_type: nil, record_type: nil, regulatory_requirements: nil, requirements_met: nil, requirements_status: nil, status: nil) ⇒ Object
The unique phone numbers given as arguments in the job creation.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 174 class PhoneNumber < Telnyx::Internal::Type::BaseModel # @!attribute id # # @return [String, nil] optional :id, String # @!attribute bundle_id # # @return [String, nil] optional :bundle_id, String # @!attribute country_code # Country code of the phone number # # @return [String, nil] optional :country_code, String # @!attribute country_iso_alpha2 # The ISO 3166-1 alpha-2 country code of the phone number. # # @return [String, nil] optional :country_iso_alpha2, String # @!attribute phone_number # # @return [String, nil] optional :phone_number, String # @!attribute phone_number_type # Phone number type # # @return [Symbol, Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::PhoneNumberType, nil] optional :phone_number_type, enum: -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::PhoneNumberType } # @!attribute record_type # # @return [String, nil] optional :record_type, String # @!attribute regulatory_requirements # # @return [Array<Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement>, nil] optional :regulatory_requirements, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement] } # @!attribute requirements_met # True if all requirements are met for a phone number, false otherwise. # # @return [Boolean, nil] optional :requirements_met, Telnyx::Internal::Type::Boolean # @!attribute requirements_status # Status of document requirements (if applicable) # # @return [Symbol, Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RequirementsStatus, nil] optional :requirements_status, enum: -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RequirementsStatus } # @!attribute status # The status of the phone number in the order. # # @return [Symbol, Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::Status, nil] optional :status, enum: -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::Status } # @!method initialize(id: nil, bundle_id: nil, country_code: nil, country_iso_alpha2: nil, phone_number: nil, phone_number_type: nil, record_type: nil, regulatory_requirements: nil, requirements_met: nil, requirements_status: nil, status: nil) # The unique phone numbers given as arguments in the job creation. # # @param id [String] # # @param bundle_id [String] # # @param country_code [String] Country code of the phone number # # @param country_iso_alpha2 [String] The ISO 3166-1 alpha-2 country code of the phone number. # # @param phone_number [String] # # @param phone_number_type [Symbol, Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::PhoneNumberType] Phone number type # # @param record_type [String] # # @param regulatory_requirements [Array<Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement>] # # @param requirements_met [Boolean] True if all requirements are met for a phone number, false otherwise. # # @param requirements_status [Symbol, Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RequirementsStatus] Status of document requirements (if applicable) # # @param status [Symbol, Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::Status] The status of the phone number in the order. # Phone number type # # @see Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber#phone_number_type module PhoneNumberType extend Telnyx::Internal::Type::Enum LOCAL = :local MOBILE = :mobile NATIONAL = :national SHARED_COST = :shared_cost TOLL_FREE = :toll_free # @!method self.values # @return [Array<Symbol>] end class RegulatoryRequirement < Telnyx::Internal::Type::BaseModel # @!attribute field_type # # @return [Symbol, Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement::FieldType, nil] optional :field_type, enum: -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement::FieldType } # @!attribute field_value # The value of the requirement, this could be an id to a resource or a string # value. # # @return [String, nil] optional :field_value, String # @!attribute record_type # # @return [String, nil] optional :record_type, String # @!attribute requirement_id # Unique id for a requirement. # # @return [String, nil] optional :requirement_id, String # @!method initialize(field_type: nil, field_value: nil, record_type: nil, requirement_id: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement} # for more details. # # Regulatory requirement data delivered in a number order webhook. # # @param field_type [Symbol, Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement::FieldType] # # @param field_value [String] The value of the requirement, this could be an id to a resource or a string valu # # @param record_type [String] # # @param requirement_id [String] Unique id for a requirement. # @see Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement#field_type module FieldType extend Telnyx::Internal::Type::Enum TEXTUAL = :textual DATETIME = :datetime ADDRESS = :address DOCUMENT = :document # @!method self.values # @return [Array<Symbol>] end end # Status of document requirements (if applicable) # # @see Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber#requirements_status module RequirementsStatus extend Telnyx::Internal::Type::Enum PENDING = :pending APPROVED = :approved CANCELLED = :cancelled DELETED = :deleted REQUIREMENT_INFO_EXCEPTION = :"requirement-info-exception" REQUIREMENT_INFO_PENDING = :"requirement-info-pending" REQUIREMENT_INFO_UNDER_REVIEW = :"requirement-info-under-review" # @!method self.values # @return [Array<Symbol>] end # The status of the phone number in the order. # # @see Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber#status module Status extend Telnyx::Internal::Type::Enum PENDING = :pending SUCCESS = :success FAILURE = :failure # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#bundle_id ⇒ String?
183 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 183 optional :bundle_id, String |
#country_code ⇒ String?
Country code of the phone number
189 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 189 optional :country_code, String |
#country_iso_alpha2 ⇒ String?
The ISO 3166-1 alpha-2 country code of the phone number.
195 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 195 optional :country_iso_alpha2, String |
#id ⇒ String?
178 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 178 optional :id, String |
#phone_number ⇒ String?
200 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 200 optional :phone_number, String |
#phone_number_type ⇒ Symbol, ...
Phone number type
206 207 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 206 optional :phone_number_type, enum: -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::PhoneNumberType } |
#record_type ⇒ String?
212 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 212 optional :record_type, String |
#regulatory_requirements ⇒ Array<Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement>?
217 218 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 217 optional :regulatory_requirements, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement] } |
#requirements_met ⇒ Boolean?
True if all requirements are met for a phone number, false otherwise.
224 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 224 optional :requirements_met, Telnyx::Internal::Type::Boolean |
#requirements_status ⇒ Symbol, ...
Status of document requirements (if applicable)
230 231 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 230 optional :requirements_status, enum: -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RequirementsStatus } |
#status ⇒ Symbol, ...
The status of the phone number in the order.
237 238 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 237 optional :status, enum: -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 277
|
Instance Method Details
#to_hash ⇒ {
248 |
# File 'sig/telnyx/models/number_order_status_update_webhook_event.rbs', line 248
def to_hash: -> {
|