Class: Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement
- Defined in:
- lib/telnyx/models/number_order_status_update_webhook_event.rb,
sig/telnyx/models/number_order_status_update_webhook_event.rbs
Defined Under Namespace
Modules: FieldType
Instance Attribute Summary collapse
- #field_type ⇒ Symbol, ...
-
#field_value ⇒ String?
The value of the requirement, this could be an id to a resource or a string value.
- #record_type ⇒ String?
-
#requirement_id ⇒ String?
Unique id for a requirement.
Instance Method Summary collapse
-
#initialize(field_type: nil, field_value: nil, record_type: nil, requirement_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RegulatoryRequirement for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field_type: nil, field_value: nil, record_type: nil, requirement_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement for more details.
Regulatory requirement data delivered in a number order webhook.
|
|
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 306
|
Instance Attribute Details
#field_type ⇒ Symbol, ...
285 286 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 285 optional :field_type, enum: -> { Telnyx::NumberOrderStatusUpdateWebhookEvent::Data::Payload::PhoneNumber::RegulatoryRequirement::FieldType } |
#field_value ⇒ String?
The value of the requirement, this could be an id to a resource or a string value.
293 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 293 optional :field_value, String |
#record_type ⇒ String?
298 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 298 optional :record_type, String |
#requirement_id ⇒ String?
Unique id for a requirement.
304 |
# File 'lib/telnyx/models/number_order_status_update_webhook_event.rb', line 304 optional :requirement_id, String |
Instance Method Details
#to_hash ⇒ {
311 |
# File 'sig/telnyx/models/number_order_status_update_webhook_event.rbs', line 311
def to_hash: -> {
|