Class: Telnyx::Models::NumberOrderWithPhoneNumbers
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::NumberOrderWithPhoneNumbers
- Defined in:
- lib/telnyx/models/number_order_with_phone_numbers.rb,
sig/telnyx/models/number_order_with_phone_numbers.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Identifies the messaging profile associated with the phone number.
-
#connection_id ⇒ String?
Identifies the connection associated with this phone number.
-
#created_at ⇒ Time?
readonly
Returns the value of attribute created_at.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
- #phone_numbers ⇒ Array<Telnyx::Models::PhoneNumber>?
-
#phone_numbers_count ⇒ Integer?
readonly
Returns the value of attribute phone_numbers_count.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#requirements_met ⇒ Boolean?
readonly
Returns the value of attribute requirements_met.
-
#status ⇒ Telnyx::Models::NumberOrderWithPhoneNumbers::status?
readonly
Returns the value of attribute status.
- #sub_number_orders_ids ⇒ Array<String>?
-
#updated_at ⇒ Time?
readonly
Returns the value of attribute updated_at.
Instance Method Summary collapse
- #created_at ⇒ Time readonly
- #id ⇒ String readonly
- #initialize(id: nil, billing_group_id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers: nil, phone_numbers_count: nil, record_type: nil, requirements_met: nil, status: nil, sub_number_orders_ids: nil, updated_at: nil) ⇒ Object constructor
- #phone_numbers_count ⇒ Integer readonly
- #record_type ⇒ String readonly
- #requirements_met ⇒ Boolean readonly
- #status ⇒ Object readonly
- #to_hash ⇒ {
- #updated_at ⇒ Time readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, billing_group_id: nil, connection_id: nil, created_at: nil, customer_reference: nil, messaging_profile_id: nil, phone_numbers: nil, phone_numbers_count: nil, record_type: nil, requirements_met: nil, status: nil, sub_number_orders_ids: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 82
|
Instance Attribute Details
#billing_group_id ⇒ String?
Identifies the messaging profile associated with the phone number.
10 |
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 10 optional :billing_group_id, String |
#connection_id ⇒ String?
Identifies the connection associated with this phone number.
16 |
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 16 optional :connection_id, String |
#created_at ⇒ Time? (readonly)
Returns the value of attribute created_at.
51 52 53 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 51 def created_at @created_at end |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
22 |
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 22 optional :customer_reference, String |
#id ⇒ String? (readonly)
Returns the value of attribute id.
47 48 49 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 47 def id @id end |
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
28 |
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 28 optional :messaging_profile_id, String |
#phone_numbers ⇒ Array<Telnyx::Models::PhoneNumber>?
33 |
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 33 optional :phone_numbers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PhoneNumber] } |
#phone_numbers_count ⇒ Integer? (readonly)
Returns the value of attribute phone_numbers_count.
55 56 57 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 55 def phone_numbers_count @phone_numbers_count end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
59 60 61 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 59 def record_type @record_type end |
#requirements_met ⇒ Boolean? (readonly)
Returns the value of attribute requirements_met.
63 64 65 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 63 def requirements_met @requirements_met end |
#status ⇒ Telnyx::Models::NumberOrderWithPhoneNumbers::status? (readonly)
Returns the value of attribute status.
67 68 69 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 67 def status @status end |
#sub_number_orders_ids ⇒ Array<String>?
38 |
# File 'lib/telnyx/models/number_order_with_phone_numbers.rb', line 38 optional :sub_number_orders_ids, Telnyx::Internal::Type::ArrayOf[String] |
#updated_at ⇒ Time? (readonly)
Returns the value of attribute updated_at.
73 74 75 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 73 def updated_at @updated_at end |
Instance Method Details
#created_at= ⇒ Time (readonly)
53 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 53
def created_at=: (Time) -> Time
|
#id= ⇒ String (readonly)
49 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 49
def id=: (String) -> String
|
#phone_numbers_count= ⇒ Integer (readonly)
57 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 57
def phone_numbers_count=: (Integer) -> Integer
|
#record_type= ⇒ String (readonly)
61 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 61
def record_type=: (String) -> String
|
#requirements_met= ⇒ Boolean (readonly)
65 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 65
def requirements_met=: (bool) -> bool
|
#status= ⇒ Object (readonly)
69 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 69
def status=: (
|
#to_hash ⇒ {
93 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 93
def to_hash: -> {
|
#updated_at= ⇒ Time (readonly)
75 |
# File 'sig/telnyx/models/number_order_with_phone_numbers.rbs', line 75
def updated_at=: (Time) -> Time
|