Class: Telnyx::Models::Organizations::OrganizationUser
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Organizations::OrganizationUser
- Defined in:
- lib/telnyx/models/organizations/organization_user.rb
Overview
Defined Under Namespace
Modules: UserStatus
Instance Attribute Summary collapse
-
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
-
#email ⇒ String?
The email address of the user.
-
#groups ⇒ Array<Telnyx::Models::Organizations::UserGroupReference>?
The groups the user belongs to.
-
#id ⇒ String?
Identifies the specific resource.
-
#last_sign_in_at ⇒ String?
ISO 8601 formatted date indicating when the resource last signed into the portal.
-
#organization_user_bypasses_sso ⇒ Boolean?
Indicates whether this user is allowed to bypass SSO and use password authentication.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#user_status ⇒ Symbol, ...
The status of the account.
Instance Method Summary collapse
-
#initialize(id: nil, created_at: nil, email: nil, groups: nil, last_sign_in_at: nil, organization_user_bypasses_sso: nil, record_type: nil, user_status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see OrganizationUser for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, email: nil, groups: nil, last_sign_in_at: nil, organization_user_bypasses_sso: nil, record_type: nil, user_status: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Organizations::OrganizationUser for more details.
|
|
# File 'lib/telnyx/models/organizations/organization_user.rb', line 60
|
Instance Attribute Details
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
18 |
# File 'lib/telnyx/models/organizations/organization_user.rb', line 18 optional :created_at, String |
#email ⇒ String?
The email address of the user.
24 |
# File 'lib/telnyx/models/organizations/organization_user.rb', line 24 optional :email, String |
#groups ⇒ Array<Telnyx::Models::Organizations::UserGroupReference>?
The groups the user belongs to. Only included when include_groups parameter is true.
31 |
# File 'lib/telnyx/models/organizations/organization_user.rb', line 31 optional :groups, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Organizations::UserGroupReference] } |
#id ⇒ String?
Identifies the specific resource.
12 |
# File 'lib/telnyx/models/organizations/organization_user.rb', line 12 optional :id, String |
#last_sign_in_at ⇒ String?
ISO 8601 formatted date indicating when the resource last signed into the portal. Null if the user has never signed in.
38 |
# File 'lib/telnyx/models/organizations/organization_user.rb', line 38 optional :last_sign_in_at, String, nil?: true |
#organization_user_bypasses_sso ⇒ Boolean?
Indicates whether this user is allowed to bypass SSO and use password authentication.
45 |
# File 'lib/telnyx/models/organizations/organization_user.rb', line 45 optional :organization_user_bypasses_sso, Telnyx::Internal::Type::Boolean |
#record_type ⇒ String?
Identifies the type of the resource. Can be ‘organization_owner’ or ‘organization_sub_user’.
52 |
# File 'lib/telnyx/models/organizations/organization_user.rb', line 52 optional :record_type, String |
#user_status ⇒ Symbol, ...
The status of the account.
58 |
# File 'lib/telnyx/models/organizations/organization_user.rb', line 58 optional :user_status, enum: -> { Telnyx::Organizations::OrganizationUser::UserStatus } |