Class: Telnyx::Models::Organizations::UserListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Organizations::UserListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/organizations/user_list_params.rb
Overview
Defined Under Namespace
Modules: FilterUserStatus
Instance Attribute Summary collapse
-
#filter_email ⇒ String?
Filter by email address (partial match).
-
#filter_user_status ⇒ Symbol, ...
Filter by user status.
-
#include_groups ⇒ Boolean?
When set to true, includes the groups array for each user in the response.
-
#page_number ⇒ Integer?
The page number to load.
-
#page_size ⇒ Integer?
The size of the page.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(filter_email: nil, filter_user_status: nil, include_groups: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see UserListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filter_email: nil, filter_user_status: nil, include_groups: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Organizations::UserListParams for more details.
|
|
# File 'lib/telnyx/models/organizations/user_list_params.rb', line 43
|
Instance Attribute Details
#filter_email ⇒ String?
Filter by email address (partial match)
15 |
# File 'lib/telnyx/models/organizations/user_list_params.rb', line 15 optional :filter_email, String |
#filter_user_status ⇒ Symbol, ...
Filter by user status
21 |
# File 'lib/telnyx/models/organizations/user_list_params.rb', line 21 optional :filter_user_status, enum: -> { Telnyx::Organizations::UserListParams::FilterUserStatus } |
#include_groups ⇒ Boolean?
When set to true, includes the groups array for each user in the response. The groups array contains objects with id and name for each group the user belongs to.
29 |
# File 'lib/telnyx/models/organizations/user_list_params.rb', line 29 optional :include_groups, Telnyx::Internal::Type::Boolean |
#page_number ⇒ Integer?
The page number to load
35 |
# File 'lib/telnyx/models/organizations/user_list_params.rb', line 35 optional :page_number, Integer |
#page_size ⇒ Integer?
The size of the page
41 |
# File 'lib/telnyx/models/organizations/user_list_params.rb', line 41 optional :page_size, Integer |