Class: Telnyx::Models::Organizations::UserRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Organizations::UserRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/organizations/user_retrieve_params.rb
Overview
Instance Attribute Summary collapse
- #id ⇒ String
-
#include_groups ⇒ Boolean?
When set to true, includes the groups array for each user in the response.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, include_groups: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see UserRetrieveParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, include_groups: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Organizations::UserRetrieveParams for more details.
|
|
# File 'lib/telnyx/models/organizations/user_retrieve_params.rb', line 24
|
Instance Attribute Details
#id ⇒ String
14 |
# File 'lib/telnyx/models/organizations/user_retrieve_params.rb', line 14 required :id, String |
#include_groups ⇒ Boolean?
When set to true, includes the groups array for each user in the response. The groups array contains objects with id and name for each group the user belongs to.
22 |
# File 'lib/telnyx/models/organizations/user_retrieve_params.rb', line 22 optional :include_groups, Telnyx::Internal::Type::Boolean |