Class: Telnyx::Models::OtaUpdateRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::OtaUpdateRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/ota_update_retrieve_response.rb,
sig/telnyx/models/ota_update_retrieve_response.rbs
Overview
Defined Under Namespace
Modules: Status, Type Classes: Settings
Instance Attribute Summary collapse
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#settings ⇒ Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings?
A JSON object representation of the operation.
-
#sim_card_id ⇒ String?
The identification UUID of the related SIM card resource.
- #status ⇒ Symbol, ...
-
#type ⇒ Symbol, ...
Represents the type of the operation requested.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Class Method Summary collapse
Instance Method Summary collapse
- #created_at ⇒ String readonly
- #id ⇒ String readonly
-
#initialize(mobile_network_operator_id: nil, mobile_network_operator_name: nil, priority: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Settings::MobileNetworkOperatorsPreference for more details.
- #record_type ⇒ String readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mobile_network_operator_id: nil, mobile_network_operator_name: nil, priority: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings::MobileNetworkOperatorsPreference for more details.
|
|
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 73
|
Instance Attribute Details
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
58 59 60 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 58 def created_at @created_at end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
54 55 56 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 54 def id @id end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
62 63 64 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 62 def record_type @record_type end |
#settings ⇒ Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings?
A JSON object representation of the operation. The information present here will relate directly to the source of the OTA request.
28 |
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 28 optional :settings, -> { Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings } |
#sim_card_id ⇒ String?
The identification UUID of the related SIM card resource.
34 |
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 34 optional :sim_card_id, String |
#status ⇒ Symbol, ...
39 |
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 39 optional :status, enum: -> { Telnyx::Models::OtaUpdateRetrieveResponse::Data::Status } |
#type ⇒ Symbol, ...
Represents the type of the operation requested. This will relate directly to the source of the request.
46 |
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 46 optional :type, enum: -> { Telnyx::Models::OtaUpdateRetrieveResponse::Data::Type } |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
66 67 68 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 66 def updated_at @updated_at end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 158
|
Instance Method Details
#created_at= ⇒ String (readonly)
60 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 60
def created_at=: (String) -> String
|
#id= ⇒ String (readonly)
56 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 56
def id=: (String) -> String
|
#record_type= ⇒ String (readonly)
64 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 64
def record_type=: (String) -> String
|
#to_hash ⇒ {
81 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 81
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
68 |
# File 'sig/telnyx/models/ota_update_retrieve_response.rbs', line 68
def updated_at=: (String) -> String
|