Class: Telnyx::Models::OtaUpdateRetrieveResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/ota_update_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Status, Type Classes: Settings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mobile_network_operator_id: nil, mobile_network_operator_name: nil, priority: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings::MobileNetworkOperatorsPreference for more details.

Parameters:

  • mobile_network_operator_id (String) (defaults to: nil)

    The mobile network operator resource identification UUID.

  • mobile_network_operator_name (String) (defaults to: nil)

    The mobile network operator resource name.

  • priority (Integer) (defaults to: nil)

    It determines what is the priority of a specific network operator that should be



# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 73

Instance Attribute Details

#settingsTelnyx::Models::OtaUpdateRetrieveResponse::Data::Settings?

A JSON object representation of the operation. The information present here will relate directly to the source of the OTA request.



28
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 28

optional :settings, -> { Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings }

#sim_card_idString?

The identification UUID of the related SIM card resource.

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 34

optional :sim_card_id, String

#statusSymbol, ...



39
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 39

optional :status, enum: -> { Telnyx::Models::OtaUpdateRetrieveResponse::Data::Status }

#typeSymbol, ...

Represents the type of the operation requested. This will relate directly to the source of the request.



46
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 46

optional :type, enum: -> { Telnyx::Models::OtaUpdateRetrieveResponse::Data::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 158