Class: Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings::MobileNetworkOperatorsPreference
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings::MobileNetworkOperatorsPreference
- Defined in:
- lib/telnyx/models/ota_update_retrieve_response.rb
Instance Attribute Summary collapse
-
#mobile_network_operator_id ⇒ String?
The mobile network operator resource identification UUID.
-
#mobile_network_operator_name ⇒ String?
The mobile network operator resource name.
-
#priority ⇒ Integer?
It determines what is the priority of a specific network operator that should be assumed by a SIM card when connecting to a network.
Instance Method Summary collapse
-
#initialize(mobile_network_operators_preferences: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mobile_network_operators_preferences: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings for more details.
A JSON object representation of the operation. The information present here will relate directly to the source of the OTA request.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 116 class MobileNetworkOperatorsPreference < Telnyx::Internal::Type::BaseModel # @!attribute mobile_network_operator_id # The mobile network operator resource identification UUID. # # @return [String, nil] optional :mobile_network_operator_id, String # @!attribute mobile_network_operator_name # The mobile network operator resource name. # # @return [String, nil] optional :mobile_network_operator_name, String # @!attribute priority # It determines what is the priority of a specific network operator that should be # assumed by a SIM card when connecting to a network. The highest priority is 0, # the second highest is 1 and so on. # # @return [Integer, nil] optional :priority, Integer # @!method initialize(mobile_network_operator_id: nil, mobile_network_operator_name: nil, priority: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::OtaUpdateRetrieveResponse::Data::Settings::MobileNetworkOperatorsPreference} # for more details. # # @param mobile_network_operator_id [String] The mobile network operator resource identification UUID. # # @param mobile_network_operator_name [String] The mobile network operator resource name. # # @param priority [Integer] It determines what is the priority of a specific network operator that should be end |
Instance Attribute Details
#mobile_network_operator_id ⇒ String?
The mobile network operator resource identification UUID.
121 |
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 121 optional :mobile_network_operator_id, String |
#mobile_network_operator_name ⇒ String?
The mobile network operator resource name.
127 |
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 127 optional :mobile_network_operator_name, String |
#priority ⇒ Integer?
It determines what is the priority of a specific network operator that should be assumed by a SIM card when connecting to a network. The highest priority is 0, the second highest is 1 and so on.
135 |
# File 'lib/telnyx/models/ota_update_retrieve_response.rb', line 135 optional :priority, Integer |