Class: Telnyx::Models::OutboundFqdn
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::OutboundFqdn
- Defined in:
- lib/telnyx/models/outbound_fqdn.rb
Defined Under Namespace
Modules: AniOverrideType, IPAuthenticationMethod, T38ReinviteSource
Instance Attribute Summary collapse
-
#ani_override ⇒ String?
Set a phone number as the ani_override value to override caller id number on outbound calls.
-
#ani_override_type ⇒ Symbol, ...
Specifies when we should apply your ani_override setting.
-
#call_parking_enabled ⇒ Boolean?
Forces all SIP calls originated on this connection to be "parked" instead of "bridged" to the destination specified on the URI.
-
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
-
#encrypted_media ⇒ Symbol, ...
Enable use of SRTP for encryption.
-
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
-
#instant_ringback_enabled ⇒ Boolean?
When set, ringback will not wait for indication before sending ringback tone to calling party.
- #ip_authentication_method ⇒ Symbol, ...
- #ip_authentication_token ⇒ String?
-
#localization ⇒ String?
A 2-character country code specifying the country whose national dialing rules should be used.
-
#outbound_voice_profile_id ⇒ String?
Identifies the associated outbound voice profile.
-
#t38_reinvite_source ⇒ Symbol, ...
This setting only affects connections with Fax-type Outbound Voice Profiles.
-
#tech_prefix ⇒ String?
Numerical chars only, exactly 4 characters.
-
#timeout_1xx_secs ⇒ Integer?
Time(sec) before aborting if connection is not made.
-
#timeout_2xx_secs ⇒ Integer?
Time(sec) before aborting if call is unanswered (min: 1, max: 600).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ani_override: nil, ani_override_type: nil, call_parking_enabled: nil, channel_limit: nil, encrypted_media: nil, generate_ringback_tone: nil, instant_ringback_enabled: nil, ip_authentication_method: nil, ip_authentication_token: nil, localization: nil, outbound_voice_profile_id: nil, t38_reinvite_source: nil, tech_prefix: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see OutboundFqdn for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ani_override: nil, ani_override_type: nil, call_parking_enabled: nil, channel_limit: nil, encrypted_media: nil, generate_ringback_tone: nil, instant_ringback_enabled: nil, ip_authentication_method: nil, ip_authentication_token: nil, localization: nil, outbound_voice_profile_id: nil, t38_reinvite_source: nil, tech_prefix: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::OutboundFqdn for more details.
|
|
# File 'lib/telnyx/models/outbound_fqdn.rb', line 108
|
Instance Attribute Details
#ani_override ⇒ String?
Set a phone number as the ani_override value to override caller id number on outbound calls.
11 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 11 optional :ani_override, String |
#ani_override_type ⇒ Symbol, ...
Specifies when we should apply your ani_override setting. Only applies when ani_override is not blank.
18 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 18 optional :ani_override_type, enum: -> { Telnyx::OutboundFqdn::AniOverrideType } |
#call_parking_enabled ⇒ Boolean?
Forces all SIP calls originated on this connection to be "parked" instead of "bridged" to the destination specified on the URI. Parked calls will return ringback to the caller and will await for a Call Control command to define which action will be taken next.
27 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 27 optional :call_parking_enabled, Telnyx::Internal::Type::Boolean, nil?: true |
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
34 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 34 optional :channel_limit, Integer |
#encrypted_media ⇒ Symbol, ...
Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.
41 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 41 optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true |
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
47 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 47 optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean |
#instant_ringback_enabled ⇒ Boolean?
When set, ringback will not wait for indication before sending ringback tone to calling party.
54 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 54 optional :instant_ringback_enabled, Telnyx::Internal::Type::Boolean |
#ip_authentication_method ⇒ Symbol, ...
59 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 59 optional :ip_authentication_method, enum: -> { Telnyx::OutboundFqdn::IPAuthenticationMethod } |
#ip_authentication_token ⇒ String?
64 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 64 optional :ip_authentication_token, String |
#localization ⇒ String?
A 2-character country code specifying the country whose national dialing rules should be used. For example, if set to ‘US` then any US number can be dialed without preprending +1 to the number. When left blank, Telnyx will try US and GB dialing rules, in that order, by default.“,
73 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 73 optional :localization, String |
#outbound_voice_profile_id ⇒ String?
Identifies the associated outbound voice profile.
79 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 79 optional :outbound_voice_profile_id, String |
#t38_reinvite_source ⇒ Symbol, ...
This setting only affects connections with Fax-type Outbound Voice Profiles. The setting dictates whether or not Telnyx sends a t.38 reinvite. By default, Telnyx will send the re-invite. If set to ‘customer`, the caller is expected to send the t.38 reinvite.
88 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 88 optional :t38_reinvite_source, enum: -> { Telnyx::OutboundFqdn::T38ReinviteSource } |
#tech_prefix ⇒ String?
Numerical chars only, exactly 4 characters.
94 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 94 optional :tech_prefix, String |
#timeout_1xx_secs ⇒ Integer?
Time(sec) before aborting if connection is not made.
100 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 100 optional :timeout_1xx_secs, Integer |
#timeout_2xx_secs ⇒ Integer?
Time(sec) before aborting if call is unanswered (min: 1, max: 600).
106 |
# File 'lib/telnyx/models/outbound_fqdn.rb', line 106 optional :timeout_2xx_secs, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/outbound_fqdn.rb', line 153
|