Class: Telnyx::Models::OutboundVoiceProfile
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::OutboundVoiceProfile
- Defined in:
- lib/telnyx/models/outbound_voice_profile.rb
Overview
Defined Under Namespace
Classes: CallingWindow
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
The ID of the billing group associated with the outbound proflile.
- #call_recording ⇒ Telnyx::Models::OutboundCallRecording?
-
#calling_window ⇒ Telnyx::Models::OutboundVoiceProfile::CallingWindow?
(BETA) Specifies the time window and call limits for calls made using this outbound voice profile.
-
#concurrent_call_limit ⇒ Integer?
Must be no more than your global concurrent call limit.
-
#connections_count ⇒ Integer?
Amount of connections associated with this outbound voice profile.
-
#created_at ⇒ String?
ISO 8601 formatted date-time indicating when the resource was created.
-
#daily_spend_limit ⇒ String?
The maximum amount of usage charges, in USD, you want Telnyx to allow on this outbound voice profile in a day before disallowing new calls.
-
#daily_spend_limit_enabled ⇒ Boolean?
Specifies whether to enforce the daily_spend_limit on this outbound voice profile.
-
#enabled ⇒ Boolean?
Specifies whether the outbound voice profile can be used.
-
#id ⇒ String?
Identifies the resource.
-
#max_destination_rate ⇒ Float?
Maximum rate (price per minute) for a Destination to be allowed when making outbound calls.
-
#name ⇒ String
A user-supplied name to help with organization.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#service_plan ⇒ Symbol, ...
Indicates the coverage of the termination regions.
- #tags ⇒ Array<String>?
-
#traffic_type ⇒ Symbol, ...
Specifies the type of traffic allowed in this profile.
-
#updated_at ⇒ String?
ISO 8601 formatted date-time indicating when the resource was updated.
-
#usage_payment_method ⇒ Symbol, ...
Setting for how costs for outbound profile are calculated.
-
#whitelisted_destinations ⇒ Array<String>?
The list of destinations you want to be able to call using this outbound voice profile formatted in alpha2.
Instance Method Summary collapse
-
#initialize(name:, id: nil, billing_group_id: nil, call_recording: nil, calling_window: nil, concurrent_call_limit: nil, connections_count: nil, created_at: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, enabled: nil, max_destination_rate: nil, record_type: nil, service_plan: nil, tags: nil, traffic_type: nil, updated_at: nil, usage_payment_method: nil, whitelisted_destinations: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see OutboundVoiceProfile for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, id: nil, billing_group_id: nil, call_recording: nil, calling_window: nil, concurrent_call_limit: nil, connections_count: nil, created_at: nil, daily_spend_limit: nil, daily_spend_limit_enabled: nil, enabled: nil, max_destination_rate: nil, record_type: nil, service_plan: nil, tags: nil, traffic_type: nil, updated_at: nil, usage_payment_method: nil, whitelisted_destinations: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::OutboundVoiceProfile for more details.
|
|
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 126
|
Instance Attribute Details
#billing_group_id ⇒ String?
The ID of the billing group associated with the outbound proflile. Defaults to null (for no group assigned).
24 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 24 optional :billing_group_id, String, nil?: true |
#call_recording ⇒ Telnyx::Models::OutboundCallRecording?
29 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 29 optional :call_recording, -> { Telnyx::OutboundCallRecording } |
#calling_window ⇒ Telnyx::Models::OutboundVoiceProfile::CallingWindow?
(BETA) Specifies the time window and call limits for calls made using this outbound voice profile. Note that all times are UTC in 24-hour clock time.
36 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 36 optional :calling_window, -> { Telnyx::OutboundVoiceProfile::CallingWindow } |
#concurrent_call_limit ⇒ Integer?
Must be no more than your global concurrent call limit. Null means no limit.
42 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 42 optional :concurrent_call_limit, Integer, nil?: true |
#connections_count ⇒ Integer?
Amount of connections associated with this outbound voice profile.
48 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 48 optional :connections_count, Integer |
#created_at ⇒ String?
ISO 8601 formatted date-time indicating when the resource was created.
54 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 54 optional :created_at, String |
#daily_spend_limit ⇒ String?
The maximum amount of usage charges, in USD, you want Telnyx to allow on this outbound voice profile in a day before disallowing new calls.
61 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 61 optional :daily_spend_limit, String |
#daily_spend_limit_enabled ⇒ Boolean?
Specifies whether to enforce the daily_spend_limit on this outbound voice profile.
68 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 68 optional :daily_spend_limit_enabled, Telnyx::Internal::Type::Boolean |
#enabled ⇒ Boolean?
Specifies whether the outbound voice profile can be used. Disabled profiles will result in outbound calls being blocked for the associated Connections.
75 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 75 optional :enabled, Telnyx::Internal::Type::Boolean |
#id ⇒ String?
Identifies the resource.
17 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 17 optional :id, String |
#max_destination_rate ⇒ Float?
Maximum rate (price per minute) for a Destination to be allowed when making outbound calls.
82 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 82 optional :max_destination_rate, Float |
#name ⇒ String
A user-supplied name to help with organization.
11 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 11 required :name, String |
#record_type ⇒ String?
Identifies the type of the resource.
88 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 88 optional :record_type, String |
#service_plan ⇒ Symbol, ...
Indicates the coverage of the termination regions.
94 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 94 optional :service_plan, enum: -> { Telnyx::ServicePlan } |
#tags ⇒ Array<String>?
99 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 99 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#traffic_type ⇒ Symbol, ...
Specifies the type of traffic allowed in this profile.
105 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 105 optional :traffic_type, enum: -> { Telnyx::TrafficType } |
#updated_at ⇒ String?
ISO 8601 formatted date-time indicating when the resource was updated.
111 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 111 optional :updated_at, String |
#usage_payment_method ⇒ Symbol, ...
Setting for how costs for outbound profile are calculated.
117 |
# File 'lib/telnyx/models/outbound_voice_profile.rb', line 117 optional :usage_payment_method, enum: -> { Telnyx::UsagePaymentMethod } |