Class: Telnyx::Models::OutboundVoiceProfileCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::OutboundVoiceProfileCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/outbound_voice_profile_create_params.rb
Overview
Defined Under Namespace
Classes: CallingWindow
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
The ID of the billing group associated with the outbound proflile.
- #call_recording ⇒ Telnyx::Models::OutboundCallRecording?
-
#calling_window ⇒ Telnyx::Models::OutboundVoiceProfileCreateParams::CallingWindow?
(BETA) Specifies the time window and call limits for calls made using this outbound voice profile.
-
#concurrent_call_limit ⇒ Integer?
Must be no more than your global concurrent call limit.
-
#daily_spend_limit ⇒ String?
The maximum amount of usage charges, in USD, you want Telnyx to allow on this outbound voice profile in a day before disallowing new calls.
-
#daily_spend_limit_enabled ⇒ Boolean?
Specifies whether to enforce the daily_spend_limit on this outbound voice profile.
-
#enabled ⇒ Boolean?
Specifies whether the outbound voice profile can be used.
-
#max_destination_rate ⇒ Float?
Maximum rate (price per minute) for a Destination to be allowed when making outbound calls.
-
#name ⇒ String
A user-supplied name to help with organization.
-
#service_plan ⇒ Symbol, ...
Indicates the coverage of the termination regions.
- #tags ⇒ Array<String>?
-
#traffic_type ⇒ Symbol, ...
Specifies the type of traffic allowed in this profile.
-
#usage_payment_method ⇒ Symbol, ...
Setting for how costs for outbound profile are calculated.
-
#whitelisted_destinations ⇒ Array<String>?
The list of destinations you want to be able to call using this outbound voice profile formatted in alpha2.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#billing_group_id ⇒ String?
The ID of the billing group associated with the outbound proflile. Defaults to null (for no group assigned).
21 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 21 optional :billing_group_id, String, nil?: true |
#call_recording ⇒ Telnyx::Models::OutboundCallRecording?
26 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 26 optional :call_recording, -> { Telnyx::OutboundCallRecording } |
#calling_window ⇒ Telnyx::Models::OutboundVoiceProfileCreateParams::CallingWindow?
(BETA) Specifies the time window and call limits for calls made using this outbound voice profile. Note that all times are UTC in 24-hour clock time.
33 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 33 optional :calling_window, -> { Telnyx::OutboundVoiceProfileCreateParams::CallingWindow } |
#concurrent_call_limit ⇒ Integer?
Must be no more than your global concurrent call limit. Null means no limit.
39 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 39 optional :concurrent_call_limit, Integer, nil?: true |
#daily_spend_limit ⇒ String?
The maximum amount of usage charges, in USD, you want Telnyx to allow on this outbound voice profile in a day before disallowing new calls.
46 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 46 optional :daily_spend_limit, String |
#daily_spend_limit_enabled ⇒ Boolean?
Specifies whether to enforce the daily_spend_limit on this outbound voice profile.
53 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 53 optional :daily_spend_limit_enabled, Telnyx::Internal::Type::Boolean |
#enabled ⇒ Boolean?
Specifies whether the outbound voice profile can be used. Disabled profiles will result in outbound calls being blocked for the associated Connections.
60 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 60 optional :enabled, Telnyx::Internal::Type::Boolean |
#max_destination_rate ⇒ Float?
Maximum rate (price per minute) for a Destination to be allowed when making outbound calls.
67 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 67 optional :max_destination_rate, Float |
#name ⇒ String
A user-supplied name to help with organization.
14 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 14 required :name, String |
#service_plan ⇒ Symbol, ...
Indicates the coverage of the termination regions.
73 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 73 optional :service_plan, enum: -> { Telnyx::ServicePlan } |
#tags ⇒ Array<String>?
78 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 78 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#traffic_type ⇒ Symbol, ...
Specifies the type of traffic allowed in this profile.
84 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 84 optional :traffic_type, enum: -> { Telnyx::TrafficType } |
#usage_payment_method ⇒ Symbol, ...
Setting for how costs for outbound profile are calculated.
90 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 90 optional :usage_payment_method, enum: -> { Telnyx::UsagePaymentMethod } |
#whitelisted_destinations ⇒ Array<String>?
The list of destinations you want to be able to call using this outbound voice profile formatted in alpha2.
97 |
# File 'lib/telnyx/models/outbound_voice_profile_create_params.rb', line 97 optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String] |