Class: Telnyx::Models::Payment::AutoRechargePrefUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Payment::AutoRechargePrefUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/payment/auto_recharge_pref_update_params.rb
Overview
Defined Under Namespace
Modules: Preference
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean?
Whether auto recharge is enabled.
- #invoice_enabled ⇒ Boolean?
-
#preference ⇒ Symbol, ...
The payment preference for auto recharge.
-
#recharge_amount ⇒ String?
The amount to recharge the account, the actual recharge amount will be the amount necessary to reach the threshold amount plus the recharge amount.
-
#threshold_amount ⇒ String?
The threshold amount at which the account will be recharged.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(enabled: nil, invoice_enabled: nil, preference: nil, recharge_amount: nil, threshold_amount: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AutoRechargePrefUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(enabled: nil, invoice_enabled: nil, preference: nil, recharge_amount: nil, threshold_amount: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Payment::AutoRechargePrefUpdateParams for more details.
|
|
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 41
|
Instance Attribute Details
#enabled ⇒ Boolean?
Whether auto recharge is enabled.
15 |
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 15 optional :enabled, Telnyx::Internal::Type::Boolean |
#invoice_enabled ⇒ Boolean?
20 |
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 20 optional :invoice_enabled, Telnyx::Internal::Type::Boolean |
#preference ⇒ Symbol, ...
The payment preference for auto recharge.
26 |
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 26 optional :preference, enum: -> { Telnyx::Payment::AutoRechargePrefUpdateParams::Preference } |
#recharge_amount ⇒ String?
The amount to recharge the account, the actual recharge amount will be the amount necessary to reach the threshold amount plus the recharge amount.
33 |
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 33 optional :recharge_amount, String |
#threshold_amount ⇒ String?
The threshold amount at which the account will be recharged.
39 |
# File 'lib/telnyx/models/payment/auto_recharge_pref_update_params.rb', line 39 optional :threshold_amount, String |