Class: Telnyx::Models::PhoneNumberDeleteResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_number_delete_response.rb

Overview

See Also:

Defined Under Namespace

Modules: PhoneNumberType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, created_at: nil, customer_reference: nil, deletion_lock_enabled: nil, emergency_address_id: nil, emergency_enabled: nil, external_pin: nil, hd_voice_enabled: nil, messaging_profile_id: nil, messaging_profile_name: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, tags: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberDeleteResponse::Data for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • billing_group_id (String) (defaults to: nil)

    Identifies the billing group associated with the phone number.

  • call_forwarding_enabled (Boolean) (defaults to: nil)

    Indicates if call forwarding will be enabled for this number if forwards_to and

  • call_recording_enabled (Boolean) (defaults to: nil)

    Indicates whether call recording is enabled for this number.

  • caller_id_name_enabled (Boolean) (defaults to: nil)

    Indicates whether caller ID is enabled for this number.

  • cnam_listing_enabled (Boolean) (defaults to: nil)

    Indicates whether a CNAM listing is enabled for this number.

  • connection_id (String) (defaults to: nil)

    Identifies the connection associated with the phone number.

  • connection_name (String) (defaults to: nil)

    The user-assigned name of the connection to be associated with this phone number

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the time it took to activate after the p

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • deletion_lock_enabled (Boolean) (defaults to: nil)

    Indicates whether deletion lock is enabled for this number. When enabled, this p

  • emergency_address_id (String) (defaults to: nil)

    Identifies the emergency address associated with the phone number.

  • emergency_enabled (Boolean) (defaults to: nil)

    Indicates whether emergency services are enabled for this number.

  • external_pin (String) (defaults to: nil)

    If someone attempts to port your phone number away from Telnyx and your phone nu

  • hd_voice_enabled (Boolean) (defaults to: nil)

    Indicates whether HD voice is enabled for this number.

  • messaging_profile_id (String) (defaults to: nil)

    Identifies the messaging profile associated with the phone number.

  • messaging_profile_name (String) (defaults to: nil)

    The name of the messaging profile associated with the phone number.

  • phone_number (String) (defaults to: nil)

    The +E.164-formatted phone number associated with this record.

  • phone_number_type (Symbol, Telnyx::Models::PhoneNumberDeleteResponse::Data::PhoneNumberType) (defaults to: nil)

    The phone number’s type.

  • purchased_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating the time the request was made to purchase the

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • status (Symbol, Telnyx::Models::PhoneNumberDeleteResponse::Data::Status) (defaults to: nil)

    The phone number’s current status.

  • t38_fax_gateway_enabled (Boolean) (defaults to: nil)

    Indicates whether T38 Fax Gateway for inbound calls to this number.

  • tags (Array<String>) (defaults to: nil)

    A list of user-assigned tags to help manage the phone number.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/phone_number_delete_response.rb', line 178

Instance Attribute Details

#billing_group_idString?

Identifies the billing group associated with the phone number.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 21

optional :billing_group_id, String

#connection_idString?

Identifies the connection associated with the phone number.

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 27

optional :connection_id, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 33

optional :customer_reference, String

#external_pinString?

If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.

Returns:

  • (String, nil)


42
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 42

optional :external_pin, String

#messaging_profile_idString?

Identifies the messaging profile associated with the phone number.

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 48

optional :messaging_profile_id, String

#messaging_profile_nameString?

The name of the messaging profile associated with the phone number.

Returns:

  • (String, nil)


54
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 54

optional :messaging_profile_name, String

#tagsArray<String>?

A list of user-assigned tags to help manage the phone number.

Returns:

  • (Array<String>, nil)


60
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 60

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_number_delete_response.rb', line 245