Class: Telnyx::Models::PhoneNumberDeleteResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberDeleteResponse::Data
- Defined in:
- lib/telnyx/models/phone_number_delete_response.rb
Overview
Defined Under Namespace
Modules: PhoneNumberType, Status
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
-
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier.
-
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
-
#messaging_profile_name ⇒ String?
The name of the messaging profile associated with the phone number.
-
#tags ⇒ Array<String>?
A list of user-assigned tags to help manage the phone number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, created_at: nil, customer_reference: nil, deletion_lock_enabled: nil, emergency_address_id: nil, emergency_enabled: nil, external_pin: nil, hd_voice_enabled: nil, messaging_profile_id: nil, messaging_profile_name: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, tags: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, created_at: nil, customer_reference: nil, deletion_lock_enabled: nil, emergency_address_id: nil, emergency_enabled: nil, external_pin: nil, hd_voice_enabled: nil, messaging_profile_id: nil, messaging_profile_name: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, tags: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberDeleteResponse::Data for more details.
|
|
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 178
|
Instance Attribute Details
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
21 |
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 21 optional :billing_group_id, String |
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
27 |
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 27 optional :connection_id, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
33 |
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 33 optional :customer_reference, String |
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.
42 |
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 42 optional :external_pin, String |
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
48 |
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 48 optional :messaging_profile_id, String |
#messaging_profile_name ⇒ String?
The name of the messaging profile associated with the phone number.
54 |
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 54 optional :messaging_profile_name, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_delete_response.rb', line 245
|