Class: Telnyx::Models::PhoneNumberDetailed
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberDetailed
- Defined in:
- lib/telnyx/models/phone_number_detailed.rb,
sig/telnyx/models/phone_number_detailed.rbs
Overview
Defined Under Namespace
Modules: EmergencyStatus, InboundCallScreening, PhoneNumberType, SourceType, Status
Instance Attribute Summary collapse
-
#activated_at ⇒ Time?
Returns the value of attribute activated_at.
-
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
-
#call_forwarding_enabled ⇒ Boolean?
readonly
Returns the value of attribute call_forwarding_enabled.
-
#call_recording_enabled ⇒ Boolean?
readonly
Returns the value of attribute call_recording_enabled.
-
#caller_id_name_enabled ⇒ Boolean?
readonly
Returns the value of attribute caller_id_name_enabled.
-
#cnam_listing_enabled ⇒ Boolean?
readonly
Returns the value of attribute cnam_listing_enabled.
-
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
-
#connection_name ⇒ String?
Returns the value of attribute connection_name.
-
#country_iso_alpha2 ⇒ String
Returns the value of attribute country_iso_alpha2.
-
#created_at ⇒ Time
Returns the value of attribute created_at.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#deletion_lock_enabled ⇒ Boolean
Indicates whether deletion lock is enabled for this number.
-
#emergency_address_id ⇒ String?
Returns the value of attribute emergency_address_id.
-
#emergency_enabled ⇒ Boolean?
readonly
Returns the value of attribute emergency_enabled.
-
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number.
-
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier.
-
#hd_voice_enabled ⇒ Boolean?
readonly
Returns the value of attribute hd_voice_enabled.
-
#id ⇒ String
Returns the value of attribute id.
-
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls.
-
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
-
#messaging_profile_name ⇒ String?
The name of the messaging profile associated with the phone number.
-
#phone_number ⇒ String
Returns the value of attribute phone_number.
-
#phone_number_type ⇒ Telnyx::Models::PhoneNumberDetailed::phone_number_type
Returns the value of attribute phone_number_type.
-
#purchased_at ⇒ String
Returns the value of attribute purchased_at.
-
#record_type ⇒ String
Returns the value of attribute record_type.
-
#source_type ⇒ Telnyx::Models::PhoneNumberDetailed::source_type?
Returns the value of attribute source_type.
-
#status ⇒ Telnyx::Models::PhoneNumberDetailed::status
Returns the value of attribute status.
-
#t38_fax_gateway_enabled ⇒ Boolean?
readonly
Returns the value of attribute t38_fax_gateway_enabled.
-
#tags ⇒ Array<String>
A list of user-assigned tags to help manage the phone number.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Class Method Summary collapse
Instance Method Summary collapse
- #call_forwarding_enabled ⇒ Boolean readonly
- #call_recording_enabled ⇒ Boolean readonly
- #caller_id_name_enabled ⇒ Boolean readonly
- #cnam_listing_enabled ⇒ Boolean readonly
- #emergency_enabled ⇒ Boolean readonly
- #hd_voice_enabled ⇒ Boolean readonly
-
#initialize(id:, country_iso_alpha2:, created_at:, deletion_lock_enabled:, external_pin:, phone_number:, phone_number_type:, purchased_at:, record_type:, status:, tags:, activated_at: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, hd_voice_enabled: nil, inbound_call_screening: nil, messaging_profile_id: nil, messaging_profile_name: nil, source_type: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberDetailed for more details.
- #t38_fax_gateway_enabled ⇒ Boolean readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, country_iso_alpha2:, created_at:, deletion_lock_enabled:, external_pin:, phone_number:, phone_number_type:, purchased_at:, record_type:, status:, tags:, activated_at: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, hd_voice_enabled: nil, inbound_call_screening: nil, messaging_profile_id: nil, messaging_profile_name: nil, source_type: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberDetailed for more details.
|
|
# File 'lib/telnyx/models/phone_number_detailed.rb', line 208
|
Instance Attribute Details
#activated_at ⇒ Time?
Returns the value of attribute activated_at.
82 83 84 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 82 def activated_at @activated_at end |
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
33 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 33 optional :billing_group_id, String, nil?: true |
#call_forwarding_enabled ⇒ Boolean? (readonly)
Returns the value of attribute call_forwarding_enabled.
84 85 86 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 84 def call_forwarding_enabled @call_forwarding_enabled end |
#call_recording_enabled ⇒ Boolean? (readonly)
Returns the value of attribute call_recording_enabled.
88 89 90 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 88 def call_recording_enabled @call_recording_enabled end |
#caller_id_name_enabled ⇒ Boolean? (readonly)
Returns the value of attribute caller_id_name_enabled.
92 93 94 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 92 def caller_id_name_enabled @caller_id_name_enabled end |
#cnam_listing_enabled ⇒ Boolean? (readonly)
Returns the value of attribute cnam_listing_enabled.
96 97 98 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 96 def cnam_listing_enabled @cnam_listing_enabled end |
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
39 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 39 optional :connection_id, String, nil?: true |
#connection_name ⇒ String?
Returns the value of attribute connection_name.
100 101 102 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 100 def connection_name @connection_name end |
#country_iso_alpha2 ⇒ String
Returns the value of attribute country_iso_alpha2.
68 69 70 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 68 def country_iso_alpha2 @country_iso_alpha2 end |
#created_at ⇒ Time
Returns the value of attribute created_at.
70 71 72 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 70 def created_at @created_at end |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
45 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 45 optional :customer_reference, String, nil?: true |
#deletion_lock_enabled ⇒ Boolean
Indicates whether deletion lock is enabled for this number. When enabled, this prevents the phone number from being deleted via the API or Telnyx portal.
12 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 12 required :deletion_lock_enabled, Telnyx::Internal::Type::Boolean |
#emergency_address_id ⇒ String?
Returns the value of attribute emergency_address_id.
102 103 104 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 102 def emergency_address_id @emergency_address_id end |
#emergency_enabled ⇒ Boolean? (readonly)
Returns the value of attribute emergency_enabled.
104 105 106 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 104 def emergency_enabled @emergency_enabled end |
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.
54 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 54 optional :emergency_status, enum: -> { Telnyx::PhoneNumberDetailed::EmergencyStatus } |
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.
21 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 21 required :external_pin, String, nil?: true |
#hd_voice_enabled ⇒ Boolean? (readonly)
Returns the value of attribute hd_voice_enabled.
108 109 110 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 108 def hd_voice_enabled @hd_voice_enabled end |
#id ⇒ String
Returns the value of attribute id.
66 67 68 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 66 def id @id end |
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.
63 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 63 optional :inbound_call_screening, enum: -> { Telnyx::PhoneNumberDetailed::InboundCallScreening } |
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
69 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 69 optional :messaging_profile_id, String, nil?: true |
#messaging_profile_name ⇒ String?
The name of the messaging profile associated with the phone number.
75 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 75 optional :messaging_profile_name, String, nil?: true |
#phone_number ⇒ String
Returns the value of attribute phone_number.
72 73 74 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 72 def phone_number @phone_number end |
#phone_number_type ⇒ Telnyx::Models::PhoneNumberDetailed::phone_number_type
Returns the value of attribute phone_number_type.
74 75 76 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 74 def phone_number_type @phone_number_type end |
#purchased_at ⇒ String
Returns the value of attribute purchased_at.
76 77 78 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 76 def purchased_at @purchased_at end |
#record_type ⇒ String
Returns the value of attribute record_type.
78 79 80 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 78 def record_type @record_type end |
#source_type ⇒ Telnyx::Models::PhoneNumberDetailed::source_type?
Returns the value of attribute source_type.
112 113 114 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 112 def source_type @source_type end |
#status ⇒ Telnyx::Models::PhoneNumberDetailed::status
Returns the value of attribute status.
80 81 82 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 80 def status @status end |
#t38_fax_gateway_enabled ⇒ Boolean? (readonly)
Returns the value of attribute t38_fax_gateway_enabled.
114 115 116 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 114 def t38_fax_gateway_enabled @t38_fax_gateway_enabled end |
#tags ⇒ Array<String>
A list of user-assigned tags to help manage the phone number.
27 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 27 required :tags, Telnyx::Internal::Type::ArrayOf[String] |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
118 119 120 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 118 def updated_at @updated_at end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_detailed.rb', line 290
|
Instance Method Details
#call_forwarding_enabled= ⇒ Boolean (readonly)
86 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 86
def call_forwarding_enabled=: (bool) -> bool
|
#call_recording_enabled= ⇒ Boolean (readonly)
90 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 90
def call_recording_enabled=: (bool) -> bool
|
#caller_id_name_enabled= ⇒ Boolean (readonly)
94 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 94
def caller_id_name_enabled=: (bool) -> bool
|
#cnam_listing_enabled= ⇒ Boolean (readonly)
98 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 98
def cnam_listing_enabled=: (bool) -> bool
|
#emergency_enabled= ⇒ Boolean (readonly)
106 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 106
def emergency_enabled=: (bool) -> bool
|
#hd_voice_enabled= ⇒ Boolean (readonly)
110 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 110
def hd_voice_enabled=: (bool) -> bool
|
#t38_fax_gateway_enabled= ⇒ Boolean (readonly)
116 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 116
def t38_fax_gateway_enabled=: (bool) -> bool
|
#to_hash ⇒ {
155 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 155
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
120 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 120
def updated_at=: (String) -> String
|