Class: Telnyx::Models::PhoneNumberDetailed

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_number_detailed.rb,
sig/telnyx/models/phone_number_detailed.rbs

Overview

See Also:

  • Telnyx::Resources::PhoneNumbers#list

Defined Under Namespace

Modules: EmergencyStatus, InboundCallScreening, PhoneNumberType, SourceType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, country_iso_alpha2:, created_at:, deletion_lock_enabled:, external_pin:, phone_number:, phone_number_type:, purchased_at:, record_type:, status:, tags:, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, hd_voice_enabled: nil, inbound_call_screening: nil, messaging_profile_id: nil, messaging_profile_name: nil, source_type: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberDetailed for more details.

Parameters:

  • id (String)

    Identifies the resource.

  • country_iso_alpha2 (String)

    The ISO 3166-1 alpha-2 country code of the phone number.

  • created_at (Time)

    ISO 8601 formatted date indicating when the resource was created.

  • deletion_lock_enabled (Boolean)

    Indicates whether deletion lock is enabled for this number. When enabled, this p

  • external_pin (String, nil)

    If someone attempts to port your phone number away from Telnyx and your phone nu

  • phone_number (String)

    The +E.164-formatted phone number associated with this record.

  • phone_number_type (Symbol, Telnyx::Models::PhoneNumberDetailed::PhoneNumberType)

    The phone number's type.

  • purchased_at (String)

    ISO 8601 formatted date indicating when the resource was purchased.

  • record_type (String)

    Identifies the type of the resource.

  • status (Symbol, Telnyx::Models::PhoneNumberDetailed::Status)

    The phone number's current status.

  • tags (Array<String>)

    A list of user-assigned tags to help manage the phone number.

  • billing_group_id (String, nil) (defaults to: nil)

    Identifies the billing group associated with the phone number.

  • call_forwarding_enabled (Boolean) (defaults to: nil)

    Indicates if call forwarding will be enabled for this number if forwards_to and

  • call_recording_enabled (Boolean) (defaults to: nil)

    Indicates whether call recording is enabled for this number.

  • caller_id_name_enabled (Boolean) (defaults to: nil)

    Indicates whether caller ID is enabled for this number.

  • cnam_listing_enabled (Boolean) (defaults to: nil)

    Indicates whether a CNAM listing is enabled for this number.

  • connection_id (String, nil) (defaults to: nil)

    Identifies the connection associated with the phone number.

  • connection_name (String, nil) (defaults to: nil)

    The user-assigned name of the connection to be associated with this phone number

  • customer_reference (String, nil) (defaults to: nil)

    A customer reference string for customer look ups.

  • emergency_address_id (String, nil) (defaults to: nil)

    Identifies the emergency address associated with the phone number.

  • emergency_enabled (Boolean) (defaults to: nil)

    Indicates whether emergency services are enabled for this number.

  • emergency_status (Symbol, Telnyx::Models::PhoneNumberDetailed::EmergencyStatus) (defaults to: nil)

    Indicates the status of the provisioning of emergency services for the phone num

  • hd_voice_enabled (Boolean) (defaults to: nil)

    Indicates whether HD voice is enabled for this number.

  • inbound_call_screening (Symbol, Telnyx::Models::PhoneNumberDetailed::InboundCallScreening) (defaults to: nil)

    The inbound_call_screening setting is a phone number configuration option variab

  • messaging_profile_id (String, nil) (defaults to: nil)

    Identifies the messaging profile associated with the phone number.

  • messaging_profile_name (String, nil) (defaults to: nil)

    The name of the messaging profile associated with the phone number.

  • source_type (Symbol, Telnyx::Models::PhoneNumberDetailed::SourceType, nil) (defaults to: nil)

    Indicates if the phone number was purchased or ported in. For some numbers this

  • t38_fax_gateway_enabled (Boolean) (defaults to: nil)

    Indicates whether T38 Fax Gateway for inbound calls to this number.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/phone_number_detailed.rb', line 199

Instance Attribute Details

#billing_group_idString?

Identifies the billing group associated with the phone number.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/phone_number_detailed.rb', line 33

optional :billing_group_id, String, nil?: true

#call_forwarding_enabledBoolean? (readonly)

Returns the value of attribute call_forwarding_enabled.

Returns:

  • (Boolean, nil)


81
82
83
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 81

def call_forwarding_enabled
  @call_forwarding_enabled
end

#call_recording_enabledBoolean? (readonly)

Returns the value of attribute call_recording_enabled.

Returns:

  • (Boolean, nil)


85
86
87
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 85

def call_recording_enabled
  @call_recording_enabled
end

#caller_id_name_enabledBoolean? (readonly)

Returns the value of attribute caller_id_name_enabled.

Returns:

  • (Boolean, nil)


89
90
91
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 89

def caller_id_name_enabled
  @caller_id_name_enabled
end

#cnam_listing_enabledBoolean? (readonly)

Returns the value of attribute cnam_listing_enabled.

Returns:

  • (Boolean, nil)


93
94
95
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 93

def cnam_listing_enabled
  @cnam_listing_enabled
end

#connection_idString?

Identifies the connection associated with the phone number.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/phone_number_detailed.rb', line 39

optional :connection_id, String, nil?: true

#connection_nameString?

Returns the value of attribute connection_name.

Returns:

  • (String, nil)


97
98
99
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 97

def connection_name
  @connection_name
end

#country_iso_alpha2String

Returns the value of attribute country_iso_alpha2.

Returns:

  • (String)


67
68
69
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 67

def country_iso_alpha2
  @country_iso_alpha2
end

#created_atTime

Returns the value of attribute created_at.

Returns:

  • (Time)


69
70
71
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 69

def created_at
  @created_at
end

#customer_referenceString?

A customer reference string for customer look ups.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/phone_number_detailed.rb', line 45

optional :customer_reference, String, nil?: true

#deletion_lock_enabledBoolean

Indicates whether deletion lock is enabled for this number. When enabled, this prevents the phone number from being deleted via the API or Telnyx portal.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


12
# File 'lib/telnyx/models/phone_number_detailed.rb', line 12

required :deletion_lock_enabled, Telnyx::Internal::Type::Boolean

#emergency_address_idString?

Returns the value of attribute emergency_address_id.

Returns:

  • (String, nil)


99
100
101
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 99

def emergency_address_id
  @emergency_address_id
end

#emergency_enabledBoolean? (readonly)

Returns the value of attribute emergency_enabled.

Returns:

  • (Boolean, nil)


101
102
103
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 101

def emergency_enabled
  @emergency_enabled
end

#emergency_statusSymbol, ...

Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.



54
# File 'lib/telnyx/models/phone_number_detailed.rb', line 54

optional :emergency_status, enum: -> { Telnyx::PhoneNumberDetailed::EmergencyStatus }

#external_pinString?

If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/phone_number_detailed.rb', line 21

required :external_pin, String, nil?: true

#hd_voice_enabledBoolean? (readonly)

Returns the value of attribute hd_voice_enabled.

Returns:

  • (Boolean, nil)


105
106
107
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 105

def hd_voice_enabled
  @hd_voice_enabled
end

#idString

Returns the value of attribute id.

Returns:

  • (String)


65
66
67
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 65

def id
  @id
end

#inbound_call_screeningSymbol, ...

The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.



63
# File 'lib/telnyx/models/phone_number_detailed.rb', line 63

optional :inbound_call_screening, enum: -> { Telnyx::PhoneNumberDetailed::InboundCallScreening }

#messaging_profile_idString?

Identifies the messaging profile associated with the phone number.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


69
# File 'lib/telnyx/models/phone_number_detailed.rb', line 69

optional :messaging_profile_id, String, nil?: true

#messaging_profile_nameString?

The name of the messaging profile associated with the phone number.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


75
# File 'lib/telnyx/models/phone_number_detailed.rb', line 75

optional :messaging_profile_name, String, nil?: true

#phone_numberString

Returns the value of attribute phone_number.

Returns:

  • (String)


71
72
73
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 71

def phone_number
  @phone_number
end

#phone_number_typeTelnyx::Models::PhoneNumberDetailed::phone_number_type

Returns the value of attribute phone_number_type.

Returns:

  • (Telnyx::Models::PhoneNumberDetailed::phone_number_type)


73
74
75
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 73

def phone_number_type
  @phone_number_type
end

#purchased_atString

Returns the value of attribute purchased_at.

Returns:

  • (String)


75
76
77
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 75

def purchased_at
  @purchased_at
end

#record_typeString

Returns the value of attribute record_type.

Returns:

  • (String)


77
78
79
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 77

def record_type
  @record_type
end

#source_typeTelnyx::Models::PhoneNumberDetailed::source_type?

Returns the value of attribute source_type.

Returns:

  • (Telnyx::Models::PhoneNumberDetailed::source_type, nil)


109
110
111
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 109

def source_type
  @source_type
end

#statusTelnyx::Models::PhoneNumberDetailed::status

Returns the value of attribute status.

Returns:

  • (Telnyx::Models::PhoneNumberDetailed::status)


79
80
81
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 79

def status
  @status
end

#t38_fax_gateway_enabledBoolean? (readonly)

Returns the value of attribute t38_fax_gateway_enabled.

Returns:

  • (Boolean, nil)


111
112
113
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 111

def t38_fax_gateway_enabled
  @t38_fax_gateway_enabled
end

#tagsArray<String>

A list of user-assigned tags to help manage the phone number.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


27
# File 'lib/telnyx/models/phone_number_detailed.rb', line 27

required :tags, Telnyx::Internal::Type::ArrayOf[String]

#updated_atString? (readonly)

Returns the value of attribute updated_at.

Returns:

  • (String, nil)


115
116
117
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 115

def updated_at
  @updated_at
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_number_detailed.rb', line 279

Instance Method Details

#call_forwarding_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


83
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 83

def call_forwarding_enabled=: (bool) -> bool

#call_recording_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


87
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 87

def call_recording_enabled=: (bool) -> bool

#caller_id_name_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


91
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 91

def caller_id_name_enabled=: (bool) -> bool

#cnam_listing_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


95
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 95

def cnam_listing_enabled=: (bool) -> bool

#emergency_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


103
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 103

def emergency_enabled=: (bool) -> bool

#hd_voice_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


107
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 107

def hd_voice_enabled=: (bool) -> bool

#t38_fax_gateway_enabled=Boolean (readonly)

Parameters:

  • (Boolean)

Returns:

  • (Boolean)


113
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 113

def t38_fax_gateway_enabled=: (bool) -> bool

#to_hash{

Returns:

  • ({)


151
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 151

def to_hash: -> {

#updated_at=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


117
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 117

def updated_at=: (String) -> String