Class: Telnyx::Models::PhoneNumberDetailed
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberDetailed
- Defined in:
- lib/telnyx/models/phone_number_detailed.rb,
sig/telnyx/models/phone_number_detailed.rbs
Overview
Defined Under Namespace
Modules: EmergencyStatus, InboundCallScreening, PhoneNumberType, SourceType, Status
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
-
#call_forwarding_enabled ⇒ Boolean?
readonly
Returns the value of attribute call_forwarding_enabled.
-
#call_recording_enabled ⇒ Boolean?
readonly
Returns the value of attribute call_recording_enabled.
-
#caller_id_name_enabled ⇒ Boolean?
readonly
Returns the value of attribute caller_id_name_enabled.
-
#cnam_listing_enabled ⇒ Boolean?
readonly
Returns the value of attribute cnam_listing_enabled.
-
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
-
#connection_name ⇒ String?
Returns the value of attribute connection_name.
-
#country_iso_alpha2 ⇒ String
Returns the value of attribute country_iso_alpha2.
-
#created_at ⇒ Time
Returns the value of attribute created_at.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#deletion_lock_enabled ⇒ Boolean
Indicates whether deletion lock is enabled for this number.
-
#emergency_address_id ⇒ String?
Returns the value of attribute emergency_address_id.
-
#emergency_enabled ⇒ Boolean?
readonly
Returns the value of attribute emergency_enabled.
-
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number.
-
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier.
-
#hd_voice_enabled ⇒ Boolean?
readonly
Returns the value of attribute hd_voice_enabled.
-
#id ⇒ String
Returns the value of attribute id.
-
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls.
-
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
-
#messaging_profile_name ⇒ String?
The name of the messaging profile associated with the phone number.
-
#phone_number ⇒ String
Returns the value of attribute phone_number.
-
#phone_number_type ⇒ Telnyx::Models::PhoneNumberDetailed::phone_number_type
Returns the value of attribute phone_number_type.
-
#purchased_at ⇒ String
Returns the value of attribute purchased_at.
-
#record_type ⇒ String
Returns the value of attribute record_type.
-
#source_type ⇒ Telnyx::Models::PhoneNumberDetailed::source_type?
Returns the value of attribute source_type.
-
#status ⇒ Telnyx::Models::PhoneNumberDetailed::status
Returns the value of attribute status.
-
#t38_fax_gateway_enabled ⇒ Boolean?
readonly
Returns the value of attribute t38_fax_gateway_enabled.
-
#tags ⇒ Array<String>
A list of user-assigned tags to help manage the phone number.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Class Method Summary collapse
Instance Method Summary collapse
- #call_forwarding_enabled ⇒ Boolean readonly
- #call_recording_enabled ⇒ Boolean readonly
- #caller_id_name_enabled ⇒ Boolean readonly
- #cnam_listing_enabled ⇒ Boolean readonly
- #emergency_enabled ⇒ Boolean readonly
- #hd_voice_enabled ⇒ Boolean readonly
-
#initialize(id:, country_iso_alpha2:, created_at:, deletion_lock_enabled:, external_pin:, phone_number:, phone_number_type:, purchased_at:, record_type:, status:, tags:, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, hd_voice_enabled: nil, inbound_call_screening: nil, messaging_profile_id: nil, messaging_profile_name: nil, source_type: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberDetailed for more details.
- #t38_fax_gateway_enabled ⇒ Boolean readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, country_iso_alpha2:, created_at:, deletion_lock_enabled:, external_pin:, phone_number:, phone_number_type:, purchased_at:, record_type:, status:, tags:, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, hd_voice_enabled: nil, inbound_call_screening: nil, messaging_profile_id: nil, messaging_profile_name: nil, source_type: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberDetailed for more details.
|
|
# File 'lib/telnyx/models/phone_number_detailed.rb', line 199
|
Instance Attribute Details
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
33 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 33 optional :billing_group_id, String, nil?: true |
#call_forwarding_enabled ⇒ Boolean? (readonly)
Returns the value of attribute call_forwarding_enabled.
81 82 83 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 81 def call_forwarding_enabled @call_forwarding_enabled end |
#call_recording_enabled ⇒ Boolean? (readonly)
Returns the value of attribute call_recording_enabled.
85 86 87 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 85 def call_recording_enabled @call_recording_enabled end |
#caller_id_name_enabled ⇒ Boolean? (readonly)
Returns the value of attribute caller_id_name_enabled.
89 90 91 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 89 def caller_id_name_enabled @caller_id_name_enabled end |
#cnam_listing_enabled ⇒ Boolean? (readonly)
Returns the value of attribute cnam_listing_enabled.
93 94 95 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 93 def cnam_listing_enabled @cnam_listing_enabled end |
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
39 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 39 optional :connection_id, String, nil?: true |
#connection_name ⇒ String?
Returns the value of attribute connection_name.
97 98 99 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 97 def connection_name @connection_name end |
#country_iso_alpha2 ⇒ String
Returns the value of attribute country_iso_alpha2.
67 68 69 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 67 def country_iso_alpha2 @country_iso_alpha2 end |
#created_at ⇒ Time
Returns the value of attribute created_at.
69 70 71 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 69 def created_at @created_at end |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
45 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 45 optional :customer_reference, String, nil?: true |
#deletion_lock_enabled ⇒ Boolean
Indicates whether deletion lock is enabled for this number. When enabled, this prevents the phone number from being deleted via the API or Telnyx portal.
12 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 12 required :deletion_lock_enabled, Telnyx::Internal::Type::Boolean |
#emergency_address_id ⇒ String?
Returns the value of attribute emergency_address_id.
99 100 101 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 99 def emergency_address_id @emergency_address_id end |
#emergency_enabled ⇒ Boolean? (readonly)
Returns the value of attribute emergency_enabled.
101 102 103 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 101 def emergency_enabled @emergency_enabled end |
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.
54 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 54 optional :emergency_status, enum: -> { Telnyx::PhoneNumberDetailed::EmergencyStatus } |
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.
21 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 21 required :external_pin, String, nil?: true |
#hd_voice_enabled ⇒ Boolean? (readonly)
Returns the value of attribute hd_voice_enabled.
105 106 107 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 105 def hd_voice_enabled @hd_voice_enabled end |
#id ⇒ String
Returns the value of attribute id.
65 66 67 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 65 def id @id end |
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.
63 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 63 optional :inbound_call_screening, enum: -> { Telnyx::PhoneNumberDetailed::InboundCallScreening } |
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
69 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 69 optional :messaging_profile_id, String, nil?: true |
#messaging_profile_name ⇒ String?
The name of the messaging profile associated with the phone number.
75 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 75 optional :messaging_profile_name, String, nil?: true |
#phone_number ⇒ String
Returns the value of attribute phone_number.
71 72 73 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 71 def phone_number @phone_number end |
#phone_number_type ⇒ Telnyx::Models::PhoneNumberDetailed::phone_number_type
Returns the value of attribute phone_number_type.
73 74 75 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 73 def phone_number_type @phone_number_type end |
#purchased_at ⇒ String
Returns the value of attribute purchased_at.
75 76 77 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 75 def purchased_at @purchased_at end |
#record_type ⇒ String
Returns the value of attribute record_type.
77 78 79 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 77 def record_type @record_type end |
#source_type ⇒ Telnyx::Models::PhoneNumberDetailed::source_type?
Returns the value of attribute source_type.
109 110 111 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 109 def source_type @source_type end |
#status ⇒ Telnyx::Models::PhoneNumberDetailed::status
Returns the value of attribute status.
79 80 81 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 79 def status @status end |
#t38_fax_gateway_enabled ⇒ Boolean? (readonly)
Returns the value of attribute t38_fax_gateway_enabled.
111 112 113 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 111 def t38_fax_gateway_enabled @t38_fax_gateway_enabled end |
#tags ⇒ Array<String>
A list of user-assigned tags to help manage the phone number.
27 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 27 required :tags, Telnyx::Internal::Type::ArrayOf[String] |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
115 116 117 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 115 def updated_at @updated_at end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_detailed.rb', line 279
|
Instance Method Details
#call_forwarding_enabled= ⇒ Boolean (readonly)
83 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 83
def call_forwarding_enabled=: (bool) -> bool
|
#call_recording_enabled= ⇒ Boolean (readonly)
87 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 87
def call_recording_enabled=: (bool) -> bool
|
#caller_id_name_enabled= ⇒ Boolean (readonly)
91 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 91
def caller_id_name_enabled=: (bool) -> bool
|
#cnam_listing_enabled= ⇒ Boolean (readonly)
95 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 95
def cnam_listing_enabled=: (bool) -> bool
|
#emergency_enabled= ⇒ Boolean (readonly)
103 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 103
def emergency_enabled=: (bool) -> bool
|
#hd_voice_enabled= ⇒ Boolean (readonly)
107 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 107
def hd_voice_enabled=: (bool) -> bool
|
#t38_fax_gateway_enabled= ⇒ Boolean (readonly)
113 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 113
def t38_fax_gateway_enabled=: (bool) -> bool
|
#to_hash ⇒ {
151 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 151
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
117 |
# File 'sig/telnyx/models/phone_number_detailed.rbs', line 117
def updated_at=: (String) -> String
|