Class: Telnyx::Models::PhoneNumberDetailed

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_number_detailed.rb

Overview

Defined Under Namespace

Modules: EmergencyStatus, InboundCallScreening, PhoneNumberType, SourceType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, country_iso_alpha2:, created_at:, deletion_lock_enabled:, external_pin:, phone_number:, phone_number_type:, purchased_at:, record_type:, status:, tags:, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, hd_voice_enabled: nil, inbound_call_screening: nil, messaging_profile_id: nil, messaging_profile_name: nil, source_type: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberDetailed for more details.

Parameters:

  • id (String)

    Identifies the resource.

  • country_iso_alpha2 (String)

    The ISO 3166-1 alpha-2 country code of the phone number.

  • created_at (Time)

    ISO 8601 formatted date indicating when the resource was created.

  • deletion_lock_enabled (Boolean)

    Indicates whether deletion lock is enabled for this number. When enabled, this p

  • external_pin (String, nil)

    If someone attempts to port your phone number away from Telnyx and your phone nu

  • phone_number (String)

    The +E.164-formatted phone number associated with this record.

  • phone_number_type (Symbol, Telnyx::Models::PhoneNumberDetailed::PhoneNumberType)

    The phone number’s type.

  • purchased_at (String)

    ISO 8601 formatted date indicating when the resource was purchased.

  • record_type (String)

    Identifies the type of the resource.

  • status (Symbol, Telnyx::Models::PhoneNumberDetailed::Status)

    The phone number’s current status.

  • tags (Array<String>)

    A list of user-assigned tags to help manage the phone number.

  • billing_group_id (String, nil) (defaults to: nil)

    Identifies the billing group associated with the phone number.

  • call_forwarding_enabled (Boolean) (defaults to: nil)

    Indicates if call forwarding will be enabled for this number if forwards_to and

  • call_recording_enabled (Boolean) (defaults to: nil)

    Indicates whether call recording is enabled for this number.

  • caller_id_name_enabled (Boolean) (defaults to: nil)

    Indicates whether caller ID is enabled for this number.

  • cnam_listing_enabled (Boolean) (defaults to: nil)

    Indicates whether a CNAM listing is enabled for this number.

  • connection_id (String, nil) (defaults to: nil)

    Identifies the connection associated with the phone number.

  • connection_name (String, nil) (defaults to: nil)

    The user-assigned name of the connection to be associated with this phone number

  • customer_reference (String, nil) (defaults to: nil)

    A customer reference string for customer look ups.

  • emergency_address_id (String, nil) (defaults to: nil)

    Identifies the emergency address associated with the phone number.

  • emergency_enabled (Boolean) (defaults to: nil)

    Indicates whether emergency services are enabled for this number.

  • emergency_status (Symbol, Telnyx::Models::PhoneNumberDetailed::EmergencyStatus) (defaults to: nil)

    Indicates the status of the provisioning of emergency services for the phone num

  • hd_voice_enabled (Boolean) (defaults to: nil)

    Indicates whether HD voice is enabled for this number.

  • inbound_call_screening (Symbol, Telnyx::Models::PhoneNumberDetailed::InboundCallScreening) (defaults to: nil)

    The inbound_call_screening setting is a phone number configuration option variab

  • messaging_profile_id (String, nil) (defaults to: nil)

    Identifies the messaging profile associated with the phone number.

  • messaging_profile_name (String, nil) (defaults to: nil)

    The name of the messaging profile associated with the phone number.

  • source_type (Symbol, Telnyx::Models::PhoneNumberDetailed::SourceType, nil) (defaults to: nil)

    Indicates if the phone number was purchased or ported in. For some numbers this

  • t38_fax_gateway_enabled (Boolean) (defaults to: nil)

    Indicates whether T38 Fax Gateway for inbound calls to this number.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/phone_number_detailed.rb', line 199

Instance Attribute Details

#billing_group_idString?

Identifies the billing group associated with the phone number.

Returns:

  • (String, nil)


33
# File 'lib/telnyx/models/phone_number_detailed.rb', line 33

optional :billing_group_id, String, nil?: true

#connection_idString?

Identifies the connection associated with the phone number.

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/phone_number_detailed.rb', line 39

optional :connection_id, String, nil?: true

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


45
# File 'lib/telnyx/models/phone_number_detailed.rb', line 45

optional :customer_reference, String, nil?: true

#deletion_lock_enabledBoolean

Indicates whether deletion lock is enabled for this number. When enabled, this prevents the phone number from being deleted via the API or Telnyx portal.

Returns:

  • (Boolean)


12
# File 'lib/telnyx/models/phone_number_detailed.rb', line 12

required :deletion_lock_enabled, Telnyx::Internal::Type::Boolean

#emergency_statusSymbol, ...

Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.



54
# File 'lib/telnyx/models/phone_number_detailed.rb', line 54

optional :emergency_status, enum: -> { Telnyx::PhoneNumberDetailed::EmergencyStatus }

#external_pinString?

If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/phone_number_detailed.rb', line 21

required :external_pin, String, nil?: true

#inbound_call_screeningSymbol, ...

The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.



63
# File 'lib/telnyx/models/phone_number_detailed.rb', line 63

optional :inbound_call_screening, enum: -> { Telnyx::PhoneNumberDetailed::InboundCallScreening }

#messaging_profile_idString?

Identifies the messaging profile associated with the phone number.

Returns:

  • (String, nil)


69
# File 'lib/telnyx/models/phone_number_detailed.rb', line 69

optional :messaging_profile_id, String, nil?: true

#messaging_profile_nameString?

The name of the messaging profile associated with the phone number.

Returns:

  • (String, nil)


75
# File 'lib/telnyx/models/phone_number_detailed.rb', line 75

optional :messaging_profile_name, String, nil?: true

#tagsArray<String>

A list of user-assigned tags to help manage the phone number.

Returns:

  • (Array<String>)


27
# File 'lib/telnyx/models/phone_number_detailed.rb', line 27

required :tags, Telnyx::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_number_detailed.rb', line 279