Class: Telnyx::Models::PhoneNumberDetailed
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberDetailed
- Defined in:
- lib/telnyx/models/phone_number_detailed.rb
Overview
Defined Under Namespace
Modules: EmergencyStatus, InboundCallScreening, PhoneNumberType, SourceType, Status
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
-
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#deletion_lock_enabled ⇒ Boolean
Indicates whether deletion lock is enabled for this number.
-
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number.
-
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier.
-
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls.
-
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
-
#messaging_profile_name ⇒ String?
The name of the messaging profile associated with the phone number.
-
#tags ⇒ Array<String>
A list of user-assigned tags to help manage the phone number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, country_iso_alpha2:, created_at:, deletion_lock_enabled:, external_pin:, phone_number:, phone_number_type:, purchased_at:, record_type:, status:, tags:, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, hd_voice_enabled: nil, inbound_call_screening: nil, messaging_profile_id: nil, messaging_profile_name: nil, source_type: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberDetailed for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, country_iso_alpha2:, created_at:, deletion_lock_enabled:, external_pin:, phone_number:, phone_number_type:, purchased_at:, record_type:, status:, tags:, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, connection_name: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, hd_voice_enabled: nil, inbound_call_screening: nil, messaging_profile_id: nil, messaging_profile_name: nil, source_type: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberDetailed for more details.
|
|
# File 'lib/telnyx/models/phone_number_detailed.rb', line 199
|
Instance Attribute Details
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
33 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 33 optional :billing_group_id, String, nil?: true |
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
39 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 39 optional :connection_id, String, nil?: true |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
45 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 45 optional :customer_reference, String, nil?: true |
#deletion_lock_enabled ⇒ Boolean
Indicates whether deletion lock is enabled for this number. When enabled, this prevents the phone number from being deleted via the API or Telnyx portal.
12 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 12 required :deletion_lock_enabled, Telnyx::Internal::Type::Boolean |
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.
54 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 54 optional :emergency_status, enum: -> { Telnyx::PhoneNumberDetailed::EmergencyStatus } |
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.
21 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 21 required :external_pin, String, nil?: true |
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.
63 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 63 optional :inbound_call_screening, enum: -> { Telnyx::PhoneNumberDetailed::InboundCallScreening } |
#messaging_profile_id ⇒ String?
Identifies the messaging profile associated with the phone number.
69 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 69 optional :messaging_profile_id, String, nil?: true |
#messaging_profile_name ⇒ String?
The name of the messaging profile associated with the phone number.
75 |
# File 'lib/telnyx/models/phone_number_detailed.rb', line 75 optional :messaging_profile_name, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_detailed.rb', line 279
|