Module: Telnyx::Models::PhoneNumberDetailed::EmergencyStatus
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/phone_number_detailed.rb
Overview
Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.
Constant Summary collapse
- ACTIVE =
:active- DEPROVISIONING =
:deprovisioning- DISABLED =
:disabled- PROVISIONING =
:provisioning- PROVISIONING_FAILED =
:"provisioning-failed"
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info