Class: Telnyx::Models::PhoneNumberListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/phone_number_list_params.rb
Overview
Defined Under Namespace
Modules: HandleMessagingProfileError, Sort Classes: Filter
Instance Attribute Summary collapse
-
#filter ⇒ Telnyx::Models::PhoneNumberListParams::Filter?
Consolidated filter parameter (deepObject style).
-
#handle_messaging_profile_error ⇒ Symbol, ...
Although it is an infrequent occurrence, due to the highly distributed nature of the Telnyx platform, it is possible that there will be an issue when loading in Messaging Profile information.
- #page_number ⇒ Integer?
- #page_size ⇒ Integer?
-
#sort ⇒ Symbol, ...
Specifies the sort order for results.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#filter ⇒ Telnyx::Models::PhoneNumberListParams::Filter?
19 |
# File 'lib/telnyx/models/phone_number_list_params.rb', line 19 optional :filter, -> { Telnyx::PhoneNumberListParams::Filter } |
#handle_messaging_profile_error ⇒ Symbol, ...
Although it is an infrequent occurrence, due to the highly distributed nature of the Telnyx platform, it is possible that there will be an issue when loading in Messaging Profile information. As such, when this parameter is set to ‘true` and an error in fetching this information occurs, messaging profile related fields will be omitted in the response and an error message will be included instead of returning a 503 error.
30 31 |
# File 'lib/telnyx/models/phone_number_list_params.rb', line 30 optional :handle_messaging_profile_error, enum: -> { Telnyx::PhoneNumberListParams::HandleMessagingProfileError } |
#page_number ⇒ Integer?
36 |
# File 'lib/telnyx/models/phone_number_list_params.rb', line 36 optional :page_number, Integer |
#page_size ⇒ Integer?
41 |
# File 'lib/telnyx/models/phone_number_list_params.rb', line 41 optional :page_size, Integer |
#sort ⇒ Symbol, ...
Specifies the sort order for results. If not given, results are sorted by created_at in descending order.
48 |
# File 'lib/telnyx/models/phone_number_list_params.rb', line 48 optional :sort, enum: -> { Telnyx::PhoneNumberListParams::Sort } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_list_params.rb', line 337
|