Class: Telnyx::Models::PhoneNumberSlimListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberSlimListResponse
- Defined in:
- lib/telnyx/models/phone_number_slim_list_response.rb,
sig/telnyx/models/phone_number_slim_list_response.rbs
Overview
Defined Under Namespace
Modules: EmergencyStatus, InboundCallScreening, PhoneNumberType, Status
Instance Attribute Summary collapse
-
#activated_at ⇒ Time?
Returns the value of attribute activated_at.
-
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
-
#call_forwarding_enabled ⇒ Boolean?
readonly
Returns the value of attribute call_forwarding_enabled.
-
#call_recording_enabled ⇒ Boolean?
readonly
Returns the value of attribute call_recording_enabled.
-
#caller_id_name_enabled ⇒ Boolean?
readonly
Returns the value of attribute caller_id_name_enabled.
-
#cnam_listing_enabled ⇒ Boolean?
readonly
Returns the value of attribute cnam_listing_enabled.
-
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
-
#country_iso_alpha2 ⇒ String?
readonly
Returns the value of attribute country_iso_alpha2.
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#emergency_address_id ⇒ String?
readonly
Returns the value of attribute emergency_address_id.
-
#emergency_enabled ⇒ Boolean?
readonly
Returns the value of attribute emergency_enabled.
-
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number.
-
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier.
-
#hd_voice_enabled ⇒ Boolean?
readonly
Returns the value of attribute hd_voice_enabled.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls.
-
#phone_number ⇒ String?
readonly
Returns the value of attribute phone_number.
-
#phone_number_type ⇒ Telnyx::Models::PhoneNumberSlimListResponse::phone_number_type?
readonly
Returns the value of attribute phone_number_type.
-
#purchased_at ⇒ String?
readonly
Returns the value of attribute purchased_at.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#status ⇒ Telnyx::Models::PhoneNumberSlimListResponse::status?
readonly
Returns the value of attribute status.
-
#t38_fax_gateway_enabled ⇒ Boolean?
readonly
Returns the value of attribute t38_fax_gateway_enabled.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Class Method Summary collapse
Instance Method Summary collapse
- #call_forwarding_enabled ⇒ Boolean readonly
- #call_recording_enabled ⇒ Boolean readonly
- #caller_id_name_enabled ⇒ Boolean readonly
- #cnam_listing_enabled ⇒ Boolean readonly
- #country_iso_alpha2 ⇒ String readonly
- #created_at ⇒ String readonly
- #emergency_address_id ⇒ String readonly
- #emergency_enabled ⇒ Boolean readonly
- #hd_voice_enabled ⇒ Boolean readonly
- #id ⇒ String readonly
-
#initialize(id: nil, activated_at: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, country_iso_alpha2: nil, created_at: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, external_pin: nil, hd_voice_enabled: nil, inbound_call_screening: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberSlimListResponse for more details.
- #phone_number ⇒ String readonly
- #phone_number_type ⇒ Object readonly
- #purchased_at ⇒ String readonly
- #record_type ⇒ String readonly
- #status ⇒ Object readonly
- #t38_fax_gateway_enabled ⇒ Boolean readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, activated_at: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, country_iso_alpha2: nil, created_at: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, external_pin: nil, hd_voice_enabled: nil, inbound_call_screening: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberSlimListResponse for more details.
|
|
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 170
|
Instance Attribute Details
#activated_at ⇒ Time?
Returns the value of attribute activated_at.
64 65 66 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 64 def activated_at @activated_at end |
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
11 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 11 optional :billing_group_id, String |
#call_forwarding_enabled ⇒ Boolean? (readonly)
Returns the value of attribute call_forwarding_enabled.
66 67 68 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 66 def call_forwarding_enabled @call_forwarding_enabled end |
#call_recording_enabled ⇒ Boolean? (readonly)
Returns the value of attribute call_recording_enabled.
70 71 72 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 70 def call_recording_enabled @call_recording_enabled end |
#caller_id_name_enabled ⇒ Boolean? (readonly)
Returns the value of attribute caller_id_name_enabled.
74 75 76 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 74 def caller_id_name_enabled @caller_id_name_enabled end |
#cnam_listing_enabled ⇒ Boolean? (readonly)
Returns the value of attribute cnam_listing_enabled.
78 79 80 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 78 def cnam_listing_enabled @cnam_listing_enabled end |
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
17 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 17 optional :connection_id, String |
#country_iso_alpha2 ⇒ String? (readonly)
Returns the value of attribute country_iso_alpha2.
82 83 84 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 82 def country_iso_alpha2 @country_iso_alpha2 end |
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
86 87 88 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 86 def created_at @created_at end |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
23 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 23 optional :customer_reference, String |
#emergency_address_id ⇒ String? (readonly)
Returns the value of attribute emergency_address_id.
90 91 92 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 90 def emergency_address_id @emergency_address_id end |
#emergency_enabled ⇒ Boolean? (readonly)
Returns the value of attribute emergency_enabled.
94 95 96 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 94 def emergency_enabled @emergency_enabled end |
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.
32 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 32 optional :emergency_status, enum: -> { Telnyx::Models::PhoneNumberSlimListResponse::EmergencyStatus } |
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.
41 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 41 optional :external_pin, String |
#hd_voice_enabled ⇒ Boolean? (readonly)
Returns the value of attribute hd_voice_enabled.
98 99 100 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 98 def hd_voice_enabled @hd_voice_enabled end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
60 61 62 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 60 def id @id end |
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.
50 51 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 50 optional :inbound_call_screening, enum: -> { Telnyx::Models::PhoneNumberSlimListResponse::InboundCallScreening } |
#phone_number ⇒ String? (readonly)
Returns the value of attribute phone_number.
102 103 104 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 102 def phone_number @phone_number end |
#phone_number_type ⇒ Telnyx::Models::PhoneNumberSlimListResponse::phone_number_type? (readonly)
Returns the value of attribute phone_number_type.
106 107 108 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 106 def phone_number_type @phone_number_type end |
#purchased_at ⇒ String? (readonly)
Returns the value of attribute purchased_at.
112 113 114 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 112 def purchased_at @purchased_at end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
116 117 118 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 116 def record_type @record_type end |
#status ⇒ Telnyx::Models::PhoneNumberSlimListResponse::status? (readonly)
Returns the value of attribute status.
120 121 122 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 120 def status @status end |
#t38_fax_gateway_enabled ⇒ Boolean? (readonly)
Returns the value of attribute t38_fax_gateway_enabled.
126 127 128 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 126 def t38_fax_gateway_enabled @t38_fax_gateway_enabled end |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
130 131 132 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 130 def updated_at @updated_at end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 237
|
Instance Method Details
#call_forwarding_enabled= ⇒ Boolean (readonly)
68 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 68
def call_forwarding_enabled=: (bool) -> bool
|
#call_recording_enabled= ⇒ Boolean (readonly)
72 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 72
def call_recording_enabled=: (bool) -> bool
|
#caller_id_name_enabled= ⇒ Boolean (readonly)
76 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 76
def caller_id_name_enabled=: (bool) -> bool
|
#cnam_listing_enabled= ⇒ Boolean (readonly)
80 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 80
def cnam_listing_enabled=: (bool) -> bool
|
#country_iso_alpha2= ⇒ String (readonly)
84 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 84
def country_iso_alpha2=: (String) -> String
|
#created_at= ⇒ String (readonly)
88 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 88
def created_at=: (String) -> String
|
#emergency_address_id= ⇒ String (readonly)
92 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 92
def emergency_address_id=: (String) -> String
|
#emergency_enabled= ⇒ Boolean (readonly)
96 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 96
def emergency_enabled=: (bool) -> bool
|
#hd_voice_enabled= ⇒ Boolean (readonly)
100 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 100
def hd_voice_enabled=: (bool) -> bool
|
#id= ⇒ String (readonly)
62 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 62
def id=: (String) -> String
|
#phone_number= ⇒ String (readonly)
104 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 104
def phone_number=: (String) -> String
|
#phone_number_type= ⇒ Object (readonly)
108 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 108
def phone_number_type=: (
|
#purchased_at= ⇒ String (readonly)
114 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 114
def purchased_at=: (String) -> String
|
#record_type= ⇒ String (readonly)
118 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 118
def record_type=: (String) -> String
|
#status= ⇒ Object (readonly)
122 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 122
def status=: (
|
#t38_fax_gateway_enabled= ⇒ Boolean (readonly)
128 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 128
def t38_fax_gateway_enabled=: (bool) -> bool
|
#to_hash ⇒ {
161 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 161
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
132 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 132
def updated_at=: (String) -> String
|