Class: Telnyx::Models::PhoneNumberSlimListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberSlimListResponse
- Defined in:
- lib/telnyx/models/phone_number_slim_list_response.rb,
sig/telnyx/models/phone_number_slim_list_response.rbs
Overview
Defined Under Namespace
Modules: EmergencyStatus, InboundCallScreening, PhoneNumberType, Status
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
-
#call_forwarding_enabled ⇒ Boolean?
readonly
Returns the value of attribute call_forwarding_enabled.
-
#call_recording_enabled ⇒ Boolean?
readonly
Returns the value of attribute call_recording_enabled.
-
#caller_id_name_enabled ⇒ Boolean?
readonly
Returns the value of attribute caller_id_name_enabled.
-
#cnam_listing_enabled ⇒ Boolean?
readonly
Returns the value of attribute cnam_listing_enabled.
-
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
-
#country_iso_alpha2 ⇒ String?
readonly
Returns the value of attribute country_iso_alpha2.
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#emergency_address_id ⇒ String?
readonly
Returns the value of attribute emergency_address_id.
-
#emergency_enabled ⇒ Boolean?
readonly
Returns the value of attribute emergency_enabled.
-
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number.
-
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier.
-
#hd_voice_enabled ⇒ Boolean?
readonly
Returns the value of attribute hd_voice_enabled.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls.
-
#phone_number ⇒ String?
readonly
Returns the value of attribute phone_number.
-
#phone_number_type ⇒ Telnyx::Models::PhoneNumberSlimListResponse::phone_number_type?
readonly
Returns the value of attribute phone_number_type.
-
#purchased_at ⇒ String?
readonly
Returns the value of attribute purchased_at.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#status ⇒ Telnyx::Models::PhoneNumberSlimListResponse::status?
readonly
Returns the value of attribute status.
-
#t38_fax_gateway_enabled ⇒ Boolean?
readonly
Returns the value of attribute t38_fax_gateway_enabled.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Class Method Summary collapse
Instance Method Summary collapse
- #call_forwarding_enabled ⇒ Boolean readonly
- #call_recording_enabled ⇒ Boolean readonly
- #caller_id_name_enabled ⇒ Boolean readonly
- #cnam_listing_enabled ⇒ Boolean readonly
- #country_iso_alpha2 ⇒ String readonly
- #created_at ⇒ String readonly
- #emergency_address_id ⇒ String readonly
- #emergency_enabled ⇒ Boolean readonly
- #hd_voice_enabled ⇒ Boolean readonly
- #id ⇒ String readonly
-
#initialize(id: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, country_iso_alpha2: nil, created_at: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, external_pin: nil, hd_voice_enabled: nil, inbound_call_screening: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberSlimListResponse for more details.
- #phone_number ⇒ String readonly
- #phone_number_type ⇒ Object readonly
- #purchased_at ⇒ String readonly
- #record_type ⇒ String readonly
- #status ⇒ Object readonly
- #t38_fax_gateway_enabled ⇒ Boolean readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, country_iso_alpha2: nil, created_at: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, external_pin: nil, hd_voice_enabled: nil, inbound_call_screening: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberSlimListResponse for more details.
|
|
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 161
|
Instance Attribute Details
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
11 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 11 optional :billing_group_id, String |
#call_forwarding_enabled ⇒ Boolean? (readonly)
Returns the value of attribute call_forwarding_enabled.
63 64 65 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 63 def call_forwarding_enabled @call_forwarding_enabled end |
#call_recording_enabled ⇒ Boolean? (readonly)
Returns the value of attribute call_recording_enabled.
67 68 69 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 67 def call_recording_enabled @call_recording_enabled end |
#caller_id_name_enabled ⇒ Boolean? (readonly)
Returns the value of attribute caller_id_name_enabled.
71 72 73 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 71 def caller_id_name_enabled @caller_id_name_enabled end |
#cnam_listing_enabled ⇒ Boolean? (readonly)
Returns the value of attribute cnam_listing_enabled.
75 76 77 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 75 def cnam_listing_enabled @cnam_listing_enabled end |
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
17 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 17 optional :connection_id, String |
#country_iso_alpha2 ⇒ String? (readonly)
Returns the value of attribute country_iso_alpha2.
79 80 81 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 79 def country_iso_alpha2 @country_iso_alpha2 end |
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
83 84 85 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 83 def created_at @created_at end |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
23 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 23 optional :customer_reference, String |
#emergency_address_id ⇒ String? (readonly)
Returns the value of attribute emergency_address_id.
87 88 89 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 87 def emergency_address_id @emergency_address_id end |
#emergency_enabled ⇒ Boolean? (readonly)
Returns the value of attribute emergency_enabled.
91 92 93 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 91 def emergency_enabled @emergency_enabled end |
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.
32 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 32 optional :emergency_status, enum: -> { Telnyx::Models::PhoneNumberSlimListResponse::EmergencyStatus } |
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.
41 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 41 optional :external_pin, String |
#hd_voice_enabled ⇒ Boolean? (readonly)
Returns the value of attribute hd_voice_enabled.
95 96 97 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 95 def hd_voice_enabled @hd_voice_enabled end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
59 60 61 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 59 def id @id end |
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.
50 51 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 50 optional :inbound_call_screening, enum: -> { Telnyx::Models::PhoneNumberSlimListResponse::InboundCallScreening } |
#phone_number ⇒ String? (readonly)
Returns the value of attribute phone_number.
99 100 101 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 99 def phone_number @phone_number end |
#phone_number_type ⇒ Telnyx::Models::PhoneNumberSlimListResponse::phone_number_type? (readonly)
Returns the value of attribute phone_number_type.
103 104 105 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 103 def phone_number_type @phone_number_type end |
#purchased_at ⇒ String? (readonly)
Returns the value of attribute purchased_at.
109 110 111 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 109 def purchased_at @purchased_at end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
113 114 115 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 113 def record_type @record_type end |
#status ⇒ Telnyx::Models::PhoneNumberSlimListResponse::status? (readonly)
Returns the value of attribute status.
117 118 119 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 117 def status @status end |
#t38_fax_gateway_enabled ⇒ Boolean? (readonly)
Returns the value of attribute t38_fax_gateway_enabled.
123 124 125 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 123 def t38_fax_gateway_enabled @t38_fax_gateway_enabled end |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
127 128 129 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 127 def updated_at @updated_at end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 226
|
Instance Method Details
#call_forwarding_enabled= ⇒ Boolean (readonly)
65 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 65
def call_forwarding_enabled=: (bool) -> bool
|
#call_recording_enabled= ⇒ Boolean (readonly)
69 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 69
def call_recording_enabled=: (bool) -> bool
|
#caller_id_name_enabled= ⇒ Boolean (readonly)
73 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 73
def caller_id_name_enabled=: (bool) -> bool
|
#cnam_listing_enabled= ⇒ Boolean (readonly)
77 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 77
def cnam_listing_enabled=: (bool) -> bool
|
#country_iso_alpha2= ⇒ String (readonly)
81 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 81
def country_iso_alpha2=: (String) -> String
|
#created_at= ⇒ String (readonly)
85 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 85
def created_at=: (String) -> String
|
#emergency_address_id= ⇒ String (readonly)
89 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 89
def emergency_address_id=: (String) -> String
|
#emergency_enabled= ⇒ Boolean (readonly)
93 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 93
def emergency_enabled=: (bool) -> bool
|
#hd_voice_enabled= ⇒ Boolean (readonly)
97 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 97
def hd_voice_enabled=: (bool) -> bool
|
#id= ⇒ String (readonly)
61 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 61
def id=: (String) -> String
|
#phone_number= ⇒ String (readonly)
101 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 101
def phone_number=: (String) -> String
|
#phone_number_type= ⇒ Object (readonly)
105 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 105
def phone_number_type=: (
|
#purchased_at= ⇒ String (readonly)
111 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 111
def purchased_at=: (String) -> String
|
#record_type= ⇒ String (readonly)
115 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 115
def record_type=: (String) -> String
|
#status= ⇒ Object (readonly)
119 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 119
def status=: (
|
#t38_fax_gateway_enabled= ⇒ Boolean (readonly)
125 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 125
def t38_fax_gateway_enabled=: (bool) -> bool
|
#to_hash ⇒ {
157 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 157
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
129 |
# File 'sig/telnyx/models/phone_number_slim_list_response.rbs', line 129
def updated_at=: (String) -> String
|