Class: Telnyx::Models::PhoneNumberSlimListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_number_slim_list_response.rb

Overview

Defined Under Namespace

Modules: EmergencyStatus, InboundCallScreening, PhoneNumberType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, country_iso_alpha2: nil, created_at: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, external_pin: nil, hd_voice_enabled: nil, inbound_call_screening: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberSlimListResponse for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • billing_group_id (String) (defaults to: nil)

    Identifies the billing group associated with the phone number.

  • call_forwarding_enabled (Boolean) (defaults to: nil)

    Indicates if call forwarding will be enabled for this number if forwards_to and

  • call_recording_enabled (Boolean) (defaults to: nil)

    Indicates whether call recording is enabled for this number.

  • caller_id_name_enabled (Boolean) (defaults to: nil)

    Indicates whether caller ID is enabled for this number.

  • cnam_listing_enabled (Boolean) (defaults to: nil)

    Indicates whether a CNAM listing is enabled for this number.

  • connection_id (String) (defaults to: nil)

    Identifies the connection associated with the phone number.

  • country_iso_alpha2 (String) (defaults to: nil)

    The ISO 3166-1 alpha-2 country code of the phone number.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • emergency_address_id (String) (defaults to: nil)

    Identifies the emergency address associated with the phone number.

  • emergency_enabled (Boolean) (defaults to: nil)

    Indicates whether emergency services are enabled for this number.

  • emergency_status (Symbol, Telnyx::Models::PhoneNumberSlimListResponse::EmergencyStatus) (defaults to: nil)

    Indicates the status of the provisioning of emergency services for the phone num

  • external_pin (String) (defaults to: nil)

    If someone attempts to port your phone number away from Telnyx and your phone nu

  • hd_voice_enabled (Boolean) (defaults to: nil)

    Indicates whether HD voice is enabled for this number.

  • inbound_call_screening (Symbol, Telnyx::Models::PhoneNumberSlimListResponse::InboundCallScreening) (defaults to: nil)

    The inbound_call_screening setting is a phone number configuration option variab

  • phone_number (String) (defaults to: nil)

    The +E.164-formatted phone number associated with this record.

  • phone_number_type (Symbol, Telnyx::Models::PhoneNumberSlimListResponse::PhoneNumberType) (defaults to: nil)

    The phone number’s type.

  • purchased_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was purchased.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • status (Symbol, Telnyx::Models::PhoneNumberSlimListResponse::Status) (defaults to: nil)

    The phone number’s current status.

  • t38_fax_gateway_enabled (Boolean) (defaults to: nil)

    Indicates whether T38 Fax Gateway for inbound calls to this number.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 161

Instance Attribute Details

#billing_group_idString?

Identifies the billing group associated with the phone number.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 11

optional :billing_group_id, String

#connection_idString?

Identifies the connection associated with the phone number.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 17

optional :connection_id, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 23

optional :customer_reference, String

#emergency_statusSymbol, ...

Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.



32
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 32

optional :emergency_status, enum: -> { Telnyx::Models::PhoneNumberSlimListResponse::EmergencyStatus }

#external_pinString?

If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 41

optional :external_pin, String

#inbound_call_screeningSymbol, ...

The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.



50
51
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 50

optional :inbound_call_screening,
enum: -> { Telnyx::Models::PhoneNumberSlimListResponse::InboundCallScreening }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 226