Class: Telnyx::Models::PhoneNumberSlimListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberSlimListResponse
- Defined in:
- lib/telnyx/models/phone_number_slim_list_response.rb
Overview
Defined Under Namespace
Modules: EmergencyStatus, InboundCallScreening, PhoneNumberType, Status
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
-
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number.
-
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier.
-
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, country_iso_alpha2: nil, created_at: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, external_pin: nil, hd_voice_enabled: nil, inbound_call_screening: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberSlimListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, billing_group_id: nil, call_forwarding_enabled: nil, call_recording_enabled: nil, caller_id_name_enabled: nil, cnam_listing_enabled: nil, connection_id: nil, country_iso_alpha2: nil, created_at: nil, customer_reference: nil, emergency_address_id: nil, emergency_enabled: nil, emergency_status: nil, external_pin: nil, hd_voice_enabled: nil, inbound_call_screening: nil, phone_number: nil, phone_number_type: nil, purchased_at: nil, record_type: nil, status: nil, t38_fax_gateway_enabled: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberSlimListResponse for more details.
|
|
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 161
|
Instance Attribute Details
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
11 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 11 optional :billing_group_id, String |
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
17 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 17 optional :connection_id, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
23 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 23 optional :customer_reference, String |
#emergency_status ⇒ Symbol, ...
Indicates the status of the provisioning of emergency services for the phone number. This field contains information about activity that may be ongoing for a number where it either is being provisioned or deprovisioned but is not yet enabled/disabled.
32 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 32 optional :emergency_status, enum: -> { Telnyx::Models::PhoneNumberSlimListResponse::EmergencyStatus } |
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, Telnyx will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.
41 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 41 optional :external_pin, String |
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.
50 51 |
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 50 optional :inbound_call_screening, enum: -> { Telnyx::Models::PhoneNumberSlimListResponse::InboundCallScreening } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_slim_list_response.rb', line 226
|