Class: Telnyx::Models::PhoneNumberUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/phone_number_update_params.rb
Overview
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
-
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, we will attempt to verify that you provided the correct external PIN to the winning carrier.
-
#hd_voice_enabled ⇒ Boolean?
Indicates whether HD voice is enabled for this number.
-
#tags ⇒ Array<String>?
A list of user-assigned tags to help organize phone numbers.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(billing_group_id: nil, connection_id: nil, customer_reference: nil, external_pin: nil, hd_voice_enabled: nil, tags: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing_group_id: nil, connection_id: nil, customer_reference: nil, external_pin: nil, hd_voice_enabled: nil, tags: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumberUpdateParams for more details.
|
|
# File 'lib/telnyx/models/phone_number_update_params.rb', line 49
|
Instance Attribute Details
#billing_group_id ⇒ String?
Identifies the billing group associated with the phone number.
14 |
# File 'lib/telnyx/models/phone_number_update_params.rb', line 14 optional :billing_group_id, String |
#connection_id ⇒ String?
Identifies the connection associated with the phone number.
20 |
# File 'lib/telnyx/models/phone_number_update_params.rb', line 20 optional :connection_id, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
26 |
# File 'lib/telnyx/models/phone_number_update_params.rb', line 26 optional :customer_reference, String |
#external_pin ⇒ String?
If someone attempts to port your phone number away from Telnyx and your phone number has an external PIN set, we will attempt to verify that you provided the correct external PIN to the winning carrier. Note that not all carriers cooperate with this security mechanism.
35 |
# File 'lib/telnyx/models/phone_number_update_params.rb', line 35 optional :external_pin, String |