Class: Telnyx::Models::PhoneNumberWithMessagingSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberWithMessagingSettings
- Defined in:
- lib/telnyx/models/phone_number_with_messaging_settings.rb,
sig/telnyx/models/phone_number_with_messaging_settings.rbs
Defined Under Namespace
Modules: RecordType, Type Classes: Features
Instance Attribute Summary collapse
-
#country_code ⇒ String?
readonly
Returns the value of attribute country_code.
-
#created_at ⇒ Time?
readonly
Returns the value of attribute created_at.
-
#eligible_messaging_products ⇒ ::Array[String]?
readonly
Returns the value of attribute eligible_messaging_products.
-
#features ⇒ Telnyx::PhoneNumberWithMessagingSettings::Features?
readonly
Returns the value of attribute features.
-
#health ⇒ Telnyx::Models::NumberHealthMetrics?
High level health metrics about the number and it's messaging sending patterns.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#messaging_product ⇒ String?
The messaging product that the number is registered to use.
-
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
-
#organization_id ⇒ String?
The organization that owns this phone number.
-
#phone_number ⇒ String?
readonly
Returns the value of attribute phone_number.
-
#record_type ⇒ Telnyx::Models::PhoneNumberWithMessagingSettings::record_type?
readonly
Returns the value of attribute record_type.
-
#tags ⇒ Array<String>?
Tags associated with this phone number.
-
#traffic_type ⇒ String?
readonly
Returns the value of attribute traffic_type.
-
#type ⇒ Telnyx::Models::PhoneNumberWithMessagingSettings::type_?
readonly
Returns the value of attribute type.
-
#updated_at ⇒ Time?
readonly
Returns the value of attribute updated_at.
Class Method Summary collapse
Instance Method Summary collapse
- #country_code ⇒ String readonly
- #created_at ⇒ Time readonly
- #eligible_messaging_products ⇒ ::Array[String] readonly
- #features ⇒ Object readonly
- #id ⇒ String readonly
-
#initialize(mms: nil, sms: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Features for more details.
- #phone_number ⇒ String readonly
- #record_type ⇒ Object readonly
- #to_hash ⇒ {
- #traffic_type ⇒ String readonly
- #type ⇒ Object readonly
- #updated_at ⇒ Time readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mms: nil, sms: nil) ⇒ Object
Some parameter documentations has been truncated, see Features for more details.
|
|
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 97
|
Instance Attribute Details
#country_code ⇒ String? (readonly)
Returns the value of attribute country_code.
45 46 47 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 45 def country_code @country_code end |
#created_at ⇒ Time? (readonly)
Returns the value of attribute created_at.
49 50 51 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 49 def created_at @created_at end |
#eligible_messaging_products ⇒ ::Array[String]? (readonly)
Returns the value of attribute eligible_messaging_products.
53 54 55 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 53 def eligible_messaging_products @eligible_messaging_products end |
#features ⇒ Telnyx::PhoneNumberWithMessagingSettings::Features? (readonly)
Returns the value of attribute features.
57 58 59 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 57 def features @features end |
#health ⇒ Telnyx::Models::NumberHealthMetrics?
High level health metrics about the number and it's messaging sending patterns.
10 |
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 10 optional :health, -> { Telnyx::NumberHealthMetrics } |
#id ⇒ String? (readonly)
Returns the value of attribute id.
41 42 43 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 41 def id @id end |
#messaging_product ⇒ String?
The messaging product that the number is registered to use
16 |
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 16 optional :messaging_product, String |
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
22 |
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 22 optional :messaging_profile_id, String, nil?: true |
#organization_id ⇒ String?
The organization that owns this phone number.
28 |
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 28 optional :organization_id, String |
#phone_number ⇒ String? (readonly)
Returns the value of attribute phone_number.
63 64 65 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 63 def phone_number @phone_number end |
#record_type ⇒ Telnyx::Models::PhoneNumberWithMessagingSettings::record_type? (readonly)
Returns the value of attribute record_type.
67 68 69 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 67 def record_type @record_type end |
#tags ⇒ Array<String>?
Tags associated with this phone number.
34 |
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 34 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#traffic_type ⇒ String? (readonly)
Returns the value of attribute traffic_type.
73 74 75 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 73 def traffic_type @traffic_type end |
#type ⇒ Telnyx::Models::PhoneNumberWithMessagingSettings::type_? (readonly)
Returns the value of attribute type.
77 78 79 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 77 def type @type end |
#updated_at ⇒ Time? (readonly)
Returns the value of attribute updated_at.
83 84 85 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 83 def updated_at @updated_at end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 167
|
Instance Method Details
#country_code= ⇒ String (readonly)
47 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 47
def country_code=: (String) -> String
|
#created_at= ⇒ Time (readonly)
51 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 51
def created_at=: (Time) -> Time
|
#eligible_messaging_products= ⇒ ::Array[String] (readonly)
55 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 55
def eligible_messaging_products=: (::Array[String]) -> ::Array[String]
|
#features= ⇒ Object (readonly)
59 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 59
def features=: (
|
#id= ⇒ String (readonly)
43 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 43
def id=: (String) -> String
|
#phone_number= ⇒ String (readonly)
65 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 65
def phone_number=: (String) -> String
|
#record_type= ⇒ Object (readonly)
69 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 69
def record_type=: (
|
#to_hash ⇒ {
105 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 105
def to_hash: -> {
|
#traffic_type= ⇒ String (readonly)
75 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 75
def traffic_type=: (String) -> String
|
#type= ⇒ Object (readonly)
79 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 79
def type=: (
|
#updated_at= ⇒ Time (readonly)
85 |
# File 'sig/telnyx/models/phone_number_with_messaging_settings.rbs', line 85
def updated_at=: (Time) -> Time
|