Class: Telnyx::Models::PhoneNumberWithMessagingSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_number_with_messaging_settings.rb

Defined Under Namespace

Modules: RecordType, Type Classes: Features

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mms: nil, sms: nil) ⇒ Object

Some parameter documentations has been truncated, see Features for more details.

Parameters:



# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 97

Instance Attribute Details

#healthTelnyx::Models::NumberHealthMetrics?

High level health metrics about the number and it’s messaging sending patterns.



10
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 10

optional :health, -> { Telnyx::NumberHealthMetrics }

#messaging_productString?

The messaging product that the number is registered to use

Returns:

  • (String, nil)


16
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 16

optional :messaging_product, String

#messaging_profile_idString?

Unique identifier for a messaging profile.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 22

optional :messaging_profile_id, String, nil?: true

#organization_idString?

The organization that owns this phone number.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 28

optional :organization_id, String

#tagsArray<String>?

Tags associated with this phone number.

Returns:

  • (Array<String>, nil)


34
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 34

optional :tags, Telnyx::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 167