Class: Telnyx::Models::PhoneNumberWithMessagingSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumberWithMessagingSettings
- Defined in:
- lib/telnyx/models/phone_number_with_messaging_settings.rb
Defined Under Namespace
Modules: RecordType, Type Classes: Features
Instance Attribute Summary collapse
-
#health ⇒ Telnyx::Models::NumberHealthMetrics?
High level health metrics about the number and it’s messaging sending patterns.
-
#messaging_product ⇒ String?
The messaging product that the number is registered to use.
-
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
-
#organization_id ⇒ String?
The organization that owns this phone number.
-
#tags ⇒ Array<String>?
Tags associated with this phone number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(mms: nil, sms: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Features for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mms: nil, sms: nil) ⇒ Object
Some parameter documentations has been truncated, see Features for more details.
|
|
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 97
|
Instance Attribute Details
#health ⇒ Telnyx::Models::NumberHealthMetrics?
High level health metrics about the number and it’s messaging sending patterns.
10 |
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 10 optional :health, -> { Telnyx::NumberHealthMetrics } |
#messaging_product ⇒ String?
The messaging product that the number is registered to use
16 |
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 16 optional :messaging_product, String |
#messaging_profile_id ⇒ String?
Unique identifier for a messaging profile.
22 |
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 22 optional :messaging_profile_id, String, nil?: true |
#organization_id ⇒ String?
The organization that owns this phone number.
28 |
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 28 optional :organization_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_number_with_messaging_settings.rb', line 167
|