Class: Telnyx::Models::PhoneNumbers::ActionVerifyOwnershipResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/phone_numbers/action_verify_ownership_response.rb

Overview

See Also:

Defined Under Namespace

Classes: Found

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#foundArray<Telnyx::Models::PhoneNumbers::ActionVerifyOwnershipResponse::Data::Found>?

The list of phone numbers which you own and are in an editable state



22
23
# File 'lib/telnyx/models/phone_numbers/action_verify_ownership_response.rb', line 22

optional :found,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::PhoneNumbers::ActionVerifyOwnershipResponse::Data::Found] }

#not_foundArray<String>?

Phone numbers that are not found in the account

Returns:

  • (Array<String>, nil)


29
# File 'lib/telnyx/models/phone_numbers/action_verify_ownership_response.rb', line 29

optional :not_found, Telnyx::Internal::Type::ArrayOf[String]