Class: Telnyx::Models::PhoneNumbers::CallForwarding
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumbers::CallForwarding
- Defined in:
- lib/telnyx/models/phone_numbers/call_forwarding.rb
Defined Under Namespace
Modules: ForwardingType
Instance Attribute Summary collapse
-
#call_forwarding_enabled ⇒ Boolean?
Indicates if call forwarding will be enabled for this number if forwards_to and forwarding_type are filled in.
-
#forwarding_type ⇒ Symbol, ...
Call forwarding type.
-
#forwards_to ⇒ String?
The phone number to which inbound calls to this number are forwarded.
Instance Method Summary collapse
-
#initialize(call_forwarding_enabled: nil, forwarding_type: nil, forwards_to: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallForwarding for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_forwarding_enabled: nil, forwarding_type: nil, forwards_to: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumbers::CallForwarding for more details.
The call forwarding settings for a phone number.
|
|
# File 'lib/telnyx/models/phone_numbers/call_forwarding.rb', line 29
|
Instance Attribute Details
#call_forwarding_enabled ⇒ Boolean?
Indicates if call forwarding will be enabled for this number if forwards_to and forwarding_type are filled in. Defaults to true for backwards compatibility with APIV1 use of numbers endpoints.
13 |
# File 'lib/telnyx/models/phone_numbers/call_forwarding.rb', line 13 optional :call_forwarding_enabled, Telnyx::Internal::Type::Boolean |
#forwarding_type ⇒ Symbol, ...
Call forwarding type. ‘forwards_to’ must be set for this to have an effect.
19 |
# File 'lib/telnyx/models/phone_numbers/call_forwarding.rb', line 19 optional :forwarding_type, enum: -> { Telnyx::PhoneNumbers::CallForwarding::ForwardingType } |
#forwards_to ⇒ String?
The phone number to which inbound calls to this number are forwarded. Inbound calls will not be forwarded if this field is left blank. If set, must be a +E.164-formatted phone number.
27 |
# File 'lib/telnyx/models/phone_numbers/call_forwarding.rb', line 27 optional :forwards_to, String |