Class: Telnyx::Models::PhoneNumbers::CallRecording
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumbers::CallRecording
- Defined in:
- lib/telnyx/models/phone_numbers/call_recording.rb
Defined Under Namespace
Modules: InboundCallRecordingChannels, InboundCallRecordingFormat
Instance Attribute Summary collapse
-
#inbound_call_recording_channels ⇒ Symbol, ...
When using ‘dual’ channels, final audio file will be stereo recorded with the first leg on channel A, and the rest on channel B.
-
#inbound_call_recording_enabled ⇒ Boolean?
When enabled, any inbound call to this number will be recorded.
-
#inbound_call_recording_format ⇒ Symbol, ...
The audio file format for calls being recorded.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(inbound_call_recording_channels: nil, inbound_call_recording_enabled: nil, inbound_call_recording_format: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallRecording for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(inbound_call_recording_channels: nil, inbound_call_recording_enabled: nil, inbound_call_recording_format: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumbers::CallRecording for more details.
The call recording settings for a phone number.
|
|
# File 'lib/telnyx/models/phone_numbers/call_recording.rb', line 28
|
Instance Attribute Details
#inbound_call_recording_channels ⇒ Symbol, ...
When using ‘dual’ channels, final audio file will be stereo recorded with the first leg on channel A, and the rest on channel B.
12 13 |
# File 'lib/telnyx/models/phone_numbers/call_recording.rb', line 12 optional :inbound_call_recording_channels, enum: -> { Telnyx::PhoneNumbers::CallRecording::InboundCallRecordingChannels } |
#inbound_call_recording_enabled ⇒ Boolean?
When enabled, any inbound call to this number will be recorded.
19 |
# File 'lib/telnyx/models/phone_numbers/call_recording.rb', line 19 optional :inbound_call_recording_enabled, Telnyx::Internal::Type::Boolean |
#inbound_call_recording_format ⇒ Symbol, ...
The audio file format for calls being recorded.
25 26 |
# File 'lib/telnyx/models/phone_numbers/call_recording.rb', line 25 optional :inbound_call_recording_format, enum: -> { Telnyx::PhoneNumbers::CallRecording::InboundCallRecordingFormat } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_numbers/call_recording.rb', line 50
|