Class: Telnyx::Models::PhoneNumbers::CsvDownloadCreateParams::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumbers::CsvDownloadCreateParams::Filter
- Defined in:
- lib/telnyx/models/phone_numbers/csv_download_create_params.rb
Defined Under Namespace
Modules: Status, VoiceUsagePaymentMethod Classes: VoiceConnectionName
Instance Attribute Summary collapse
-
#billing_group_id ⇒ String?
Filter by the billing_group_id associated with phone numbers.
-
#connection_id ⇒ String?
Filter by connection_id.
-
#customer_reference ⇒ String?
Filter numbers via the customer_reference set.
-
#emergency_address_id ⇒ String?
Filter by the emergency_address_id associated with phone numbers.
-
#has_bundle ⇒ String?
Filter by phone number that have bundles.
-
#phone_number ⇒ String?
Filter by phone number.
-
#status ⇒ Symbol, ...
Filter by phone number status.
-
#tag ⇒ String?
Filter by phone number tags.
-
#voice_connection_name ⇒ Telnyx::Models::PhoneNumbers::CsvDownloadCreateParams::Filter::VoiceConnectionName?
Filter by voice connection name pattern matching.
-
#voice_usage_payment_method ⇒ Symbol, ...
Filter by usage_payment_method.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(contains: nil, ends_with: nil, eq: nil, starts_with: nil) ⇒ Object
constructor
Filter by voice connection name pattern matching.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(contains: nil, ends_with: nil, eq: nil, starts_with: nil) ⇒ Object
Filter by voice connection name pattern matching.
|
|
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 122
|
Instance Attribute Details
#billing_group_id ⇒ String?
Filter by the billing_group_id associated with phone numbers. To filter to only phone numbers that have no billing group associated them, set the value of this filter to the string ‘null’.
57 |
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 57 optional :billing_group_id, String |
#connection_id ⇒ String?
Filter by connection_id.
63 |
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 63 optional :connection_id, String |
#customer_reference ⇒ String?
Filter numbers via the customer_reference set.
69 |
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 69 optional :customer_reference, String |
#emergency_address_id ⇒ String?
Filter by the emergency_address_id associated with phone numbers. To filter only phone numbers that have no emergency address associated with them, set the value of this filter to the string ‘null’.
77 |
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 77 optional :emergency_address_id, String |
#has_bundle ⇒ String?
Filter by phone number that have bundles.
83 |
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 83 optional :has_bundle, String |
#phone_number ⇒ String?
Filter by phone number. Requires at least three digits. Non-numerical characters will result in no values being returned.
90 |
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 90 optional :phone_number, String |
#status ⇒ Symbol, ...
Filter by phone number status.
96 |
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 96 optional :status, enum: -> { Telnyx::PhoneNumbers::CsvDownloadCreateParams::Filter::Status } |
#tag ⇒ String?
Filter by phone number tags.
102 |
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 102 optional :tag, String |
#voice_connection_name ⇒ Telnyx::Models::PhoneNumbers::CsvDownloadCreateParams::Filter::VoiceConnectionName?
Filter by voice connection name pattern matching.
108 109 110 |
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 108 optional :voice_connection_name, -> { Telnyx::PhoneNumbers::CsvDownloadCreateParams::Filter::VoiceConnectionName }, api_name: :"voice.connection_name" |
#voice_usage_payment_method ⇒ Symbol, ...
Filter by usage_payment_method.
116 117 118 119 120 |
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 116 optional :voice_usage_payment_method, enum: -> { Telnyx::PhoneNumbers::CsvDownloadCreateParams::Filter::VoiceUsagePaymentMethod }, api_name: :"voice.usage_payment_method" |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_numbers/csv_download_create_params.rb', line 169
|