Class: Telnyx::Models::PhoneNumbers::MediaFeatures
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumbers::MediaFeatures
- Defined in:
- lib/telnyx/models/phone_numbers/media_features.rb
Instance Attribute Summary collapse
-
#accept_any_rtp_packets_enabled ⇒ Boolean?
When enabled, Telnyx will accept RTP packets from any customer-side IP address and port, not just those to which Telnyx is sending RTP.
-
#rtp_auto_adjust_enabled ⇒ Boolean?
When RTP Auto-Adjust is enabled, the destination RTP address port will be automatically changed to match the source of the incoming RTP packets.
-
#t38_fax_gateway_enabled ⇒ Boolean?
Controls whether Telnyx will accept a T.38 re-INVITE for this phone number.
Instance Method Summary collapse
-
#initialize(accept_any_rtp_packets_enabled: nil, rtp_auto_adjust_enabled: nil, t38_fax_gateway_enabled: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MediaFeatures for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(accept_any_rtp_packets_enabled: nil, rtp_auto_adjust_enabled: nil, t38_fax_gateway_enabled: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumbers::MediaFeatures for more details.
The media features settings for a phone number.
|
|
# File 'lib/telnyx/models/phone_numbers/media_features.rb', line 29
|
Instance Attribute Details
#accept_any_rtp_packets_enabled ⇒ Boolean?
When enabled, Telnyx will accept RTP packets from any customer-side IP address and port, not just those to which Telnyx is sending RTP.
12 |
# File 'lib/telnyx/models/phone_numbers/media_features.rb', line 12 optional :accept_any_rtp_packets_enabled, Telnyx::Internal::Type::Boolean |
#rtp_auto_adjust_enabled ⇒ Boolean?
When RTP Auto-Adjust is enabled, the destination RTP address port will be automatically changed to match the source of the incoming RTP packets.
19 |
# File 'lib/telnyx/models/phone_numbers/media_features.rb', line 19 optional :rtp_auto_adjust_enabled, Telnyx::Internal::Type::Boolean |
#t38_fax_gateway_enabled ⇒ Boolean?
Controls whether Telnyx will accept a T.38 re-INVITE for this phone number. Note that Telnyx will not send a T.38 re-INVITE; this option only controls whether one will be accepted.
27 |
# File 'lib/telnyx/models/phone_numbers/media_features.rb', line 27 optional :t38_fax_gateway_enabled, Telnyx::Internal::Type::Boolean |