Class: Telnyx::Models::PhoneNumbers::PhoneNumberWithVoiceSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PhoneNumbers::PhoneNumberWithVoiceSettings
- Defined in:
- lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb,
sig/telnyx/models/phone_numbers/phone_number_with_voice_settings.rbs
Defined Under Namespace
Modules: InboundCallScreening, UsagePaymentMethod Classes: Emergency
Instance Attribute Summary collapse
-
#call_forwarding ⇒ Telnyx::Models::PhoneNumbers::CallForwarding?
The call forwarding settings for a phone number.
-
#call_recording ⇒ Telnyx::Models::PhoneNumbers::CallRecording?
The call recording settings for a phone number.
-
#cnam_listing ⇒ Telnyx::Models::PhoneNumbers::CnamListing?
The CNAM listing settings for a phone number.
-
#connection_id ⇒ String?
Identifies the connection associated with this phone number.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#emergency ⇒ Telnyx::Models::PhoneNumbers::PhoneNumberWithVoiceSettings::Emergency?
The emergency services settings for a phone number.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls.
-
#media_features ⇒ Telnyx::Models::PhoneNumbers::MediaFeatures?
The media features settings for a phone number.
-
#phone_number ⇒ String?
readonly
Returns the value of attribute phone_number.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#tech_prefix_enabled ⇒ Boolean?
Controls whether a tech prefix is enabled for this phone number.
-
#translated_number ⇒ String?
This field allows you to rewrite the destination number of an inbound call before the call is routed to you.
-
#usage_payment_method ⇒ Symbol, ...
Controls whether a number is billed per minute or uses your concurrent channels.
Class Method Summary collapse
Instance Method Summary collapse
- #id ⇒ String readonly
-
#initialize(id: nil, call_forwarding: nil, call_recording: nil, cnam_listing: nil, connection_id: nil, customer_reference: nil, emergency: nil, inbound_call_screening: nil, media_features: nil, phone_number: nil, record_type: nil, tech_prefix_enabled: nil, translated_number: nil, usage_payment_method: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberWithVoiceSettings for more details.
- #phone_number ⇒ String readonly
- #record_type ⇒ String readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, call_forwarding: nil, call_recording: nil, cnam_listing: nil, connection_id: nil, customer_reference: nil, emergency: nil, inbound_call_screening: nil, media_features: nil, phone_number: nil, record_type: nil, tech_prefix_enabled: nil, translated_number: nil, usage_payment_method: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PhoneNumbers::PhoneNumberWithVoiceSettings for more details.
|
|
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 100
|
Instance Attribute Details
#call_forwarding ⇒ Telnyx::Models::PhoneNumbers::CallForwarding?
The call forwarding settings for a phone number.
11 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 11 optional :call_forwarding, -> { Telnyx::PhoneNumbers::CallForwarding } |
#call_recording ⇒ Telnyx::Models::PhoneNumbers::CallRecording?
The call recording settings for a phone number.
17 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 17 optional :call_recording, -> { Telnyx::PhoneNumbers::CallRecording } |
#cnam_listing ⇒ Telnyx::Models::PhoneNumbers::CnamListing?
The CNAM listing settings for a phone number.
23 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 23 optional :cnam_listing, -> { Telnyx::PhoneNumbers::CnamListing } |
#connection_id ⇒ String?
Identifies the connection associated with this phone number.
29 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 29 optional :connection_id, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
35 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 35 optional :customer_reference, String |
#emergency ⇒ Telnyx::Models::PhoneNumbers::PhoneNumberWithVoiceSettings::Emergency?
The emergency services settings for a phone number.
41 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 41 optional :emergency, -> { Telnyx::PhoneNumbers::PhoneNumberWithVoiceSettings::Emergency } |
#id ⇒ String? (readonly)
Returns the value of attribute id.
83 84 85 |
# File 'sig/telnyx/models/phone_numbers/phone_number_with_voice_settings.rbs', line 83 def id @id end |
#inbound_call_screening ⇒ Symbol, ...
The inbound_call_screening setting is a phone number configuration option variable that allows users to configure their settings to block or flag fraudulent calls. It can be set to disabled, reject_calls, or flag_calls. This feature has an additional per-number monthly cost associated with it.
50 51 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 50 optional :inbound_call_screening, enum: -> { Telnyx::PhoneNumbers::PhoneNumberWithVoiceSettings::InboundCallScreening } |
#media_features ⇒ Telnyx::Models::PhoneNumbers::MediaFeatures?
The media features settings for a phone number.
57 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 57 optional :media_features, -> { Telnyx::PhoneNumbers::MediaFeatures } |
#phone_number ⇒ String? (readonly)
Returns the value of attribute phone_number.
87 88 89 |
# File 'sig/telnyx/models/phone_numbers/phone_number_with_voice_settings.rbs', line 87 def phone_number @phone_number end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
91 92 93 |
# File 'sig/telnyx/models/phone_numbers/phone_number_with_voice_settings.rbs', line 91 def record_type @record_type end |
#tech_prefix_enabled ⇒ Boolean?
Controls whether a tech prefix is enabled for this phone number.
63 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 63 optional :tech_prefix_enabled, Telnyx::Internal::Type::Boolean |
#translated_number ⇒ String?
This field allows you to rewrite the destination number of an inbound call before the call is routed to you. The value of this field may be any alphanumeric value, and the value will replace the number originally dialed.
71 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 71 optional :translated_number, String |
#usage_payment_method ⇒ Symbol, ...
Controls whether a number is billed per minute or uses your concurrent channels.
77 78 |
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 77 optional :usage_payment_method, enum: -> { Telnyx::PhoneNumbers::PhoneNumberWithVoiceSettings::UsagePaymentMethod } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/phone_numbers/phone_number_with_voice_settings.rb', line 179
|
Instance Method Details
#id= ⇒ String (readonly)
85 |
# File 'sig/telnyx/models/phone_numbers/phone_number_with_voice_settings.rbs', line 85
def id=: (String) -> String
|
#phone_number= ⇒ String (readonly)
89 |
# File 'sig/telnyx/models/phone_numbers/phone_number_with_voice_settings.rbs', line 89
def phone_number=: (String) -> String
|
#record_type= ⇒ String (readonly)
93 |
# File 'sig/telnyx/models/phone_numbers/phone_number_with_voice_settings.rbs', line 93
def record_type=: (String) -> String
|
#to_hash ⇒ {
112 |
# File 'sig/telnyx/models/phone_numbers/phone_number_with_voice_settings.rbs', line 112
def to_hash: -> {
|