Class: Telnyx::Models::PortabilityCheckRunResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/portability_check_run_response.rb

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(fast_portable: nil, not_portable_reason: nil, phone_number: nil, portable: nil, record_type: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PortabilityCheckRunResponse::Data for more details.

Parameters:

  • fast_portable (Boolean) (defaults to: nil)

    Indicates whether this phone number is FastPort eligible

  • not_portable_reason (String) (defaults to: nil)

    If this phone number is not portable, explains why. Empty string if the number i

  • phone_number (String) (defaults to: nil)

    The +E.164 formatted phone number this result is about

  • portable (Boolean) (defaults to: nil)

    Indicates whether this phone number is portable

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/telnyx/models/portability_check_run_response.rb', line 15

class Data < Telnyx::Internal::Type::BaseModel
  response_only do
    # @!attribute fast_portable
    #   Indicates whether this phone number is FastPort eligible
    #
    #   @return [Boolean, nil]
    optional :fast_portable, Telnyx::Internal::Type::Boolean

    # @!attribute not_portable_reason
    #   If this phone number is not portable, explains why. Empty string if the number
    #   is portable.
    #
    #   @return [String, nil]
    optional :not_portable_reason, String

    # @!attribute phone_number
    #   The +E.164 formatted phone number this result is about
    #
    #   @return [String, nil]
    optional :phone_number, String

    # @!attribute portable
    #   Indicates whether this phone number is portable
    #
    #   @return [Boolean, nil]
    optional :portable, Telnyx::Internal::Type::Boolean

    # @!attribute record_type
    #   Identifies the type of the resource.
    #
    #   @return [String, nil]
    optional :record_type, String
  end

  # @!method initialize(fast_portable: nil, not_portable_reason: nil, phone_number: nil, portable: nil, record_type: nil)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::PortabilityCheckRunResponse::Data} for more details.
  #
  #   @param fast_portable [Boolean] Indicates whether this phone number is FastPort eligible
  #
  #   @param not_portable_reason [String] If this phone number is not portable, explains why. Empty string if the number i
  #
  #   @param phone_number [String] The +E.164 formatted phone number this result is about
  #
  #   @param portable [Boolean] Indicates whether this phone number is portable
  #
  #   @param record_type [String] Identifies the type of the resource.
end