Class: Telnyx::Models::Porting::EventListResponse::PortingEventDeletedPayload::Payload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Porting::EventListResponse::PortingEventDeletedPayload::Payload
- Defined in:
- lib/telnyx/models/porting/event_list_response.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
-
#customer_reference ⇒ String?
Identifies the customer reference associated with the porting order.
-
#deleted_at ⇒ Time?
ISO 8601 formatted date indicating when the porting order was deleted.
-
#id ⇒ String?
Identifies the porting order that was deleted.
-
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
117 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 117 optional :created_at, Time |
#customer_reference ⇒ String?
Identifies the customer reference associated with the porting order.
123 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 123 optional :customer_reference, String |
#deleted_at ⇒ Time?
ISO 8601 formatted date indicating when the porting order was deleted.
129 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 129 optional :deleted_at, Time |
#id ⇒ String?
Identifies the porting order that was deleted.
111 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 111 optional :id, String |
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
135 |
# File 'lib/telnyx/models/porting/event_list_response.rb', line 135 optional :updated_at, Time |