Class: Telnyx::Models::Porting::PortingEventMessagingChangedPayload::Payload::Messaging
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Porting::PortingEventMessagingChangedPayload::Payload::Messaging
- Defined in:
- lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb
Overview
Defined Under Namespace
Modules: MessagingPortStatus
Instance Attribute Summary collapse
-
#enable_messaging ⇒ Boolean?
Indicates whether Telnyx will port messaging capabilities from the losing carrier.
-
#messaging_capable ⇒ Boolean?
Indicates whether the porting order is messaging capable.
-
#messaging_port_completed ⇒ Boolean?
Indicates whether the messaging port is completed.
-
#messaging_port_status ⇒ Symbol, ...
Indicates the messaging port status of the porting order.
Instance Method Summary collapse
-
#initialize(enable_messaging: nil, messaging_capable: nil, messaging_port_completed: nil, messaging_port_status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Messaging for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(enable_messaging: nil, messaging_capable: nil, messaging_port_completed: nil, messaging_port_status: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Porting::PortingEventMessagingChangedPayload::Payload::Messaging for more details.
The messaging portability status of the porting order.
|
|
# File 'lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb', line 172
|
Instance Attribute Details
#enable_messaging ⇒ Boolean?
Indicates whether Telnyx will port messaging capabilities from the losing carrier. If false, any messaging capabilities will stay with their current provider.
151 |
# File 'lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb', line 151 optional :enable_messaging, Telnyx::Internal::Type::Boolean |
#messaging_capable ⇒ Boolean?
Indicates whether the porting order is messaging capable.
157 |
# File 'lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb', line 157 optional :messaging_capable, Telnyx::Internal::Type::Boolean |
#messaging_port_completed ⇒ Boolean?
Indicates whether the messaging port is completed.
163 |
# File 'lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb', line 163 optional :messaging_port_completed, Telnyx::Internal::Type::Boolean |
#messaging_port_status ⇒ Symbol, ...
Indicates the messaging port status of the porting order.
169 170 |
# File 'lib/telnyx/models/porting/porting_event_messaging_changed_payload.rb', line 169 optional :messaging_port_status, enum: -> { Telnyx::Porting::PortingEventMessagingChangedPayload::Payload::Messaging::MessagingPortStatus } |