Class: Telnyx::Models::Porting::PortingEventNewCommentEvent::Payload::Comment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Porting::PortingEventNewCommentEvent::Payload::Comment
- Defined in:
- lib/telnyx/models/porting/porting_event_new_comment_event.rb
Overview
Defined Under Namespace
Modules: UserType
Instance Attribute Summary collapse
-
#body ⇒ String?
The body of the comment.
-
#id ⇒ String?
Identifies the comment.
-
#inserted_at ⇒ Time?
ISO 8601 formatted date indicating when the comment was created.
-
#user_id ⇒ String?
Identifies the user that create the comment.
-
#user_type ⇒ Symbol, ...
Identifies the type of the user that created the comment.
Instance Method Summary collapse
-
#initialize(id: nil, body: nil, inserted_at: nil, user_id: nil, user_type: nil) ⇒ Object
constructor
The comment that was added to the porting order.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, body: nil, inserted_at: nil, user_id: nil, user_type: nil) ⇒ Object
The comment that was added to the porting order.
|
|
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 167
|
Instance Attribute Details
#body ⇒ String?
The body of the comment.
147 |
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 147 optional :body, String |
#id ⇒ String?
Identifies the comment.
141 |
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 141 optional :id, String |
#inserted_at ⇒ Time?
ISO 8601 formatted date indicating when the comment was created.
153 |
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 153 optional :inserted_at, Time |
#user_id ⇒ String?
Identifies the user that create the comment.
159 |
# File 'lib/telnyx/models/porting/porting_event_new_comment_event.rb', line 159 optional :user_id, String |