Class: Telnyx::Models::Porting::PortingReport
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Porting::PortingReport
- Defined in:
- lib/telnyx/models/porting/porting_report.rb
Overview
Defined Under Namespace
Modules: ReportType, Status
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
-
#document_id ⇒ String?
Identifies the document that was uploaded when report was generated.
-
#id ⇒ String?
Uniquely identifies the report.
-
#params ⇒ Telnyx::Models::Porting::ExportPortingOrdersCsvReport?
The parameters for generating a porting orders CSV report.
-
#report_type ⇒ Symbol, ...
Identifies the type of report.
-
#status ⇒ Symbol, ...
The current status of the report generation.
-
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, created_at: nil, document_id: nil, params: nil, record_type: nil, report_type: nil, status: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PortingReport for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, document_id: nil, params: nil, record_type: nil, report_type: nil, status: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Porting::PortingReport for more details.
|
|
# File 'lib/telnyx/models/porting/porting_report.rb', line 59
|
Instance Attribute Details
#created_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was created.
18 |
# File 'lib/telnyx/models/porting/porting_report.rb', line 18 optional :created_at, Time |
#document_id ⇒ String?
Identifies the document that was uploaded when report was generated. This field is only populated when the report is under completed status.
25 |
# File 'lib/telnyx/models/porting/porting_report.rb', line 25 optional :document_id, String |
#id ⇒ String?
Uniquely identifies the report.
12 |
# File 'lib/telnyx/models/porting/porting_report.rb', line 12 optional :id, String |
#params ⇒ Telnyx::Models::Porting::ExportPortingOrdersCsvReport?
The parameters for generating a porting orders CSV report.
31 |
# File 'lib/telnyx/models/porting/porting_report.rb', line 31 optional :params, -> { Telnyx::Porting::ExportPortingOrdersCsvReport } |
#report_type ⇒ Symbol, ...
Identifies the type of report
37 |
# File 'lib/telnyx/models/porting/porting_report.rb', line 37 optional :report_type, enum: -> { Telnyx::Porting::PortingReport::ReportType } |
#status ⇒ Symbol, ...
The current status of the report generation.
43 |
# File 'lib/telnyx/models/porting/porting_report.rb', line 43 optional :status, enum: -> { Telnyx::Porting::PortingReport::Status } |
#updated_at ⇒ Time?
ISO 8601 formatted date indicating when the resource was updated.
49 |
# File 'lib/telnyx/models/porting/porting_report.rb', line 49 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/porting/porting_report.rb', line 87
|