Class: Telnyx::Models::PortingOrderEndUserAdmin
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrderEndUserAdmin
- Defined in:
- lib/telnyx/models/porting_order_end_user_admin.rb
Instance Attribute Summary collapse
-
#account_number ⇒ String?
The authorized person’s account number with the current service provider.
-
#auth_person_name ⇒ String?
Name of person authorizing the porting order.
-
#billing_phone_number ⇒ String?
Billing phone number associated with these phone numbers.
-
#business_identifier ⇒ String?
European business identification number.
-
#entity_name ⇒ String?
Person Name or Company name requesting the port.
-
#pin_passcode ⇒ String?
PIN/passcode possibly required by the old service provider for extra verification.
-
#tax_identifier ⇒ String?
European tax identification number.
Instance Method Summary collapse
-
#initialize(account_number: nil, auth_person_name: nil, billing_phone_number: nil, business_identifier: nil, entity_name: nil, pin_passcode: nil, tax_identifier: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PortingOrderEndUserAdmin for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_number: nil, auth_person_name: nil, billing_phone_number: nil, business_identifier: nil, entity_name: nil, pin_passcode: nil, tax_identifier: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PortingOrderEndUserAdmin for more details.
|
|
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 49
|
Instance Attribute Details
#account_number ⇒ String?
The authorized person’s account number with the current service provider
10 |
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 10 optional :account_number, String, nil?: true |
#auth_person_name ⇒ String?
Name of person authorizing the porting order
16 |
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 16 optional :auth_person_name, String, nil?: true |
#billing_phone_number ⇒ String?
Billing phone number associated with these phone numbers
22 |
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 22 optional :billing_phone_number, String, nil?: true |
#business_identifier ⇒ String?
European business identification number. Applicable only in the European Union
28 |
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 28 optional :business_identifier, String, nil?: true |
#entity_name ⇒ String?
Person Name or Company name requesting the port
34 |
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 34 optional :entity_name, String, nil?: true |
#pin_passcode ⇒ String?
PIN/passcode possibly required by the old service provider for extra verification
41 |
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 41 optional :pin_passcode, String, nil?: true |
#tax_identifier ⇒ String?
European tax identification number. Applicable only in the European Union
47 |
# File 'lib/telnyx/models/porting_order_end_user_admin.rb', line 47 optional :tax_identifier, String, nil?: true |