Class: Telnyx::Models::PortingOrderMisc
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrderMisc
- Defined in:
- lib/telnyx/models/porting_order_misc.rb
Defined Under Namespace
Modules: RemainingNumbersAction
Instance Attribute Summary collapse
-
#new_billing_phone_number ⇒ String?
New billing phone number for the remaining numbers.
-
#remaining_numbers_action ⇒ Symbol, ...
Remaining numbers can be either kept with their current service provider or disconnected.
-
#type ⇒ Symbol, ...
A port can be either ‘full’ or ‘partial’.
Instance Method Summary collapse
-
#initialize(new_billing_phone_number: nil, remaining_numbers_action: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PortingOrderMisc for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(new_billing_phone_number: nil, remaining_numbers_action: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PortingOrderMisc for more details.
|
|
# File 'lib/telnyx/models/porting_order_misc.rb', line 32
|
Instance Attribute Details
#new_billing_phone_number ⇒ String?
New billing phone number for the remaining numbers. Used in case the current billing phone number is being ported to Telnyx. This will be set on your account with your current service provider and should be one of the numbers remaining on that account.
13 |
# File 'lib/telnyx/models/porting_order_misc.rb', line 13 optional :new_billing_phone_number, String, nil?: true |
#remaining_numbers_action ⇒ Symbol, ...
Remaining numbers can be either kept with their current service provider or disconnected. ‘new_billing_telephone_number’ is required when ‘remaining_numbers_action’ is ‘keep’.
21 22 23 |
# File 'lib/telnyx/models/porting_order_misc.rb', line 21 optional :remaining_numbers_action, enum: -> { Telnyx::PortingOrderMisc::RemainingNumbersAction }, nil?: true |
#type ⇒ Symbol, ...
A port can be either ‘full’ or ‘partial’. When type is ‘full’ the other attributes should be omitted.
30 |
# File 'lib/telnyx/models/porting_order_misc.rb', line 30 optional :type, enum: -> { Telnyx::PortingOrderType } |