Class: Telnyx::Models::PortingOrderRetrieveSubRequestResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrderRetrieveSubRequestResponse::Data
- Defined in:
- lib/telnyx/models/porting_order_retrieve_sub_request_response.rb
Overview
Instance Attribute Summary collapse
-
#port_request_id ⇒ String?
Identifies the Port Request associated with the Porting Order.
-
#sub_request_id ⇒ String?
Identifies the Sub Request associated with the Porting Order.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(port_request_id: nil, sub_request_id: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/porting_order_retrieve_sub_request_response.rb', line 29
|
Instance Attribute Details
#port_request_id ⇒ String?
Identifies the Port Request associated with the Porting Order
21 |
# File 'lib/telnyx/models/porting_order_retrieve_sub_request_response.rb', line 21 optional :port_request_id, String |
#sub_request_id ⇒ String?
Identifies the Sub Request associated with the Porting Order
27 |
# File 'lib/telnyx/models/porting_order_retrieve_sub_request_response.rb', line 27 optional :sub_request_id, String |