Class: Telnyx::Models::PortingOrderUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/porting_order_update_params.rb

Overview

Defined Under Namespace

Classes: ActivationSettings, Messaging, Requirement

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enable_messaging: nil) ⇒ Object

Some parameter documentations has been truncated, see Messaging for more details.

Parameters:

  • enable_messaging (Boolean) (defaults to: nil)

    Indicates whether Telnyx will port messaging capabilities from the losing carrie



# File 'lib/telnyx/models/porting_order_update_params.rb', line 122

Instance Attribute Details

#activation_settingsTelnyx::Models::PortingOrderUpdateParams::ActivationSettings?



18
# File 'lib/telnyx/models/porting_order_update_params.rb', line 18

optional :activation_settings, -> { Telnyx::PortingOrderUpdateParams::ActivationSettings }

#customer_group_referenceString?

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/porting_order_update_params.rb', line 23

optional :customer_group_reference, String

#customer_referenceString?

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/porting_order_update_params.rb', line 28

optional :customer_reference, String

#documentsTelnyx::Models::PortingOrderDocuments?

Can be specified directly or via the ‘requirement_group_id` parameter.



34
# File 'lib/telnyx/models/porting_order_update_params.rb', line 34

optional :documents, -> { Telnyx::PortingOrderDocuments }

#end_userTelnyx::Models::PortingOrderEndUser?



39
# File 'lib/telnyx/models/porting_order_update_params.rb', line 39

optional :end_user, -> { Telnyx::PortingOrderEndUser }

#idString

Returns:

  • (String)


13
# File 'lib/telnyx/models/porting_order_update_params.rb', line 13

required :id, String

#messagingTelnyx::Models::PortingOrderUpdateParams::Messaging?



44
# File 'lib/telnyx/models/porting_order_update_params.rb', line 44

optional :messaging, -> { Telnyx::PortingOrderUpdateParams::Messaging }

#miscTelnyx::Models::PortingOrderMisc?



49
# File 'lib/telnyx/models/porting_order_update_params.rb', line 49

optional :misc, -> { Telnyx::PortingOrderMisc }, nil?: true

#phone_number_configurationTelnyx::Models::PortingOrderPhoneNumberConfiguration?



54
# File 'lib/telnyx/models/porting_order_update_params.rb', line 54

optional :phone_number_configuration, -> { Telnyx::PortingOrderPhoneNumberConfiguration }

#requirement_group_idString?

If present, we will read the current values from the specified Requirement Group into the Documents and Requirements for this Porting Order. Note that any future changes in the Requirement Group would have no impact on this Porting Order. We will return an error if a specified Requirement Group conflicts with documents or requirements in the same request.

Returns:

  • (String, nil)


64
# File 'lib/telnyx/models/porting_order_update_params.rb', line 64

optional :requirement_group_id, String

#requirementsArray<Telnyx::Models::PortingOrderUpdateParams::Requirement>?

List of requirements for porting numbers.



70
71
# File 'lib/telnyx/models/porting_order_update_params.rb', line 70

optional :requirements,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::PortingOrderUpdateParams::Requirement] }

#user_feedbackTelnyx::Models::PortingOrderUserFeedback?



76
# File 'lib/telnyx/models/porting_order_update_params.rb', line 76

optional :user_feedback, -> { Telnyx::PortingOrderUserFeedback }

#webhook_urlString?

Returns:

  • (String, nil)


81
# File 'lib/telnyx/models/porting_order_update_params.rb', line 81

optional :webhook_url, String