Class: Telnyx::Models::PortingOrderUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrderUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/porting_order_update_params.rb
Overview
Defined Under Namespace
Classes: ActivationSettings, Messaging, Requirement
Instance Attribute Summary collapse
- #activation_settings ⇒ Telnyx::Models::PortingOrderUpdateParams::ActivationSettings?
- #customer_group_reference ⇒ String?
- #customer_reference ⇒ String?
-
#documents ⇒ Telnyx::Models::PortingOrderDocuments?
Can be specified directly or via the ‘requirement_group_id` parameter.
- #end_user ⇒ Telnyx::Models::PortingOrderEndUser?
- #messaging ⇒ Telnyx::Models::PortingOrderUpdateParams::Messaging?
- #misc ⇒ Telnyx::Models::PortingOrderMisc?
- #phone_number_configuration ⇒ Telnyx::Models::PortingOrderPhoneNumberConfiguration?
-
#requirement_group_id ⇒ String?
If present, we will read the current values from the specified Requirement Group into the Documents and Requirements for this Porting Order.
-
#requirements ⇒ Array<Telnyx::Models::PortingOrderUpdateParams::Requirement>?
List of requirements for porting numbers.
- #user_feedback ⇒ Telnyx::Models::PortingOrderUserFeedback?
- #webhook_url ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(enable_messaging: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Messaging for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(enable_messaging: nil) ⇒ Object
Some parameter documentations has been truncated, see Messaging for more details.
|
|
# File 'lib/telnyx/models/porting_order_update_params.rb', line 115
|
Instance Attribute Details
#activation_settings ⇒ Telnyx::Models::PortingOrderUpdateParams::ActivationSettings?
13 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 13 optional :activation_settings, -> { Telnyx::PortingOrderUpdateParams::ActivationSettings } |
#customer_group_reference ⇒ String?
18 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 18 optional :customer_group_reference, String |
#customer_reference ⇒ String?
23 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 23 optional :customer_reference, String |
#documents ⇒ Telnyx::Models::PortingOrderDocuments?
Can be specified directly or via the ‘requirement_group_id` parameter.
29 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 29 optional :documents, -> { Telnyx::PortingOrderDocuments } |
#end_user ⇒ Telnyx::Models::PortingOrderEndUser?
34 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 34 optional :end_user, -> { Telnyx::PortingOrderEndUser } |
#messaging ⇒ Telnyx::Models::PortingOrderUpdateParams::Messaging?
39 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 39 optional :messaging, -> { Telnyx::PortingOrderUpdateParams::Messaging } |
#misc ⇒ Telnyx::Models::PortingOrderMisc?
44 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 44 optional :misc, -> { Telnyx::PortingOrderMisc }, nil?: true |
#phone_number_configuration ⇒ Telnyx::Models::PortingOrderPhoneNumberConfiguration?
49 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 49 optional :phone_number_configuration, -> { Telnyx::PortingOrderPhoneNumberConfiguration } |
#requirement_group_id ⇒ String?
If present, we will read the current values from the specified Requirement Group into the Documents and Requirements for this Porting Order. Note that any future changes in the Requirement Group would have no impact on this Porting Order. We will return an error if a specified Requirement Group conflicts with documents or requirements in the same request.
59 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 59 optional :requirement_group_id, String |
#requirements ⇒ Array<Telnyx::Models::PortingOrderUpdateParams::Requirement>?
List of requirements for porting numbers.
65 66 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 65 optional :requirements, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PortingOrderUpdateParams::Requirement] } |
#user_feedback ⇒ Telnyx::Models::PortingOrderUserFeedback?
71 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 71 optional :user_feedback, -> { Telnyx::PortingOrderUserFeedback } |
#webhook_url ⇒ String?
76 |
# File 'lib/telnyx/models/porting_order_update_params.rb', line 76 optional :webhook_url, String |