Class: Telnyx::Models::PortingOrderUserFeedback
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrderUserFeedback
- Defined in:
- lib/telnyx/models/porting_order_user_feedback.rb
Instance Attribute Summary collapse
-
#user_comment ⇒ String?
A comment related to the customer rating.
-
#user_rating ⇒ Integer?
Once an order is ported, cancellation is requested or the request is cancelled, the user may rate their experience.
Instance Method Summary collapse
-
#initialize(user_comment: nil, user_rating: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PortingOrderUserFeedback for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(user_comment: nil, user_rating: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PortingOrderUserFeedback for more details.
|
|
# File 'lib/telnyx/models/porting_order_user_feedback.rb', line 19
|
Instance Attribute Details
#user_comment ⇒ String?
A comment related to the customer rating.
10 |
# File 'lib/telnyx/models/porting_order_user_feedback.rb', line 10 optional :user_comment, String, nil?: true |
#user_rating ⇒ Integer?
Once an order is ported, cancellation is requested or the request is cancelled, the user may rate their experience
17 |
# File 'lib/telnyx/models/porting_order_user_feedback.rb', line 17 optional :user_rating, Integer, nil?: true |