Class: Telnyx::Models::PortingOrders::ActionRequirementInitiateParams::Params
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::ActionRequirementInitiateParams::Params
- Defined in:
- lib/telnyx/models/porting_orders/action_requirement_initiate_params.rb
Instance Attribute Summary collapse
-
#first_name ⇒ String
The first name of the person that will perform the verification flow.
-
#last_name ⇒ String
The last name of the person that will perform the verification flow.
Instance Method Summary collapse
-
#initialize(first_name:, last_name:) ⇒ Object
constructor
Required information for initiating the action requirement for AU ID verification.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(first_name:, last_name:) ⇒ Object
Required information for initiating the action requirement for AU ID verification.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_params.rb', line 41 class Params < Telnyx::Internal::Type::BaseModel # @!attribute first_name # The first name of the person that will perform the verification flow. # # @return [String] required :first_name, String # @!attribute last_name # The last name of the person that will perform the verification flow. # # @return [String] required :last_name, String # @!method initialize(first_name:, last_name:) # Required information for initiating the action requirement for AU ID # verification. # # @param first_name [String] The first name of the person that will perform the verification flow. # # @param last_name [String] The last name of the person that will perform the verification flow. end |
Instance Attribute Details
#first_name ⇒ String
The first name of the person that will perform the verification flow.
46 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_params.rb', line 46 required :first_name, String |
#last_name ⇒ String
The last name of the person that will perform the verification flow.
52 |
# File 'lib/telnyx/models/porting_orders/action_requirement_initiate_params.rb', line 52 required :last_name, String |