Class: Telnyx::Models::PortingOrders::ActionRequirementListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::ActionRequirementListResponse
- Defined in:
- lib/telnyx/models/porting_orders/action_requirement_list_response.rb
Overview
Defined Under Namespace
Modules: RecordType, Status
Instance Attribute Summary collapse
-
#action_type ⇒ String?
The type of action required.
-
#action_url ⇒ String?
Optional URL for the action.
-
#cancel_reason ⇒ String?
Reason for cancellation if status is ‘cancelled’.
-
#created_at ⇒ Time?
ISO 8601 formatted date-time indicating when the resource was created.
-
#id ⇒ String?
Identifies the action requirement.
-
#porting_order_id ⇒ String?
The ID of the porting order this action requirement belongs to.
-
#record_type ⇒ Symbol, ...
Identifies the type of the resource.
-
#requirement_type_id ⇒ String?
The ID of the requirement type.
-
#status ⇒ Symbol, ...
Current status of the action requirement.
-
#updated_at ⇒ Time?
ISO 8601 formatted date-time indicating when the resource was updated.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, action_type: nil, action_url: nil, cancel_reason: nil, created_at: nil, porting_order_id: nil, record_type: nil, requirement_type_id: nil, status: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 69
|
Instance Attribute Details
#action_type ⇒ String?
The type of action required
18 |
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 18 optional :action_type, String |
#action_url ⇒ String?
Optional URL for the action
24 |
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 24 optional :action_url, String, nil?: true |
#cancel_reason ⇒ String?
Reason for cancellation if status is ‘cancelled’
30 |
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 30 optional :cancel_reason, String, nil?: true |
#created_at ⇒ Time?
ISO 8601 formatted date-time indicating when the resource was created
36 |
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 36 optional :created_at, Time |
#id ⇒ String?
Identifies the action requirement
12 |
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 12 optional :id, String |
#porting_order_id ⇒ String?
The ID of the porting order this action requirement belongs to
42 |
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 42 optional :porting_order_id, String |
#record_type ⇒ Symbol, ...
Identifies the type of the resource
48 49 |
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 48 optional :record_type, enum: -> { Telnyx::Models::PortingOrders::ActionRequirementListResponse::RecordType } |
#requirement_type_id ⇒ String?
The ID of the requirement type
55 |
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 55 optional :requirement_type_id, String |
#status ⇒ Symbol, ...
Current status of the action requirement
61 |
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 61 optional :status, enum: -> { Telnyx::Models::PortingOrders::ActionRequirementListResponse::Status } |
#updated_at ⇒ Time?
ISO 8601 formatted date-time indicating when the resource was updated
67 |
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 67 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/porting_orders/action_requirement_list_response.rb', line 98
|