Class: Telnyx::Models::PortingOrders::ActionShareResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders/action_share_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Permission

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#created_atTime?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (Time, nil)


34
# File 'lib/telnyx/models/porting_orders/action_share_response.rb', line 34

optional :created_at, Time

#expires_atTime?

ISO 8601 formatted date indicating when the sharing token expires.

Returns:

  • (Time, nil)


40
# File 'lib/telnyx/models/porting_orders/action_share_response.rb', line 40

optional :expires_at, Time

#expires_in_secondsInteger?

The number of seconds until the sharing token expires

Returns:

  • (Integer, nil)


46
# File 'lib/telnyx/models/porting_orders/action_share_response.rb', line 46

optional :expires_in_seconds, Integer

#idString?

Uniquely identifies this sharing token

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/porting_orders/action_share_response.rb', line 22

optional :id, String

#permissionsArray<Symbol, Telnyx::Models::PortingOrders::ActionShareResponse::Data::Permission>?

The permissions granted to the sharing token



52
53
# File 'lib/telnyx/models/porting_orders/action_share_response.rb', line 52

optional :permissions,
-> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::PortingOrders::ActionShareResponse::Data::Permission] }

#porting_order_idString?

Identifies the porting order resource being shared

Returns:

  • (String, nil)


59
# File 'lib/telnyx/models/porting_orders/action_share_response.rb', line 59

optional :porting_order_id, String

#tokenString?

A signed JWT token that can be used to access the shared resource

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/porting_orders/action_share_response.rb', line 28

optional :token, String