Class: Telnyx::Models::PortingOrders::PhoneNumberBlockCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::PhoneNumberBlockCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/porting_orders/phone_number_block_create_params.rb
Overview
Defined Under Namespace
Classes: ActivationRange, PhoneNumberRange
Instance Attribute Summary collapse
-
#activation_ranges ⇒ Array<Telnyx::Models::PortingOrders::PhoneNumberBlockCreateParams::ActivationRange>
Specifies the activation ranges for this porting phone number block.
- #phone_number_range ⇒ Telnyx::Models::PortingOrders::PhoneNumberBlockCreateParams::PhoneNumberRange
- #porting_order_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(end_at:, start_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActivationRange for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_at:, start_at:) ⇒ Object
Some parameter documentations has been truncated, see ActivationRange for more details.
|
|
# File 'lib/telnyx/models/porting_orders/phone_number_block_create_params.rb', line 57
|
Instance Attribute Details
#activation_ranges ⇒ Array<Telnyx::Models::PortingOrders::PhoneNumberBlockCreateParams::ActivationRange>
Specifies the activation ranges for this porting phone number block. The activation range must be within the block range and should not overlap with other activation ranges.
22 23 |
# File 'lib/telnyx/models/porting_orders/phone_number_block_create_params.rb', line 22 required :activation_ranges, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PortingOrders::PhoneNumberBlockCreateParams::ActivationRange] } |
#phone_number_range ⇒ Telnyx::Models::PortingOrders::PhoneNumberBlockCreateParams::PhoneNumberRange
28 |
# File 'lib/telnyx/models/porting_orders/phone_number_block_create_params.rb', line 28 required :phone_number_range, -> { Telnyx::PortingOrders::PhoneNumberBlockCreateParams::PhoneNumberRange } |
#porting_order_id ⇒ String
14 |
# File 'lib/telnyx/models/porting_orders/phone_number_block_create_params.rb', line 14 required :porting_order_id, String |