Class: Telnyx::Models::PortingOrders::PortingAssociatedPhoneNumber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::PortingAssociatedPhoneNumber
- Defined in:
- lib/telnyx/models/porting_orders/porting_associated_phone_number.rb
Overview
Defined Under Namespace
Modules: Action, PhoneNumberType Classes: PhoneNumberRange
Instance Attribute Summary collapse
-
#action ⇒ Symbol, ...
Specifies the action to take with this phone number during partial porting.
-
#country_code ⇒ String?
Specifies the country code for this associated phone number.
-
#phone_number_range ⇒ Telnyx::Models::PortingOrders::PortingAssociatedPhoneNumber::PhoneNumberRange?
Specifies the phone number range for this associated phone number.
-
#phone_number_type ⇒ Symbol, ...
Specifies the phone number type for this associated phone number.
-
#porting_order_id ⇒ String?
Identifies the porting order associated with this phone number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(end_at: nil, start_at: nil) ⇒ Object
constructor
Specifies the phone number range for this associated phone number.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_at: nil, start_at: nil) ⇒ Object
Specifies the phone number range for this associated phone number.
|
|
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 66
|
Instance Attribute Details
#action ⇒ Symbol, ...
Specifies the action to take with this phone number during partial porting.
12 |
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 12 optional :action, enum: -> { Telnyx::PortingOrders::PortingAssociatedPhoneNumber::Action } |
#country_code ⇒ String?
Specifies the country code for this associated phone number. It is a two-letter ISO 3166-1 alpha-2 country code.
19 |
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 19 optional :country_code, String |
#phone_number_range ⇒ Telnyx::Models::PortingOrders::PortingAssociatedPhoneNumber::PhoneNumberRange?
Specifies the phone number range for this associated phone number.
25 |
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 25 optional :phone_number_range, -> { Telnyx::PortingOrders::PortingAssociatedPhoneNumber::PhoneNumberRange } |
#phone_number_type ⇒ Symbol, ...
Specifies the phone number type for this associated phone number.
31 32 |
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 31 optional :phone_number_type, enum: -> { Telnyx::PortingOrders::PortingAssociatedPhoneNumber::PhoneNumberType } |
#porting_order_id ⇒ String?
Identifies the porting order associated with this phone number.
38 |
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 38 optional :porting_order_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 97
|