Class: Telnyx::Models::PortingOrders::PortingAssociatedPhoneNumber::PhoneNumberRange
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::PortingAssociatedPhoneNumber::PhoneNumberRange
- Defined in:
- lib/telnyx/models/porting_orders/porting_associated_phone_number.rb,
sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs
Overview
Instance Attribute Summary collapse
-
#end_at ⇒ String?
Specifies the end of the phone number range for this associated phone number.
-
#start_at ⇒ String?
Specifies the start of the phone number range for this associated phone number.
Instance Method Summary collapse
-
#initialize ⇒ PhoneNumberRange
constructor
A new instance of PhoneNumberRange.
- #to_hash ⇒ { end_at: String, start_at: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ PhoneNumberRange
Returns a new instance of PhoneNumberRange.
106 |
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 106
def initialize: (?end_at: String, ?start_at: String) -> void
|
Instance Attribute Details
#end_at ⇒ String?
Specifies the end of the phone number range for this associated phone number.
107 |
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 107 optional :end_at, String |
#start_at ⇒ String?
Specifies the start of the phone number range for this associated phone number.
113 |
# File 'lib/telnyx/models/porting_orders/porting_associated_phone_number.rb', line 113 optional :start_at, String |
Instance Method Details
#to_hash ⇒ { end_at: String, start_at: String }
108 |
# File 'sig/telnyx/models/porting_orders/porting_associated_phone_number.rbs', line 108
def to_hash: -> { end_at: String, start_at: String }
|