Class: Telnyx::Models::PortingOrders::PortingPhoneNumberBlock
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::PortingPhoneNumberBlock
- Defined in:
- lib/telnyx/models/porting_orders/porting_phone_number_block.rb
Overview
Defined Under Namespace
Modules: PhoneNumberType Classes: ActivationRange, PhoneNumberRange
Instance Attribute Summary collapse
-
#activation_ranges ⇒ Array<Telnyx::Models::PortingOrders::PortingPhoneNumberBlock::ActivationRange>?
Specifies the activation ranges for this porting phone number block.
-
#country_code ⇒ String?
Specifies the country code for this porting phone number block.
-
#phone_number_range ⇒ Telnyx::Models::PortingOrders::PortingPhoneNumberBlock::PhoneNumberRange?
Specifies the phone number range for this porting phone number block.
-
#phone_number_type ⇒ Symbol, ...
Specifies the phone number type for this porting phone number block.
Instance Method Summary collapse
-
#initialize(end_at: nil, start_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberRange for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_at: nil, start_at: nil) ⇒ Object
Some parameter documentations has been truncated, see PhoneNumberRange for more details.
Specifies the phone number range for this porting phone number block.
|
|
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 97
|
Instance Attribute Details
#activation_ranges ⇒ Array<Telnyx::Models::PortingOrders::PortingPhoneNumberBlock::ActivationRange>?
Specifies the activation ranges for this porting phone number block. The activation range must be within the phone number range and should not overlap with other activation ranges.
14 15 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 14 optional :activation_ranges, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PortingOrders::PortingPhoneNumberBlock::ActivationRange] } |
#country_code ⇒ String?
Specifies the country code for this porting phone number block. It is a two-letter ISO 3166-1 alpha-2 country code.
22 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 22 optional :country_code, String |
#phone_number_range ⇒ Telnyx::Models::PortingOrders::PortingPhoneNumberBlock::PhoneNumberRange?
Specifies the phone number range for this porting phone number block.
28 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 28 optional :phone_number_range, -> { Telnyx::PortingOrders::PortingPhoneNumberBlock::PhoneNumberRange } |
#phone_number_type ⇒ Symbol, ...
Specifies the phone number type for this porting phone number block.
34 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 34 optional :phone_number_type, enum: -> { Telnyx::PortingOrders::PortingPhoneNumberBlock::PhoneNumberType } |