Class: Telnyx::Models::PortingOrders::PortingPhoneNumberBlock::ActivationRange
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::PortingPhoneNumberBlock::ActivationRange
- Defined in:
- lib/telnyx/models/porting_orders/porting_phone_number_block.rb
Instance Attribute Summary collapse
-
#end_at ⇒ String?
Specifies the end of the activation range.
-
#start_at ⇒ String?
Specifies the start of the activation range.
Instance Method Summary collapse
-
#initialize(id: nil, activation_ranges: nil, country_code: nil, created_at: nil, phone_number_range: nil, phone_number_type: nil, record_type: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Telnyx::Models::PortingOrders::PortingPhoneNumberBlock for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, activation_ranges: nil, country_code: nil, created_at: nil, phone_number_range: nil, phone_number_type: nil, record_type: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PortingOrders::PortingPhoneNumberBlock for more details.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 82 class ActivationRange < Telnyx::Internal::Type::BaseModel # @!attribute end_at # Specifies the end of the activation range. It must be no more than the end of # the phone number range. # # @return [String, nil] optional :end_at, String # @!attribute start_at # Specifies the start of the activation range. Must be greater or equal the start # of the phone number range. # # @return [String, nil] optional :start_at, String # @!method initialize(end_at: nil, start_at: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::PortingOrders::PortingPhoneNumberBlock::ActivationRange} for # more details. # # @param end_at [String] Specifies the end of the activation range. It must be no more than the end of th # # @param start_at [String] Specifies the start of the activation range. Must be greater or equal the start end |
Instance Attribute Details
#end_at ⇒ String?
Specifies the end of the activation range. It must be no more than the end of the phone number range.
88 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 88 optional :end_at, String |
#start_at ⇒ String?
Specifies the start of the activation range. Must be greater or equal the start of the phone number range.
95 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_block.rb', line 95 optional :start_at, String |