Class: Telnyx::Models::PortingOrders::PortingPhoneNumberExtension

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/porting_orders/porting_phone_number_extension.rb

Overview

Defined Under Namespace

Classes: ActivationRange, ExtensionRange

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_at: nil, start_at: nil) ⇒ Object

Some parameter documentations has been truncated, see ActivationRange for more details.

Parameters:

  • end_at (Integer) (defaults to: nil)

    Specifies the end of the activation range. It must be no more than the end of th

  • start_at (Integer) (defaults to: nil)

    Specifies the start of the activation range. Must be greater or equal the start



# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 89

Instance Attribute Details

#activation_rangesArray<Telnyx::Models::PortingOrders::PortingPhoneNumberExtension::ActivationRange>?

Specifies the activation ranges for this porting phone number extension. The activation range must be within the extension range and should not overlap with other activation ranges.



14
15
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 14

optional :activation_ranges,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::PortingOrders::PortingPhoneNumberExtension::ActivationRange] }

#extension_rangeTelnyx::Models::PortingOrders::PortingPhoneNumberExtension::ExtensionRange?

Specifies the extension range for this porting phone number extension.



21
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 21

optional :extension_range, -> { Telnyx::PortingOrders::PortingPhoneNumberExtension::ExtensionRange }

#porting_phone_number_idString?

Identifies the porting phone number associated with this porting phone number extension.

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 28

optional :porting_phone_number_id, String