Class: Telnyx::Models::PortingOrders::PortingPhoneNumberExtension::ActivationRange
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrders::PortingPhoneNumberExtension::ActivationRange
- Defined in:
- lib/telnyx/models/porting_orders/porting_phone_number_extension.rb
Instance Attribute Summary collapse
-
#end_at ⇒ Integer?
Specifies the end of the activation range.
-
#start_at ⇒ Integer?
Specifies the start of the activation range.
Instance Method Summary collapse
-
#initialize(id: nil, activation_ranges: nil, created_at: nil, extension_range: nil, porting_phone_number_id: nil, record_type: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Telnyx::Models::PortingOrders::PortingPhoneNumberExtension for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, activation_ranges: nil, created_at: nil, extension_range: nil, porting_phone_number_id: nil, record_type: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PortingOrders::PortingPhoneNumberExtension for more details.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 74 class ActivationRange < Telnyx::Internal::Type::BaseModel # @!attribute end_at # Specifies the end of the activation range. It must be no more than the end of # the extension range. # # @return [Integer, nil] optional :end_at, Integer # @!attribute start_at # Specifies the start of the activation range. Must be greater or equal the start # of the extension range. # # @return [Integer, nil] optional :start_at, Integer # @!method initialize(end_at: nil, start_at: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::PortingOrders::PortingPhoneNumberExtension::ActivationRange} # for more details. # # @param end_at [Integer] Specifies the end of the activation range. It must be no more than the end of th # # @param start_at [Integer] Specifies the start of the activation range. Must be greater or equal the start end |
Instance Attribute Details
#end_at ⇒ Integer?
Specifies the end of the activation range. It must be no more than the end of the extension range.
80 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 80 optional :end_at, Integer |
#start_at ⇒ Integer?
Specifies the start of the activation range. Must be greater or equal the start of the extension range.
87 |
# File 'lib/telnyx/models/porting_orders/porting_phone_number_extension.rb', line 87 optional :start_at, Integer |