Class: Telnyx::Models::PortingOrdersActivationJob
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortingOrdersActivationJob
- Defined in:
- lib/telnyx/models/porting_orders_activation_job.rb
Defined Under Namespace
Modules: ActivationType, Status Classes: ActivationWindow
Instance Attribute Summary collapse
-
#activate_at ⇒ Time?
ISO 8601 formatted date indicating when the activation job should be executed.
-
#activation_type ⇒ Symbol, ...
Specifies the type of this activation job.
-
#activation_windows ⇒ Array<Telnyx::Models::PortingOrdersActivationJob::ActivationWindow>?
List of allowed activation windows for this activation job.
-
#status ⇒ Symbol, ...
Specifies the status of this activation job.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(end_at: nil, start_at: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_at: nil, start_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 58
|
Instance Attribute Details
#activate_at ⇒ Time?
ISO 8601 formatted date indicating when the activation job should be executed. This time should be between some activation window.
11 |
# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 11 optional :activate_at, Time |
#activation_type ⇒ Symbol, ...
Specifies the type of this activation job
17 |
# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 17 optional :activation_type, enum: -> { Telnyx::PortingOrdersActivationJob::ActivationType } |
#activation_windows ⇒ Array<Telnyx::Models::PortingOrdersActivationJob::ActivationWindow>?
List of allowed activation windows for this activation job
23 24 |
# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 23 optional :activation_windows, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PortingOrdersActivationJob::ActivationWindow] } |
#status ⇒ Symbol, ...
Specifies the status of this activation job
30 |
# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 30 optional :status, enum: -> { Telnyx::PortingOrdersActivationJob::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/porting_orders_activation_job.rb', line 87
|