Class: Telnyx::Models::PortoutDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PortoutDetails
- Defined in:
- lib/telnyx/models/portout_details.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#already_ported ⇒ Boolean?
Is true when the number is already ported.
-
#authorized_name ⇒ String?
Name of person authorizing the porting order.
-
#carrier_name ⇒ String?
Carrier the number will be ported out to.
-
#city ⇒ String?
City or municipality of billing address.
-
#created_at ⇒ String?
ISO 8601 formatted date of when the portout was created.
-
#current_carrier ⇒ String?
The current carrier.
-
#end_user_name ⇒ String?
Person name or company name requesting the port.
-
#foc_date ⇒ String?
ISO 8601 formatted Date/Time of the FOC date.
-
#host_messaging ⇒ Boolean?
Indicates whether messaging services should be maintained with Telnyx after the port out completes.
- #id ⇒ String?
-
#inserted_at ⇒ String?
ISO 8601 formatted date of when the portout was created.
-
#lsr ⇒ Array<String>?
The Local Service Request.
-
#phone_numbers ⇒ Array<String>?
Phone numbers associated with this portout.
-
#pon ⇒ String?
Port order number assigned by the carrier the number will be ported out to.
-
#reason ⇒ String?
The reason why the order is being rejected by the user.
-
#rejection_code ⇒ Integer?
The rejection code for one of the valid rejections to reject a port out order.
-
#requested_foc_date ⇒ String?
ISO 8601 formatted Date/Time of the user requested FOC date.
-
#service_address ⇒ String?
First line of billing address (street address).
-
#spid ⇒ String?
New service provider spid.
-
#state ⇒ String?
State, province, or similar of billing address.
-
#status ⇒ Symbol, ...
Status of portout request.
-
#support_key ⇒ String?
A key to reference this port out request when contacting Telnyx customer support.
-
#updated_at ⇒ String?
ISO 8601 formatted date of when the portout was last updated.
-
#user_id ⇒ String?
Identifies the user (or organization) who requested the port out.
-
#vendor ⇒ String?
Telnyx partner providing network coverage.
-
#zip ⇒ String?
Postal Code of billing address.
Instance Method Summary collapse
-
#initialize(id: nil, already_ported: nil, authorized_name: nil, carrier_name: nil, city: nil, created_at: nil, current_carrier: nil, end_user_name: nil, foc_date: nil, host_messaging: nil, inserted_at: nil, lsr: nil, phone_numbers: nil, pon: nil, reason: nil, record_type: nil, rejection_code: nil, requested_foc_date: nil, service_address: nil, spid: nil, state: nil, status: nil, support_key: nil, updated_at: nil, user_id: nil, vendor: nil, zip: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PortoutDetails for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, already_ported: nil, authorized_name: nil, carrier_name: nil, city: nil, created_at: nil, current_carrier: nil, end_user_name: nil, foc_date: nil, host_messaging: nil, inserted_at: nil, lsr: nil, phone_numbers: nil, pon: nil, reason: nil, record_type: nil, rejection_code: nil, requested_foc_date: nil, service_address: nil, spid: nil, state: nil, status: nil, support_key: nil, updated_at: nil, user_id: nil, vendor: nil, zip: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PortoutDetails for more details.
|
|
# File 'lib/telnyx/models/portout_details.rb', line 172
|
Instance Attribute Details
#already_ported ⇒ Boolean?
Is true when the number is already ported
16 |
# File 'lib/telnyx/models/portout_details.rb', line 16 optional :already_ported, Telnyx::Internal::Type::Boolean |
#authorized_name ⇒ String?
Name of person authorizing the porting order
22 |
# File 'lib/telnyx/models/portout_details.rb', line 22 optional :authorized_name, String |
#carrier_name ⇒ String?
Carrier the number will be ported out to
28 |
# File 'lib/telnyx/models/portout_details.rb', line 28 optional :carrier_name, String |
#city ⇒ String?
City or municipality of billing address
34 |
# File 'lib/telnyx/models/portout_details.rb', line 34 optional :city, String |
#created_at ⇒ String?
ISO 8601 formatted date of when the portout was created
40 |
# File 'lib/telnyx/models/portout_details.rb', line 40 optional :created_at, String |
#current_carrier ⇒ String?
The current carrier
46 |
# File 'lib/telnyx/models/portout_details.rb', line 46 optional :current_carrier, String |
#end_user_name ⇒ String?
Person name or company name requesting the port
52 |
# File 'lib/telnyx/models/portout_details.rb', line 52 optional :end_user_name, String |
#foc_date ⇒ String?
ISO 8601 formatted Date/Time of the FOC date
58 |
# File 'lib/telnyx/models/portout_details.rb', line 58 optional :foc_date, String |
#host_messaging ⇒ Boolean?
Indicates whether messaging services should be maintained with Telnyx after the port out completes
65 |
# File 'lib/telnyx/models/portout_details.rb', line 65 optional :host_messaging, Telnyx::Internal::Type::Boolean |
#id ⇒ String?
10 |
# File 'lib/telnyx/models/portout_details.rb', line 10 optional :id, String |
#inserted_at ⇒ String?
ISO 8601 formatted date of when the portout was created
71 |
# File 'lib/telnyx/models/portout_details.rb', line 71 optional :inserted_at, String |
#lsr ⇒ Array<String>?
The Local Service Request
77 |
# File 'lib/telnyx/models/portout_details.rb', line 77 optional :lsr, Telnyx::Internal::Type::ArrayOf[String] |
#phone_numbers ⇒ Array<String>?
Phone numbers associated with this portout
83 |
# File 'lib/telnyx/models/portout_details.rb', line 83 optional :phone_numbers, Telnyx::Internal::Type::ArrayOf[String] |
#pon ⇒ String?
Port order number assigned by the carrier the number will be ported out to
89 |
# File 'lib/telnyx/models/portout_details.rb', line 89 optional :pon, String |
#reason ⇒ String?
The reason why the order is being rejected by the user. If the order is authorized, this field can be left null
96 |
# File 'lib/telnyx/models/portout_details.rb', line 96 optional :reason, String, nil?: true |
#rejection_code ⇒ Integer?
The rejection code for one of the valid rejections to reject a port out order
102 |
# File 'lib/telnyx/models/portout_details.rb', line 102 optional :rejection_code, Integer |
#requested_foc_date ⇒ String?
ISO 8601 formatted Date/Time of the user requested FOC date
108 |
# File 'lib/telnyx/models/portout_details.rb', line 108 optional :requested_foc_date, String |
#service_address ⇒ String?
First line of billing address (street address)
114 |
# File 'lib/telnyx/models/portout_details.rb', line 114 optional :service_address, String |
#spid ⇒ String?
New service provider spid
120 |
# File 'lib/telnyx/models/portout_details.rb', line 120 optional :spid, String |
#state ⇒ String?
State, province, or similar of billing address
126 |
# File 'lib/telnyx/models/portout_details.rb', line 126 optional :state, String |
#status ⇒ Symbol, ...
Status of portout request
132 |
# File 'lib/telnyx/models/portout_details.rb', line 132 optional :status, enum: -> { Telnyx::PortoutDetails::Status } |
#support_key ⇒ String?
A key to reference this port out request when contacting Telnyx customer support
138 |
# File 'lib/telnyx/models/portout_details.rb', line 138 optional :support_key, String |
#updated_at ⇒ String?
ISO 8601 formatted date of when the portout was last updated
144 |
# File 'lib/telnyx/models/portout_details.rb', line 144 optional :updated_at, String |
#user_id ⇒ String?
Identifies the user (or organization) who requested the port out
150 |
# File 'lib/telnyx/models/portout_details.rb', line 150 optional :user_id, String |
#vendor ⇒ String?
Telnyx partner providing network coverage
156 |
# File 'lib/telnyx/models/portout_details.rb', line 156 optional :vendor, String |
#zip ⇒ String?
Postal Code of billing address
162 |
# File 'lib/telnyx/models/portout_details.rb', line 162 optional :zip, String |