Class: Telnyx::Models::PrivateWirelessGateway

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/private_wireless_gateway.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, assigned_resources: nil, created_at: nil, ip_range: nil, name: nil, network_id: nil, record_type: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::PrivateWirelessGateway for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • assigned_resources (Array<Telnyx::Models::PwgAssignedResourcesSummary>) (defaults to: nil)

    A list of the resources that have been assigned to the Private Wireless Gateway.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • ip_range (String) (defaults to: nil)

    IP block used to assign IPs to the SIM cards in the Private Wireless Gateway.

  • name (String) (defaults to: nil)

    The private wireless gateway name.

  • network_id (String) (defaults to: nil)

    The identification of the related network resource.

  • record_type (String) (defaults to: nil)
  • region_code (String) (defaults to: nil)

    The name of the region where the Private Wireless Gateway is deployed.

  • status (Telnyx::Models::PrivateWirelessGatewayStatus) (defaults to: nil)

    The current status or failure details of the Private Wireless Gateway.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/private_wireless_gateway.rb', line 68

Instance Attribute Details

#assigned_resourcesArray<Telnyx::Models::PwgAssignedResourcesSummary>?

A list of the resources that have been assigned to the Private Wireless Gateway.



11
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 11

optional :assigned_resources, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PwgAssignedResourcesSummary] }

#nameString?

The private wireless gateway name.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 17

optional :name, String

#network_idString?

The identification of the related network resource.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 23

optional :network_id, String

#region_codeString?

The name of the region where the Private Wireless Gateway is deployed.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 29

optional :region_code, String

#statusTelnyx::Models::PrivateWirelessGatewayStatus?

The current status or failure details of the Private Wireless Gateway.



35
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 35

optional :status, -> { Telnyx::PrivateWirelessGatewayStatus }