Class: Telnyx::Models::PrivateWirelessGateway
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PrivateWirelessGateway
- Defined in:
- lib/telnyx/models/private_wireless_gateway.rb
Overview
Instance Attribute Summary collapse
-
#assigned_resources ⇒ Array<Telnyx::Models::PwgAssignedResourcesSummary>?
A list of the resources that have been assigned to the Private Wireless Gateway.
-
#name ⇒ String?
The private wireless gateway name.
-
#network_id ⇒ String?
The identification of the related network resource.
-
#region_code ⇒ String?
The name of the region where the Private Wireless Gateway is deployed.
-
#status ⇒ Telnyx::Models::PrivateWirelessGatewayStatus?
The current status or failure details of the Private Wireless Gateway.
Instance Method Summary collapse
-
#initialize(id: nil, assigned_resources: nil, created_at: nil, ip_range: nil, name: nil, network_id: nil, record_type: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PrivateWirelessGateway for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, assigned_resources: nil, created_at: nil, ip_range: nil, name: nil, network_id: nil, record_type: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PrivateWirelessGateway for more details.
|
|
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 68
|
Instance Attribute Details
#assigned_resources ⇒ Array<Telnyx::Models::PwgAssignedResourcesSummary>?
A list of the resources that have been assigned to the Private Wireless Gateway.
11 |
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 11 optional :assigned_resources, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::PwgAssignedResourcesSummary] } |
#name ⇒ String?
The private wireless gateway name.
17 |
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 17 optional :name, String |
#network_id ⇒ String?
The identification of the related network resource.
23 |
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 23 optional :network_id, String |
#region_code ⇒ String?
The name of the region where the Private Wireless Gateway is deployed.
29 |
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 29 optional :region_code, String |
#status ⇒ Telnyx::Models::PrivateWirelessGatewayStatus?
The current status or failure details of the Private Wireless Gateway.
35 |
# File 'lib/telnyx/models/private_wireless_gateway.rb', line 35 optional :status, -> { Telnyx::PrivateWirelessGatewayStatus } |