Module: Telnyx::Models::PrivateWirelessGatewayStatus::Value

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/private_wireless_gateway_status.rb

Overview

The current status or failure details of the Private Wireless Gateway. <ul>

<li><code>provisioning</code> - the Private Wireless Gateway is being provisioned.</li>
<li><code>provisioned</code> - the Private Wireless Gateway was provisioned and able to receive connections.</li>
<li><code>failed</code> - the provisioning had failed for a reason and it requires an intervention.</li>
<li><code>decommissioning</code> - the Private Wireless Gateway is being removed from the network.</li>
</ul>
Transitioning between the provisioning and provisioned states may take some time.

See Also:

  • #value

Constant Summary collapse

PROVISIONING =
:provisioning
PROVISIONED =
:provisioned
FAILED =
:failed
DECOMMISSIONING =
:decommissioning

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/private_wireless_gateway_status.rb', line 65