Class: Telnyx::Models::PublicInternetGateway
- Inherits:
-
Record
- Object
- Internal::Type::BaseModel
- Record
- Telnyx::Models::PublicInternetGateway
- Defined in:
- lib/telnyx/models/public_internet_gateway.rb,
sig/telnyx/models/public_internet_gateway.rbs
Direct Known Subclasses
Instance Attribute Summary collapse
-
#name ⇒ String?
A user specified name for the interface.
-
#network_id ⇒ String?
The id of the network associated with the interface.
-
#region_code ⇒ String?
The region interface is deployed to.
Attributes inherited from Record
#created_at, #id, #record_type, #updated_at
Instance Method Summary collapse
Methods inherited from Record
#created_at=, #id=, #record_type=, #updated_at=
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil, network_id: nil, region_code: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/public_internet_gateway.rb', line 24
|
Instance Attribute Details
#name ⇒ String?
A user specified name for the interface.
10 |
# File 'lib/telnyx/models/public_internet_gateway.rb', line 10 optional :name, String |
#network_id ⇒ String?
The id of the network associated with the interface.
16 |
# File 'lib/telnyx/models/public_internet_gateway.rb', line 16 optional :network_id, String |
#region_code ⇒ String?
The region interface is deployed to.
22 |
# File 'lib/telnyx/models/public_internet_gateway.rb', line 22 optional :region_code, String |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/telnyx/models/public_internet_gateway.rbs', line 31
def to_hash: -> {
|