Class: Telnyx::Models::PublicInternetGatewayRead
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PublicInternetGatewayRead
- Defined in:
- lib/telnyx/models/public_internet_gateway_read.rb,
sig/telnyx/models/public_internet_gateway_read.rbs
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#name ⇒ String?
A user specified name for the interface.
-
#network_id ⇒ String?
The id of the network associated with the interface.
-
#public_ip ⇒ String?
readonly
Returns the value of attribute public_ip.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#region_code ⇒ String?
The region interface is deployed to.
-
#status ⇒ Telnyx::Models::interface_status?
readonly
Returns the value of attribute status.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Instance Method Summary collapse
- #created_at ⇒ String readonly
- #id ⇒ String readonly
- #initialize(id: nil, created_at: nil, name: nil, network_id: nil, public_ip: nil, record_type: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object constructor
- #public_ip ⇒ String readonly
- #record_type ⇒ String readonly
- #status ⇒ Object readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, name: nil, network_id: nil, public_ip: nil, record_type: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 63
|
Instance Attribute Details
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
33 34 35 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 33 def created_at @created_at end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
29 30 31 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 29 def id @id end |
#name ⇒ String?
A user specified name for the interface.
11 |
# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 11 optional :name, String |
#network_id ⇒ String?
The id of the network associated with the interface.
17 |
# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 17 optional :network_id, String |
#public_ip ⇒ String? (readonly)
Returns the value of attribute public_ip.
37 38 39 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 37 def public_ip @public_ip end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
41 42 43 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 41 def record_type @record_type end |
#region_code ⇒ String?
The region interface is deployed to.
23 |
# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 23 optional :region_code, String |
#status ⇒ Telnyx::Models::interface_status? (readonly)
Returns the value of attribute status.
45 46 47 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 45 def status @status end |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
51 52 53 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 51 def updated_at @updated_at end |
Instance Method Details
#created_at= ⇒ String (readonly)
35 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 35
def created_at=: (String) -> String
|
#id= ⇒ String (readonly)
31 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 31
def id=: (String) -> String
|
#public_ip= ⇒ String (readonly)
39 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 39
def public_ip=: (String) -> String
|
#record_type= ⇒ String (readonly)
43 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 43
def record_type=: (String) -> String
|
#status= ⇒ Object (readonly)
47 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 47
def status=: (
|
#to_hash ⇒ {
67 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 67
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
53 |
# File 'sig/telnyx/models/public_internet_gateway_read.rbs', line 53
def updated_at=: (String) -> String
|