Class: Telnyx::Models::PublicInternetGatewayRead

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/public_internet_gateway_read.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, name: nil, network_id: nil, public_ip: nil, record_type: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • public_ip (String) (defaults to: nil)

    The publically accessible ip for this interface.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • region_code (String) (defaults to: nil)

    The region interface is deployed to.

  • status (Symbol, Telnyx::Models::InterfaceStatus) (defaults to: nil)

    The current status of the interface deployment.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 63

Instance Attribute Details

#nameString?

A user specified name for the interface.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 11

optional :name, String

#network_idString?

The id of the network associated with the interface.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 17

optional :network_id, String

#region_codeString?

The region interface is deployed to.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/public_internet_gateway_read.rb', line 23

optional :region_code, String