Class: Telnyx::Models::PushCredential
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::PushCredential
- Defined in:
- lib/telnyx/models/push_credential.rb
Overview
Instance Attribute Summary collapse
-
#alias_ ⇒ String
Alias to uniquely identify a credential.
-
#certificate ⇒ String
Apple certificate for sending push notifications.
-
#created_at ⇒ Time
ISO 8601 timestamp when the room was created.
-
#id ⇒ String
Unique identifier of a push credential.
-
#private_key ⇒ String
Apple private key for a given certificate for sending push notifications.
-
#project_account_json_file ⇒ Hash{Symbol=>Object}
Google server key for sending push notifications.
-
#type ⇒ String
Type of mobile push credential.
-
#updated_at ⇒ Time
ISO 8601 timestamp when the room was updated.
Instance Method Summary collapse
-
#initialize(id:, alias_:, certificate:, created_at:, private_key:, project_account_json_file:, record_type:, type:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PushCredential for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, alias_:, certificate:, created_at:, private_key:, project_account_json_file:, record_type:, type:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::PushCredential for more details.
|
|
# File 'lib/telnyx/models/push_credential.rb', line 63
|
Instance Attribute Details
#alias_ ⇒ String
Alias to uniquely identify a credential
17 |
# File 'lib/telnyx/models/push_credential.rb', line 17 required :alias_, String, api_name: :alias |
#certificate ⇒ String
Apple certificate for sending push notifications. For iOS only
23 |
# File 'lib/telnyx/models/push_credential.rb', line 23 required :certificate, String |
#created_at ⇒ Time
ISO 8601 timestamp when the room was created
29 |
# File 'lib/telnyx/models/push_credential.rb', line 29 required :created_at, Time |
#id ⇒ String
Unique identifier of a push credential
11 |
# File 'lib/telnyx/models/push_credential.rb', line 11 required :id, String |
#private_key ⇒ String
Apple private key for a given certificate for sending push notifications. For iOS only
36 |
# File 'lib/telnyx/models/push_credential.rb', line 36 required :private_key, String |
#project_account_json_file ⇒ Hash{Symbol=>Object}
Google server key for sending push notifications. For Android only
42 |
# File 'lib/telnyx/models/push_credential.rb', line 42 required :project_account_json_file, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#type ⇒ String
Type of mobile push credential. Either ios or android
48 |
# File 'lib/telnyx/models/push_credential.rb', line 48 required :type, String |
#updated_at ⇒ Time
ISO 8601 timestamp when the room was updated.
54 |
# File 'lib/telnyx/models/push_credential.rb', line 54 required :updated_at, Time |