Class: Telnyx::Models::PwgAssignedResourcesSummary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/pwg_assigned_resources_summary.rb

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(count: nil, record_type: nil) ⇒ Object

The summary of the resource that have been assigned to the Private Wireless Gateway.

Parameters:

  • count (Integer) (defaults to: nil)

    The current count of a resource type assigned to the Private Wireless Gateway.

  • record_type (String) (defaults to: nil)

    The type of the resource assigned to the Private Wireless Gateway.



# File 'lib/telnyx/models/pwg_assigned_resources_summary.rb', line 20