Class: Telnyx::Models::Queue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Queue
- Defined in:
- lib/telnyx/models/queue.rb
Overview
Defined Under Namespace
Modules: RecordType
Instance Attribute Summary collapse
-
#average_wait_time_secs ⇒ Integer
The average time that the calls currently in the queue have spent waiting, given in seconds.
-
#created_at ⇒ String
ISO 8601 formatted date of when the queue was created.
-
#current_size ⇒ Integer
The number of calls currently in the queue.
-
#id ⇒ String
Uniquely identifies the queue.
-
#max_size ⇒ Integer
The maximum number of calls allowed in the queue.
-
#name ⇒ String
Name of the queue.
- #record_type ⇒ Symbol, Telnyx::Models::Queue::RecordType
-
#updated_at ⇒ String
ISO 8601 formatted date of when the queue was last updated.
Instance Method Summary collapse
-
#initialize(id:, average_wait_time_secs:, created_at:, current_size:, max_size:, name:, record_type:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Queue for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, average_wait_time_secs:, created_at:, current_size:, max_size:, name:, record_type:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Queue for more details.
|
|
# File 'lib/telnyx/models/queue.rb', line 55
|
Instance Attribute Details
#average_wait_time_secs ⇒ Integer
The average time that the calls currently in the queue have spent waiting, given in seconds.
18 |
# File 'lib/telnyx/models/queue.rb', line 18 required :average_wait_time_secs, Integer |
#created_at ⇒ String
ISO 8601 formatted date of when the queue was created
24 |
# File 'lib/telnyx/models/queue.rb', line 24 required :created_at, String |
#current_size ⇒ Integer
The number of calls currently in the queue
30 |
# File 'lib/telnyx/models/queue.rb', line 30 required :current_size, Integer |
#id ⇒ String
Uniquely identifies the queue
11 |
# File 'lib/telnyx/models/queue.rb', line 11 required :id, String |
#max_size ⇒ Integer
The maximum number of calls allowed in the queue
36 |
# File 'lib/telnyx/models/queue.rb', line 36 required :max_size, Integer |
#name ⇒ String
Name of the queue
42 |
# File 'lib/telnyx/models/queue.rb', line 42 required :name, String |
#record_type ⇒ Symbol, Telnyx::Models::Queue::RecordType
47 |
# File 'lib/telnyx/models/queue.rb', line 47 required :record_type, enum: -> { Telnyx::Queue::RecordType } |
#updated_at ⇒ String
ISO 8601 formatted date of when the queue was last updated
53 |
# File 'lib/telnyx/models/queue.rb', line 53 required :updated_at, String |