Class: Telnyx::Models::Queues::CallRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Queues::CallRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/queues/call_retrieve_response.rb
Overview
Defined Under Namespace
Modules: RecordType
Instance Attribute Summary collapse
-
#call_control_id ⇒ String
Unique identifier and token for controlling the call.
-
#call_leg_id ⇒ String
ID that is unique to the call and can be used to correlate webhook events.
-
#call_session_id ⇒ String
ID that is unique to the call session and can be used to correlate webhook events.
-
#connection_id ⇒ String
Call Control App ID (formerly Telnyx connection ID) used in the call.
-
#enqueued_at ⇒ String
ISO 8601 formatted date of when the call was put in the queue.
-
#from ⇒ String
Number or SIP URI placing the call.
-
#is_alive ⇒ Boolean?
Indicates whether the call is still active in the queue.
-
#queue_id ⇒ String
Unique identifier of the queue the call is in.
-
#queue_position ⇒ Integer
Current position of the call in the queue.
- #record_type ⇒ Symbol, Telnyx::Models::Queues::CallRetrieveResponse::Data::RecordType
-
#to ⇒ String
Destination number or SIP URI of the call.
-
#wait_time_secs ⇒ Integer
The time the call has been waiting in the queue, given in seconds.
Instance Method Summary collapse
-
#initialize(call_control_id:, call_leg_id:, call_session_id:, connection_id:, enqueued_at:, from:, queue_id:, queue_position:, record_type:, to:, wait_time_secs:, is_alive: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_control_id:, call_leg_id:, call_session_id:, connection_id:, enqueued_at:, from:, queue_id:, queue_position:, record_type:, to:, wait_time_secs:, is_alive: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Queues::CallRetrieveResponse::Data for more details.
|
|
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 91
|
Instance Attribute Details
#call_control_id ⇒ String
Unique identifier and token for controlling the call.
22 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 22 required :call_control_id, String |
#call_leg_id ⇒ String
ID that is unique to the call and can be used to correlate webhook events
28 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 28 required :call_leg_id, String |
#call_session_id ⇒ String
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call
36 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 36 required :call_session_id, String |
#connection_id ⇒ String
Call Control App ID (formerly Telnyx connection ID) used in the call.
42 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 42 required :connection_id, String |
#enqueued_at ⇒ String
ISO 8601 formatted date of when the call was put in the queue
48 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 48 required :enqueued_at, String |
#from ⇒ String
Number or SIP URI placing the call.
54 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 54 required :from, String |
#is_alive ⇒ Boolean?
Indicates whether the call is still active in the queue.
89 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 89 optional :is_alive, Telnyx::Internal::Type::Boolean |
#queue_id ⇒ String
Unique identifier of the queue the call is in.
60 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 60 required :queue_id, String |
#queue_position ⇒ Integer
Current position of the call in the queue
66 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 66 required :queue_position, Integer |
#record_type ⇒ Symbol, Telnyx::Models::Queues::CallRetrieveResponse::Data::RecordType
71 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 71 required :record_type, enum: -> { Telnyx::Models::Queues::CallRetrieveResponse::Data::RecordType } |
#to ⇒ String
Destination number or SIP URI of the call.
77 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 77 required :to, String |
#wait_time_secs ⇒ Integer
The time the call has been waiting in the queue, given in seconds
83 |
# File 'lib/telnyx/models/queues/call_retrieve_response.rb', line 83 required :wait_time_secs, Integer |