Class: Telnyx::Models::RcsCardContent::Media
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RcsCardContent::Media
- Defined in:
- lib/telnyx/models/rcs_card_content.rb
Overview
Defined Under Namespace
Modules: Height
Instance Attribute Summary collapse
- #content_info ⇒ Telnyx::Models::RcsContentInfo?
-
#height ⇒ Symbol, ...
The height of the media within a rich card with a vertical layout.
Instance Method Summary collapse
-
#initialize(content_info: nil, height: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Media for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_info: nil, height: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::RcsCardContent::Media for more details.
A media file within a rich card.
|
|
# File 'lib/telnyx/models/rcs_card_content.rb', line 54
|
Instance Attribute Details
#content_info ⇒ Telnyx::Models::RcsContentInfo?
44 |
# File 'lib/telnyx/models/rcs_card_content.rb', line 44 optional :content_info, -> { Telnyx::RcsContentInfo } |
#height ⇒ Symbol, ...
The height of the media within a rich card with a vertical layout. For a standalone card with horizontal layout, height is not customizable, and this field is ignored.
52 |
# File 'lib/telnyx/models/rcs_card_content.rb', line 52 optional :height, enum: -> { Telnyx::RcsCardContent::Media::Height } |