Module: Telnyx::Models::RcsCardContent::Media::Height

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/rcs_card_content.rb

Overview

The height of the media within a rich card with a vertical layout. For a standalone card with horizontal layout, height is not customizable, and this field is ignored.

See Also:

Constant Summary collapse

HEIGHT_UNSPECIFIED =
:HEIGHT_UNSPECIFIED
SHORT =
:SHORT
MEDIUM =
:MEDIUM
TALL =
:TALL

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/rcs_card_content.rb', line 77