Class: Telnyx::Models::RecordingResponseData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RecordingResponseData
- Defined in:
- lib/telnyx/models/recording_response_data.rb
Overview
Defined Under Namespace
Modules: Channels, RecordType, Source, Status Classes: DownloadURLs
Instance Attribute Summary collapse
-
#call_control_id ⇒ String?
Unique identifier and token for controlling the call.
-
#call_leg_id ⇒ String?
ID unique to the call leg (used to correlate webhook events).
-
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events.
-
#channels ⇒ Symbol, ...
When ‘dual`, the final audio file has the first leg on channel A, and the rest on channel B.
-
#conference_id ⇒ String?
Uniquely identifies the conference.
-
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
-
#download_urls ⇒ Telnyx::Models::RecordingResponseData::DownloadURLs?
Links to download the recording files.
-
#duration_millis ⇒ Integer?
The duration of the recording in milliseconds.
-
#id ⇒ String?
Uniquely identifies the recording.
- #record_type ⇒ Symbol, ...
-
#recording_ended_at ⇒ String?
ISO 8601 formatted date of when the recording ended.
-
#recording_started_at ⇒ String?
ISO 8601 formatted date of when the recording started.
-
#source ⇒ Symbol, ...
The kind of event that led to this recording being created.
-
#status ⇒ Symbol, ...
The status of the recording.
-
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(mp3: nil, wav: nil) ⇒ Object
constructor
Links to download the recording files.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mp3: nil, wav: nil) ⇒ Object
Links to download the recording files.
|
|
# File 'lib/telnyx/models/recording_response_data.rb', line 100
|
Instance Attribute Details
#call_control_id ⇒ String?
Unique identifier and token for controlling the call.
17 |
# File 'lib/telnyx/models/recording_response_data.rb', line 17 optional :call_control_id, String |
#call_leg_id ⇒ String?
ID unique to the call leg (used to correlate webhook events).
23 |
# File 'lib/telnyx/models/recording_response_data.rb', line 23 optional :call_leg_id, String |
#call_session_id ⇒ String?
ID that is unique to the call session and can be used to correlate webhook events. Call session is a group of related call legs that logically belong to the same phone call, e.g. an inbound and outbound leg of a transferred call.
31 |
# File 'lib/telnyx/models/recording_response_data.rb', line 31 optional :call_session_id, String |
#channels ⇒ Symbol, ...
When ‘dual`, the final audio file has the first leg on channel A, and the rest on channel B.
38 |
# File 'lib/telnyx/models/recording_response_data.rb', line 38 optional :channels, enum: -> { Telnyx::RecordingResponseData::Channels } |
#conference_id ⇒ String?
Uniquely identifies the conference.
44 |
# File 'lib/telnyx/models/recording_response_data.rb', line 44 optional :conference_id, String |
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
50 |
# File 'lib/telnyx/models/recording_response_data.rb', line 50 optional :created_at, String |
#download_urls ⇒ Telnyx::Models::RecordingResponseData::DownloadURLs?
Links to download the recording files.
56 |
# File 'lib/telnyx/models/recording_response_data.rb', line 56 optional :download_urls, -> { Telnyx::RecordingResponseData::DownloadURLs } |
#duration_millis ⇒ Integer?
The duration of the recording in milliseconds.
62 |
# File 'lib/telnyx/models/recording_response_data.rb', line 62 optional :duration_millis, Integer |
#id ⇒ String?
Uniquely identifies the recording.
11 |
# File 'lib/telnyx/models/recording_response_data.rb', line 11 optional :id, String |
#record_type ⇒ Symbol, ...
67 |
# File 'lib/telnyx/models/recording_response_data.rb', line 67 optional :record_type, enum: -> { Telnyx::RecordingResponseData::RecordType } |
#recording_ended_at ⇒ String?
ISO 8601 formatted date of when the recording ended.
73 |
# File 'lib/telnyx/models/recording_response_data.rb', line 73 optional :recording_ended_at, String |
#recording_started_at ⇒ String?
ISO 8601 formatted date of when the recording started.
79 |
# File 'lib/telnyx/models/recording_response_data.rb', line 79 optional :recording_started_at, String |
#source ⇒ Symbol, ...
The kind of event that led to this recording being created.
85 |
# File 'lib/telnyx/models/recording_response_data.rb', line 85 optional :source, enum: -> { Telnyx::RecordingResponseData::Source } |
#status ⇒ Symbol, ...
The status of the recording. Only ‘completed` recordings are currently supported.
92 |
# File 'lib/telnyx/models/recording_response_data.rb', line 92 optional :status, enum: -> { Telnyx::RecordingResponseData::Status } |
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
98 |
# File 'lib/telnyx/models/recording_response_data.rb', line 98 optional :updated_at, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/recording_response_data.rb', line 144
|