Class: Telnyx::Models::ReplacedLinkClick
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::ReplacedLinkClick
- Defined in:
- lib/telnyx/models/replaced_link_click.rb
Instance Attribute Summary collapse
-
#message_id ⇒ String?
The message ID associated with the clicked link.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#time_clicked ⇒ Time?
ISO 8601 formatted date indicating when the message request was received.
-
#to ⇒ String?
Sending address (+E.164 formatted phone number, alphanumeric sender ID, or short code).
-
#url ⇒ String?
The original link that was sent in the message.
Instance Method Summary collapse
-
#initialize(message_id: nil, record_type: nil, time_clicked: nil, to: nil, url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ReplacedLinkClick for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(message_id: nil, record_type: nil, time_clicked: nil, to: nil, url: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::ReplacedLinkClick for more details.
|
|
# File 'lib/telnyx/models/replaced_link_click.rb', line 37
|
Instance Attribute Details
#message_id ⇒ String?
The message ID associated with the clicked link.
10 |
# File 'lib/telnyx/models/replaced_link_click.rb', line 10 optional :message_id, String |
#record_type ⇒ String?
Identifies the type of the resource.
16 |
# File 'lib/telnyx/models/replaced_link_click.rb', line 16 optional :record_type, String |
#time_clicked ⇒ Time?
ISO 8601 formatted date indicating when the message request was received.
22 |
# File 'lib/telnyx/models/replaced_link_click.rb', line 22 optional :time_clicked, Time |
#to ⇒ String?
Sending address (+E.164 formatted phone number, alphanumeric sender ID, or short code).
29 |
# File 'lib/telnyx/models/replaced_link_click.rb', line 29 optional :to, String |
#url ⇒ String?
The original link that was sent in the message.
35 |
# File 'lib/telnyx/models/replaced_link_click.rb', line 35 optional :url, String |