Class: Telnyx::Models::RequirementRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RequirementRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/requirement_retrieve_response.rb
Overview
Defined Under Namespace
Modules: Action, PhoneNumberType
Instance Attribute Summary collapse
-
#action ⇒ Symbol, ...
Indicates whether this requirement applies to branded_calling, ordering, porting, or both ordering and porting.
-
#country_code ⇒ String?
The 2-character (ISO 3166-1 alpha-2) country code where this requirement applies.
-
#locality ⇒ String?
The locality where this requirement applies.
-
#phone_number_type ⇒ Symbol, ...
Indicates the phone_number_type this requirement applies to.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, action: nil, country_code: nil, created_at: nil, locality: nil, phone_number_type: nil, record_type: nil, requirements_types: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, action: nil, country_code: nil, created_at: nil, locality: nil, phone_number_type: nil, record_type: nil, requirements_types: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::RequirementRetrieveResponse::Data for more details.
|
|
# File 'lib/telnyx/models/requirement_retrieve_response.rb', line 76
|
Instance Attribute Details
#action ⇒ Symbol, ...
Indicates whether this requirement applies to branded_calling, ordering, porting, or both ordering and porting
22 |
# File 'lib/telnyx/models/requirement_retrieve_response.rb', line 22 optional :action, enum: -> { Telnyx::Models::RequirementRetrieveResponse::Data::Action } |
#country_code ⇒ String?
The 2-character (ISO 3166-1 alpha-2) country code where this requirement applies
28 |
# File 'lib/telnyx/models/requirement_retrieve_response.rb', line 28 optional :country_code, String |
#locality ⇒ String?
The locality where this requirement applies
34 |
# File 'lib/telnyx/models/requirement_retrieve_response.rb', line 34 optional :locality, String |
#phone_number_type ⇒ Symbol, ...
Indicates the phone_number_type this requirement applies to. Leave blank if this requirement applies to all number_types.
41 42 |
# File 'lib/telnyx/models/requirement_retrieve_response.rb', line 41 optional :phone_number_type, enum: -> { Telnyx::Models::RequirementRetrieveResponse::Data::PhoneNumberType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/requirement_retrieve_response.rb', line 110
|