Class: Telnyx::Models::ReservedPhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/reserved_phone_number.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, errors: nil, expired_at: nil, phone_number: nil, record_type: nil, status: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::ReservedPhoneNumber for more details.

Parameters:

  • id (String) (defaults to: nil)
  • created_at (Time) (defaults to: nil)

    An ISO 8901 datetime string denoting when the individual number reservation was

  • errors (String) (defaults to: nil)

    Errors the reservation could happen upon

  • expired_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the individual number reservation is going

  • phone_number (String) (defaults to: nil)
  • record_type (String) (defaults to: nil)
  • status (Symbol, Telnyx::Models::ReservedPhoneNumber::Status) (defaults to: nil)

    The status of the phone number’s reservation.

  • updated_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the the individual number reservation was u



# File 'lib/telnyx/models/reserved_phone_number.rb', line 56

Instance Attribute Details

#phone_numberString?

Returns:

  • (String, nil)


9
# File 'lib/telnyx/models/reserved_phone_number.rb', line 9

optional :phone_number, String