Class: Telnyx::Models::Room
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Room
- Defined in:
- lib/telnyx/models/room.rb
Overview
Instance Attribute Summary collapse
-
#active_session_id ⇒ String?
The identifier of the active room session if any.
-
#created_at ⇒ Time?
ISO 8601 timestamp when the room was created.
-
#enable_recording ⇒ Boolean?
Enable or disable recording for that room.
-
#id ⇒ String?
A unique identifier for the room.
-
#max_participants ⇒ Integer?
Maximum participants allowed in the room.
- #sessions ⇒ Array<Telnyx::Models::RoomSession>?
-
#unique_name ⇒ String?
The unique (within the Telnyx account scope) name of the room.
-
#updated_at ⇒ Time?
ISO 8601 timestamp when the room was updated.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this room will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String?
The URL where webhooks related to this room will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Instance Method Summary collapse
-
#initialize(id: nil, active_session_id: nil, created_at: nil, enable_recording: nil, max_participants: nil, record_type: nil, sessions: nil, unique_name: nil, updated_at: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Room for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, active_session_id: nil, created_at: nil, enable_recording: nil, max_participants: nil, record_type: nil, sessions: nil, unique_name: nil, updated_at: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Room for more details.
|
|
# File 'lib/telnyx/models/room.rb', line 81
|
Instance Attribute Details
#active_session_id ⇒ String?
The identifier of the active room session if any.
17 |
# File 'lib/telnyx/models/room.rb', line 17 optional :active_session_id, String |
#created_at ⇒ Time?
ISO 8601 timestamp when the room was created.
23 |
# File 'lib/telnyx/models/room.rb', line 23 optional :created_at, Time |
#enable_recording ⇒ Boolean?
Enable or disable recording for that room.
29 |
# File 'lib/telnyx/models/room.rb', line 29 optional :enable_recording, Telnyx::Internal::Type::Boolean |
#id ⇒ String?
A unique identifier for the room.
11 |
# File 'lib/telnyx/models/room.rb', line 11 optional :id, String |
#max_participants ⇒ Integer?
Maximum participants allowed in the room.
35 |
# File 'lib/telnyx/models/room.rb', line 35 optional :max_participants, Integer |
#sessions ⇒ Array<Telnyx::Models::RoomSession>?
40 |
# File 'lib/telnyx/models/room.rb', line 40 optional :sessions, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::RoomSession] } |
#unique_name ⇒ String?
The unique (within the Telnyx account scope) name of the room.
46 |
# File 'lib/telnyx/models/room.rb', line 46 optional :unique_name, String |
#updated_at ⇒ Time?
ISO 8601 timestamp when the room was updated.
52 |
# File 'lib/telnyx/models/room.rb', line 52 optional :updated_at, Time |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this room will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.
59 |
# File 'lib/telnyx/models/room.rb', line 59 optional :webhook_event_failover_url, String |
#webhook_event_url ⇒ String?
The URL where webhooks related to this room will be sent. Must include a scheme, such as ‘https’.
66 |
# File 'lib/telnyx/models/room.rb', line 66 optional :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
72 |
# File 'lib/telnyx/models/room.rb', line 72 optional :webhook_timeout_secs, Integer |