Class: Telnyx::Models::RoomComposition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RoomComposition
- Defined in:
- lib/telnyx/models/room_composition.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#completed_at ⇒ Time?
ISO 8601 timestamp when the room composition has completed.
-
#created_at ⇒ Time?
ISO 8601 timestamp when the room composition was created.
-
#download_url ⇒ String?
Url to download the composition.
-
#duration_secs ⇒ Integer?
Shows the room composition duration in seconds.
-
#ended_at ⇒ Time?
ISO 8601 timestamp when the room composition has ended.
-
#file_format ⇒ Symbol, ...
Shows format of the room composition.
-
#id ⇒ String?
A unique identifier for the room composition.
-
#resolution ⇒ String?
The resolution of the room composition.
-
#room_id ⇒ String?
Identify the room associated with the room composition.
-
#session_id ⇒ String?
Identify the room session associated with the room composition.
-
#size_mb ⇒ Float?
Shows the room composition size in MB.
-
#started_at ⇒ Time?
ISO 8601 timestamp when the room composition has stated.
-
#status ⇒ Symbol, ...
Shows the room composition status.
-
#updated_at ⇒ Time?
ISO 8601 timestamp when the room composition was updated.
-
#user_id ⇒ String?
Identify the user associated with the room composition.
-
#video_layout ⇒ Hash{Symbol=>Telnyx::Models::VideoRegion}?
Describes the video layout of the room composition in terms of regions.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this room composition will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String?
The URL where webhooks related to this room composition will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, completed_at: nil, created_at: nil, download_url: nil, duration_secs: nil, ended_at: nil, file_format: nil, record_type: nil, resolution: nil, room_id: nil, session_id: nil, size_mb: nil, started_at: nil, status: nil, updated_at: nil, user_id: nil, video_layout: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RoomComposition for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, completed_at: nil, created_at: nil, download_url: nil, duration_secs: nil, ended_at: nil, file_format: nil, record_type: nil, resolution: nil, room_id: nil, session_id: nil, size_mb: nil, started_at: nil, status: nil, updated_at: nil, user_id: nil, video_layout: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::RoomComposition for more details.
|
|
# File 'lib/telnyx/models/room_composition.rb', line 131
|
Instance Attribute Details
#completed_at ⇒ Time?
ISO 8601 timestamp when the room composition has completed.
17 |
# File 'lib/telnyx/models/room_composition.rb', line 17 optional :completed_at, Time |
#created_at ⇒ Time?
ISO 8601 timestamp when the room composition was created.
23 |
# File 'lib/telnyx/models/room_composition.rb', line 23 optional :created_at, Time |
#download_url ⇒ String?
Url to download the composition.
29 |
# File 'lib/telnyx/models/room_composition.rb', line 29 optional :download_url, String |
#duration_secs ⇒ Integer?
Shows the room composition duration in seconds.
35 |
# File 'lib/telnyx/models/room_composition.rb', line 35 optional :duration_secs, Integer |
#ended_at ⇒ Time?
ISO 8601 timestamp when the room composition has ended.
41 |
# File 'lib/telnyx/models/room_composition.rb', line 41 optional :ended_at, Time |
#file_format ⇒ Symbol, ...
Shows format of the room composition.
47 |
# File 'lib/telnyx/models/room_composition.rb', line 47 optional :file_format, enum: -> { Telnyx::RoomComposition::Format }, api_name: :format |
#id ⇒ String?
A unique identifier for the room composition.
11 |
# File 'lib/telnyx/models/room_composition.rb', line 11 optional :id, String |
#resolution ⇒ String?
The resolution of the room composition.
53 |
# File 'lib/telnyx/models/room_composition.rb', line 53 optional :resolution, String |
#room_id ⇒ String?
Identify the room associated with the room composition.
59 |
# File 'lib/telnyx/models/room_composition.rb', line 59 optional :room_id, String |
#session_id ⇒ String?
Identify the room session associated with the room composition.
65 |
# File 'lib/telnyx/models/room_composition.rb', line 65 optional :session_id, String |
#size_mb ⇒ Float?
Shows the room composition size in MB.
71 |
# File 'lib/telnyx/models/room_composition.rb', line 71 optional :size_mb, Float |
#started_at ⇒ Time?
ISO 8601 timestamp when the room composition has stated.
77 |
# File 'lib/telnyx/models/room_composition.rb', line 77 optional :started_at, Time |
#status ⇒ Symbol, ...
Shows the room composition status.
83 |
# File 'lib/telnyx/models/room_composition.rb', line 83 optional :status, enum: -> { Telnyx::RoomComposition::Status } |
#updated_at ⇒ Time?
ISO 8601 timestamp when the room composition was updated.
89 |
# File 'lib/telnyx/models/room_composition.rb', line 89 optional :updated_at, Time |
#user_id ⇒ String?
Identify the user associated with the room composition.
95 |
# File 'lib/telnyx/models/room_composition.rb', line 95 optional :user_id, String |
#video_layout ⇒ Hash{Symbol=>Telnyx::Models::VideoRegion}?
Describes the video layout of the room composition in terms of regions. Limited to 2 regions.
102 |
# File 'lib/telnyx/models/room_composition.rb', line 102 optional :video_layout, -> { Telnyx::Internal::Type::HashOf[Telnyx::VideoRegion] } |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this room composition will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.
109 |
# File 'lib/telnyx/models/room_composition.rb', line 109 optional :webhook_event_failover_url, String |
#webhook_event_url ⇒ String?
The URL where webhooks related to this room composition will be sent. Must include a scheme, such as ‘https’.
116 |
# File 'lib/telnyx/models/room_composition.rb', line 116 optional :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
122 |
# File 'lib/telnyx/models/room_composition.rb', line 122 optional :webhook_timeout_secs, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/room_composition.rb', line 183
|