Class: Telnyx::Models::RoomCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RoomCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/room_create_params.rb
Overview
Instance Attribute Summary collapse
-
#enable_recording ⇒ Boolean?
Enable or disable recording for that room.
-
#max_participants ⇒ Integer?
The maximum amount of participants allowed in a room.
-
#unique_name ⇒ String?
The unique (within the Telnyx account scope) name of the room.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this room will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String?
The URL where webhooks related to this room will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(enable_recording: nil, max_participants: nil, unique_name: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see RoomCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(enable_recording: nil, max_participants: nil, unique_name: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::RoomCreateParams for more details.
|
|
# File 'lib/telnyx/models/room_create_params.rb', line 49
|
Instance Attribute Details
#enable_recording ⇒ Boolean?
Enable or disable recording for that room.
14 |
# File 'lib/telnyx/models/room_create_params.rb', line 14 optional :enable_recording, Telnyx::Internal::Type::Boolean |
#max_participants ⇒ Integer?
The maximum amount of participants allowed in a room. If new participants try to join after that limit is reached, their request will be rejected.
21 |
# File 'lib/telnyx/models/room_create_params.rb', line 21 optional :max_participants, Integer |
#unique_name ⇒ String?
The unique (within the Telnyx account scope) name of the room.
27 |
# File 'lib/telnyx/models/room_create_params.rb', line 27 optional :unique_name, String |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this room will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.
34 |
# File 'lib/telnyx/models/room_create_params.rb', line 34 optional :webhook_event_failover_url, String |
#webhook_event_url ⇒ String?
The URL where webhooks related to this room will be sent. Must include a scheme, such as ‘https’.
41 |
# File 'lib/telnyx/models/room_create_params.rb', line 41 optional :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
47 |
# File 'lib/telnyx/models/room_create_params.rb', line 47 optional :webhook_timeout_secs, Integer |