Class: Telnyx::Models::RoomParticipant
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RoomParticipant
- Defined in:
- lib/telnyx/models/room_participant.rb
Instance Attribute Summary collapse
-
#context ⇒ String?
Context provided to the given participant through the client SDK.
-
#id ⇒ String?
A unique identifier for the room participant.
-
#joined_at ⇒ Time?
ISO 8601 timestamp when the participant joined the session.
-
#left_at ⇒ Time?
ISO 8601 timestamp when the participant left the session.
-
#session_id ⇒ String?
Identify the room session that participant is part of.
-
#updated_at ⇒ Time?
ISO 8601 timestamp when the participant was updated.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, context: nil, joined_at: nil, left_at: nil, record_type: nil, session_id: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/room_participant.rb', line 49
|
Instance Attribute Details
#context ⇒ String?
Context provided to the given participant through the client SDK
16 |
# File 'lib/telnyx/models/room_participant.rb', line 16 optional :context, String |
#id ⇒ String?
A unique identifier for the room participant.
10 |
# File 'lib/telnyx/models/room_participant.rb', line 10 optional :id, String |
#joined_at ⇒ Time?
ISO 8601 timestamp when the participant joined the session.
22 |
# File 'lib/telnyx/models/room_participant.rb', line 22 optional :joined_at, Time |
#left_at ⇒ Time?
ISO 8601 timestamp when the participant left the session.
28 |
# File 'lib/telnyx/models/room_participant.rb', line 28 optional :left_at, Time |
#session_id ⇒ String?
Identify the room session that participant is part of.
34 |
# File 'lib/telnyx/models/room_participant.rb', line 34 optional :session_id, String |
#updated_at ⇒ Time?
ISO 8601 timestamp when the participant was updated.
40 |
# File 'lib/telnyx/models/room_participant.rb', line 40 optional :updated_at, Time |