Class: Telnyx::Models::RoomRecordingRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::RoomRecordingRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/room_recording_retrieve_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#codec ⇒ String?
Shows the codec used for the room recording.
-
#completed_at ⇒ Time?
ISO 8601 timestamp when the room recording has completed.
-
#created_at ⇒ Time?
ISO 8601 timestamp when the room recording was created.
-
#download_url ⇒ String?
Url to download the recording.
-
#duration_secs ⇒ Integer?
Shows the room recording duration in seconds.
-
#ended_at ⇒ Time?
ISO 8601 timestamp when the room recording has ended.
-
#id ⇒ String?
A unique identifier for the room recording.
-
#participant_id ⇒ String?
Identify the room participant associated with the room recording.
-
#room_id ⇒ String?
Identify the room associated with the room recording.
-
#session_id ⇒ String?
Identify the room session associated with the room recording.
-
#size_mb ⇒ Float?
Shows the room recording size in MB.
-
#started_at ⇒ Time?
ISO 8601 timestamp when the room recording has stated.
-
#status ⇒ Symbol, ...
Shows the room recording status.
-
#type ⇒ Symbol, ...
Shows the room recording type.
-
#updated_at ⇒ Time?
ISO 8601 timestamp when the room recording was updated.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, codec: nil, completed_at: nil, created_at: nil, download_url: nil, duration_secs: nil, ended_at: nil, participant_id: nil, record_type: nil, room_id: nil, session_id: nil, size_mb: nil, started_at: nil, status: nil, type: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 114
|
Instance Attribute Details
#codec ⇒ String?
Shows the codec used for the room recording.
27 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 27 optional :codec, String |
#completed_at ⇒ Time?
ISO 8601 timestamp when the room recording has completed.
33 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 33 optional :completed_at, Time |
#created_at ⇒ Time?
ISO 8601 timestamp when the room recording was created.
39 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 39 optional :created_at, Time |
#download_url ⇒ String?
Url to download the recording.
45 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 45 optional :download_url, String |
#duration_secs ⇒ Integer?
Shows the room recording duration in seconds.
51 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 51 optional :duration_secs, Integer |
#ended_at ⇒ Time?
ISO 8601 timestamp when the room recording has ended.
57 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 57 optional :ended_at, Time |
#id ⇒ String?
A unique identifier for the room recording.
21 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 21 optional :id, String |
#participant_id ⇒ String?
Identify the room participant associated with the room recording.
63 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 63 optional :participant_id, String |
#room_id ⇒ String?
Identify the room associated with the room recording.
69 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 69 optional :room_id, String |
#session_id ⇒ String?
Identify the room session associated with the room recording.
75 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 75 optional :session_id, String |
#size_mb ⇒ Float?
Shows the room recording size in MB.
81 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 81 optional :size_mb, Float |
#started_at ⇒ Time?
ISO 8601 timestamp when the room recording has stated.
87 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 87 optional :started_at, Time |
#status ⇒ Symbol, ...
Shows the room recording status.
93 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 93 optional :status, enum: -> { Telnyx::Models::RoomRecordingRetrieveResponse::Data::Status } |
#type ⇒ Symbol, ...
Shows the room recording type.
99 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 99 optional :type, enum: -> { Telnyx::Models::RoomRecordingRetrieveResponse::Data::Type } |
#updated_at ⇒ Time?
ISO 8601 timestamp when the room recording was updated.
105 |
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 105 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/room_recording_retrieve_response.rb', line 156
|