Class: Telnyx::Models::RoomSession

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/room_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, active: nil, created_at: nil, ended_at: nil, participants: nil, record_type: nil, room_id: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    A unique identifier for the room session.

  • active (Boolean) (defaults to: nil)

    Shows if the room session is active or not.

  • created_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the room session was created.

  • ended_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the room session has ended.

  • participants (Array<Telnyx::Models::RoomParticipant>) (defaults to: nil)
  • record_type (String) (defaults to: nil)
  • room_id (String) (defaults to: nil)

    Identify the room hosting that room session.

  • updated_at (Time) (defaults to: nil)

    ISO 8601 timestamp when the room session was updated.



# File 'lib/telnyx/models/room_session.rb', line 54

Instance Attribute Details

#activeBoolean?

Shows if the room session is active or not.

Returns:

  • (Boolean, nil)


16
# File 'lib/telnyx/models/room_session.rb', line 16

optional :active, Telnyx::Internal::Type::Boolean

#created_atTime?

ISO 8601 timestamp when the room session was created.

Returns:

  • (Time, nil)


22
# File 'lib/telnyx/models/room_session.rb', line 22

optional :created_at, Time

#ended_atTime?

ISO 8601 timestamp when the room session has ended.

Returns:

  • (Time, nil)


28
# File 'lib/telnyx/models/room_session.rb', line 28

optional :ended_at, Time

#idString?

A unique identifier for the room session.

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/room_session.rb', line 10

optional :id, String

#participantsArray<Telnyx::Models::RoomParticipant>?

Returns:



33
# File 'lib/telnyx/models/room_session.rb', line 33

optional :participants, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::RoomParticipant] }

#room_idString?

Identify the room hosting that room session.

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/room_session.rb', line 39

optional :room_id, String

#updated_atTime?

ISO 8601 timestamp when the room session was updated.

Returns:

  • (Time, nil)


45
# File 'lib/telnyx/models/room_session.rb', line 45

optional :updated_at, Time