Class: Telnyx::Models::Rooms::ActionGenerateJoinClientTokenParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Rooms::ActionGenerateJoinClientTokenParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/rooms/action_generate_join_client_token_params.rb
Overview
Instance Attribute Summary collapse
-
#refresh_token_ttl_secs ⇒ Integer?
The time to live in seconds of the Refresh Token, after that time the Refresh Token is invalid and can’t be used to refresh Client Token.
- #room_id ⇒ String
-
#token_ttl_secs ⇒ Integer?
The time to live in seconds of the Client Token, after that time the Client Token is invalid and can’t be used to join a Room.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(room_id:, refresh_token_ttl_secs: nil, token_ttl_secs: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionGenerateJoinClientTokenParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(room_id:, refresh_token_ttl_secs: nil, token_ttl_secs: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Rooms::ActionGenerateJoinClientTokenParams for more details.
|
|
# File 'lib/telnyx/models/rooms/action_generate_join_client_token_params.rb', line 30
|
Instance Attribute Details
#refresh_token_ttl_secs ⇒ Integer?
The time to live in seconds of the Refresh Token, after that time the Refresh Token is invalid and can’t be used to refresh Client Token.
21 |
# File 'lib/telnyx/models/rooms/action_generate_join_client_token_params.rb', line 21 optional :refresh_token_ttl_secs, Integer |
#room_id ⇒ String
14 |
# File 'lib/telnyx/models/rooms/action_generate_join_client_token_params.rb', line 14 required :room_id, String |
#token_ttl_secs ⇒ Integer?
The time to live in seconds of the Client Token, after that time the Client Token is invalid and can’t be used to join a Room.
28 |
# File 'lib/telnyx/models/rooms/action_generate_join_client_token_params.rb', line 28 optional :token_ttl_secs, Integer |