Class: Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateJoinedAt
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateJoinedAt
- Defined in:
- lib/telnyx/models/rooms/session_retrieve_participants_params.rb,
sig/telnyx/models/rooms/session_retrieve_participants_params.rbs
Overview
Instance Attribute Summary collapse
-
#eq ⇒ Date?
ISO 8601 date for filtering room participants that joined on that date.
-
#gte ⇒ Date?
ISO 8601 date for filtering room participants that joined on or after that date.
-
#lte ⇒ Date?
ISO 8601 date for filtering room participants that joined on or before that date.
Instance Method Summary collapse
-
#initialize ⇒ DateJoinedAt
constructor
A new instance of DateJoinedAt.
- #to_hash ⇒ { eq: Date, gte: Date, lte: Date }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ DateJoinedAt
Returns a new instance of DateJoinedAt.
109 |
# File 'sig/telnyx/models/rooms/session_retrieve_participants_params.rbs', line 109 def initialize: (?eq: Date, ?gte: Date, ?lte: Date) -> void |
Instance Attribute Details
#eq ⇒ Date?
ISO 8601 date for filtering room participants that joined on that date.
95 |
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 95 optional :eq, Date |
#gte ⇒ Date?
ISO 8601 date for filtering room participants that joined on or after that date.
101 |
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 101 optional :gte, Date |
#lte ⇒ Date?
ISO 8601 date for filtering room participants that joined on or before that date.
108 |
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 108 optional :lte, Date |
Instance Method Details
#to_hash ⇒ { eq: Date, gte: Date, lte: Date }
111 |
# File 'sig/telnyx/models/rooms/session_retrieve_participants_params.rbs', line 111 def to_hash: -> { eq: Date, gte: Date, lte: Date } |