Class: Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateLeftAt
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Rooms::SessionRetrieveParticipantsParams::Filter::DateLeftAt
- Defined in:
- lib/telnyx/models/rooms/session_retrieve_participants_params.rb,
sig/telnyx/models/rooms/session_retrieve_participants_params.rbs
Overview
Instance Attribute Summary collapse
-
#eq ⇒ Date?
ISO 8601 date for filtering room participants that left on that date.
-
#gte ⇒ Date?
ISO 8601 date for filtering room participants that left on or after that date.
-
#lte ⇒ Date?
ISO 8601 date for filtering room participants that left on or before that date.
Instance Method Summary collapse
-
#initialize ⇒ DateLeftAt
constructor
A new instance of DateLeftAt.
- #to_hash ⇒ { eq: Date, gte: Date, lte: Date }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ DateLeftAt
Returns a new instance of DateLeftAt.
129 |
# File 'sig/telnyx/models/rooms/session_retrieve_participants_params.rbs', line 129
def initialize: (?eq: Date, ?gte: Date, ?lte: Date) -> void
|
Instance Attribute Details
#eq ⇒ Date?
ISO 8601 date for filtering room participants that left on that date.
128 |
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 128 optional :eq, Date |
#gte ⇒ Date?
ISO 8601 date for filtering room participants that left on or after that date.
134 |
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 134 optional :gte, Date |
#lte ⇒ Date?
ISO 8601 date for filtering room participants that left on or before that date.
140 |
# File 'lib/telnyx/models/rooms/session_retrieve_participants_params.rb', line 140 optional :lte, Date |
Instance Method Details
#to_hash ⇒ { eq: Date, gte: Date, lte: Date }
131 |
# File 'sig/telnyx/models/rooms/session_retrieve_participants_params.rbs', line 131
def to_hash: -> { eq: Date, gte: Date, lte: Date }
|