Class: Telnyx::Models::S3ConfigurationData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::S3ConfigurationData
- Defined in:
- lib/telnyx/models/s3_configuration_data.rb
Defined Under Namespace
Modules: Backend
Instance Attribute Summary collapse
-
#aws_access_key_id ⇒ String?
AWS credentials access key id.
-
#aws_secret_access_key ⇒ String?
AWS secret access key.
-
#backend ⇒ Symbol, Telnyx::Models::S3ConfigurationData::Backend
Storage backend type.
-
#bucket ⇒ String?
Name of the bucket to be used to store recording files.
-
#region ⇒ String?
Region where the bucket is located.
Instance Method Summary collapse
- #initialize(backend:, aws_access_key_id: nil, aws_secret_access_key: nil, bucket: nil, region: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(backend:, aws_access_key_id: nil, aws_secret_access_key: nil, bucket: nil, region: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/s3_configuration_data.rb', line 36
|
Instance Attribute Details
#aws_access_key_id ⇒ String?
AWS credentials access key id.
16 |
# File 'lib/telnyx/models/s3_configuration_data.rb', line 16 optional :aws_access_key_id, String |
#aws_secret_access_key ⇒ String?
AWS secret access key.
22 |
# File 'lib/telnyx/models/s3_configuration_data.rb', line 22 optional :aws_secret_access_key, String |
#backend ⇒ Symbol, Telnyx::Models::S3ConfigurationData::Backend
Storage backend type
10 |
# File 'lib/telnyx/models/s3_configuration_data.rb', line 10 required :backend, enum: -> { Telnyx::S3ConfigurationData::Backend } |
#bucket ⇒ String?
Name of the bucket to be used to store recording files.
28 |
# File 'lib/telnyx/models/s3_configuration_data.rb', line 28 optional :bucket, String |
#region ⇒ String?
Region where the bucket is located.
34 |
# File 'lib/telnyx/models/s3_configuration_data.rb', line 34 optional :region, String |