Class: Telnyx::Models::SessionStatusChangedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SessionStatusChangedWebhookEvent
- Defined in:
- lib/telnyx/models/session_status_changed_webhook_event.rb,
sig/telnyx/models/session_status_changed_webhook_event.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#data ⇒ Telnyx::Models::SessionStatusChangedWebhookEvent::Data
Status transition details.
-
#event ⇒ Symbol, Telnyx::Models::SessionStatusChangedWebhookEvent::Event
Event type.
-
#id ⇒ String
Unique event id; deduplicate deliveries on it.
-
#occurred_at ⇒ Time
When the event occurred.
-
#version ⇒ String
Envelope version.
Instance Method Summary collapse
-
#initialize(recording:, session_id:, status:, status_detail:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(recording:, session_id:, status:, status_detail:) ⇒ Object
Some parameter documentations has been truncated, see Data for more details.
Status transition details.
|
|
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 36
|
Instance Attribute Details
#data ⇒ Telnyx::Models::SessionStatusChangedWebhookEvent::Data
Status transition details.
16 |
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 16 required :data, -> { Telnyx::SessionStatusChangedWebhookEvent::Data } |
#event ⇒ Symbol, Telnyx::Models::SessionStatusChangedWebhookEvent::Event
Event type.
22 |
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 22 required :event, enum: -> { Telnyx::SessionStatusChangedWebhookEvent::Event } |
#id ⇒ String
Unique event id; deduplicate deliveries on it.
10 |
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 10 required :id, String |
#occurred_at ⇒ Time
When the event occurred.
28 |
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 28 required :occurred_at, Time |
#version ⇒ String
Envelope version.
34 |
# File 'lib/telnyx/models/session_status_changed_webhook_event.rb', line 34 required :version, String |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/telnyx/models/session_status_changed_webhook_event.rbs', line 31
def to_hash: -> {
|