Class: Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse::Data
- Defined in:
- lib/telnyx/models/seti_retrieve_black_box_test_results_response.rb
Defined Under Namespace
Classes: BlackBoxTest
Instance Attribute Summary collapse
- #black_box_tests ⇒ Array<Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse::Data::BlackBoxTest>?
-
#product ⇒ String?
The product associated with the black box test group.
- #record_type ⇒ String?
Instance Method Summary collapse
- #initialize(data: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data: nil) ⇒ Object
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/telnyx/models/seti_retrieve_black_box_test_results_response.rb', line 16 class Data < Telnyx::Internal::Type::BaseModel # @!attribute black_box_tests # # @return [Array<Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse::Data::BlackBoxTest>, nil] optional :black_box_tests, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse::Data::BlackBoxTest] } # @!attribute product # The product associated with the black box test group. # # @return [String, nil] optional :product, String # @!attribute record_type # # @return [String, nil] optional :record_type, String # @!method initialize(black_box_tests: nil, product: nil, record_type: nil) # @param black_box_tests [Array<Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse::Data::BlackBoxTest>] # # @param product [String] The product associated with the black box test group. # # @param record_type [String] class BlackBoxTest < Telnyx::Internal::Type::BaseModel # @!attribute id # The name of the black box test. # # @return [String, nil] optional :id, String # @!attribute record_type # # @return [String, nil] optional :record_type, String # @!attribute result # The average result of the black box test over the last hour. # # @return [Float, nil] optional :result, Float # @!method initialize(id: nil, record_type: nil, result: nil) # @param id [String] The name of the black box test. # # @param record_type [String] # # @param result [Float] The average result of the black box test over the last hour. end end |
Instance Attribute Details
#black_box_tests ⇒ Array<Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse::Data::BlackBoxTest>?
20 21 |
# File 'lib/telnyx/models/seti_retrieve_black_box_test_results_response.rb', line 20 optional :black_box_tests, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::SetiRetrieveBlackBoxTestResultsResponse::Data::BlackBoxTest] } |
#product ⇒ String?
The product associated with the black box test group.
27 |
# File 'lib/telnyx/models/seti_retrieve_black_box_test_results_response.rb', line 27 optional :product, String |
#record_type ⇒ String?
32 |
# File 'lib/telnyx/models/seti_retrieve_black_box_test_results_response.rb', line 32 optional :record_type, String |