Class: Telnyx::Models::SimCardGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimCardGroup
- Defined in:
- lib/telnyx/models/sim_card_group.rb,
sig/telnyx/models/sim_card_group.rbs
Defined Under Namespace
Classes: DataLimit
Instance Attribute Summary collapse
-
#consumed_data ⇒ Telnyx::Models::ConsumedData?
Represents the amount of data consumed.
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#data_limit ⇒ Telnyx::Models::SimCardGroup::DataLimit?
Upper limit on the amount of data the SIM cards, within the group, can use.
-
#default ⇒ Boolean?
readonly
Returns the value of attribute default.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#name ⇒ String?
A user friendly name for the SIM card group.
-
#private_wireless_gateway_id ⇒ String?
The identification of the related Private Wireless Gateway resource.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
-
#wireless_blocklist_id ⇒ String?
The identification of the related Wireless Blocklist resource.
Instance Method Summary collapse
- #created_at ⇒ String readonly
- #default ⇒ Boolean readonly
- #id ⇒ String readonly
-
#initialize(id: nil, consumed_data: nil, created_at: nil, data_limit: nil, default: nil, name: nil, private_wireless_gateway_id: nil, record_type: nil, updated_at: nil, wireless_blocklist_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SimCardGroup for more details.
- #record_type ⇒ String readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, consumed_data: nil, created_at: nil, data_limit: nil, default: nil, name: nil, private_wireless_gateway_id: nil, record_type: nil, updated_at: nil, wireless_blocklist_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::SimCardGroup for more details.
|
|
# File 'lib/telnyx/models/sim_card_group.rb', line 69
|
Instance Attribute Details
#consumed_data ⇒ Telnyx::Models::ConsumedData?
Represents the amount of data consumed.
10 |
# File 'lib/telnyx/models/sim_card_group.rb', line 10 optional :consumed_data, -> { Telnyx::ConsumedData } |
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
44 45 46 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 44 def created_at @created_at end |
#data_limit ⇒ Telnyx::Models::SimCardGroup::DataLimit?
Upper limit on the amount of data the SIM cards, within the group, can use.
16 |
# File 'lib/telnyx/models/sim_card_group.rb', line 16 optional :data_limit, -> { Telnyx::SimCardGroup::DataLimit } |
#default ⇒ Boolean? (readonly)
Returns the value of attribute default.
48 49 50 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 48 def default @default end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
40 41 42 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 40 def id @id end |
#name ⇒ String?
A user friendly name for the SIM card group.
22 |
# File 'lib/telnyx/models/sim_card_group.rb', line 22 optional :name, String |
#private_wireless_gateway_id ⇒ String?
The identification of the related Private Wireless Gateway resource.
28 |
# File 'lib/telnyx/models/sim_card_group.rb', line 28 optional :private_wireless_gateway_id, String |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
52 53 54 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 52 def record_type @record_type end |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
56 57 58 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 56 def updated_at @updated_at end |
#wireless_blocklist_id ⇒ String?
The identification of the related Wireless Blocklist resource.
34 |
# File 'lib/telnyx/models/sim_card_group.rb', line 34 optional :wireless_blocklist_id, String |
Instance Method Details
#created_at= ⇒ String (readonly)
46 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 46
def created_at=: (String) -> String
|
#default= ⇒ Boolean (readonly)
50 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 50
def default=: (bool) -> bool
|
#id= ⇒ String (readonly)
42 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 42
def id=: (String) -> String
|
#record_type= ⇒ String (readonly)
54 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 54
def record_type=: (String) -> String
|
#to_hash ⇒ {
73 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 73
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
58 |
# File 'sig/telnyx/models/sim_card_group.rbs', line 58
def updated_at=: (String) -> String
|