Class: Telnyx::Models::SimCardGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimCardGroup
- Defined in:
- lib/telnyx/models/sim_card_group.rb
Defined Under Namespace
Classes: DataLimit
Instance Attribute Summary collapse
-
#consumed_data ⇒ Telnyx::Models::ConsumedData?
Represents the amount of data consumed.
-
#data_limit ⇒ Telnyx::Models::SimCardGroup::DataLimit?
Upper limit on the amount of data the SIM cards, within the group, can use.
-
#name ⇒ String?
A user friendly name for the SIM card group.
-
#private_wireless_gateway_id ⇒ String?
The identification of the related Private Wireless Gateway resource.
-
#wireless_blocklist_id ⇒ String?
The identification of the related Wireless Blocklist resource.
Instance Method Summary collapse
-
#initialize(id: nil, consumed_data: nil, created_at: nil, data_limit: nil, default: nil, name: nil, private_wireless_gateway_id: nil, record_type: nil, updated_at: nil, wireless_blocklist_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SimCardGroup for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, consumed_data: nil, created_at: nil, data_limit: nil, default: nil, name: nil, private_wireless_gateway_id: nil, record_type: nil, updated_at: nil, wireless_blocklist_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::SimCardGroup for more details.
|
|
# File 'lib/telnyx/models/sim_card_group.rb', line 69
|
Instance Attribute Details
#consumed_data ⇒ Telnyx::Models::ConsumedData?
Represents the amount of data consumed.
10 |
# File 'lib/telnyx/models/sim_card_group.rb', line 10 optional :consumed_data, -> { Telnyx::ConsumedData } |
#data_limit ⇒ Telnyx::Models::SimCardGroup::DataLimit?
Upper limit on the amount of data the SIM cards, within the group, can use.
16 |
# File 'lib/telnyx/models/sim_card_group.rb', line 16 optional :data_limit, -> { Telnyx::SimCardGroup::DataLimit } |
#name ⇒ String?
A user friendly name for the SIM card group.
22 |
# File 'lib/telnyx/models/sim_card_group.rb', line 22 optional :name, String |
#private_wireless_gateway_id ⇒ String?
The identification of the related Private Wireless Gateway resource.
28 |
# File 'lib/telnyx/models/sim_card_group.rb', line 28 optional :private_wireless_gateway_id, String |
#wireless_blocklist_id ⇒ String?
The identification of the related Wireless Blocklist resource.
34 |
# File 'lib/telnyx/models/sim_card_group.rb', line 34 optional :wireless_blocklist_id, String |