Class: Telnyx::Models::SimCardGroupListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sim_card_group_list_response.rb

Overview

Defined Under Namespace

Classes: DataLimit

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, consumed_data: nil, created_at: nil, data_limit: nil, default: nil, name: nil, private_wireless_gateway_id: nil, record_type: nil, sim_card_count: nil, updated_at: nil, wireless_blocklist_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SimCardGroupListResponse for more details.

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • consumed_data (Telnyx::Models::ConsumedData) (defaults to: nil)

    Represents the amount of data consumed.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • data_limit (Telnyx::Models::SimCardGroupListResponse::DataLimit) (defaults to: nil)

    Upper limit on the amount of data the SIM cards, within the group, can use.

  • default (Boolean) (defaults to: nil)

    Indicates whether the SIM card group is the users default group.<br/>The default

  • name (String) (defaults to: nil)

    A user friendly name for the SIM card group.

  • private_wireless_gateway_id (String) (defaults to: nil)

    The identification of the related Private Wireless Gateway resource.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • sim_card_count (Integer) (defaults to: nil)

    The number of SIM cards associated with the group.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.

  • wireless_blocklist_id (String) (defaults to: nil)

    The identification of the related Wireless Blocklist resource.



# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 76

Instance Attribute Details

#consumed_dataTelnyx::Models::ConsumedData?

Represents the amount of data consumed.



11
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 11

optional :consumed_data, -> { Telnyx::ConsumedData }

#data_limitTelnyx::Models::SimCardGroupListResponse::DataLimit?

Upper limit on the amount of data the SIM cards, within the group, can use.



17
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 17

optional :data_limit, -> { Telnyx::Models::SimCardGroupListResponse::DataLimit }

#nameString?

A user friendly name for the SIM card group.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 23

optional :name, String

#private_wireless_gateway_idString?

The identification of the related Private Wireless Gateway resource.

Returns:

  • (String, nil)


29
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 29

optional :private_wireless_gateway_id, String

#sim_card_countInteger?

The number of SIM cards associated with the group.

Returns:

  • (Integer, nil)


35
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 35

optional :sim_card_count, Integer

#wireless_blocklist_idString?

The identification of the related Wireless Blocklist resource.

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/sim_card_group_list_response.rb', line 41

optional :wireless_blocklist_id, String