Class: Telnyx::Models::SimCardListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimCardListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/sim_card_list_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#filter ⇒ Telnyx::Models::SimCardListParams::Filter?
Consolidated filter parameter for SIM cards (deepObject style).
-
#filter_sim_card_group_id ⇒ String?
A valid SIM card group ID.
-
#include_sim_card_group ⇒ Boolean?
It includes the associated SIM card group object in the response when present.
- #page_number ⇒ Integer?
- #page_size ⇒ Integer?
-
#sort ⇒ Symbol, ...
Sorts SIM cards by the given field.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#filter ⇒ Telnyx::Models::SimCardListParams::Filter?
15 |
# File 'lib/telnyx/models/sim_card_list_params.rb', line 15 optional :filter, -> { Telnyx::SimCardListParams::Filter } |
#filter_sim_card_group_id ⇒ String?
A valid SIM card group ID.
21 |
# File 'lib/telnyx/models/sim_card_list_params.rb', line 21 optional :filter_sim_card_group_id, String |
#include_sim_card_group ⇒ Boolean?
It includes the associated SIM card group object in the response when present.
27 |
# File 'lib/telnyx/models/sim_card_list_params.rb', line 27 optional :include_sim_card_group, Telnyx::Internal::Type::Boolean |
#page_number ⇒ Integer?
32 |
# File 'lib/telnyx/models/sim_card_list_params.rb', line 32 optional :page_number, Integer |
#page_size ⇒ Integer?
37 |
# File 'lib/telnyx/models/sim_card_list_params.rb', line 37 optional :page_size, Integer |
#sort ⇒ Symbol, ...
Sorts SIM cards by the given field. Defaults to ascending order unless field is prefixed with a minus sign.
44 |
# File 'lib/telnyx/models/sim_card_list_params.rb', line 44 optional :sort, enum: -> { Telnyx::SimCardListParams::Sort } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/sim_card_list_params.rb', line 121
|