Class: Telnyx::Models::SimCardListWirelessConnectivityLogsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rb

Overview

Defined Under Namespace

Modules: LogType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, apn: nil, cell_id: nil, created_at: nil, imei: nil, imsi: nil, ipv4: nil, ipv6: nil, last_seen: nil, log_type: nil, mobile_country_code: nil, mobile_network_code: nil, radio_access_technology: nil, record_type: nil, sim_card_id: nil, start_time: nil, state: nil, stop_time: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SimCardListWirelessConnectivityLogsResponse for more details.

This object represents a wireless connectivity session log that happened through a SIM card. It aids in finding out potential problems when the SIM is not able to attach properly.

Parameters:

  • id (Integer) (defaults to: nil)

    Uniquely identifies the session.

  • apn (String) (defaults to: nil)

    The Access Point Name (APN) identifies the packet data network that a mobile dat

  • cell_id (String) (defaults to: nil)

    The cell ID to which the SIM connected.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the record was created.

  • imei (String) (defaults to: nil)

    The International Mobile Equipment Identity (or IMEI) is a number, usually uniqu

  • imsi (String) (defaults to: nil)

    SIM cards are identified on their individual network operators by a unique Inter

  • ipv4 (String) (defaults to: nil)

    The SIM’s address in the currently connected network. This IPv4 address is usual

  • ipv6 (String) (defaults to: nil)

    The SIM’s address in the currently connected network. This IPv6 address is usual

  • last_seen (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the last heartbeat to the device wa

  • log_type (Symbol, Telnyx::Models::SimCardListWirelessConnectivityLogsResponse::LogType) (defaults to: nil)

    The type of the session, ‘registration’ being the initial authentication session

  • mobile_country_code (String) (defaults to: nil)

    It’s a three decimal digit that identifies a country.<br/><br/>

  • mobile_network_code (String) (defaults to: nil)

    It’s a two to three decimal digits that identify a network.<br/><br/>

  • radio_access_technology (String) (defaults to: nil)

    The radio technology the SIM card used during the session.

  • record_type (String) (defaults to: nil)
  • sim_card_id (String) (defaults to: nil)

    The identification UUID of the related SIM card resource.

  • start_time (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the session started.

  • state (String) (defaults to: nil)

    The state of the SIM card after when the session happened.

  • stop_time (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the session ended.



# File 'lib/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rb', line 134

Instance Attribute Details

#sim_card_idString?

The identification UUID of the related SIM card resource.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rb', line 11

optional :sim_card_id, String