Class: Telnyx::Models::SimCardListWirelessConnectivityLogsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimCardListWirelessConnectivityLogsResponse
- Defined in:
- lib/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rb
Overview
Defined Under Namespace
Modules: LogType
Instance Attribute Summary collapse
-
#sim_card_id ⇒ String?
The identification UUID of the related SIM card resource.
Instance Method Summary collapse
-
#initialize(id: nil, apn: nil, cell_id: nil, created_at: nil, imei: nil, imsi: nil, ipv4: nil, ipv6: nil, last_seen: nil, log_type: nil, mobile_country_code: nil, mobile_network_code: nil, radio_access_technology: nil, record_type: nil, sim_card_id: nil, start_time: nil, state: nil, stop_time: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SimCardListWirelessConnectivityLogsResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, apn: nil, cell_id: nil, created_at: nil, imei: nil, imsi: nil, ipv4: nil, ipv6: nil, last_seen: nil, log_type: nil, mobile_country_code: nil, mobile_network_code: nil, radio_access_technology: nil, record_type: nil, sim_card_id: nil, start_time: nil, state: nil, stop_time: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::SimCardListWirelessConnectivityLogsResponse for more details.
This object represents a wireless connectivity session log that happened through a SIM card. It aids in finding out potential problems when the SIM is not able to attach properly.
|
|
# File 'lib/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rb', line 134
|
Instance Attribute Details
#sim_card_id ⇒ String?
The identification UUID of the related SIM card resource.
11 |
# File 'lib/telnyx/models/sim_card_list_wireless_connectivity_logs_response.rb', line 11 optional :sim_card_id, String |