Class: Telnyx::Models::SimCardOrder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimCardOrder
- Defined in:
- lib/telnyx/models/sim_card_order.rb,
sig/telnyx/models/sim_card_order.rbs
Overview
Defined Under Namespace
Modules: Status Classes: Cost, OrderAddress
Instance Attribute Summary collapse
-
#cost ⇒ Telnyx::Models::SimCardOrder::Cost?
An object representing the total cost of the order.
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#order_address ⇒ Telnyx::SimCardOrder::OrderAddress?
readonly
Returns the value of attribute order_address.
-
#quantity ⇒ Integer?
The amount of SIM cards requested in the SIM card order.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#status ⇒ Symbol, ...
The current status of the SIM Card order.
pending- the order is waiting to be processed.processing- the order is currently being processed.ready_to_ship- the order is ready to be shipped to the specified address.shipped- the order was shipped and is on its way to be delivered to the specified address.delivered- the order was delivered to the specified address.canceled- the order was canceled.
-
#tracking_url ⇒ String?
The URL used to get tracking information about the order.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Instance Method Summary collapse
- #created_at ⇒ String readonly
- #id ⇒ String readonly
-
#initialize(id: nil, administrative_area: nil, business_name: nil, country_code: nil, extended_address: nil, first_name: nil, last_name: nil, locality: nil, postal_code: nil, street_address: nil) ⇒ Object
constructor
An object representing the address information from when the order was submitted.
- #order_address ⇒ Object readonly
- #record_type ⇒ String readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, administrative_area: nil, business_name: nil, country_code: nil, extended_address: nil, first_name: nil, last_name: nil, locality: nil, postal_code: nil, street_address: nil) ⇒ Object
An object representing the address information from when the order was submitted.
|
|
# File 'lib/telnyx/models/sim_card_order.rb', line 71
|
Instance Attribute Details
#cost ⇒ Telnyx::Models::SimCardOrder::Cost?
An object representing the total cost of the order.
11 |
# File 'lib/telnyx/models/sim_card_order.rb', line 11 optional :cost, -> { Telnyx::SimCardOrder::Cost } |
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
39 40 41 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 39 def created_at @created_at end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
35 36 37 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 35 def id @id end |
#order_address ⇒ Telnyx::SimCardOrder::OrderAddress? (readonly)
Returns the value of attribute order_address.
43 44 45 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 43 def order_address @order_address end |
#quantity ⇒ Integer?
The amount of SIM cards requested in the SIM card order.
17 |
# File 'lib/telnyx/models/sim_card_order.rb', line 17 optional :quantity, Integer |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
49 50 51 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 49 def record_type @record_type end |
#status ⇒ Symbol, ...
The current status of the SIM Card order.
pending- the order is waiting to be processed.processing- the order is currently being processed.ready_to_ship- the order is ready to be shipped to the specified address.shipped- the order was shipped and is on its way to be delivered to the specified address.delivered- the order was delivered to the specified address.canceled- the order was canceled.
30 |
# File 'lib/telnyx/models/sim_card_order.rb', line 30 optional :status, enum: -> { Telnyx::SimCardOrder::Status } |
#tracking_url ⇒ String?
The URL used to get tracking information about the order.
36 |
# File 'lib/telnyx/models/sim_card_order.rb', line 36 optional :tracking_url, String |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
53 54 55 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 53 def updated_at @updated_at end |
Instance Method Details
#created_at= ⇒ String (readonly)
41 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 41
def created_at=: (String) -> String
|
#id= ⇒ String (readonly)
37 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 37
def id=: (String) -> String
|
#order_address= ⇒ Object (readonly)
45 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 45
def order_address=: (
|
#record_type= ⇒ String (readonly)
51 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 51
def record_type=: (String) -> String
|
#to_hash ⇒ {
69 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 69
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
55 |
# File 'sig/telnyx/models/sim_card_order.rbs', line 55
def updated_at=: (String) -> String
|