Class: Telnyx::Models::SimCardOrder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sim_card_order.rb

Overview

Defined Under Namespace

Modules: Status Classes: Cost, OrderAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, administrative_area: nil, business_name: nil, country_code: nil, extended_address: nil, first_name: nil, last_name: nil, locality: nil, postal_code: nil, street_address: nil) ⇒ Object

An object representing the address information from when the order was submitted.

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the address for the order.

  • administrative_area (String) (defaults to: nil)

    State or province where the address is located.

  • business_name (String) (defaults to: nil)

    The name of the business where the address is located.

  • country_code (String) (defaults to: nil)

    The mobile operator two-character (ISO 3166-1 alpha-2) origin country code.

  • extended_address (String) (defaults to: nil)

    Supplemental field for address information.

  • first_name (String) (defaults to: nil)

    The first name of the shipping recipient.

  • last_name (String) (defaults to: nil)

    The last name of the shipping recipient.

  • locality (String) (defaults to: nil)

    The name of the city where the address is located.

  • postal_code (String) (defaults to: nil)

    Postal code for the address.

  • street_address (String) (defaults to: nil)

    The name of the street where the address is located.



# File 'lib/telnyx/models/sim_card_order.rb', line 71

Instance Attribute Details

#costTelnyx::Models::SimCardOrder::Cost?

An object representing the total cost of the order.



11
# File 'lib/telnyx/models/sim_card_order.rb', line 11

optional :cost, -> { Telnyx::SimCardOrder::Cost }

#quantityInteger?

The amount of SIM cards requested in the SIM card order.

Returns:

  • (Integer, nil)


17
# File 'lib/telnyx/models/sim_card_order.rb', line 17

optional :quantity, Integer

#statusSymbol, ...

The current status of the SIM Card order.<ul> <li>pending - the order is waiting to be processed.</li> <li>processing - the order is currently being processed.</li> <li>ready_to_ship - the order is ready to be shipped to the specified address.</li> <li>shipped - the order was shipped and is on its way to be delivered to the specified address.</li> <li>delivered - the order was delivered to the specified address.</li> <li>canceled - the order was canceled.</li> </ul>

Returns:



30
# File 'lib/telnyx/models/sim_card_order.rb', line 30

optional :status, enum: -> { Telnyx::SimCardOrder::Status }

#tracking_urlString?

The URL used to get tracking information about the order.

Returns:

  • (String, nil)


36
# File 'lib/telnyx/models/sim_card_order.rb', line 36

optional :tracking_url, String