Class: Telnyx::Models::SimCardOrder::OrderAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimCardOrder::OrderAddress
- Defined in:
- lib/telnyx/models/sim_card_order.rb
Overview
Instance Attribute Summary collapse
-
#administrative_area ⇒ String?
State or province where the address is located.
-
#business_name ⇒ String?
The name of the business where the address is located.
-
#country_code ⇒ String?
The mobile operator two-character (ISO 3166-1 alpha-2) origin country code.
-
#extended_address ⇒ String?
Supplemental field for address information.
-
#first_name ⇒ String?
The first name of the shipping recipient.
-
#id ⇒ String?
Uniquely identifies the address for the order.
-
#last_name ⇒ String?
The last name of the shipping recipient.
-
#locality ⇒ String?
The name of the city where the address is located.
-
#postal_code ⇒ String?
Postal code for the address.
-
#street_address ⇒ String?
The name of the street where the address is located.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#administrative_area ⇒ String?
State or province where the address is located.
127 |
# File 'lib/telnyx/models/sim_card_order.rb', line 127 optional :administrative_area, String |
#business_name ⇒ String?
The name of the business where the address is located.
133 |
# File 'lib/telnyx/models/sim_card_order.rb', line 133 optional :business_name, String |
#country_code ⇒ String?
The mobile operator two-character (ISO 3166-1 alpha-2) origin country code.
139 |
# File 'lib/telnyx/models/sim_card_order.rb', line 139 optional :country_code, String |
#extended_address ⇒ String?
Supplemental field for address information.
145 |
# File 'lib/telnyx/models/sim_card_order.rb', line 145 optional :extended_address, String |
#first_name ⇒ String?
The first name of the shipping recipient.
151 |
# File 'lib/telnyx/models/sim_card_order.rb', line 151 optional :first_name, String |
#id ⇒ String?
Uniquely identifies the address for the order.
121 |
# File 'lib/telnyx/models/sim_card_order.rb', line 121 optional :id, String |
#last_name ⇒ String?
The last name of the shipping recipient.
157 |
# File 'lib/telnyx/models/sim_card_order.rb', line 157 optional :last_name, String |
#locality ⇒ String?
The name of the city where the address is located.
163 |
# File 'lib/telnyx/models/sim_card_order.rb', line 163 optional :locality, String |
#postal_code ⇒ String?
Postal code for the address.
169 |
# File 'lib/telnyx/models/sim_card_order.rb', line 169 optional :postal_code, String |
#street_address ⇒ String?
The name of the street where the address is located.
175 |
# File 'lib/telnyx/models/sim_card_order.rb', line 175 optional :street_address, String |