Class: Telnyx::Models::SimCardOrderListParams::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimCardOrderListParams::Filter
- Defined in:
- lib/telnyx/models/sim_card_order_list_params.rb,
sig/telnyx/models/sim_card_order_list_params.rbs
Instance Attribute Summary collapse
-
#address_administrative_area ⇒ String?
Filter by state or province where the address is located.
-
#address_country_code ⇒ String?
Filter by the mobile operator two-character (ISO 3166-1 alpha-2) origin country code.
-
#address_extended_address ⇒ String?
Returns entries with matching name of the supplemental field for address information.
-
#address_id ⇒ String?
Uniquely identifies the address for the order.
-
#address_locality ⇒ String?
Filter by the name of the city where the address is located.
-
#address_postal_code ⇒ String?
Filter by postal code for the address.
-
#address_street_address ⇒ String?
Returns entries with matching name of the street where the address is located.
-
#cost_amount ⇒ String?
The total monetary amount of the order.
-
#cost_currency ⇒ String?
Filter by ISO 4217 currency string.
-
#created_at ⇒ Time?
Filter by ISO 8601 formatted date-time string matching resource creation date-time.
-
#quantity ⇒ Integer?
Filter orders by how many SIM cards were ordered.
-
#updated_at ⇒ Time?
Filter by ISO 8601 formatted date-time string matching resource last update date-time.
Instance Method Summary collapse
-
#initialize(address_administrative_area: nil, address_country_code: nil, address_extended_address: nil, address_id: nil, address_locality: nil, address_postal_code: nil, address_street_address: nil, cost_amount: nil, cost_currency: nil, created_at: nil, quantity: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Filter for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(address_administrative_area: nil, address_country_code: nil, address_extended_address: nil, address_id: nil, address_locality: nil, address_postal_code: nil, address_street_address: nil, cost_amount: nil, cost_currency: nil, created_at: nil, quantity: nil, updated_at: nil) ⇒ Object
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 43 class Filter < Telnyx::Internal::Type::BaseModel # @!attribute address_administrative_area # Filter by state or province where the address is located. # # @return [String, nil] optional :address_administrative_area, String, api_name: :"address.administrative_area" # @!attribute address_country_code # Filter by the mobile operator two-character (ISO 3166-1 alpha-2) origin country # code. # # @return [String, nil] optional :address_country_code, String, api_name: :"address.country_code" # @!attribute address_extended_address # Returns entries with matching name of the supplemental field for address # information. # # @return [String, nil] optional :address_extended_address, String, api_name: :"address.extended_address" # @!attribute address_id # Uniquely identifies the address for the order. # # @return [String, nil] optional :address_id, String, api_name: :"address.id" # @!attribute address_locality # Filter by the name of the city where the address is located. # # @return [String, nil] optional :address_locality, String, api_name: :"address.locality" # @!attribute address_postal_code # Filter by postal code for the address. # # @return [String, nil] optional :address_postal_code, String, api_name: :"address.postal_code" # @!attribute address_street_address # Returns entries with matching name of the street where the address is located. # # @return [String, nil] optional :address_street_address, String, api_name: :"address.street_address" # @!attribute cost_amount # The total monetary amount of the order. # # @return [String, nil] optional :cost_amount, String, api_name: :"cost.amount" # @!attribute cost_currency # Filter by ISO 4217 currency string. # # @return [String, nil] optional :cost_currency, String, api_name: :"cost.currency" # @!attribute created_at # Filter by ISO 8601 formatted date-time string matching resource creation # date-time. # # @return [Time, nil] optional :created_at, Time # @!attribute quantity # Filter orders by how many SIM cards were ordered. # # @return [Integer, nil] optional :quantity, Integer # @!attribute updated_at # Filter by ISO 8601 formatted date-time string matching resource last update # date-time. # # @return [Time, nil] optional :updated_at, Time # @!method initialize(address_administrative_area: nil, address_country_code: nil, address_extended_address: nil, address_id: nil, address_locality: nil, address_postal_code: nil, address_street_address: nil, cost_amount: nil, cost_currency: nil, created_at: nil, quantity: nil, updated_at: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::SimCardOrderListParams::Filter} for more details. # # Consolidated filter parameter for SIM card orders (deepObject style). # Originally: filter[created_at], filter[updated_at], filter[quantity], # filter[cost.amount], filter[cost.currency], filter[address.id], # filter[address.street_address], filter[address.extended_address], # filter[address.locality], filter[address.administrative_area], # filter[address.country_code], filter[address.postal_code] # # @param address_administrative_area [String] Filter by state or province where the address is located. # # @param address_country_code [String] Filter by the mobile operator two-character (ISO 3166-1 alpha-2) origin country # # @param address_extended_address [String] Returns entries with matching name of the supplemental field for address informa # # @param address_id [String] Uniquely identifies the address for the order. # # @param address_locality [String] Filter by the name of the city where the address is located. # # @param address_postal_code [String] Filter by postal code for the address. # # @param address_street_address [String] Returns entries with matching name of the street where the address is located. # # @param cost_amount [String] The total monetary amount of the order. # # @param cost_currency [String] Filter by ISO 4217 currency string. # # @param created_at [Time] Filter by ISO 8601 formatted date-time string matching resource creation date-ti # # @param quantity [Integer] Filter orders by how many SIM cards were ordered. # # @param updated_at [Time] Filter by ISO 8601 formatted date-time string matching resource last update date end |
Instance Attribute Details
#address_administrative_area ⇒ String?
Filter by state or province where the address is located.
48 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 48 optional :address_administrative_area, String, api_name: :"address.administrative_area" |
#address_country_code ⇒ String?
Filter by the mobile operator two-character (ISO 3166-1 alpha-2) origin country code.
55 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 55 optional :address_country_code, String, api_name: :"address.country_code" |
#address_extended_address ⇒ String?
Returns entries with matching name of the supplemental field for address information.
62 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 62 optional :address_extended_address, String, api_name: :"address.extended_address" |
#address_id ⇒ String?
Uniquely identifies the address for the order.
68 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 68 optional :address_id, String, api_name: :"address.id" |
#address_locality ⇒ String?
Filter by the name of the city where the address is located.
74 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 74 optional :address_locality, String, api_name: :"address.locality" |
#address_postal_code ⇒ String?
Filter by postal code for the address.
80 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 80 optional :address_postal_code, String, api_name: :"address.postal_code" |
#address_street_address ⇒ String?
Returns entries with matching name of the street where the address is located.
86 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 86 optional :address_street_address, String, api_name: :"address.street_address" |
#cost_amount ⇒ String?
The total monetary amount of the order.
92 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 92 optional :cost_amount, String, api_name: :"cost.amount" |
#cost_currency ⇒ String?
Filter by ISO 4217 currency string.
98 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 98 optional :cost_currency, String, api_name: :"cost.currency" |
#created_at ⇒ Time?
Filter by ISO 8601 formatted date-time string matching resource creation date-time.
105 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 105 optional :created_at, Time |
#quantity ⇒ Integer?
Filter orders by how many SIM cards were ordered.
111 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 111 optional :quantity, Integer |
#updated_at ⇒ Time?
Filter by ISO 8601 formatted date-time string matching resource last update date-time.
118 |
# File 'lib/telnyx/models/sim_card_order_list_params.rb', line 118 optional :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
123 |
# File 'sig/telnyx/models/sim_card_order_list_params.rbs', line 123
def to_hash: -> {
|