Module: Telnyx::Models::SimCardStatus::Value
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/sim_card_status.rb,
sig/telnyx/models/sim_card_status.rbs
Overview
The current status of the SIM card. It will be one of the following:
registering- the card is being registeredenabling- the card is being enabledenabled- the card is enabled and ready for usedisabling- the card is being disableddisabled- the card has been disabled and cannot be useddata_limit_exceeded- the card has exceeded its data consumption limitsetting_standby- the process to set the card in stand by is in progressstandby- the card is in stand by
Constant Summary collapse
- REGISTERING =
:registering- ENABLING =
:enabling- ENABLED =
:enabled- DISABLING =
:disabling- DISABLED =
:disabled- DATA_LIMIT_EXCEEDED =
:data_limit_exceeded- SETTING_STANDBY =
:setting_standby- STANDBY =
:standby
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/sim_card_status.rb', line 67
|
Instance Method Details
#self?.values ⇒ ::Array[Telnyx::Models::SimCardStatus::value]
49 |
# File 'sig/telnyx/models/sim_card_status.rbs', line 49
def self?.values: -> ::Array[Telnyx::Models::SimCardStatus::value]
|