Module: Telnyx::Models::SimCardStatus::Value
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/sim_card_status.rb
Overview
The current status of the SIM card. It will be one of the following: <br/>
<ul>
<li><code>registering</code> - the card is being registered</li>
<li><code>enabling</code> - the card is being enabled</li>
<li><code>enabled</code> - the card is enabled and ready for use</li>
<li><code>disabling</code> - the card is being disabled</li>
<li><code>disabled</code> - the card has been disabled and cannot be used</li>
<li><code>data_limit_exceeded</code> - the card has exceeded its data consumption limit</li>
<li><code>setting_standby</code> - the process to set the card in stand by is in progress</li>
<li><code>standby</code> - the card is in stand by</li>
</ul> Transitioning between the enabled and disabled states may take a period of time.
Constant Summary collapse
- REGISTERING =
:registering- ENABLING =
:enabling- ENABLED =
:enabled- DISABLING =
:disabling- DISABLED =
:disabled- DATA_LIMIT_EXCEEDED =
:data_limit_exceeded- SETTING_STANDBY =
:setting_standby- STANDBY =
:standby
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/sim_card_status.rb', line 67
|