Class: Telnyx::Models::SimpleSimCard
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SimpleSimCard
- Defined in:
- lib/telnyx/models/simple_sim_card.rb
Defined Under Namespace
Modules: EsimInstallationStatus, Type Classes: CurrentBillingPeriodConsumedData, DataLimit
Instance Attribute Summary collapse
-
#authorized_imeis ⇒ Array<String>?
List of IMEIs authorized to use a given SIM card.
-
#sim_card_group_id ⇒ String?
The group SIMCardGroup identification.
- #status ⇒ Telnyx::Models::SimCardStatus?
-
#tags ⇒ Array<String>?
Searchable tags associated with the SIM card.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount: nil, unit: nil) ⇒ Object
constructor
The SIM card consumption so far in the current billing cycle.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount: nil, unit: nil) ⇒ Object
The SIM card consumption so far in the current billing cycle.
|
|
# File 'lib/telnyx/models/simple_sim_card.rb', line 145
|
Instance Attribute Details
#authorized_imeis ⇒ Array<String>?
List of IMEIs authorized to use a given SIM card.
10 |
# File 'lib/telnyx/models/simple_sim_card.rb', line 10 optional :authorized_imeis, Telnyx::Internal::Type::ArrayOf[String], nil?: true |
#sim_card_group_id ⇒ String?
The group SIMCardGroup identification. This attribute can be null when it’s present in an associated resource.
17 |
# File 'lib/telnyx/models/simple_sim_card.rb', line 17 optional :sim_card_group_id, String |
#status ⇒ Telnyx::Models::SimCardStatus?
22 |
# File 'lib/telnyx/models/simple_sim_card.rb', line 22 optional :status, -> { Telnyx::SimCardStatus } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/simple_sim_card.rb', line 233
|