Class: Telnyx::Models::SipRegistrationStatusRetrieveResponse::SipRegistrationDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SipRegistrationStatusRetrieveResponse::SipRegistrationDetails
- Defined in:
- lib/telnyx/models/sip_registration_status_retrieve_response.rb,
sig/telnyx/models/sip_registration_status_retrieve_response.rbs
Overview
Instance Attribute Summary collapse
-
#auth_retries ⇒ Integer?
Number of authentication retries on the last attempt (uac_external_credential).
-
#expires ⇒ Integer?
Unix timestamp when the current registration expires.
-
#failures ⇒ Integer?
Count of consecutive registration failures (uac_external_credential).
-
#last_modified ⇒ String?
Timestamp when the registration was last modified (telephony_credential and sip_credential_connection).
-
#next_action_at ⇒ Integer?
Unix timestamp of the next scheduled registration action (uac_external_credential).
-
#sip_uri_user_host ⇒ String?
SIP URI user@host of the registered contact (uac_external_credential).
-
#transport ⇒ String?
Transport used for the registration, e.g.
-
#ua_ip ⇒ String?
IP address of the registered user agent (telephony_credential and sip_credential_connection).
-
#ua_port ⇒ Integer?
Port of the registered user agent (telephony_credential and sip_credential_connection).
-
#uptime ⇒ Integer?
Registration uptime reported by the registrar (uac_external_credential).
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
144 |
# File 'sig/telnyx/models/sip_registration_status_retrieve_response.rbs', line 144
def initialize: (
|
Instance Attribute Details
#auth_retries ⇒ Integer?
Number of authentication retries on the last attempt (uac_external_credential).
102 |
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 102 optional :auth_retries, Integer |
#expires ⇒ Integer?
Unix timestamp when the current registration expires.
108 |
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 108 optional :expires, Integer |
#failures ⇒ Integer?
Count of consecutive registration failures (uac_external_credential).
114 |
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 114 optional :failures, Integer |
#last_modified ⇒ String?
Timestamp when the registration was last modified (telephony_credential and sip_credential_connection).
121 |
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 121 optional :last_modified, String |
#next_action_at ⇒ Integer?
Unix timestamp of the next scheduled registration action (uac_external_credential).
128 |
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 128 optional :next_action_at, Integer |
#sip_uri_user_host ⇒ String?
SIP URI user@host of the registered contact (uac_external_credential).
134 |
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 134 optional :sip_uri_user_host, String |
#transport ⇒ String?
Transport used for the registration, e.g. UDP/TCP/TLS (telephony_credential and sip_credential_connection).
141 |
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 141 optional :transport, String |
#ua_ip ⇒ String?
IP address of the registered user agent (telephony_credential and sip_credential_connection).
148 |
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 148 optional :ua_ip, String |
#ua_port ⇒ Integer?
Port of the registered user agent (telephony_credential and sip_credential_connection).
155 |
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 155 optional :ua_port, Integer |
#uptime ⇒ Integer?
Registration uptime reported by the registrar (uac_external_credential).
161 |
# File 'lib/telnyx/models/sip_registration_status_retrieve_response.rb', line 161 optional :uptime, Integer |
Instance Method Details
#to_hash ⇒ {
157 |
# File 'sig/telnyx/models/sip_registration_status_retrieve_response.rbs', line 157
def to_hash: -> {
|