Class: Telnyx::Models::SiprecConnectorUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SiprecConnectorUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/siprec_connector_update_params.rb
Overview
Instance Attribute Summary collapse
-
#app_subdomain ⇒ String?
Subdomain to route the call when using Telnyx SRS (optional for non-Telnyx SRS).
- #connector_name ⇒ String
-
#host ⇒ String
Hostname/IPv4 address of the SIPREC SRS.
-
#name ⇒ String
Name for the SIPREC connector resource.
-
#port ⇒ Integer
Port for the SIPREC SRS.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(connector_name:, host:, name:, port:, app_subdomain: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SiprecConnectorUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connector_name:, host:, name:, port:, app_subdomain: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::SiprecConnectorUpdateParams for more details.
|
|
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 39
|
Instance Attribute Details
#app_subdomain ⇒ String?
Subdomain to route the call when using Telnyx SRS (optional for non-Telnyx SRS).
37 |
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 37 optional :app_subdomain, String |
#connector_name ⇒ String
13 |
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 13 required :connector_name, String |
#host ⇒ String
Hostname/IPv4 address of the SIPREC SRS.
19 |
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 19 required :host, String |
#name ⇒ String
Name for the SIPREC connector resource.
25 |
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 25 required :name, String |
#port ⇒ Integer
Port for the SIPREC SRS.
31 |
# File 'lib/telnyx/models/siprec_connector_update_params.rb', line 31 required :port, Integer |