Class: Telnyx::Models::SoundModifications
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SoundModifications
- Defined in:
- lib/telnyx/models/sound_modifications.rb
Instance Attribute Summary collapse
-
#octaves ⇒ Float?
Adjust the pitch in octaves, values should be between -1 and 1, default 0.
-
#pitch ⇒ Float?
Set the pitch directly, value should be > 0, default 1 (lower = lower tone).
-
#semitone ⇒ Float?
Adjust the pitch in semitones, values should be between -14 and 14, default 0.
-
#track ⇒ String?
The track to which the sound modifications will be applied.
Instance Method Summary collapse
-
#initialize(octaves: nil, pitch: nil, semitone: nil, track: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SoundModifications for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(octaves: nil, pitch: nil, semitone: nil, track: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::SoundModifications for more details.
Use this field to modify sound effects, for example adjust the pitch.
|
|
# File 'lib/telnyx/models/sound_modifications.rb', line 31
|
Instance Attribute Details
#octaves ⇒ Float?
Adjust the pitch in octaves, values should be between -1 and 1, default 0
10 |
# File 'lib/telnyx/models/sound_modifications.rb', line 10 optional :octaves, Float |
#pitch ⇒ Float?
Set the pitch directly, value should be > 0, default 1 (lower = lower tone)
16 |
# File 'lib/telnyx/models/sound_modifications.rb', line 16 optional :pitch, Float |
#semitone ⇒ Float?
Adjust the pitch in semitones, values should be between -14 and 14, default 0
22 |
# File 'lib/telnyx/models/sound_modifications.rb', line 22 optional :semitone, Float |
#track ⇒ String?
The track to which the sound modifications will be applied. Accepted values are ‘inbound` or `outbound`
29 |
# File 'lib/telnyx/models/sound_modifications.rb', line 29 optional :track, String |