Class: Telnyx::Models::SpeechToTextListProvidersParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/speech_to_text_list_providers_params.rb

Overview

Defined Under Namespace

Modules: Provider, ServiceType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(provider: nil, service_type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SpeechToTextListProvidersParams for more details.

Parameters:



# File 'lib/telnyx/models/speech_to_text_list_providers_params.rb', line 26

Instance Attribute Details

#providerSymbol, ...

Filter to entries for a specific STT provider. The enum mirrors the providers advertised across the speech-to-text spec (including ‘google` and `telnyx`, which are accepted as WebSocket transcription engines). A provider that has no models currently registered for any service type will return an empty `data` array rather than an error.



18
# File 'lib/telnyx/models/speech_to_text_list_providers_params.rb', line 18

optional :provider, enum: -> { Telnyx::SpeechToTextListProvidersParams::Provider }

#service_typeSymbol, ...

Filter to entries that support the given service type.



24
# File 'lib/telnyx/models/speech_to_text_list_providers_params.rb', line 24

optional :service_type, enum: -> { Telnyx::SpeechToTextListProvidersParams::ServiceType }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/speech_to_text_list_providers_params.rb', line 54