Module: Telnyx::Models::SpeechToTextListProvidersParams::Provider
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/telnyx/models/speech_to_text_list_providers_params.rb
Overview
Filter to entries for a specific STT provider. The enum mirrors the providers advertised across the speech-to-text spec (including ‘google` and `telnyx`, which are accepted as WebSocket transcription engines). A provider that has no models currently registered for any service type will return an empty `data` array rather than an error.
Constant Summary collapse
- DEEPGRAM =
:deepgram- SPEECHMATICS =
:speechmatics- ASSEMBLYAI =
:assemblyai- XAI =
:xai- SONIOX =
:soniox- AZURE =
:azure- OPENAI =
:openai- GOOGLE =
:google- TELNYX =
:telnyx
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info