Class: Telnyx::Models::SpeechToTextListProvidersResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/speech_to_text_list_providers_response.rb

Defined Under Namespace

Modules: ServiceType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(languages:, model:, provider:, service_types:) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::SpeechToTextListProvidersResponse::Data for more details.

A (provider, model) tuple along with its supported service types and languages.

Parameters:

  • languages (Array<String>)

    Languages this (provider, model) accepts, in the provider’s native code format.

  • model (String)

    Provider-scoped model name.

  • provider (String)

    STT provider name.

  • service_types (Array<Symbol, Telnyx::Models::SpeechToTextListProvidersResponse::Data::ServiceType>)

    Service surfaces this (provider, model) supports.



24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/telnyx/models/speech_to_text_list_providers_response.rb', line 24

class Data < Telnyx::Internal::Type::BaseModel
  # @!attribute languages
  #   Languages this (provider, model) accepts, in the provider's native code format.
  #   `auto` indicates the provider performs language detection.
  #
  #   @return [Array<String>]
  required :languages, Telnyx::Internal::Type::ArrayOf[String]

  # @!attribute model
  #   Provider-scoped model name.
  #
  #   @return [String]
  required :model, String

  # @!attribute provider
  #   STT provider name.
  #
  #   @return [String]
  required :provider, String

  # @!attribute service_types
  #   Service surfaces this (provider, model) supports.
  #
  #   @return [Array<Symbol, Telnyx::Models::SpeechToTextListProvidersResponse::Data::ServiceType>]
  required :service_types,
           -> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::SpeechToTextListProvidersResponse::Data::ServiceType] }

  # @!method initialize(languages:, model:, provider:, service_types:)
  #   Some parameter documentations has been truncated, see
  #   {Telnyx::Models::SpeechToTextListProvidersResponse::Data} for more details.
  #
  #   A (provider, model) tuple along with its supported service types and languages.
  #
  #   @param languages [Array<String>] Languages this (provider, model) accepts, in the provider's native code format.
  #
  #   @param model [String] Provider-scoped model name.
  #
  #   @param provider [String] STT provider name.
  #
  #   @param service_types [Array<Symbol, Telnyx::Models::SpeechToTextListProvidersResponse::Data::ServiceType>] Service surfaces this (provider, model) supports.

  # Service surface a model is available on.
  module ServiceType
    extend Telnyx::Internal::Type::Enum

    STREAMING = :streaming
    FILE_TRANSCRIPTION = :file_transcription
    IN_CALL_TRANSCRIPTION = :in_call_transcription

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#languagesArray<String>

Languages this (provider, model) accepts, in the provider’s native code format. ‘auto` indicates the provider performs language detection.

Returns:

  • (Array<String>)


30
# File 'lib/telnyx/models/speech_to_text_list_providers_response.rb', line 30

required :languages, Telnyx::Internal::Type::ArrayOf[String]

#modelString

Provider-scoped model name.

Returns:

  • (String)


36
# File 'lib/telnyx/models/speech_to_text_list_providers_response.rb', line 36

required :model, String

#providerString

STT provider name.

Returns:

  • (String)


42
# File 'lib/telnyx/models/speech_to_text_list_providers_response.rb', line 42

required :provider, String

#service_typesArray<Symbol, Telnyx::Models::SpeechToTextListProvidersResponse::Data::ServiceType>

Service surfaces this (provider, model) supports.



48
49
# File 'lib/telnyx/models/speech_to_text_list_providers_response.rb', line 48

required :service_types,
-> { Telnyx::Internal::Type::ArrayOf[enum: Telnyx::Models::SpeechToTextListProvidersResponse::Data::ServiceType] }