Class: Telnyx::Models::SpeechToTextRetrieveTranscriptionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SpeechToTextRetrieveTranscriptionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb
Overview
Defined Under Namespace
Modules: InputFormat, Model, TranscriptionEngine
Instance Attribute Summary collapse
-
#endpointing ⇒ Integer?
Silence duration (in milliseconds) that triggers end-of-speech detection.
-
#input_format ⇒ Symbol, Telnyx::Models::SpeechToTextRetrieveTranscriptionParams::InputFormat
The format of input audio stream.
-
#interim_results ⇒ Boolean?
Whether to receive interim transcription results.
-
#keyterm ⇒ String?
A key term to boost in the transcription.
-
#keywords ⇒ String?
Comma-separated list of keywords to boost in the transcription.
-
#language ⇒ String?
The language spoken in the audio stream.
-
#model ⇒ Symbol, ...
The specific model to use within the selected transcription engine.
-
#redact ⇒ String?
Enable redaction of sensitive information (e.g., PCI data, SSN) from transcription results.
-
#transcription_engine ⇒ Symbol, Telnyx::Models::SpeechToTextRetrieveTranscriptionParams::TranscriptionEngine
The transcription engine to use for processing the audio stream.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(input_format:, transcription_engine:, endpointing: nil, interim_results: nil, keyterm: nil, keywords: nil, language: nil, model: nil, redact: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SpeechToTextRetrieveTranscriptionParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input_format:, transcription_engine:, endpointing: nil, interim_results: nil, keyterm: nil, keywords: nil, language: nil, model: nil, redact: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::SpeechToTextRetrieveTranscriptionParams for more details.
|
|
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 72
|
Instance Attribute Details
#endpointing ⇒ Integer?
Silence duration (in milliseconds) that triggers end-of-speech detection. When set, the engine uses this value to determine when a speaker has stopped talking. Supported by ‘xAI`, `Deepgram`, `Google`, `Speechmatics`, and `Soniox`. `Soniox` accepts values between 500 and 3000. Other engines may not support this parameter.
31 |
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 31 optional :endpointing, Integer |
#input_format ⇒ Symbol, Telnyx::Models::SpeechToTextRetrieveTranscriptionParams::InputFormat
The format of input audio stream.
14 |
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 14 required :input_format, enum: -> { Telnyx::SpeechToTextRetrieveTranscriptionParams::InputFormat } |
#interim_results ⇒ Boolean?
Whether to receive interim transcription results.
37 |
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 37 optional :interim_results, Telnyx::Internal::Type::Boolean |
#keyterm ⇒ String?
A key term to boost in the transcription. The engine will be more likely to recognize this term. Can be specified multiple times for multiple terms.
44 |
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 44 optional :keyterm, String |
#keywords ⇒ String?
Comma-separated list of keywords to boost in the transcription. The engine will prioritize recognition of these words.
51 |
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 51 optional :keywords, String |
#language ⇒ String?
The language spoken in the audio stream.
57 |
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 57 optional :language, String |
#model ⇒ Symbol, ...
The specific model to use within the selected transcription engine.
63 |
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 63 optional :model, enum: -> { Telnyx::SpeechToTextRetrieveTranscriptionParams::Model } |
#redact ⇒ String?
Enable redaction of sensitive information (e.g., PCI data, SSN) from transcription results. Supported values depend on the transcription engine.
70 |
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 70 optional :redact, String |
#transcription_engine ⇒ Symbol, Telnyx::Models::SpeechToTextRetrieveTranscriptionParams::TranscriptionEngine
The transcription engine to use for processing the audio stream.
20 21 |
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 20 required :transcription_engine, enum: -> { Telnyx::SpeechToTextRetrieveTranscriptionParams::TranscriptionEngine } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/speech_to_text_retrieve_transcription_params.rb', line 103
|