Class: Telnyx::Models::Storage::BucketCreatePresignedURLParams::Body
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Storage::BucketCreatePresignedURLParams::Body
- Defined in:
- lib/telnyx/models/storage/bucket_create_presigned_url_params.rb,
sig/telnyx/models/storage/bucket_create_presigned_url_params.rbs
Instance Attribute Summary collapse
-
#ttl ⇒ Integer?
The time to live of the token in seconds.
Instance Method Summary collapse
-
#initialize(ttl: nil) ⇒ Body
constructor
A new instance of Body.
- #to_hash ⇒ { ttl: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ttl: nil) ⇒ Body
Returns a new instance of Body.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/telnyx/models/storage/bucket_create_presigned_url_params.rb', line 32 class Body < Telnyx::Internal::Type::BaseModel # @!attribute ttl # The time to live of the token in seconds # # @return [Integer, nil] optional :ttl, Integer # @!method initialize(ttl: nil) # @param ttl [Integer] The time to live of the token in seconds end |
Instance Attribute Details
#ttl ⇒ Integer?
The time to live of the token in seconds
37 |
# File 'lib/telnyx/models/storage/bucket_create_presigned_url_params.rb', line 37 optional :ttl, Integer |
Instance Method Details
#to_hash ⇒ { ttl: Integer }
49 |
# File 'sig/telnyx/models/storage/bucket_create_presigned_url_params.rbs', line 49
def to_hash: -> { ttl: Integer }
|