Class: Telnyx::Models::Storage::CloudfListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/storage/cloudf_list_params.rb,
sig/telnyx/models/storage/cloudf_list_params.rbs

Overview

See Also:

  • Telnyx::Resources::Storage::Cloudfs#list

Defined Under Namespace

Modules: FilterStatus, Sort

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filter_name: nil, filter_region: nil, filter_status: nil, page_after: nil, page_before: nil, page_limit: nil, sort: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Storage::CloudfListParams for more details.

Parameters:

  • filter_name (String) (defaults to: nil)

    Return only the filesystem whose name matches exactly.

  • filter_region (String) (defaults to: nil)

    Return only filesystems in this region.

  • filter_status (Symbol, Telnyx::Models::Storage::CloudfListParams::FilterStatus) (defaults to: nil)

    Return only filesystems with this status. Unrecognized values are ignored.

  • page_after (String) (defaults to: nil)

    Opaque cursor from a previous response's meta.cursors.after; returns the page

  • page_before (String) (defaults to: nil)

    Opaque cursor from a previous response's meta.cursors.before; returns the page

  • page_limit (Integer) (defaults to: nil)

    The number of filesystems to return per page. Values above 250 are treated as 25

  • sort (Symbol, Telnyx::Models::Storage::CloudfListParams::Sort) (defaults to: nil)

    Sort order for the results: a field name for ascending, or the field name prefix

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 57

Instance Attribute Details

#filter_nameString?

Return only the filesystem whose name matches exactly.

Parameters:

  • (String)

Returns:

  • (String, nil)


15
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 15

optional :filter_name, String

#filter_regionString?

Return only filesystems in this region.

Parameters:

  • (String)

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 21

optional :filter_region, String

#filter_statusSymbol, ...

Return only filesystems with this status. Unrecognized values are ignored.



27
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 27

optional :filter_status, enum: -> { Telnyx::Storage::CloudfListParams::FilterStatus }

#page_afterString?

Opaque cursor from a previous response's meta.cursors.after; returns the page after it. Mutually exclusive with page[before].

Parameters:

  • (String)

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 34

optional :page_after, String

#page_beforeString?

Opaque cursor from a previous response's meta.cursors.before; returns the page before it. Mutually exclusive with page[after].

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 41

optional :page_before, String

#page_limitInteger?

The number of filesystems to return per page. Values above 250 are treated as 250.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


48
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 48

optional :page_limit, Integer

#sortSymbol, ...

Sort order for the results: a field name for ascending, or the field name prefixed with - for descending.



55
# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 55

optional :sort, enum: -> { Telnyx::Storage::CloudfListParams::Sort }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/storage/cloudf_list_params.rb', line 87

Instance Method Details

#to_hash{

Returns:

  • ({)


63
# File 'sig/telnyx/models/storage/cloudf_list_params.rbs', line 63

def to_hash: -> {