Class: Telnyx::Models::Storage::CloudfListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Storage::CloudfListResponse
- Defined in:
- lib/telnyx/models/storage/cloudf_list_response.rb,
sig/telnyx/models/storage/cloudf_list_response.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
- #data ⇒ Array<Telnyx::Models::Storage::CloudfListResponse::Data>?
- #meta ⇒ Telnyx::Models::Storage::CloudfListResponse::Meta?
Instance Method Summary collapse
-
#initialize(id: nil, created_at: nil, name: nil, record_type: nil, region: nil, s3_bucket: nil, s3_endpoint: nil, status: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, name: nil, record_type: nil, region: nil, s3_bucket: nil, s3_endpoint: nil, status: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Data for more details.
A CloudFS filesystem as returned in list results. Connection details
(meta_url, meta_token) are omitted — retrieve the filesystem by ID for its
redacted meta_url.
|
|
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 78
|
Instance Attribute Details
#data ⇒ Array<Telnyx::Models::Storage::CloudfListResponse::Data>?
11 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 11 optional :data, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::Storage::CloudfListResponse::Data] } |
#meta ⇒ Telnyx::Models::Storage::CloudfListResponse::Meta?
16 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 16 optional :meta, -> { Telnyx::Models::Storage::CloudfListResponse::Meta } |
Instance Method Details
#to_hash ⇒ {
28 |
# File 'sig/telnyx/models/storage/cloudf_list_response.rbs', line 28
def to_hash: -> {
|