Class: Telnyx::Models::Storage::CloudfListResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Storage::CloudfListResponse::Data
- Defined in:
- lib/telnyx/models/storage/cloudf_list_response.rb,
sig/telnyx/models/storage/cloudf_list_response.rbs
Instance Attribute Summary collapse
- #created_at ⇒ Time?
- #id ⇒ String?
- #name ⇒ String?
- #record_type ⇒ String?
- #region ⇒ String?
-
#s3_bucket ⇒ String?
Name of the bucket that stores this filesystem's data.
-
#s3_endpoint ⇒ String?
URL of the Telnyx Cloud Storage endpoint backing this filesystem.
-
#status ⇒ Symbol, ...
Lifecycle status of the filesystem.
- #updated_at ⇒ Time?
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data: nil, meta: nil) ⇒ Object
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 22 class Data < Telnyx::Internal::Type::BaseModel # @!attribute id # # @return [String, nil] optional :id, String # @!attribute created_at # # @return [Time, nil] optional :created_at, Time # @!attribute name # # @return [String, nil] optional :name, String # @!attribute record_type # # @return [String, nil] optional :record_type, String # @!attribute region # # @return [String, nil] optional :region, String # @!attribute s3_bucket # Name of the bucket that stores this filesystem's data. Created during # provisioning. # # @return [String, nil] optional :s3_bucket, String # @!attribute s3_endpoint # URL of the Telnyx Cloud Storage endpoint backing this filesystem. # # @return [String, nil] optional :s3_endpoint, String # @!attribute status # Lifecycle status of the filesystem. `ready` means it is fully provisioned and # usable. `needs_format` means the storage bucket and metadata database were # provisioned but the filesystem has not yet been formatted — run `juicefs format` # with the filesystem's `meta_url` before mounting. `failed` means the last # lifecycle action failed — see the filesystem's `error` message. `deleted` # appears only in the delete response: deleted filesystems are excluded from list # results and return a `404` on retrieval. # # @return [Symbol, Telnyx::Models::Storage::CloudfsFilesystemStatus, nil] optional :status, enum: -> { Telnyx::Storage::CloudfsFilesystemStatus } # @!attribute updated_at # # @return [Time, nil] optional :updated_at, Time # @!method initialize(id: nil, created_at: nil, name: nil, record_type: nil, region: nil, s3_bucket: nil, s3_endpoint: nil, status: nil, updated_at: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::Storage::CloudfListResponse::Data} for more details. # # A CloudFS filesystem as returned in list results. Connection details # (`meta_url`, `meta_token`) are omitted — retrieve the filesystem by ID for its # redacted `meta_url`. # # @param id [String] # # @param created_at [Time] # # @param name [String] # # @param record_type [String] # # @param region [String] # # @param s3_bucket [String] Name of the bucket that stores this filesystem's data. Created during provisioni # # @param s3_endpoint [String] URL of the Telnyx Cloud Storage endpoint backing this filesystem. # # @param status [Symbol, Telnyx::Models::Storage::CloudfsFilesystemStatus] Lifecycle status of the filesystem. `ready` means it is fully provisioned and us # # @param updated_at [Time] end |
Instance Attribute Details
#created_at ⇒ Time?
31 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 31 optional :created_at, Time |
#id ⇒ String?
26 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 26 optional :id, String |
#name ⇒ String?
36 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 36 optional :name, String |
#record_type ⇒ String?
41 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 41 optional :record_type, String |
#region ⇒ String?
46 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 46 optional :region, String |
#s3_bucket ⇒ String?
Name of the bucket that stores this filesystem's data. Created during provisioning.
53 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 53 optional :s3_bucket, String |
#s3_endpoint ⇒ String?
URL of the Telnyx Cloud Storage endpoint backing this filesystem.
59 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 59 optional :s3_endpoint, String |
#status ⇒ Symbol, ...
Lifecycle status of the filesystem. ready means it is fully provisioned and
usable. needs_format means the storage bucket and metadata database were
provisioned but the filesystem has not yet been formatted — run juicefs format
with the filesystem's meta_url before mounting. failed means the last
lifecycle action failed — see the filesystem's error message. deleted
appears only in the delete response: deleted filesystems are excluded from list
results and return a 404 on retrieval.
71 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 71 optional :status, enum: -> { Telnyx::Storage::CloudfsFilesystemStatus } |
#updated_at ⇒ Time?
76 |
# File 'lib/telnyx/models/storage/cloudf_list_response.rb', line 76 optional :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
97 |
# File 'sig/telnyx/models/storage/cloudf_list_response.rbs', line 97
def to_hash: -> {
|