Class: Telnyx::Models::Storage::CloudfsFilesystemDetailResponseWrapper::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Storage::CloudfsFilesystemDetailResponseWrapper::Data
- Defined in:
- lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb,
sig/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rbs
Overview
Instance Attribute Summary collapse
- #created_at ⇒ Time?
-
#error ⇒ String?
Explanation of the most recent failed lifecycle action.
- #id ⇒ String?
-
#meta_url ⇒ String?
PostgreSQL connection URL for the filesystem's metadata database, without the credential.
- #name ⇒ String?
- #record_type ⇒ String?
- #region ⇒ String?
-
#s3_bucket ⇒ String?
Name of the bucket that stores this filesystem's data.
-
#s3_endpoint ⇒ String?
URL of the Telnyx Cloud Storage endpoint backing this filesystem.
-
#status ⇒ Symbol, ...
Lifecycle status of the filesystem.
- #updated_at ⇒ Time?
Instance Method Summary collapse
-
#initialize(id: nil, created_at: nil, error: nil, meta_url: nil, name: nil, record_type: nil, region: nil, s3_bucket: nil, s3_endpoint: nil, status: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, error: nil, meta_url: nil, name: nil, record_type: nil, region: nil, s3_bucket: nil, s3_endpoint: nil, status: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Storage::CloudfsFilesystemDetailResponseWrapper::Data for more details.
A CloudFS filesystem as returned by get, update, and delete. meta_url omits
the credential and there is no meta_token field — the token is only returned
by create and rotate-meta-token.
|
|
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 95
|
Instance Attribute Details
#created_at ⇒ Time?
33 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 33 optional :created_at, Time |
#error ⇒ String?
Explanation of the most recent failed lifecycle action. Present only when the
filesystem is in a failed state.
40 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 40 optional :error, String |
#id ⇒ String?
28 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 28 optional :id, String |
#meta_url ⇒ String?
PostgreSQL connection URL for the filesystem's metadata database, without the credential. Combine it with your stored metadata token, or issue a new token with rotate-meta-token.
48 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 48 optional :meta_url, String |
#name ⇒ String?
53 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 53 optional :name, String |
#record_type ⇒ String?
58 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 58 optional :record_type, String |
#region ⇒ String?
63 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 63 optional :region, String |
#s3_bucket ⇒ String?
Name of the bucket that stores this filesystem's data. Created during provisioning.
70 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 70 optional :s3_bucket, String |
#s3_endpoint ⇒ String?
URL of the Telnyx Cloud Storage endpoint backing this filesystem.
76 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 76 optional :s3_endpoint, String |
#status ⇒ Symbol, ...
Lifecycle status of the filesystem. ready means it is fully provisioned and
usable. needs_format means the storage bucket and metadata database were
provisioned but the filesystem has not yet been formatted — run juicefs format
with the filesystem's meta_url before mounting. failed means the last
lifecycle action failed — see the filesystem's error message. deleted
appears only in the delete response: deleted filesystems are excluded from list
results and return a 404 on retrieval.
88 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 88 optional :status, enum: -> { Telnyx::Storage::CloudfsFilesystemStatus } |
#updated_at ⇒ Time?
93 |
# File 'lib/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rb', line 93 optional :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
98 |
# File 'sig/telnyx/models/storage/cloudfs_filesystem_detail_response_wrapper.rbs', line 98
def to_hash: -> {
|