Class: Telnyx::Models::Storage::MigrationParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Storage::MigrationParams
- Defined in:
- lib/telnyx/models/storage/migration_params.rb,
sig/telnyx/models/storage/migration_params.rbs
Direct Known Subclasses
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#bytes_migrated ⇒ Integer?
readonly
Returns the value of attribute bytes_migrated.
-
#bytes_to_migrate ⇒ Integer?
readonly
Returns the value of attribute bytes_to_migrate.
-
#created_at ⇒ Time?
readonly
Returns the value of attribute created_at.
-
#eta ⇒ Time?
readonly
Returns the value of attribute eta.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#last_copy ⇒ Time?
readonly
Returns the value of attribute last_copy.
-
#refresh ⇒ Boolean?
If true, will continue to poll the source bucket to ensure new data is continually migrated over.
-
#source_id ⇒ String
ID of the Migration Source from which to migrate data.
-
#speed ⇒ Integer?
readonly
Returns the value of attribute speed.
-
#status ⇒ Telnyx::Models::Storage::MigrationParams::status?
readonly
Returns the value of attribute status.
-
#target_bucket_name ⇒ String
Bucket name to migrate the data into.
-
#target_region ⇒ String
Telnyx Cloud Storage region to migrate the data to.
Instance Method Summary collapse
- #bytes_migrated ⇒ Integer readonly
- #bytes_to_migrate ⇒ Integer readonly
- #created_at ⇒ Time readonly
- #eta ⇒ Time readonly
- #id ⇒ String readonly
-
#initialize(source_id:, target_bucket_name:, target_region:, id: nil, bytes_migrated: nil, bytes_to_migrate: nil, created_at: nil, eta: nil, last_copy: nil, refresh: nil, speed: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MigrationParams for more details.
- #last_copy ⇒ Time readonly
- #speed ⇒ Integer readonly
- #status ⇒ Object readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(source_id:, target_bucket_name:, target_region:, id: nil, bytes_migrated: nil, bytes_to_migrate: nil, created_at: nil, eta: nil, last_copy: nil, refresh: nil, speed: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Storage::MigrationParams for more details.
|
|
# File 'lib/telnyx/models/storage/migration_params.rb', line 83
|
Instance Attribute Details
#bytes_migrated ⇒ Integer? (readonly)
Returns the value of attribute bytes_migrated.
35 36 37 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 35 def bytes_migrated @bytes_migrated end |
#bytes_to_migrate ⇒ Integer? (readonly)
Returns the value of attribute bytes_to_migrate.
39 40 41 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 39 def bytes_to_migrate @bytes_to_migrate end |
#created_at ⇒ Time? (readonly)
Returns the value of attribute created_at.
43 44 45 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 43 def created_at @created_at end |
#eta ⇒ Time? (readonly)
Returns the value of attribute eta.
47 48 49 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 47 def eta @eta end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
31 32 33 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 31 def id @id end |
#last_copy ⇒ Time? (readonly)
Returns the value of attribute last_copy.
51 52 53 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 51 def last_copy @last_copy end |
#refresh ⇒ Boolean?
If true, will continue to poll the source bucket to ensure new data is continually migrated over.
31 |
# File 'lib/telnyx/models/storage/migration_params.rb', line 31 optional :refresh, Telnyx::Internal::Type::Boolean |
#source_id ⇒ String
ID of the Migration Source from which to migrate data.
11 |
# File 'lib/telnyx/models/storage/migration_params.rb', line 11 required :source_id, String |
#speed ⇒ Integer? (readonly)
Returns the value of attribute speed.
55 56 57 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 55 def speed @speed end |
#status ⇒ Telnyx::Models::Storage::MigrationParams::status? (readonly)
Returns the value of attribute status.
59 60 61 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 59 def status @status end |
#target_bucket_name ⇒ String
Bucket name to migrate the data into. Will default to the same name as the
source_bucket_name.
18 |
# File 'lib/telnyx/models/storage/migration_params.rb', line 18 required :target_bucket_name, String |
#target_region ⇒ String
Telnyx Cloud Storage region to migrate the data to.
24 |
# File 'lib/telnyx/models/storage/migration_params.rb', line 24 required :target_region, String |
Instance Method Details
#bytes_migrated= ⇒ Integer (readonly)
37 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 37
def bytes_migrated=: (Integer) -> Integer
|
#bytes_to_migrate= ⇒ Integer (readonly)
41 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 41
def bytes_to_migrate=: (Integer) -> Integer
|
#created_at= ⇒ Time (readonly)
45 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 45
def created_at=: (Time) -> Time
|
#eta= ⇒ Time (readonly)
49 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 49
def eta=: (Time) -> Time
|
#id= ⇒ String (readonly)
33 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 33
def id=: (String) -> String
|
#last_copy= ⇒ Time (readonly)
53 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 53
def last_copy=: (Time) -> Time
|
#speed= ⇒ Integer (readonly)
57 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 57
def speed=: (Integer) -> Integer
|
#status= ⇒ Object (readonly)
61 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 61
def status=: (
|
#to_hash ⇒ {
80 |
# File 'sig/telnyx/models/storage/migration_params.rbs', line 80
def to_hash: -> {
|