Class: Telnyx::Models::Storage::MigrationParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/storage/migration_params.rb

Direct Known Subclasses

MigrationCreateParams

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(source_id:, target_bucket_name:, target_region:, id: nil, bytes_migrated: nil, bytes_to_migrate: nil, created_at: nil, eta: nil, last_copy: nil, refresh: nil, speed: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Storage::MigrationParams for more details.

Parameters:

  • source_id (String)

    ID of the Migration Source from which to migrate data.

  • target_bucket_name (String)

    Bucket name to migrate the data into. Will default to the same name as the ‘sour

  • target_region (String)

    Telnyx Cloud Storage region to migrate the data to.

  • id (String) (defaults to: nil)

    Unique identifier for the data migration.

  • bytes_migrated (Integer) (defaults to: nil)

    Total amount of data that has been succesfully migrated.

  • bytes_to_migrate (Integer) (defaults to: nil)

    Total amount of data found in source bucket to migrate.

  • created_at (Time) (defaults to: nil)

    Time when data migration was created

  • eta (Time) (defaults to: nil)

    Estimated time the migration will complete.

  • last_copy (Time) (defaults to: nil)

    Time when data migration was last copied from the source.

  • refresh (Boolean) (defaults to: nil)

    If true, will continue to poll the source bucket to ensure new data is continual

  • speed (Integer) (defaults to: nil)

    Current speed of the migration.

  • status (Symbol, Telnyx::Models::Storage::MigrationParams::Status) (defaults to: nil)

    Status of the migration.



# File 'lib/telnyx/models/storage/migration_params.rb', line 83

Instance Attribute Details

#refreshBoolean?

If true, will continue to poll the source bucket to ensure new data is continually migrated over.

Returns:

  • (Boolean, nil)


31
# File 'lib/telnyx/models/storage/migration_params.rb', line 31

optional :refresh, Telnyx::Internal::Type::Boolean

#source_idString

ID of the Migration Source from which to migrate data.

Returns:

  • (String)


11
# File 'lib/telnyx/models/storage/migration_params.rb', line 11

required :source_id, String

#target_bucket_nameString

Bucket name to migrate the data into. Will default to the same name as the ‘source_bucket_name`.

Returns:

  • (String)


18
# File 'lib/telnyx/models/storage/migration_params.rb', line 18

required :target_bucket_name, String

#target_regionString

Telnyx Cloud Storage region to migrate the data to.

Returns:

  • (String)


24
# File 'lib/telnyx/models/storage/migration_params.rb', line 24

required :target_region, String