Class: Telnyx::Models::Storage::MigrationSourceParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Storage::MigrationSourceParams
- Defined in:
- lib/telnyx/models/storage/migration_source_params.rb,
sig/telnyx/models/storage/migration_source_params.rbs
Direct Known Subclasses
Defined Under Namespace
Modules: Provider Classes: ProviderAuth
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
Bucket name to migrate the data from.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#provider ⇒ Symbol, Telnyx::Models::Storage::MigrationSourceParams::Provider
Cloud provider from which to migrate data.
- #provider_auth ⇒ Telnyx::Models::Storage::MigrationSourceParams::ProviderAuth
-
#source_region ⇒ String?
For intra-Telnyx buckets migration, specify the source bucket region in this field.
Class Method Summary collapse
Instance Method Summary collapse
- #id ⇒ String readonly
-
#initialize(bucket_name:, provider:, provider_auth:, id: nil, source_region: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MigrationSourceParams for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bucket_name:, provider:, provider_auth:, id: nil, source_region: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Storage::MigrationSourceParams for more details.
|
|
# File 'lib/telnyx/models/storage/migration_source_params.rb', line 40
|
Instance Attribute Details
#bucket_name ⇒ String
Bucket name to migrate the data from.
11 |
# File 'lib/telnyx/models/storage/migration_source_params.rb', line 11 required :bucket_name, String |
#id ⇒ String? (readonly)
Returns the value of attribute id.
24 25 26 |
# File 'sig/telnyx/models/storage/migration_source_params.rbs', line 24 def id @id end |
#provider ⇒ Symbol, Telnyx::Models::Storage::MigrationSourceParams::Provider
Cloud provider from which to migrate data. Use 'telnyx' if you want to migrate data from one Telnyx bucket to another.
18 |
# File 'lib/telnyx/models/storage/migration_source_params.rb', line 18 required :provider, enum: -> { Telnyx::Storage::MigrationSourceParams::Provider } |
#provider_auth ⇒ Telnyx::Models::Storage::MigrationSourceParams::ProviderAuth
23 |
# File 'lib/telnyx/models/storage/migration_source_params.rb', line 23 required :provider_auth, -> { Telnyx::Storage::MigrationSourceParams::ProviderAuth } |
#source_region ⇒ String?
For intra-Telnyx buckets migration, specify the source bucket region in this field.
30 |
# File 'lib/telnyx/models/storage/migration_source_params.rb', line 30 optional :source_region, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/storage/migration_source_params.rb', line 64
|
Instance Method Details
#id= ⇒ String (readonly)
26 |
# File 'sig/telnyx/models/storage/migration_source_params.rbs', line 26
def id=: (String) -> String
|
#to_hash ⇒ {
36 |
# File 'sig/telnyx/models/storage/migration_source_params.rbs', line 36
def to_hash: -> {
|