Class: Telnyx::Models::Storage::Sqldbs::ActionQueryResponse::Data::Meta
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Storage::Sqldbs::ActionQueryResponse::Data::Meta
- Defined in:
- lib/telnyx/models/storage/sqldbs/action_query_response.rb,
sig/telnyx/models/storage/sqldbs/action_query_response.rbs
Overview
Instance Attribute Summary collapse
-
#changes ⇒ Integer?
Number of rows added, changed, or removed by the statement.
-
#duration ⇒ Float?
Wall-clock duration of the statement, in milliseconds.
-
#last_row_id ⇒ Integer?
Rowid of the last inserted row, when applicable.
- #rows_read ⇒ Integer?
- #rows_written ⇒ Integer?
Instance Method Summary collapse
- #initialize(changes: nil, duration: nil, last_row_id: nil, rows_read: nil, rows_written: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(changes: nil, duration: nil, last_row_id: nil, rows_read: nil, rows_written: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 93
|
Instance Attribute Details
#changes ⇒ Integer?
Number of rows added, changed, or removed by the statement.
69 |
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 69 optional :changes, Integer |
#duration ⇒ Float?
Wall-clock duration of the statement, in milliseconds.
75 |
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 75 optional :duration, Float |
#last_row_id ⇒ Integer?
Rowid of the last inserted row, when applicable.
81 |
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 81 optional :last_row_id, Integer |
#rows_read ⇒ Integer?
86 |
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 86 optional :rows_read, Integer |
#rows_written ⇒ Integer?
91 |
# File 'lib/telnyx/models/storage/sqldbs/action_query_response.rb', line 91 optional :rows_written, Integer |
Instance Method Details
#to_hash ⇒ {
111 |
# File 'sig/telnyx/models/storage/sqldbs/action_query_response.rbs', line 111
def to_hash: -> {
|