Class: Telnyx::Models::StreamClientEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::StreamClientEvent
- Defined in:
- lib/telnyx/models/stream_client_event.rb,
sig/telnyx/models/stream_client_event.rbs
Instance Attribute Summary collapse
-
#force ⇒ Boolean?
When
true, stops the current synthesis worker and starts a new one. -
#text ⇒ String
Text to convert to speech.
-
#voice_settings ⇒ Hash{Symbol=>Object}?
Provider-specific voice settings sent with the initial handshake.
Instance Method Summary collapse
-
#initialize(text:, force: nil, voice_settings: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see StreamClientEvent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(text:, force: nil, voice_settings: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::StreamClientEvent for more details.
Client-to-server frame containing text to synthesize.
|
|
# File 'lib/telnyx/models/stream_client_event.rb', line 29
|
Instance Attribute Details
#force ⇒ Boolean?
When true, stops the current synthesis worker and starts a new one. Used to
interrupt speech mid-stream and begin synthesizing new text.
19 |
# File 'lib/telnyx/models/stream_client_event.rb', line 19 optional :force, Telnyx::Internal::Type::Boolean |
#text ⇒ String
Text to convert to speech. Send " " (single space) as an initial handshake
with optional voice_settings. Subsequent messages contain the actual text to
synthesize.
12 |
# File 'lib/telnyx/models/stream_client_event.rb', line 12 required :text, String |
#voice_settings ⇒ Hash{Symbol=>Object}?
Provider-specific voice settings sent with the initial handshake. Contents vary
by provider — e.g. {"speed": 1.2} for Minimax, {"voice_speed": 1.5} for
Telnyx.
27 |
# File 'lib/telnyx/models/stream_client_event.rb', line 27 optional :voice_settings, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/telnyx/models/stream_client_event.rbs', line 23
def to_hash: -> {
|