Class: Telnyx::Models::SubNumberOrder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/sub_number_order.rb

Defined Under Namespace

Modules: PhoneNumberType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, country_code: nil, created_at: nil, customer_reference: nil, is_block_sub_number_order: nil, order_request_id: nil, phone_number_type: nil, phone_numbers_count: nil, record_type: nil, regulatory_requirements: nil, requirements_met: nil, status: nil, updated_at: nil, user_id: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)
  • country_code (String) (defaults to: nil)
  • created_at (Time) (defaults to: nil)

    An ISO 8901 datetime string denoting when the number order was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • is_block_sub_number_order (Boolean) (defaults to: nil)

    True if the sub number order is a block sub number order

  • order_request_id (String) (defaults to: nil)
  • phone_number_type (Symbol, Telnyx::Models::SubNumberOrder::PhoneNumberType) (defaults to: nil)
  • phone_numbers_count (Integer) (defaults to: nil)

    The count of phone numbers in the number order.

  • record_type (String) (defaults to: nil)
  • regulatory_requirements (Array<Telnyx::Models::SubNumberOrderRegulatoryRequirement>) (defaults to: nil)
  • requirements_met (Boolean) (defaults to: nil)

    True if all requirements are met for every phone number, false otherwise.

  • status (Symbol, Telnyx::Models::SubNumberOrder::Status) (defaults to: nil)

    The status of the order.

  • updated_at (Time) (defaults to: nil)

    An ISO 8901 datetime string for when the number order was updated.

  • user_id (String) (defaults to: nil)


# File 'lib/telnyx/models/sub_number_order.rb', line 86

Instance Attribute Details

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


10
# File 'lib/telnyx/models/sub_number_order.rb', line 10

optional :customer_reference, String

#phone_number_typeSymbol, ...



15
# File 'lib/telnyx/models/sub_number_order.rb', line 15

optional :phone_number_type, enum: -> { Telnyx::SubNumberOrder::PhoneNumberType }

#regulatory_requirementsArray<Telnyx::Models::SubNumberOrderRegulatoryRequirement>?



20
21
# File 'lib/telnyx/models/sub_number_order.rb', line 20

optional :regulatory_requirements,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::SubNumberOrderRegulatoryRequirement] }

#user_idString?

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/sub_number_order.rb', line 26

optional :user_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/sub_number_order.rb', line 126