Class: Telnyx::Models::SubNumberOrdersReportAPI
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::SubNumberOrdersReportAPI
- Defined in:
- lib/telnyx/models/sub_number_orders_report.rb,
sig/telnyx/models/sub_number_orders_report.rbs
Defined Under Namespace
Modules: Status Classes: Filters
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
readonly
Returns the value of attribute created_at.
-
#filters ⇒ Telnyx::Models::SubNumberOrdersReportAPI::Filters?
The filters that were applied to generate this report.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#order_type ⇒ String?
readonly
Returns the value of attribute order_type.
-
#status ⇒ Symbol, ...
Indicates the completion level of the sub number orders report.
-
#updated_at ⇒ Time?
readonly
Returns the value of attribute updated_at.
-
#user_id ⇒ String?
readonly
Returns the value of attribute user_id.
Instance Method Summary collapse
- #created_at ⇒ Time readonly
- #id ⇒ String readonly
-
#initialize(country_code: nil, created_at_gt: nil, created_at_lt: nil, customer_reference: nil, order_request_id: nil, status: nil) ⇒ Object
constructor
The filters that were applied to generate this report.
- #order_type ⇒ String readonly
- #to_hash ⇒ {
- #updated_at ⇒ Time readonly
- #user_id ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country_code: nil, created_at_gt: nil, created_at_lt: nil, customer_reference: nil, order_request_id: nil, status: nil) ⇒ Object
The filters that were applied to generate this report
|
|
# File 'lib/telnyx/models/sub_number_orders_report.rb', line 51
|
Instance Attribute Details
#created_at ⇒ Time? (readonly)
Returns the value of attribute created_at.
31 32 33 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 31 def created_at @created_at end |
#filters ⇒ Telnyx::Models::SubNumberOrdersReportAPI::Filters?
The filters that were applied to generate this report
10 |
# File 'lib/telnyx/models/sub_number_orders_report.rb', line 10 optional :filters, -> { Telnyx::SubNumberOrdersReportAPI::Filters } |
#id ⇒ String? (readonly)
Returns the value of attribute id.
27 28 29 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 27 def id @id end |
#order_type ⇒ String? (readonly)
Returns the value of attribute order_type.
35 36 37 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 35 def order_type @order_type end |
#status ⇒ Symbol, ...
Indicates the completion level of the sub number orders report. The report must have a status of 'success' before it can be downloaded.
17 |
# File 'lib/telnyx/models/sub_number_orders_report.rb', line 17 optional :status, enum: -> { Telnyx::SubNumberOrdersReportAPI::Status } |
#updated_at ⇒ Time? (readonly)
Returns the value of attribute updated_at.
39 40 41 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 39 def updated_at @updated_at end |
#user_id ⇒ String? (readonly)
Returns the value of attribute user_id.
43 44 45 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 43 def user_id @user_id end |
Instance Method Details
#created_at= ⇒ Time (readonly)
33 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 33
def created_at=: (Time) -> Time
|
#id= ⇒ String (readonly)
29 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 29
def id=: (String) -> String
|
#order_type= ⇒ String (readonly)
37 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 37
def order_type=: (String) -> String
|
#to_hash ⇒ {
57 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 57
def to_hash: -> {
|
#updated_at= ⇒ Time (readonly)
41 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 41
def updated_at=: (Time) -> Time
|
#user_id= ⇒ String (readonly)
45 |
# File 'sig/telnyx/models/sub_number_orders_report.rbs', line 45
def user_id=: (String) -> String
|