Class: Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse
- Defined in:
- lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb
Overview
Defined Under Namespace
Classes: Transcription
Instance Attribute Summary collapse
-
#end_ ⇒ Integer?
The number of the last element on the page, zero-indexed.
-
#first_page_uri ⇒ String?
Relative uri to the first page of the query results.
-
#next_page_uri ⇒ String?
Relative uri to the next page of the query results.
-
#page ⇒ Integer?
Current page number, zero-indexed.
-
#page_size ⇒ Integer?
The number of items on the page.
-
#previous_page_uri ⇒ String?
Relative uri to the previous page of the query results.
-
#start ⇒ Integer?
The number of the first element on the page, zero-indexed.
- #transcriptions ⇒ Array<Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription>?
-
#uri ⇒ String?
The URI of the current page.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#end_ ⇒ Integer?
The number of the last element on the page, zero-indexed
12 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 12 optional :end_, Integer, api_name: :end |
#first_page_uri ⇒ String?
Relative uri to the first page of the query results
18 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 18 optional :first_page_uri, String |
#next_page_uri ⇒ String?
Relative uri to the next page of the query results
24 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 24 optional :next_page_uri, String |
#page ⇒ Integer?
Current page number, zero-indexed.
30 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 30 optional :page, Integer |
#page_size ⇒ Integer?
The number of items on the page
36 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 36 optional :page_size, Integer |
#previous_page_uri ⇒ String?
Relative uri to the previous page of the query results
42 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 42 optional :previous_page_uri, String |
#start ⇒ Integer?
The number of the first element on the page, zero-indexed.
48 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 48 optional :start, Integer |
#transcriptions ⇒ Array<Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription>?
53 54 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 53 optional :transcriptions, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::Texml::AccountRetrieveTranscriptionsJsonResponse::Transcription] } |
#uri ⇒ String?
The URI of the current page.
60 |
# File 'lib/telnyx/models/texml/account_retrieve_transcriptions_json_response.rb', line 60 optional :uri, String |