Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Body::ApplicationDefault

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb,
sig/telnyx/models/texml/accounts/call_calls_params.rbs

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1773

Instance Attribute Details

#application_sidString?

The ID of the TeXML Application.

Parameters:

  • (String)

Returns:

  • (String, nil)


1404
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1404

optional :application_sid, String, api_name: :ApplicationSid

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1411
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1411

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Parameters:

  • (String)

Returns:

  • (String, nil)


1417
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1417

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for AsyncAmdStatusCallback. The default value is inherited from TeXML Application setting.



1424
1425
1426
1427
1428
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1424

optional :async_amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::AsyncAmdStatusCallbackMethod
},
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (To number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and -_~!.+ special characters. If ommited, the display name will be the same as the number in the From field.

Parameters:

  • (String)

Returns:

  • (String, nil)


1437
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1437

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on greeting ended detection. Defaults to true.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1444
1445
1446
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1444

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on machine detection. Defaults to true.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1452
1453
1454
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1452

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#custom_headersArray<Telnyx::Models::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with 'name' and 'value' properties.



1461
1462
1463
1464
1465
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1461

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::CustomHeader]
},
api_name: :CustomHeaders

#deepfake_detectionSymbol, ...

Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.



1473
1474
1475
1476
1477
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1473

optional :deepfake_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::DeepfakeDetection
},
api_name: :DeepfakeDetection

#deepfake_detection_callback_methodSymbol, ...

HTTP request type used for DeepfakeDetectionCallbackUrl.



1483
1484
1485
1486
1487
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1483

optional :deepfake_detection_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::DeepfakeDetectionCallbackMethod
},
api_name: :DeepfakeDetectionCallbackMethod

#deepfake_detection_callback_urlString?

URL destination for Telnyx to send deepfake detection callback events to for the call.

Parameters:

  • (String)

Returns:

  • (String, nil)


1494
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1494

optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl

#detection_modeSymbol, ...

Allows you to choose between Regular, Premium, and PremiumCallScreening detections. See https://developers.telnyx.com/docs/voice/programmable-voice/answering-machine-detection



1502
1503
1504
1505
1506
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1502

optional :detection_mode,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::DetectionMode
},
api_name: :DetectionMode

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the Url is not responding.

Parameters:

  • (String)

Returns:

  • (String, nil)


1513
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1513

optional :fallback_url, String, api_name: :FallbackUrl

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a + and country code.

Parameters:

  • (String)

Returns:

  • (String, nil)


1520
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1520

optional :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



1526
1527
1528
1529
1530
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1526

optional :machine_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::MachineDetection
},
api_name: :MachineDetection

#machine_detection_prompt_end_timeoutInteger?

Silence duration threshold after a call screening prompt before ending prompt detection, in milliseconds. Used when DetectionMode is PremiumCallScreening.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1537
1538
1539
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1537

optional :machine_detection_prompt_end_timeout,
Integer,
api_name: :MachineDetectionPromptEndTimeout

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when premium detection is used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1546
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1546

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when premium detection is used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1553
1554
1555
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1553

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when premium detection is used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1562
1563
1564
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1562

optional :machine_detection_speech_threshold,
Integer,
api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1570
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1570

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the call. When set to SRTP, the call will use Secure Real-time Transport Protocol for media encryption. When set to DTLS, the call will use DTLS for media encryption. Only supported for SIP destinations.



1579
1580
1581
1582
1583
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1579

optional :media_encryption,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::MediaEncryption
},
api_name: :MediaEncryption

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Parameters:

  • (String)

Returns:

  • (String, nil)


1589
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1589

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant's call leg. Defaults to false.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1595
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1595

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to mono.



1601
1602
1603
1604
1605
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1601

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Parameters:

  • (String)

Returns:

  • (String, nil)


1611
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1611

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording's state that should generate a call to RecoridngStatusCallback. Can be: in-progress, completed and absent. Separate multiple values with a space. Defaults to completed.

Parameters:

  • (String)

Returns:

  • (String, nil)


1619
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1619

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for RecordingStatusCallback. Defaults to POST.



1625
1626
1627
1628
1629
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1625

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1638
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1638

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is both.



1644
1645
1646
1647
1648
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1644

optional :recording_track,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::RecordingTrack
},
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1654
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1654

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Parameters:

  • (String)

Returns:

  • (String, nil)


1660
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1660

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Parameters:

  • (String)

Returns:

  • (String, nil)


1666
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1666

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



1672
1673
1674
1675
1676
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1672

optional :sip_region,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::SipRegion
},
api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Parameters:

  • (String)

Returns:

  • (String, nil)


1682
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1682

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventString?

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.

Parameters:

  • (String)

Returns:

  • (String, nil)


1689
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1689

optional :status_callback_event, String, api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for StatusCallback.



1695
1696
1697
1698
1699
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1695

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#supervise_call_sidString?

The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.

Parameters:

  • (String)

Returns:

  • (String, nil)


1707
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1707

optional :supervise_call_sid, String, api_name: :SuperviseCallSid

#supervising_roleSymbol, ...

The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge



1715
1716
1717
1718
1719
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1715

optional :supervising_role,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::SupervisingRole
},
api_name: :SupervisingRole

#texmlString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1724
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1724

optional :texml, String, api_name: :Texml, nil?: true

#time_limitInteger?

The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1731
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1731

optional :time_limit, Integer, api_name: :TimeLimit

#timeoutInteger?

The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1739
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1739

optional :timeout, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a + and country code.

Parameters:

  • (String)

Returns:

  • (String, nil)


1746
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1746

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to trim-silence.



1753
1754
1755
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1753

optional :trim,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::Trim },
api_name: :Trim

#urlString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1760
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1760

optional :url, String, api_name: :Url, nil?: true

#url_methodSymbol, ...

HTTP request type used for Url. The default value is inherited from TeXML Application setting.



1767
1768
1769
1770
1771
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1767

optional :url_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::ApplicationDefault::URLMethod
},
api_name: :UrlMethod

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1878

Instance Method Details

#to_hash{

Returns:

  • ({)


1398
# File 'sig/telnyx/models/texml/accounts/call_calls_params.rbs', line 1398

def to_hash: -> {