Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithTeXml

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackEvent, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1107

Instance Attribute Details

#application_sidString?

The ID of the TeXML Application.

Returns:

  • (String, nil)


747
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 747

optional :application_sid, String, api_name: :ApplicationSid

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Returns:

  • (Boolean, nil)


754
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 754

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Returns:

  • (String, nil)


760
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 760

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for ‘AsyncAmdStatusCallback`. The default value is inherited from TeXML Application setting.



767
768
769
770
771
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 767

optional :async_amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::AsyncAmdStatusCallbackMethod
},
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.

Returns:

  • (String, nil)


780
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 780

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


787
788
789
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 787

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


795
796
797
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 795

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#custom_headersArray<Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithTeXml::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.



804
805
806
807
808
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 804

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::CustomHeader]
},
api_name: :CustomHeaders

#deepfake_detectionSymbol, ...

Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.



816
817
818
819
820
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 816

optional :deepfake_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::DeepfakeDetection
},
api_name: :DeepfakeDetection

#deepfake_detection_callback_methodSymbol, ...

HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.



826
827
828
829
830
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 826

optional :deepfake_detection_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::DeepfakeDetectionCallbackMethod
},
api_name: :DeepfakeDetectionCallbackMethod

#deepfake_detection_callback_urlString?

URL destination for Telnyx to send deepfake detection callback events to for the call.

Returns:

  • (String, nil)


837
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 837

optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl

#detection_modeSymbol, ...

Allows you to choose between Regular, Premium, and PremiumCallScreening detections. See developers.telnyx.com/docs/voice/programmable-voice/answering-machine-detection



845
846
847
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 845

optional :detection_mode,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::DetectionMode },
api_name: :DetectionMode

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.

Returns:

  • (String, nil)


854
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 854

optional :fallback_url, String, api_name: :FallbackUrl

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


861
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 861

optional :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



867
868
869
870
871
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 867

optional :machine_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::MachineDetection
},
api_name: :MachineDetection

#machine_detection_prompt_end_timeoutInteger?

Silence duration threshold after a call screening prompt before ending prompt detection, in milliseconds. Used when ‘DetectionMode` is `PremiumCallScreening`.

Returns:

  • (Integer, nil)


878
879
880
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 878

optional :machine_detection_prompt_end_timeout,
Integer,
api_name: :MachineDetectionPromptEndTimeout

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


887
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 887

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


894
895
896
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 894

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


903
904
905
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 903

optional :machine_detection_speech_threshold,
Integer,
api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Returns:

  • (Integer, nil)


911
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 911

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the call. When set to ‘SRTP`, the call will use Secure Real-time Transport Protocol for media encryption. When set to `DTLS`, the call will use DTLS for media encryption. Only supported for SIP destinations.



920
921
922
923
924
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 920

optional :media_encryption,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::MediaEncryption
},
api_name: :MediaEncryption

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Returns:

  • (String, nil)


930
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 930

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant’s call leg. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


936
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 936

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to ‘mono`.



942
943
944
945
946
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 942

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Returns:

  • (String, nil)


952
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 952

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.

Returns:

  • (String, nil)


960
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 960

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.



966
967
968
969
970
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 966

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


979
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 979

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



985
986
987
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 985

optional :recording_track,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::RecordingTrack },
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Returns:

  • (Boolean, nil)


993
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 993

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Returns:

  • (String, nil)


999
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 999

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Returns:

  • (String, nil)


1005
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1005

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



1011
1012
1013
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1011

optional :sip_region,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::SipRegion },
api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Returns:

  • (String, nil)


1019
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1019

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventSymbol, ...

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.



1026
1027
1028
1029
1030
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1026

optional :status_callback_event,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::StatusCallbackEvent
},
api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



1036
1037
1038
1039
1040
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1036

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#supervise_call_sidString?

The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.

Returns:

  • (String, nil)


1048
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1048

optional :supervise_call_sid, String, api_name: :SuperviseCallSid

#supervising_roleSymbol, ...

The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge



1056
1057
1058
1059
1060
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1056

optional :supervising_role,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::SupervisingRole
},
api_name: :SupervisingRole

#texmlString

TeXML to be used as instructions for the call. If provided, the call will execute these instructions instead of fetching from the Url.

Returns:

  • (String)


741
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 741

required :texml, String, api_name: :Texml

#time_limitInteger?

The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.

Returns:

  • (Integer, nil)


1067
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1067

optional :time_limit, Integer, api_name: :TimeLimit

#timeoutInteger?

The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.

Returns:

  • (Integer, nil)


1075
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1075

optional :timeout, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


1082
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1082

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.



1089
1090
1091
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1089

optional :trim,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::Trim },
api_name: :Trim

#urlString?

Returns:

  • (String, nil)


1096
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1096

optional :url, String, api_name: :Url, nil?: true

#url_methodSymbol, ...

HTTP request type used for ‘Url`. The default value is inherited from TeXML Application setting.



1103
1104
1105
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1103

optional :url_method,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithTeXml::URLMethod },
api_name: :UrlMethod

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1212