Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithURL

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackEvent, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 403

Instance Attribute Details

#application_sidString?

The ID of the TeXML Application.

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 49

optional :application_sid, String, api_name: :ApplicationSid

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Returns:

  • (Boolean, nil)


56
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 56

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 62

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for ‘AsyncAmdStatusCallback`. The default value is inherited from TeXML Application setting.



69
70
71
72
73
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 69

optional :async_amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::AsyncAmdStatusCallbackMethod
},
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 82

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


89
90
91
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 89

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


97
98
99
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 97

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#custom_headersArray<Telnyx::Models::Texml::Accounts::CallCallsParams::Body::WithURL::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.



106
107
108
109
110
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 106

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::CustomHeader]
},
api_name: :CustomHeaders

#deepfake_detectionSymbol, ...

Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.



118
119
120
121
122
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 118

optional :deepfake_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::DeepfakeDetection
},
api_name: :DeepfakeDetection

#deepfake_detection_callback_methodSymbol, ...

HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.



128
129
130
131
132
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 128

optional :deepfake_detection_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::DeepfakeDetectionCallbackMethod
},
api_name: :DeepfakeDetectionCallbackMethod

#deepfake_detection_callback_urlString?

URL destination for Telnyx to send deepfake detection callback events to for the call.

Returns:

  • (String, nil)


139
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 139

optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl

#detection_modeSymbol, ...

Allows you to choose between Regular, Premium, and PremiumCallScreening detections. See developers.telnyx.com/docs/voice/programmable-voice/answering-machine-detection



147
148
149
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 147

optional :detection_mode,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::DetectionMode },
api_name: :DetectionMode

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.

Returns:

  • (String, nil)


156
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 156

optional :fallback_url, String, api_name: :FallbackUrl

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


163
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 163

optional :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



169
170
171
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 169

optional :machine_detection,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::MachineDetection },
api_name: :MachineDetection

#machine_detection_prompt_end_timeoutInteger?

Silence duration threshold after a call screening prompt before ending prompt detection, in milliseconds. Used when ‘DetectionMode` is `PremiumCallScreening`.

Returns:

  • (Integer, nil)


178
179
180
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 178

optional :machine_detection_prompt_end_timeout,
Integer,
api_name: :MachineDetectionPromptEndTimeout

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


187
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 187

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


194
195
196
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 194

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


203
204
205
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 203

optional :machine_detection_speech_threshold,
Integer,
api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Returns:

  • (Integer, nil)


211
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 211

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the call. When set to ‘SRTP`, the call will use Secure Real-time Transport Protocol for media encryption. When set to `DTLS`, the call will use DTLS for media encryption. Only supported for SIP destinations.



220
221
222
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 220

optional :media_encryption,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::MediaEncryption },
api_name: :MediaEncryption

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Returns:

  • (String, nil)


228
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 228

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant’s call leg. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


234
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 234

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to ‘mono`.



240
241
242
243
244
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 240

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Returns:

  • (String, nil)


250
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 250

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.

Returns:

  • (String, nil)


258
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 258

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.



264
265
266
267
268
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 264

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


277
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 277

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



283
284
285
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 283

optional :recording_track,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::RecordingTrack },
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Returns:

  • (Boolean, nil)


291
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 291

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Returns:

  • (String, nil)


297
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 297

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Returns:

  • (String, nil)


303
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 303

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



309
310
311
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 309

optional :sip_region,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::SipRegion },
api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Returns:

  • (String, nil)


317
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 317

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventSymbol, ...

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.



324
325
326
327
328
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 324

optional :status_callback_event,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::StatusCallbackEvent
},
api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



334
335
336
337
338
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 334

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#supervise_call_sidString?

The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.

Returns:

  • (String, nil)


346
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 346

optional :supervise_call_sid, String, api_name: :SuperviseCallSid

#supervising_roleSymbol, ...

The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge



354
355
356
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 354

optional :supervising_role,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::SupervisingRole },
api_name: :SupervisingRole

#texmlString?

Returns:

  • (String, nil)


361
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 361

optional :texml, String, api_name: :Texml, nil?: true

#time_limitInteger?

The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.

Returns:

  • (Integer, nil)


368
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 368

optional :time_limit, Integer, api_name: :TimeLimit

#timeoutInteger?

The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.

Returns:

  • (Integer, nil)


376
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 376

optional :timeout, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


383
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 383

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.



390
391
392
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 390

optional :trim,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::Trim },
api_name: :Trim

#urlString

The URL from which Telnyx will retrieve the TeXML call instructions.

Returns:

  • (String)


43
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 43

required :url, String, api_name: :Url

#url_methodSymbol, ...

HTTP request type used for ‘Url`. The default value is inherited from TeXML Application setting.



399
400
401
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 399

optional :url_method,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Body::WithURL::URLMethod },
api_name: :UrlMethod

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 508