Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Params::ApplicationDefault
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::CallCallsParams::Params::ApplicationDefault
- Defined in:
- lib/telnyx/models/texml/accounts/call_calls_params.rb
Defined Under Namespace
Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackEvent, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader
Instance Attribute Summary collapse
-
#application_sid ⇒ String?
The ID of the TeXML Application.
-
#async_amd ⇒ Boolean?
Select whether to perform answering machine detection in the background.
-
#async_amd_status_callback ⇒ String?
URL destination for Telnyx to send AMD callback events to for the call.
-
#async_amd_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘AsyncAmdStatusCallback`.
-
#caller_id ⇒ String?
To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number).
-
#cancel_playback_on_detect_message_end ⇒ Boolean?
Whether to cancel ongoing playback on ‘greeting ended` detection.
-
#cancel_playback_on_machine_detection ⇒ Boolean?
Whether to cancel ongoing playback on ‘machine` detection.
-
#custom_headers ⇒ Array<Telnyx::Models::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::CustomHeader>?
Custom HTTP headers to be sent with the call.
-
#deepfake_detection ⇒ Symbol, ...
Enables Deepfake Detection on the dialed call.
-
#deepfake_detection_callback_method ⇒ Symbol, ...
HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.
-
#deepfake_detection_callback_url ⇒ String?
URL destination for Telnyx to send deepfake detection callback events to for the call.
-
#detection_mode ⇒ Symbol, ...
Allows you to choose between Regular, Premium, and PremiumCallScreening detections.
-
#fallback_url ⇒ String?
A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.
-
#from ⇒ String?
The phone number of the party that initiated the call.
-
#machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection.
-
#machine_detection_prompt_end_timeout ⇒ Integer?
Silence duration threshold after a call screening prompt before ending prompt detection, in milliseconds.
-
#machine_detection_silence_timeout ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine.
-
#machine_detection_speech_end_threshold ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human.
-
#machine_detection_speech_threshold ⇒ Integer?
Maximum threshold of a human greeting.
-
#machine_detection_timeout ⇒ Integer?
Maximum timeout threshold in milliseconds for overall detection.
-
#media_encryption ⇒ Symbol, ...
Defines whether media should be encrypted on the call.
-
#preferred_codecs ⇒ String?
The list of comma-separated codecs to be offered on a call.
-
#record ⇒ Boolean?
Whether to record the entire participant’s call leg.
-
#recording_channels ⇒ Symbol, ...
The number of channels in the final recording.
-
#recording_status_callback ⇒ String?
The URL the recording callbacks will be sent to.
-
#recording_status_callback_event ⇒ String?
The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`.
-
#recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘RecordingStatusCallback`.
-
#recording_timeout ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected.
-
#recording_track ⇒ Symbol, ...
The audio track to record for the call.
-
#send_recording_url ⇒ Boolean?
Whether to send RecordingUrl in webhooks.
-
#sip_auth_password ⇒ String?
The password to use for SIP authentication.
-
#sip_auth_username ⇒ String?
The username to use for SIP authentication.
-
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
-
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events to for the call.
-
#status_callback_event ⇒ Symbol, ...
The call events for which Telnyx should send a webhook.
-
#status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘StatusCallback`.
-
#supervise_call_sid ⇒ String?
The call control ID of the existing call to supervise.
-
#supervising_role ⇒ Symbol, ...
The supervising role for the new leg.
- #texml ⇒ String?
-
#time_limit ⇒ Integer?
The maximum duration of the call in seconds.
-
#timeout ⇒ Integer?
The number of seconds to wait for the called party to answer the call before the call is canceled.
-
#to ⇒ String?
The phone number of the called party.
-
#trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the recording.
- #url ⇒ String?
-
#url_method ⇒ Symbol, ...
HTTP request type used for ‘Url`.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(name:, value:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, value:) ⇒ Object
|
|
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1829
|
Instance Attribute Details
#application_sid ⇒ String?
The ID of the TeXML Application.
1454 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1454 optional :application_sid, String, api_name: :ApplicationSid |
#async_amd ⇒ Boolean?
Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.
1461 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1461 optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd |
#async_amd_status_callback ⇒ String?
URL destination for Telnyx to send AMD callback events to for the call.
1467 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1467 optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback |
#async_amd_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘AsyncAmdStatusCallback`. The default value is inherited from TeXML Application setting.
1474 1475 1476 1477 1478 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1474 optional :async_amd_status_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::AsyncAmdStatusCallbackMethod }, api_name: :AsyncAmdStatusCallbackMethod |
#caller_id ⇒ String?
To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.
1487 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1487 optional :caller_id, String, api_name: :CallerId |
#cancel_playback_on_detect_message_end ⇒ Boolean?
Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.
1494 1495 1496 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1494 optional :cancel_playback_on_detect_message_end, Telnyx::Internal::Type::Boolean, api_name: :CancelPlaybackOnDetectMessageEnd |
#cancel_playback_on_machine_detection ⇒ Boolean?
Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.
1502 1503 1504 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1502 optional :cancel_playback_on_machine_detection, Telnyx::Internal::Type::Boolean, api_name: :CancelPlaybackOnMachineDetection |
#custom_headers ⇒ Array<Telnyx::Models::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::CustomHeader>?
Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.
1511 1512 1513 1514 1515 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1511 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::CustomHeader] }, api_name: :CustomHeaders |
#deepfake_detection ⇒ Symbol, ...
Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.
1523 1524 1525 1526 1527 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1523 optional :deepfake_detection, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::DeepfakeDetection }, api_name: :DeepfakeDetection |
#deepfake_detection_callback_method ⇒ Symbol, ...
HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.
1533 1534 1535 1536 1537 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1533 optional :deepfake_detection_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::DeepfakeDetectionCallbackMethod }, api_name: :DeepfakeDetectionCallbackMethod |
#deepfake_detection_callback_url ⇒ String?
URL destination for Telnyx to send deepfake detection callback events to for the call.
1544 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1544 optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl |
#detection_mode ⇒ Symbol, ...
Allows you to choose between Regular, Premium, and PremiumCallScreening detections. See developers.telnyx.com/docs/voice/programmable-voice/answering-machine-detection
1552 1553 1554 1555 1556 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1552 optional :detection_mode, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::DetectionMode }, api_name: :DetectionMode |
#fallback_url ⇒ String?
A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.
1563 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1563 optional :fallback_url, String, api_name: :FallbackUrl |
#from ⇒ String?
The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.
1570 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1570 optional :from, String, api_name: :From |
#machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection.
1576 1577 1578 1579 1580 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1576 optional :machine_detection, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::MachineDetection }, api_name: :MachineDetection |
#machine_detection_prompt_end_timeout ⇒ Integer?
Silence duration threshold after a call screening prompt before ending prompt detection, in milliseconds. Used when ‘DetectionMode` is `PremiumCallScreening`.
1587 1588 1589 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1587 optional :machine_detection_prompt_end_timeout, Integer, api_name: :MachineDetectionPromptEndTimeout |
#machine_detection_silence_timeout ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.
1596 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1596 optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout |
#machine_detection_speech_end_threshold ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.
1603 1604 1605 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1603 optional :machine_detection_speech_end_threshold, Integer, api_name: :MachineDetectionSpeechEndThreshold |
#machine_detection_speech_threshold ⇒ Integer?
Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.
1612 1613 1614 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1612 optional :machine_detection_speech_threshold, Integer, api_name: :MachineDetectionSpeechThreshold |
#machine_detection_timeout ⇒ Integer?
Maximum timeout threshold in milliseconds for overall detection.
1620 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1620 optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout |
#media_encryption ⇒ Symbol, ...
Defines whether media should be encrypted on the call. When set to ‘SRTP`, the call will use Secure Real-time Transport Protocol for media encryption. When set to `DTLS`, the call will use DTLS for media encryption. Only supported for SIP destinations.
1629 1630 1631 1632 1633 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1629 optional :media_encryption, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::MediaEncryption }, api_name: :MediaEncryption |
#preferred_codecs ⇒ String?
The list of comma-separated codecs to be offered on a call.
1639 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1639 optional :preferred_codecs, String, api_name: :PreferredCodecs |
#record ⇒ Boolean?
Whether to record the entire participant’s call leg. Defaults to ‘false`.
1645 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1645 optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record |
#recording_channels ⇒ Symbol, ...
The number of channels in the final recording. Defaults to ‘mono`.
1651 1652 1653 1654 1655 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1651 optional :recording_channels, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::RecordingChannels }, api_name: :RecordingChannels |
#recording_status_callback ⇒ String?
The URL the recording callbacks will be sent to.
1661 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1661 optional :recording_status_callback, String, api_name: :RecordingStatusCallback |
#recording_status_callback_event ⇒ String?
The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.
1669 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1669 optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent |
#recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.
1675 1676 1677 1678 1679 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1675 optional :recording_status_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::RecordingStatusCallbackMethod }, api_name: :RecordingStatusCallbackMethod |
#recording_timeout ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)
1688 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1688 optional :recording_timeout, Integer, api_name: :RecordingTimeout |
#recording_track ⇒ Symbol, ...
The audio track to record for the call. The default is ‘both`.
1694 1695 1696 1697 1698 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1694 optional :recording_track, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::RecordingTrack }, api_name: :RecordingTrack |
#send_recording_url ⇒ Boolean?
Whether to send RecordingUrl in webhooks.
1704 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1704 optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl |
#sip_auth_password ⇒ String?
The password to use for SIP authentication.
1710 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1710 optional :sip_auth_password, String, api_name: :SipAuthPassword |
#sip_auth_username ⇒ String?
The username to use for SIP authentication.
1716 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1716 optional :sip_auth_username, String, api_name: :SipAuthUsername |
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
1722 1723 1724 1725 1726 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1722 optional :sip_region, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::SipRegion }, api_name: :SipRegion |
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events to for the call.
1732 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1732 optional :status_callback, String, api_name: :StatusCallback |
#status_callback_event ⇒ Symbol, ...
The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.
1739 1740 1741 1742 1743 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1739 optional :status_callback_event, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::StatusCallbackEvent }, api_name: :StatusCallbackEvent |
#status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘StatusCallback`.
1749 1750 1751 1752 1753 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1749 optional :status_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::StatusCallbackMethod }, api_name: :StatusCallbackMethod |
#supervise_call_sid ⇒ String?
The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.
1761 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1761 optional :supervise_call_sid, String, api_name: :SuperviseCallSid |
#supervising_role ⇒ Symbol, ...
The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge
1769 1770 1771 1772 1773 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1769 optional :supervising_role, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::SupervisingRole }, api_name: :SupervisingRole |
#texml ⇒ String?
1778 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1778 optional :texml, String, api_name: :Texml, nil?: true |
#time_limit ⇒ Integer?
The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.
1785 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1785 optional :time_limit, Integer, api_name: :TimeLimit |
#timeout ⇒ Integer?
The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.
1793 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1793 optional :timeout, Integer, api_name: :Timeout |
#to ⇒ String?
The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.
1800 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1800 optional :to, String, api_name: :To |
#trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.
1807 1808 1809 1810 1811 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1807 optional :trim, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::Trim }, api_name: :Trim |
#url ⇒ String?
1816 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1816 optional :url, String, api_name: :Url, nil?: true |
#url_method ⇒ Symbol, ...
HTTP request type used for ‘Url`. The default value is inherited from TeXML Application setting.
1823 1824 1825 1826 1827 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1823 optional :url_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::URLMethod }, api_name: :UrlMethod |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1934
|