Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Params::ApplicationDefault

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackEvent, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1784

Instance Attribute Details

#application_sidString?

The ID of the TeXML Application.

Returns:

  • (String, nil)


1420
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1420

optional :application_sid, String, api_name: :ApplicationSid

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Returns:

  • (Boolean, nil)


1427
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1427

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Returns:

  • (String, nil)


1433
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1433

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for ‘AsyncAmdStatusCallback`. The default value is inherited from TeXML Application setting.



1440
1441
1442
1443
1444
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1440

optional :async_amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::AsyncAmdStatusCallbackMethod
},
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.

Returns:

  • (String, nil)


1453
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1453

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


1460
1461
1462
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1460

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


1468
1469
1470
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1468

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#custom_headersArray<Telnyx::Models::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.



1477
1478
1479
1480
1481
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1477

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::CustomHeader]
},
api_name: :CustomHeaders

#deepfake_detectionSymbol, ...

Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.



1489
1490
1491
1492
1493
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1489

optional :deepfake_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::DeepfakeDetection
},
api_name: :DeepfakeDetection

#deepfake_detection_callback_methodSymbol, ...

HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.



1499
1500
1501
1502
1503
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1499

optional :deepfake_detection_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::DeepfakeDetectionCallbackMethod
},
api_name: :DeepfakeDetectionCallbackMethod

#deepfake_detection_callback_urlString?

URL destination for Telnyx to send deepfake detection callback events to for the call.

Returns:

  • (String, nil)


1510
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1510

optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl

#detection_modeSymbol, ...

Allows you to chose between Premium and Standard detections.



1516
1517
1518
1519
1520
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1516

optional :detection_mode,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::DetectionMode
},
api_name: :DetectionMode

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.

Returns:

  • (String, nil)


1527
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1527

optional :fallback_url, String, api_name: :FallbackUrl

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


1534
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1534

optional :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



1540
1541
1542
1543
1544
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1540

optional :machine_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::MachineDetection
},
api_name: :MachineDetection

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


1551
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1551

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


1558
1559
1560
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1558

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


1567
1568
1569
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1567

optional :machine_detection_speech_threshold,
Integer,
api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Returns:

  • (Integer, nil)


1575
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1575

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the call. When set to ‘SRTP`, the call will use Secure Real-time Transport Protocol for media encryption. When set to `DTLS`, the call will use DTLS for media encryption. Only supported for SIP destinations.



1584
1585
1586
1587
1588
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1584

optional :media_encryption,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::MediaEncryption
},
api_name: :MediaEncryption

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Returns:

  • (String, nil)


1594
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1594

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant’s call leg. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


1600
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1600

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to ‘mono`.



1606
1607
1608
1609
1610
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1606

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Returns:

  • (String, nil)


1616
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1616

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.

Returns:

  • (String, nil)


1624
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1624

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.



1630
1631
1632
1633
1634
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1630

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


1643
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1643

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



1649
1650
1651
1652
1653
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1649

optional :recording_track,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::RecordingTrack
},
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Returns:

  • (Boolean, nil)


1659
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1659

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Returns:

  • (String, nil)


1665
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1665

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Returns:

  • (String, nil)


1671
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1671

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



1677
1678
1679
1680
1681
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1677

optional :sip_region,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::SipRegion
},
api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Returns:

  • (String, nil)


1687
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1687

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventSymbol, ...

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.



1694
1695
1696
1697
1698
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1694

optional :status_callback_event,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::StatusCallbackEvent
},
api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



1704
1705
1706
1707
1708
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1704

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#supervise_call_sidString?

The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.

Returns:

  • (String, nil)


1716
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1716

optional :supervise_call_sid, String, api_name: :SuperviseCallSid

#supervising_roleSymbol, ...

The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge



1724
1725
1726
1727
1728
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1724

optional :supervising_role,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::SupervisingRole
},
api_name: :SupervisingRole

#texmlString?

Returns:

  • (String, nil)


1733
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1733

optional :texml, String, api_name: :Texml, nil?: true

#time_limitInteger?

The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.

Returns:

  • (Integer, nil)


1740
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1740

optional :time_limit, Integer, api_name: :TimeLimit

#timeoutInteger?

The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.

Returns:

  • (Integer, nil)


1748
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1748

optional :timeout, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


1755
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1755

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.



1762
1763
1764
1765
1766
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1762

optional :trim,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::Trim
},
api_name: :Trim

#urlString?

Returns:

  • (String, nil)


1771
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1771

optional :url, String, api_name: :Url, nil?: true

#url_methodSymbol, ...

HTTP request type used for ‘Url`. The default value is inherited from TeXML Application setting.



1778
1779
1780
1781
1782
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1778

optional :url_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::URLMethod
},
api_name: :UrlMethod

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1887