Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Params::ApplicationDefault

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, DetectionMode, MachineDetection, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackEvent, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1631

Instance Attribute Details

#application_sidString?

The ID of the TeXML Application.

Returns:

  • (String, nil)


1296
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1296

optional :application_sid, String, api_name: :ApplicationSid

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Returns:

  • (Boolean, nil)


1303
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1303

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Returns:

  • (String, nil)


1309
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1309

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for ‘AsyncAmdStatusCallback`. The default value is inherited from TeXML Application setting.



1316
1317
1318
1319
1320
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1316

optional :async_amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::AsyncAmdStatusCallbackMethod
},
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.

Returns:

  • (String, nil)


1329
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1329

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


1336
1337
1338
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1336

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


1344
1345
1346
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1344

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#custom_headersArray<Telnyx::Models::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.



1353
1354
1355
1356
1357
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1353

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::CustomHeader]
},
api_name: :CustomHeaders

#detection_modeSymbol, ...

Allows you to chose between Premium and Standard detections.



1363
1364
1365
1366
1367
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1363

optional :detection_mode,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::DetectionMode
},
api_name: :DetectionMode

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.

Returns:

  • (String, nil)


1374
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1374

optional :fallback_url, String, api_name: :FallbackUrl

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


1381
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1381

optional :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



1387
1388
1389
1390
1391
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1387

optional :machine_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::MachineDetection
},
api_name: :MachineDetection

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


1398
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1398

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


1405
1406
1407
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1405

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


1414
1415
1416
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1414

optional :machine_detection_speech_threshold,
Integer,
api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Returns:

  • (Integer, nil)


1422
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1422

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the call. When set to ‘SRTP`, the call will use Secure Real-time Transport Protocol for media encryption. When set to `DTLS`, the call will use DTLS for media encryption. Only supported for SIP destinations.



1431
1432
1433
1434
1435
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1431

optional :media_encryption,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::MediaEncryption
},
api_name: :MediaEncryption

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Returns:

  • (String, nil)


1441
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1441

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant’s call leg. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


1447
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1447

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to ‘mono`.



1453
1454
1455
1456
1457
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1453

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Returns:

  • (String, nil)


1463
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1463

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.

Returns:

  • (String, nil)


1471
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1471

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.



1477
1478
1479
1480
1481
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1477

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


1490
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1490

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



1496
1497
1498
1499
1500
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1496

optional :recording_track,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::RecordingTrack
},
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Returns:

  • (Boolean, nil)


1506
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1506

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Returns:

  • (String, nil)


1512
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1512

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Returns:

  • (String, nil)


1518
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1518

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



1524
1525
1526
1527
1528
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1524

optional :sip_region,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::SipRegion
},
api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Returns:

  • (String, nil)


1534
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1534

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventSymbol, ...

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.



1541
1542
1543
1544
1545
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1541

optional :status_callback_event,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::StatusCallbackEvent
},
api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



1551
1552
1553
1554
1555
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1551

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#supervise_call_sidString?

The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.

Returns:

  • (String, nil)


1563
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1563

optional :supervise_call_sid, String, api_name: :SuperviseCallSid

#supervising_roleSymbol, ...

The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge



1571
1572
1573
1574
1575
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1571

optional :supervising_role,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::SupervisingRole
},
api_name: :SupervisingRole

#texmlString?

Returns:

  • (String, nil)


1580
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1580

optional :texml, String, api_name: :Texml, nil?: true

#time_limitInteger?

The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.

Returns:

  • (Integer, nil)


1587
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1587

optional :time_limit, Integer, api_name: :TimeLimit

#timeoutInteger?

The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.

Returns:

  • (Integer, nil)


1595
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1595

optional :timeout, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


1602
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1602

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.



1609
1610
1611
1612
1613
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1609

optional :trim,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::Trim
},
api_name: :Trim

#urlString?

Returns:

  • (String, nil)


1618
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1618

optional :url, String, api_name: :Url, nil?: true

#url_methodSymbol, ...

HTTP request type used for ‘Url`. The default value is inherited from TeXML Application setting.



1625
1626
1627
1628
1629
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1625

optional :url_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::ApplicationDefault::URLMethod
},
api_name: :UrlMethod

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1728