Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithTeXml
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithTeXml
- Defined in:
- lib/telnyx/models/texml/accounts/call_calls_params.rb
Defined Under Namespace
Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackEvent, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader
Instance Attribute Summary collapse
-
#application_sid ⇒ String?
The ID of the TeXML Application.
-
#async_amd ⇒ Boolean?
Select whether to perform answering machine detection in the background.
-
#async_amd_status_callback ⇒ String?
URL destination for Telnyx to send AMD callback events to for the call.
-
#async_amd_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘AsyncAmdStatusCallback`.
-
#caller_id ⇒ String?
To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number).
-
#cancel_playback_on_detect_message_end ⇒ Boolean?
Whether to cancel ongoing playback on ‘greeting ended` detection.
-
#cancel_playback_on_machine_detection ⇒ Boolean?
Whether to cancel ongoing playback on ‘machine` detection.
-
#custom_headers ⇒ Array<Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithTeXml::CustomHeader>?
Custom HTTP headers to be sent with the call.
-
#deepfake_detection ⇒ Symbol, ...
Enables Deepfake Detection on the dialed call.
-
#deepfake_detection_callback_method ⇒ Symbol, ...
HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.
-
#deepfake_detection_callback_url ⇒ String?
URL destination for Telnyx to send deepfake detection callback events to for the call.
-
#detection_mode ⇒ Symbol, ...
Allows you to choose between Regular, Premium, and PremiumCallScreening detections.
-
#fallback_url ⇒ String?
A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.
-
#from ⇒ String?
The phone number of the party that initiated the call.
-
#machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection.
-
#machine_detection_prompt_end_timeout ⇒ Integer?
Silence duration threshold after a call screening prompt before ending prompt detection, in milliseconds.
-
#machine_detection_silence_timeout ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine.
-
#machine_detection_speech_end_threshold ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human.
-
#machine_detection_speech_threshold ⇒ Integer?
Maximum threshold of a human greeting.
-
#machine_detection_timeout ⇒ Integer?
Maximum timeout threshold in milliseconds for overall detection.
-
#media_encryption ⇒ Symbol, ...
Defines whether media should be encrypted on the call.
-
#preferred_codecs ⇒ String?
The list of comma-separated codecs to be offered on a call.
-
#record ⇒ Boolean?
Whether to record the entire participant’s call leg.
-
#recording_channels ⇒ Symbol, ...
The number of channels in the final recording.
-
#recording_status_callback ⇒ String?
The URL the recording callbacks will be sent to.
-
#recording_status_callback_event ⇒ String?
The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`.
-
#recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘RecordingStatusCallback`.
-
#recording_timeout ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected.
-
#recording_track ⇒ Symbol, ...
The audio track to record for the call.
-
#send_recording_url ⇒ Boolean?
Whether to send RecordingUrl in webhooks.
-
#sip_auth_password ⇒ String?
The password to use for SIP authentication.
-
#sip_auth_username ⇒ String?
The username to use for SIP authentication.
-
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
-
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events to for the call.
-
#status_callback_event ⇒ Symbol, ...
The call events for which Telnyx should send a webhook.
-
#status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘StatusCallback`.
-
#supervise_call_sid ⇒ String?
The call control ID of the existing call to supervise.
-
#supervising_role ⇒ Symbol, ...
The supervising role for the new leg.
-
#texml ⇒ String
TeXML to be used as instructions for the call.
-
#time_limit ⇒ Integer?
The maximum duration of the call in seconds.
-
#timeout ⇒ Integer?
The number of seconds to wait for the called party to answer the call before the call is canceled.
-
#to ⇒ String?
The phone number of the called party.
-
#trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the recording.
- #url ⇒ String?
-
#url_method ⇒ Symbol, ...
HTTP request type used for ‘Url`.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(name:, value:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, value:) ⇒ Object
|
|
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1115
|
Instance Attribute Details
#application_sid ⇒ String?
The ID of the TeXML Application.
751 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 751 optional :application_sid, String, api_name: :ApplicationSid |
#async_amd ⇒ Boolean?
Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.
758 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 758 optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd |
#async_amd_status_callback ⇒ String?
URL destination for Telnyx to send AMD callback events to for the call.
764 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 764 optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback |
#async_amd_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘AsyncAmdStatusCallback`. The default value is inherited from TeXML Application setting.
771 772 773 774 775 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 771 optional :async_amd_status_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::AsyncAmdStatusCallbackMethod }, api_name: :AsyncAmdStatusCallbackMethod |
#caller_id ⇒ String?
To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.
784 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 784 optional :caller_id, String, api_name: :CallerId |
#cancel_playback_on_detect_message_end ⇒ Boolean?
Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.
791 792 793 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 791 optional :cancel_playback_on_detect_message_end, Telnyx::Internal::Type::Boolean, api_name: :CancelPlaybackOnDetectMessageEnd |
#cancel_playback_on_machine_detection ⇒ Boolean?
Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.
799 800 801 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 799 optional :cancel_playback_on_machine_detection, Telnyx::Internal::Type::Boolean, api_name: :CancelPlaybackOnMachineDetection |
#custom_headers ⇒ Array<Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithTeXml::CustomHeader>?
Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.
808 809 810 811 812 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 808 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::CustomHeader] }, api_name: :CustomHeaders |
#deepfake_detection ⇒ Symbol, ...
Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.
820 821 822 823 824 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 820 optional :deepfake_detection, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::DeepfakeDetection }, api_name: :DeepfakeDetection |
#deepfake_detection_callback_method ⇒ Symbol, ...
HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.
830 831 832 833 834 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 830 optional :deepfake_detection_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::DeepfakeDetectionCallbackMethod }, api_name: :DeepfakeDetectionCallbackMethod |
#deepfake_detection_callback_url ⇒ String?
URL destination for Telnyx to send deepfake detection callback events to for the call.
841 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 841 optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl |
#detection_mode ⇒ Symbol, ...
Allows you to choose between Regular, Premium, and PremiumCallScreening detections. See developers.telnyx.com/docs/voice/programmable-voice/answering-machine-detection
849 850 851 852 853 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 849 optional :detection_mode, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::DetectionMode }, api_name: :DetectionMode |
#fallback_url ⇒ String?
A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.
860 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 860 optional :fallback_url, String, api_name: :FallbackUrl |
#from ⇒ String?
The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.
867 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 867 optional :from, String, api_name: :From |
#machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection.
873 874 875 876 877 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 873 optional :machine_detection, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::MachineDetection }, api_name: :MachineDetection |
#machine_detection_prompt_end_timeout ⇒ Integer?
Silence duration threshold after a call screening prompt before ending prompt detection, in milliseconds. Used when ‘DetectionMode` is `PremiumCallScreening`.
884 885 886 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 884 optional :machine_detection_prompt_end_timeout, Integer, api_name: :MachineDetectionPromptEndTimeout |
#machine_detection_silence_timeout ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.
893 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 893 optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout |
#machine_detection_speech_end_threshold ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.
900 901 902 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 900 optional :machine_detection_speech_end_threshold, Integer, api_name: :MachineDetectionSpeechEndThreshold |
#machine_detection_speech_threshold ⇒ Integer?
Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.
909 910 911 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 909 optional :machine_detection_speech_threshold, Integer, api_name: :MachineDetectionSpeechThreshold |
#machine_detection_timeout ⇒ Integer?
Maximum timeout threshold in milliseconds for overall detection.
917 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 917 optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout |
#media_encryption ⇒ Symbol, ...
Defines whether media should be encrypted on the call. When set to ‘SRTP`, the call will use Secure Real-time Transport Protocol for media encryption. When set to `DTLS`, the call will use DTLS for media encryption. Only supported for SIP destinations.
926 927 928 929 930 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 926 optional :media_encryption, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::MediaEncryption }, api_name: :MediaEncryption |
#preferred_codecs ⇒ String?
The list of comma-separated codecs to be offered on a call.
936 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 936 optional :preferred_codecs, String, api_name: :PreferredCodecs |
#record ⇒ Boolean?
Whether to record the entire participant’s call leg. Defaults to ‘false`.
942 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 942 optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record |
#recording_channels ⇒ Symbol, ...
The number of channels in the final recording. Defaults to ‘mono`.
948 949 950 951 952 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 948 optional :recording_channels, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::RecordingChannels }, api_name: :RecordingChannels |
#recording_status_callback ⇒ String?
The URL the recording callbacks will be sent to.
958 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 958 optional :recording_status_callback, String, api_name: :RecordingStatusCallback |
#recording_status_callback_event ⇒ String?
The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.
966 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 966 optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent |
#recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.
972 973 974 975 976 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 972 optional :recording_status_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::RecordingStatusCallbackMethod }, api_name: :RecordingStatusCallbackMethod |
#recording_timeout ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)
985 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 985 optional :recording_timeout, Integer, api_name: :RecordingTimeout |
#recording_track ⇒ Symbol, ...
The audio track to record for the call. The default is ‘both`.
991 992 993 994 995 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 991 optional :recording_track, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::RecordingTrack }, api_name: :RecordingTrack |
#send_recording_url ⇒ Boolean?
Whether to send RecordingUrl in webhooks.
1001 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1001 optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl |
#sip_auth_password ⇒ String?
The password to use for SIP authentication.
1007 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1007 optional :sip_auth_password, String, api_name: :SipAuthPassword |
#sip_auth_username ⇒ String?
The username to use for SIP authentication.
1013 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1013 optional :sip_auth_username, String, api_name: :SipAuthUsername |
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
1019 1020 1021 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1019 optional :sip_region, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::SipRegion }, api_name: :SipRegion |
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events to for the call.
1027 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1027 optional :status_callback, String, api_name: :StatusCallback |
#status_callback_event ⇒ Symbol, ...
The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.
1034 1035 1036 1037 1038 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1034 optional :status_callback_event, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::StatusCallbackEvent }, api_name: :StatusCallbackEvent |
#status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘StatusCallback`.
1044 1045 1046 1047 1048 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1044 optional :status_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::StatusCallbackMethod }, api_name: :StatusCallbackMethod |
#supervise_call_sid ⇒ String?
The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.
1056 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1056 optional :supervise_call_sid, String, api_name: :SuperviseCallSid |
#supervising_role ⇒ Symbol, ...
The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge
1064 1065 1066 1067 1068 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1064 optional :supervising_role, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::SupervisingRole }, api_name: :SupervisingRole |
#texml ⇒ String
TeXML to be used as instructions for the call. If provided, the call will execute these instructions instead of fetching from the Url.
745 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 745 required :texml, String, api_name: :Texml |
#time_limit ⇒ Integer?
The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.
1075 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1075 optional :time_limit, Integer, api_name: :TimeLimit |
#timeout ⇒ Integer?
The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.
1083 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1083 optional :timeout, Integer, api_name: :Timeout |
#to ⇒ String?
The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.
1090 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1090 optional :to, String, api_name: :To |
#trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.
1097 1098 1099 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1097 optional :trim, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::Trim }, api_name: :Trim |
#url ⇒ String?
1104 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1104 optional :url, String, api_name: :Url, nil?: true |
#url_method ⇒ Symbol, ...
HTTP request type used for ‘Url`. The default value is inherited from TeXML Application setting.
1111 1112 1113 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1111 optional :url_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::URLMethod }, api_name: :UrlMethod |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1220
|