Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithTeXml

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackEvent, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1117

Instance Attribute Details

#application_sidString?

The ID of the TeXML Application.

Returns:

  • (String, nil)


753
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 753

optional :application_sid, String, api_name: :ApplicationSid

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Returns:

  • (Boolean, nil)


760
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 760

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Returns:

  • (String, nil)


766
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 766

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for ‘AsyncAmdStatusCallback`. The default value is inherited from TeXML Application setting.



773
774
775
776
777
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 773

optional :async_amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::AsyncAmdStatusCallbackMethod
},
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.

Returns:

  • (String, nil)


786
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 786

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


793
794
795
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 793

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


801
802
803
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 801

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#custom_headersArray<Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithTeXml::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.



810
811
812
813
814
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 810

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::CustomHeader]
},
api_name: :CustomHeaders

#deepfake_detectionSymbol, ...

Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.



822
823
824
825
826
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 822

optional :deepfake_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::DeepfakeDetection
},
api_name: :DeepfakeDetection

#deepfake_detection_callback_methodSymbol, ...

HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.



832
833
834
835
836
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 832

optional :deepfake_detection_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::DeepfakeDetectionCallbackMethod
},
api_name: :DeepfakeDetectionCallbackMethod

#deepfake_detection_callback_urlString?

URL destination for Telnyx to send deepfake detection callback events to for the call.

Returns:

  • (String, nil)


843
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 843

optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl

#detection_modeSymbol, ...

Allows you to choose between Regular, Premium, and PremiumCallScreening detections. See developers.telnyx.com/docs/voice/programmable-voice/answering-machine-detection



851
852
853
854
855
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 851

optional :detection_mode,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::DetectionMode
},
api_name: :DetectionMode

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.

Returns:

  • (String, nil)


862
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 862

optional :fallback_url, String, api_name: :FallbackUrl

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


869
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 869

optional :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



875
876
877
878
879
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 875

optional :machine_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::MachineDetection
},
api_name: :MachineDetection

#machine_detection_prompt_end_timeoutInteger?

Silence duration threshold after a call screening prompt before ending prompt detection, in milliseconds. Used when ‘DetectionMode` is `PremiumCallScreening`.

Returns:

  • (Integer, nil)


886
887
888
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 886

optional :machine_detection_prompt_end_timeout,
Integer,
api_name: :MachineDetectionPromptEndTimeout

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


895
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 895

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


902
903
904
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 902

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


911
912
913
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 911

optional :machine_detection_speech_threshold,
Integer,
api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Returns:

  • (Integer, nil)


919
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 919

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the call. When set to ‘SRTP`, the call will use Secure Real-time Transport Protocol for media encryption. When set to `DTLS`, the call will use DTLS for media encryption. Only supported for SIP destinations.



928
929
930
931
932
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 928

optional :media_encryption,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::MediaEncryption
},
api_name: :MediaEncryption

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Returns:

  • (String, nil)


938
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 938

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant’s call leg. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


944
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 944

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to ‘mono`.



950
951
952
953
954
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 950

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Returns:

  • (String, nil)


960
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 960

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.

Returns:

  • (String, nil)


968
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 968

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.



974
975
976
977
978
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 974

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


987
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 987

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



993
994
995
996
997
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 993

optional :recording_track,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::RecordingTrack
},
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Returns:

  • (Boolean, nil)


1003
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1003

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Returns:

  • (String, nil)


1009
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1009

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Returns:

  • (String, nil)


1015
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1015

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



1021
1022
1023
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1021

optional :sip_region,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::SipRegion },
api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Returns:

  • (String, nil)


1029
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1029

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventSymbol, ...

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.



1036
1037
1038
1039
1040
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1036

optional :status_callback_event,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::StatusCallbackEvent
},
api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



1046
1047
1048
1049
1050
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1046

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#supervise_call_sidString?

The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.

Returns:

  • (String, nil)


1058
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1058

optional :supervise_call_sid, String, api_name: :SuperviseCallSid

#supervising_roleSymbol, ...

The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge



1066
1067
1068
1069
1070
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1066

optional :supervising_role,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::SupervisingRole
},
api_name: :SupervisingRole

#texmlString

TeXML to be used as instructions for the call. If provided, the call will execute these instructions instead of fetching from the Url.

Returns:

  • (String)


747
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 747

required :texml, String, api_name: :Texml

#time_limitInteger?

The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.

Returns:

  • (Integer, nil)


1077
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1077

optional :time_limit, Integer, api_name: :TimeLimit

#timeoutInteger?

The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.

Returns:

  • (Integer, nil)


1085
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1085

optional :timeout, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


1092
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1092

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.



1099
1100
1101
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1099

optional :trim,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::Trim },
api_name: :Trim

#urlString?

Returns:

  • (String, nil)


1106
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1106

optional :url, String, api_name: :Url, nil?: true

#url_methodSymbol, ...

HTTP request type used for ‘Url`. The default value is inherited from TeXML Application setting.



1113
1114
1115
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1113

optional :url_method,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::URLMethod },
api_name: :UrlMethod

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1222