Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithTeXml
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithTeXml
- Defined in:
- lib/telnyx/models/texml/accounts/call_calls_params.rb
Defined Under Namespace
Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackEvent, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader
Instance Attribute Summary collapse
-
#application_sid ⇒ String?
The ID of the TeXML Application.
-
#async_amd ⇒ Boolean?
Select whether to perform answering machine detection in the background.
-
#async_amd_status_callback ⇒ String?
URL destination for Telnyx to send AMD callback events to for the call.
-
#async_amd_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘AsyncAmdStatusCallback`.
-
#caller_id ⇒ String?
To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number).
-
#cancel_playback_on_detect_message_end ⇒ Boolean?
Whether to cancel ongoing playback on ‘greeting ended` detection.
-
#cancel_playback_on_machine_detection ⇒ Boolean?
Whether to cancel ongoing playback on ‘machine` detection.
-
#custom_headers ⇒ Array<Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithTeXml::CustomHeader>?
Custom HTTP headers to be sent with the call.
-
#deepfake_detection ⇒ Symbol, ...
Enables Deepfake Detection on the dialed call.
-
#deepfake_detection_callback_method ⇒ Symbol, ...
HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.
-
#deepfake_detection_callback_url ⇒ String?
URL destination for Telnyx to send deepfake detection callback events to for the call.
-
#detection_mode ⇒ Symbol, ...
Allows you to chose between Premium and Standard detections.
-
#fallback_url ⇒ String?
A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.
-
#from ⇒ String?
The phone number of the party that initiated the call.
-
#machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection.
-
#machine_detection_silence_timeout ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine.
-
#machine_detection_speech_end_threshold ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human.
-
#machine_detection_speech_threshold ⇒ Integer?
Maximum threshold of a human greeting.
-
#machine_detection_timeout ⇒ Integer?
Maximum timeout threshold in milliseconds for overall detection.
-
#media_encryption ⇒ Symbol, ...
Defines whether media should be encrypted on the call.
-
#preferred_codecs ⇒ String?
The list of comma-separated codecs to be offered on a call.
-
#record ⇒ Boolean?
Whether to record the entire participant’s call leg.
-
#recording_channels ⇒ Symbol, ...
The number of channels in the final recording.
-
#recording_status_callback ⇒ String?
The URL the recording callbacks will be sent to.
-
#recording_status_callback_event ⇒ String?
The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`.
-
#recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘RecordingStatusCallback`.
-
#recording_timeout ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected.
-
#recording_track ⇒ Symbol, ...
The audio track to record for the call.
-
#send_recording_url ⇒ Boolean?
Whether to send RecordingUrl in webhooks.
-
#sip_auth_password ⇒ String?
The password to use for SIP authentication.
-
#sip_auth_username ⇒ String?
The username to use for SIP authentication.
-
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
-
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events to for the call.
-
#status_callback_event ⇒ Symbol, ...
The call events for which Telnyx should send a webhook.
-
#status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘StatusCallback`.
-
#supervise_call_sid ⇒ String?
The call control ID of the existing call to supervise.
-
#supervising_role ⇒ Symbol, ...
The supervising role for the new leg.
-
#texml ⇒ String
TeXML to be used as instructions for the call.
-
#time_limit ⇒ Integer?
The maximum duration of the call in seconds.
-
#timeout ⇒ Integer?
The number of seconds to wait for the called party to answer the call before the call is canceled.
-
#to ⇒ String?
The phone number of the called party.
-
#trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the recording.
- #url ⇒ String?
-
#url_method ⇒ Symbol, ...
HTTP request type used for ‘Url`.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(name:, value:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, value:) ⇒ Object
|
|
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1088
|
Instance Attribute Details
#application_sid ⇒ String?
The ID of the TeXML Application.
735 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 735 optional :application_sid, String, api_name: :ApplicationSid |
#async_amd ⇒ Boolean?
Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.
742 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 742 optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd |
#async_amd_status_callback ⇒ String?
URL destination for Telnyx to send AMD callback events to for the call.
748 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 748 optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback |
#async_amd_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘AsyncAmdStatusCallback`. The default value is inherited from TeXML Application setting.
755 756 757 758 759 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 755 optional :async_amd_status_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::AsyncAmdStatusCallbackMethod }, api_name: :AsyncAmdStatusCallbackMethod |
#caller_id ⇒ String?
To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.
768 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 768 optional :caller_id, String, api_name: :CallerId |
#cancel_playback_on_detect_message_end ⇒ Boolean?
Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.
775 776 777 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 775 optional :cancel_playback_on_detect_message_end, Telnyx::Internal::Type::Boolean, api_name: :CancelPlaybackOnDetectMessageEnd |
#cancel_playback_on_machine_detection ⇒ Boolean?
Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.
783 784 785 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 783 optional :cancel_playback_on_machine_detection, Telnyx::Internal::Type::Boolean, api_name: :CancelPlaybackOnMachineDetection |
#custom_headers ⇒ Array<Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithTeXml::CustomHeader>?
Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.
792 793 794 795 796 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 792 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::CustomHeader] }, api_name: :CustomHeaders |
#deepfake_detection ⇒ Symbol, ...
Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.
804 805 806 807 808 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 804 optional :deepfake_detection, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::DeepfakeDetection }, api_name: :DeepfakeDetection |
#deepfake_detection_callback_method ⇒ Symbol, ...
HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.
814 815 816 817 818 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 814 optional :deepfake_detection_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::DeepfakeDetectionCallbackMethod }, api_name: :DeepfakeDetectionCallbackMethod |
#deepfake_detection_callback_url ⇒ String?
URL destination for Telnyx to send deepfake detection callback events to for the call.
825 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 825 optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl |
#detection_mode ⇒ Symbol, ...
Allows you to chose between Premium and Standard detections.
831 832 833 834 835 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 831 optional :detection_mode, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::DetectionMode }, api_name: :DetectionMode |
#fallback_url ⇒ String?
A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.
842 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 842 optional :fallback_url, String, api_name: :FallbackUrl |
#from ⇒ String?
The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.
849 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 849 optional :from, String, api_name: :From |
#machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection.
855 856 857 858 859 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 855 optional :machine_detection, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::MachineDetection }, api_name: :MachineDetection |
#machine_detection_silence_timeout ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.
866 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 866 optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout |
#machine_detection_speech_end_threshold ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.
873 874 875 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 873 optional :machine_detection_speech_end_threshold, Integer, api_name: :MachineDetectionSpeechEndThreshold |
#machine_detection_speech_threshold ⇒ Integer?
Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.
882 883 884 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 882 optional :machine_detection_speech_threshold, Integer, api_name: :MachineDetectionSpeechThreshold |
#machine_detection_timeout ⇒ Integer?
Maximum timeout threshold in milliseconds for overall detection.
890 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 890 optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout |
#media_encryption ⇒ Symbol, ...
Defines whether media should be encrypted on the call. When set to ‘SRTP`, the call will use Secure Real-time Transport Protocol for media encryption. When set to `DTLS`, the call will use DTLS for media encryption. Only supported for SIP destinations.
899 900 901 902 903 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 899 optional :media_encryption, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::MediaEncryption }, api_name: :MediaEncryption |
#preferred_codecs ⇒ String?
The list of comma-separated codecs to be offered on a call.
909 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 909 optional :preferred_codecs, String, api_name: :PreferredCodecs |
#record ⇒ Boolean?
Whether to record the entire participant’s call leg. Defaults to ‘false`.
915 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 915 optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record |
#recording_channels ⇒ Symbol, ...
The number of channels in the final recording. Defaults to ‘mono`.
921 922 923 924 925 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 921 optional :recording_channels, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::RecordingChannels }, api_name: :RecordingChannels |
#recording_status_callback ⇒ String?
The URL the recording callbacks will be sent to.
931 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 931 optional :recording_status_callback, String, api_name: :RecordingStatusCallback |
#recording_status_callback_event ⇒ String?
The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.
939 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 939 optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent |
#recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.
945 946 947 948 949 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 945 optional :recording_status_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::RecordingStatusCallbackMethod }, api_name: :RecordingStatusCallbackMethod |
#recording_timeout ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)
958 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 958 optional :recording_timeout, Integer, api_name: :RecordingTimeout |
#recording_track ⇒ Symbol, ...
The audio track to record for the call. The default is ‘both`.
964 965 966 967 968 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 964 optional :recording_track, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::RecordingTrack }, api_name: :RecordingTrack |
#send_recording_url ⇒ Boolean?
Whether to send RecordingUrl in webhooks.
974 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 974 optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl |
#sip_auth_password ⇒ String?
The password to use for SIP authentication.
980 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 980 optional :sip_auth_password, String, api_name: :SipAuthPassword |
#sip_auth_username ⇒ String?
The username to use for SIP authentication.
986 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 986 optional :sip_auth_username, String, api_name: :SipAuthUsername |
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
992 993 994 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 992 optional :sip_region, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::SipRegion }, api_name: :SipRegion |
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events to for the call.
1000 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1000 optional :status_callback, String, api_name: :StatusCallback |
#status_callback_event ⇒ Symbol, ...
The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.
1007 1008 1009 1010 1011 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1007 optional :status_callback_event, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::StatusCallbackEvent }, api_name: :StatusCallbackEvent |
#status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘StatusCallback`.
1017 1018 1019 1020 1021 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1017 optional :status_callback_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::StatusCallbackMethod }, api_name: :StatusCallbackMethod |
#supervise_call_sid ⇒ String?
The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.
1029 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1029 optional :supervise_call_sid, String, api_name: :SuperviseCallSid |
#supervising_role ⇒ Symbol, ...
The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge
1037 1038 1039 1040 1041 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1037 optional :supervising_role, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::SupervisingRole }, api_name: :SupervisingRole |
#texml ⇒ String
TeXML to be used as instructions for the call. If provided, the call will execute these instructions instead of fetching from the Url.
729 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 729 required :texml, String, api_name: :Texml |
#time_limit ⇒ Integer?
The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.
1048 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1048 optional :time_limit, Integer, api_name: :TimeLimit |
#timeout ⇒ Integer?
The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.
1056 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1056 optional :timeout, Integer, api_name: :Timeout |
#to ⇒ String?
The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.
1063 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1063 optional :to, String, api_name: :To |
#trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.
1070 1071 1072 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1070 optional :trim, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::Trim }, api_name: :Trim |
#url ⇒ String?
1077 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1077 optional :url, String, api_name: :Url, nil?: true |
#url_method ⇒ Symbol, ...
HTTP request type used for ‘Url`. The default value is inherited from TeXML Application setting.
1084 1085 1086 |
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1084 optional :url_method, enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithTeXml::URLMethod }, api_name: :UrlMethod |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 1191
|