Class: Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithURL

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/call_calls_params.rb

Defined Under Namespace

Modules: AsyncAmdStatusCallbackMethod, DeepfakeDetection, DeepfakeDetectionCallbackMethod, DetectionMode, MachineDetection, MediaEncryption, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackEvent, StatusCallbackMethod, SupervisingRole, Trim, URLMethod Classes: CustomHeader

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 396

Instance Attribute Details

#application_sidString?

The ID of the TeXML Application.

Returns:

  • (String, nil)


47
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 47

optional :application_sid, String, api_name: :ApplicationSid

#async_amdBoolean?

Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.

Returns:

  • (Boolean, nil)


54
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 54

optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd

#async_amd_status_callbackString?

URL destination for Telnyx to send AMD callback events to for the call.

Returns:

  • (String, nil)


60
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 60

optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback

#async_amd_status_callback_methodSymbol, ...

HTTP request type used for ‘AsyncAmdStatusCallback`. The default value is inherited from TeXML Application setting.



67
68
69
70
71
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 67

optional :async_amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::AsyncAmdStatusCallbackMethod
},
api_name: :AsyncAmdStatusCallbackMethod

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.

Returns:

  • (String, nil)


80
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 80

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


87
88
89
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 87

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


95
96
97
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 95

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#custom_headersArray<Telnyx::Models::Texml::Accounts::CallCallsParams::Params::WithURL::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.



104
105
106
107
108
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 104

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::CustomHeader]
},
api_name: :CustomHeaders

#deepfake_detectionSymbol, ...

Enables Deepfake Detection on the dialed call. When enabled, audio from the remote party is analyzed to determine whether the voice is AI-generated. Results are delivered asynchronously via a callback.



116
117
118
119
120
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 116

optional :deepfake_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::DeepfakeDetection
},
api_name: :DeepfakeDetection

#deepfake_detection_callback_methodSymbol, ...

HTTP request type used for ‘DeepfakeDetectionCallbackUrl`.



126
127
128
129
130
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 126

optional :deepfake_detection_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::DeepfakeDetectionCallbackMethod
},
api_name: :DeepfakeDetectionCallbackMethod

#deepfake_detection_callback_urlString?

URL destination for Telnyx to send deepfake detection callback events to for the call.

Returns:

  • (String, nil)


137
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 137

optional :deepfake_detection_callback_url, String, api_name: :DeepfakeDetectionCallbackUrl

#detection_modeSymbol, ...

Allows you to chose between Premium and Standard detections.



143
144
145
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 143

optional :detection_mode,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::DetectionMode },
api_name: :DetectionMode

#fallback_urlString?

A failover URL for which Telnyx will retrieve the TeXML call instructions if the ‘Url` is not responding.

Returns:

  • (String, nil)


152
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 152

optional :fallback_url, String, api_name: :FallbackUrl

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


159
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 159

optional :from, String, api_name: :From

#machine_detectionSymbol, ...

Enables Answering Machine Detection.



165
166
167
168
169
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 165

optional :machine_detection,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::MachineDetection
},
api_name: :MachineDetection

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


176
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 176

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


183
184
185
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 183

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


192
193
194
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 192

optional :machine_detection_speech_threshold,
Integer,
api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

Maximum timeout threshold in milliseconds for overall detection.

Returns:

  • (Integer, nil)


200
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 200

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#media_encryptionSymbol, ...

Defines whether media should be encrypted on the call. When set to ‘SRTP`, the call will use Secure Real-time Transport Protocol for media encryption. When set to `DTLS`, the call will use DTLS for media encryption. Only supported for SIP destinations.



209
210
211
212
213
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 209

optional :media_encryption,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::MediaEncryption
},
api_name: :MediaEncryption

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Returns:

  • (String, nil)


219
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 219

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant’s call leg. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


225
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 225

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to ‘mono`.



231
232
233
234
235
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 231

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Returns:

  • (String, nil)


241
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 241

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.

Returns:

  • (String, nil)


249
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 249

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.



255
256
257
258
259
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 255

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


268
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 268

optional :recording_timeout, Integer, api_name: :RecordingTimeout

#recording_trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



274
275
276
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 274

optional :recording_track,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::RecordingTrack },
api_name: :RecordingTrack

#send_recording_urlBoolean?

Whether to send RecordingUrl in webhooks.

Returns:

  • (Boolean, nil)


282
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 282

optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl

#sip_auth_passwordString?

The password to use for SIP authentication.

Returns:

  • (String, nil)


288
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 288

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Returns:

  • (String, nil)


294
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 294

optional :sip_auth_username, String, api_name: :SipAuthUsername

#sip_regionSymbol, ...

Defines the SIP region to be used for the call.



300
301
302
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 300

optional :sip_region,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::SipRegion },
api_name: :SipRegion

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Returns:

  • (String, nil)


308
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 308

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventSymbol, ...

The call events for which Telnyx should send a webhook. Multiple events can be defined when separated by a space.



315
316
317
318
319
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 315

optional :status_callback_event,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::StatusCallbackEvent
},
api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



325
326
327
328
329
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 325

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#supervise_call_sidString?

The call control ID of the existing call to supervise. When provided, the created leg will be added to the specified call in supervising mode. Status callbacks and action callbacks will NOT be sent for the supervising leg.

Returns:

  • (String, nil)


337
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 337

optional :supervise_call_sid, String, api_name: :SuperviseCallSid

#supervising_roleSymbol, ...

The supervising role for the new leg. Determines the audio behavior: barge (hear both sides), whisper (only hear supervisor), monitor (hear both sides but supervisor muted). Default: barge



345
346
347
348
349
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 345

optional :supervising_role,
enum: -> {
  Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::SupervisingRole
},
api_name: :SupervisingRole

#texmlString?

Returns:

  • (String, nil)


354
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 354

optional :texml, String, api_name: :Texml, nil?: true

#time_limitInteger?

The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.

Returns:

  • (Integer, nil)


361
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 361

optional :time_limit, Integer, api_name: :TimeLimit

#timeoutInteger?

The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.

Returns:

  • (Integer, nil)


369
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 369

optional :timeout, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


376
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 376

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.



383
384
385
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 383

optional :trim,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::Trim },
api_name: :Trim

#urlString

The URL from which Telnyx will retrieve the TeXML call instructions.

Returns:

  • (String)


41
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 41

required :url, String, api_name: :Url

#url_methodSymbol, ...

HTTP request type used for ‘Url`. The default value is inherited from TeXML Application setting.



392
393
394
# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 392

optional :url_method,
enum: -> { Telnyx::Texml::Accounts::CallCallsParams::Params::WithURL::URLMethod },
api_name: :UrlMethod

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_calls_params.rb', line 499