Class: Telnyx::Models::Texml::Accounts::CallRetrieveCallsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::CallRetrieveCallsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
- #account_sid ⇒ String
-
#end_time ⇒ String?
Filters calls by their end date.
-
#end_time_gt ⇒ String?
Filters calls by their end date (after).
-
#end_time_lt ⇒ String?
Filters calls by their end date (before).
-
#from ⇒ String?
Filters calls by the from number.
-
#page ⇒ Integer?
The number of the page to be displayed, zero-indexed, should be used in conjuction with PageToken.
-
#page_size ⇒ Integer?
The number of records to be displayed on a page.
-
#page_token ⇒ String?
Used to request the next page of results.
-
#start_time ⇒ String?
Filters calls by their start date.
-
#start_time_gt ⇒ String?
Filters calls by their start date (after).
-
#start_time_lt ⇒ String?
Filters calls by their start date (before).
-
#status ⇒ Symbol, ...
Filters calls by status.
-
#to ⇒ String?
Filters calls by the to number.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account_sid:, end_time: nil, end_time_gt: nil, end_time_lt: nil, from: nil, page: nil, page_size: nil, page_token: nil, start_time: nil, start_time_gt: nil, start_time_lt: nil, status: nil, to: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallRetrieveCallsParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid:, end_time: nil, end_time_gt: nil, end_time_lt: nil, from: nil, page: nil, page_size: nil, page_token: nil, start_time: nil, start_time_gt: nil, start_time_lt: nil, status: nil, to: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallRetrieveCallsParams for more details.
|
|
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 90
|
Instance Attribute Details
#account_sid ⇒ String
15 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 15 required :account_sid, String |
#end_time ⇒ String?
Filters calls by their end date. Expected format is YYYY-MM-DD
21 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 21 optional :end_time, String |
#end_time_gt ⇒ String?
Filters calls by their end date (after). Expected format is YYYY-MM-DD
27 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 27 optional :end_time_gt, String |
#end_time_lt ⇒ String?
Filters calls by their end date (before). Expected format is YYYY-MM-DD
33 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 33 optional :end_time_lt, String |
#from ⇒ String?
Filters calls by the from number.
39 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 39 optional :from, String |
#page ⇒ Integer?
The number of the page to be displayed, zero-indexed, should be used in conjuction with PageToken.
46 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 46 optional :page, Integer |
#page_size ⇒ Integer?
The number of records to be displayed on a page
52 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 52 optional :page_size, Integer |
#page_token ⇒ String?
Used to request the next page of results.
58 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 58 optional :page_token, String |
#start_time ⇒ String?
Filters calls by their start date. Expected format is YYYY-MM-DD.
64 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 64 optional :start_time, String |
#start_time_gt ⇒ String?
Filters calls by their start date (after). Expected format is YYYY-MM-DD
70 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 70 optional :start_time_gt, String |
#start_time_lt ⇒ String?
Filters calls by their start date (before). Expected format is YYYY-MM-DD
76 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 76 optional :start_time_lt, String |
#status ⇒ Symbol, ...
Filters calls by status.
82 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 82 optional :status, enum: -> { Telnyx::Texml::Accounts::CallRetrieveCallsParams::Status } |
#to ⇒ String?
Filters calls by the to number.
88 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 88 optional :to, String |