Class: Telnyx::Models::Texml::Accounts::CallRetrieveCallsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::CallRetrieveCallsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#end_time ⇒ String?
Filters calls by their end date.
-
#end_time_gt ⇒ String?
Filters calls by their end date (after).
-
#end_time_lt ⇒ String?
Filters calls by their end date (before).
-
#from ⇒ String?
Filters calls by the from number.
-
#page ⇒ Integer?
The number of the page to be displayed, zero-indexed, should be used in conjuction with PageToken.
-
#page_size ⇒ Integer?
The number of records to be displayed on a page.
-
#page_token ⇒ String?
Used to request the next page of results.
-
#start_time ⇒ String?
Filters calls by their start date.
-
#start_time_gt ⇒ String?
Filters calls by their start date (after).
-
#start_time_lt ⇒ String?
Filters calls by their start date (before).
-
#status ⇒ Symbol, ...
Filters calls by status.
-
#to ⇒ String?
Filters calls by the to number.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(end_time: nil, end_time_gt: nil, end_time_lt: nil, from: nil, page: nil, page_size: nil, page_token: nil, start_time: nil, start_time_gt: nil, start_time_lt: nil, status: nil, to: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallRetrieveCallsParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_time: nil, end_time_gt: nil, end_time_lt: nil, from: nil, page: nil, page_size: nil, page_token: nil, start_time: nil, start_time_gt: nil, start_time_lt: nil, status: nil, to: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallRetrieveCallsParams for more details.
|
|
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 85
|
Instance Attribute Details
#end_time ⇒ String?
Filters calls by their end date. Expected format is YYYY-MM-DD
16 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 16 optional :end_time, String |
#end_time_gt ⇒ String?
Filters calls by their end date (after). Expected format is YYYY-MM-DD
22 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 22 optional :end_time_gt, String |
#end_time_lt ⇒ String?
Filters calls by their end date (before). Expected format is YYYY-MM-DD
28 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 28 optional :end_time_lt, String |
#from ⇒ String?
Filters calls by the from number.
34 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 34 optional :from, String |
#page ⇒ Integer?
The number of the page to be displayed, zero-indexed, should be used in conjuction with PageToken.
41 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 41 optional :page, Integer |
#page_size ⇒ Integer?
The number of records to be displayed on a page
47 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 47 optional :page_size, Integer |
#page_token ⇒ String?
Used to request the next page of results.
53 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 53 optional :page_token, String |
#start_time ⇒ String?
Filters calls by their start date. Expected format is YYYY-MM-DD.
59 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 59 optional :start_time, String |
#start_time_gt ⇒ String?
Filters calls by their start date (after). Expected format is YYYY-MM-DD
65 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 65 optional :start_time_gt, String |
#start_time_lt ⇒ String?
Filters calls by their start date (before). Expected format is YYYY-MM-DD
71 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 71 optional :start_time_lt, String |
#status ⇒ Symbol, ...
Filters calls by status.
77 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 77 optional :status, enum: -> { Telnyx::Texml::Accounts::CallRetrieveCallsParams::Status } |
#to ⇒ String?
Filters calls by the to number.
83 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_params.rb', line 83 optional :to, String |