Class: Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse
- Defined in:
- lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb
Overview
Instance Attribute Summary collapse
- #calls ⇒ Array<Telnyx::Models::Texml::Accounts::CallResource>?
-
#end_ ⇒ Integer?
The number of the last element on the page, zero-indexed.
-
#first_page_uri ⇒ String?
/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Calls.json?Page=0&PageSize=1.
-
#next_page_uri ⇒ String?
/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Calls.json?Page=1&PageSize=1&PageToken=MTY4AjgyNDkwNzIxMQ.
-
#page ⇒ Integer?
Current page number, zero-indexed.
-
#page_size ⇒ Integer?
The number of items on the page.
-
#start ⇒ Integer?
The number of the first element on the page, zero-indexed.
-
#uri ⇒ String?
The URI of the current page.
Instance Method Summary collapse
-
#initialize(calls: nil, end_: nil, first_page_uri: nil, next_page_uri: nil, page: nil, page_size: nil, start: nil, uri: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallRetrieveCallsResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(calls: nil, end_: nil, first_page_uri: nil, next_page_uri: nil, page: nil, page_size: nil, start: nil, uri: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallRetrieveCallsResponse for more details.
|
|
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 56
|
Instance Attribute Details
#calls ⇒ Array<Telnyx::Models::Texml::Accounts::CallResource>?
12 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 12 optional :calls, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::CallResource] } |
#end_ ⇒ Integer?
The number of the last element on the page, zero-indexed.
18 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 18 optional :end_, Integer, api_name: :end |
#first_page_uri ⇒ String?
/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Calls.json?Page=0&PageSize=1
24 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 24 optional :first_page_uri, String |
#next_page_uri ⇒ String?
/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Calls.json?Page=1&PageSize=1&PageToken=MTY4AjgyNDkwNzIxMQ
30 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 30 optional :next_page_uri, String |
#page ⇒ Integer?
Current page number, zero-indexed.
36 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 36 optional :page, Integer |
#page_size ⇒ Integer?
The number of items on the page
42 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 42 optional :page_size, Integer |
#start ⇒ Integer?
The number of the first element on the page, zero-indexed.
48 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 48 optional :start, Integer |
#uri ⇒ String?
The URI of the current page.
54 |
# File 'lib/telnyx/models/texml/accounts/call_retrieve_calls_response.rb', line 54 optional :uri, String |