Class: Telnyx::Models::Texml::Accounts::CallSiprecJsonParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml/accounts/call_siprec_json_params.rb

Overview

Defined Under Namespace

Modules: IncludeMetadataCustomHeaders, Secure, SipTransport, StatusCallbackMethod, Track

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid:, connector_name: nil, include_metadata_custom_headers: nil, name: nil, secure: nil, session_timeout_secs: nil, sip_transport: nil, status_callback: nil, status_callback_method: nil, track: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::CallSiprecJsonParams for more details.

Parameters:



# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 89

Instance Attribute Details

#account_sidString

Returns:

  • (String)


15
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 15

required :account_sid, String

#connector_nameString?

The name of the connector to use for the SIPREC session.

Returns:

  • (String, nil)


21
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 21

optional :connector_name, String, api_name: :ConnectorName

#include_metadata_custom_headersBoolean, ...

When set, custom parameters will be added as metadata (recording.session.ExtensionParameters). Otherwise, they’ll be added to sip headers.



29
30
31
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 29

optional :include_metadata_custom_headers,
enum: -> { Telnyx::Texml::Accounts::CallSiprecJsonParams::IncludeMetadataCustomHeaders },
api_name: :IncludeMetadataCustomHeaders

#nameString?

Name of the SIPREC session. May be used to stop the SIPREC session from TeXML instruction.

Returns:

  • (String, nil)


38
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 38

optional :name, String, api_name: :Name

#secureBoolean, ...

Controls whether to encrypt media sent to your SRS using SRTP and TLS. When set you need to configure SRS port in your connector to 5061.



45
46
47
48
49
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 45

optional :secure,
enum: -> {
  Telnyx::Texml::Accounts::CallSiprecJsonParams::Secure
},
api_name: :Secure

#session_timeout_secsInteger?

Sets ‘Session-Expires` header to the INVITE. A reinvite is sent every half the value set. Usefull for session keep alive. Minimum value is 90, set to 0 to disable.

Returns:

  • (Integer, nil)


57
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 57

optional :session_timeout_secs, Integer, api_name: :SessionTimeoutSecs

#sip_transportSymbol, ...

Specifies SIP transport protocol.



63
64
65
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 63

optional :sip_transport,
enum: -> { Telnyx::Texml::Accounts::CallSiprecJsonParams::SipTransport },
api_name: :SipTransport

#status_callbackString?

URL destination for Telnyx to send status callback events to for the siprec session.

Returns:

  • (String, nil)


72
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 72

optional :status_callback, String, api_name: :StatusCallback

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



78
79
80
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 78

optional :status_callback_method,
enum: -> { Telnyx::Texml::Accounts::CallSiprecJsonParams::StatusCallbackMethod },
api_name: :StatusCallbackMethod

#trackSymbol, ...

The track to be used for siprec session. Can be ‘both_tracks`, `inbound_track` or `outbound_track`. Defaults to `both_tracks`.



87
# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 87

optional :track, enum: -> { Telnyx::Texml::Accounts::CallSiprecJsonParams::Track }, api_name: :Track

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/call_siprec_json_params.rb', line 124