Class: Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRetrieveRecordingsJsonResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::Calls::RecordingsJsonRetrieveRecordingsJsonResponse
- Defined in:
- lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb
Overview
Instance Attribute Summary collapse
-
#end_ ⇒ Integer?
The number of the last element on the page, zero-indexed.
-
#first_page_uri ⇒ String?
Relative uri to the first page of the query results.
-
#next_page_uri ⇒ String?
Relative uri to the next page of the query results.
-
#page ⇒ Integer?
Current page number, zero-indexed.
-
#page_size ⇒ Integer?
The number of items on the page.
-
#previous_page_uri ⇒ String?
Relative uri to the previous page of the query results.
- #recordings ⇒ Array<Telnyx::Models::Texml::TexmlGetCallRecordingResponseBody>?
-
#start ⇒ Integer?
The number of the first element on the page, zero-indexed.
-
#uri ⇒ String?
The URI of the current page.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_: nil, first_page_uri: nil, next_page_uri: nil, page: nil, page_size: nil, previous_page_uri: nil, recordings: nil, start: nil, uri: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 64
|
Instance Attribute Details
#end_ ⇒ Integer?
The number of the last element on the page, zero-indexed.
14 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 14 optional :end_, Integer, api_name: :end |
#first_page_uri ⇒ String?
Relative uri to the first page of the query results
20 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 20 optional :first_page_uri, String |
#next_page_uri ⇒ String?
Relative uri to the next page of the query results
26 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 26 optional :next_page_uri, String |
#page ⇒ Integer?
Current page number, zero-indexed.
32 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 32 optional :page, Integer |
#page_size ⇒ Integer?
The number of items on the page
38 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 38 optional :page_size, Integer |
#previous_page_uri ⇒ String?
Relative uri to the previous page of the query results
44 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 44 optional :previous_page_uri, String |
#recordings ⇒ Array<Telnyx::Models::Texml::TexmlGetCallRecordingResponseBody>?
49 50 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 49 optional :recordings, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::TexmlGetCallRecordingResponseBody] } |
#start ⇒ Integer?
The number of the first element on the page, zero-indexed.
56 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 56 optional :start, Integer |
#uri ⇒ String?
The URI of the current page.
62 |
# File 'lib/telnyx/models/texml/accounts/calls/recordings_json_retrieve_recordings_json_response.rb', line 62 optional :uri, String |