Class: Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse
- Defined in:
- lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb
Overview
Defined Under Namespace
Classes: Conference
Instance Attribute Summary collapse
- #conferences ⇒ Array<Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference>?
-
#end_ ⇒ Integer?
The number of the last element on the page, zero-indexed.
-
#first_page_uri ⇒ String?
/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Conferences.json?Page=0&PageSize=1.
-
#next_page_uri ⇒ String?
/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Conferences.json?Page=1&PageSize=1&PageToken=MTY4AjgyNDkwNzIxMQ.
-
#page ⇒ Integer?
Current page number, zero-indexed.
-
#page_size ⇒ Integer?
The number of items on the page.
-
#start ⇒ Integer?
The number of the first element on the page, zero-indexed.
-
#uri ⇒ String?
The URI of the current page.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#conferences ⇒ Array<Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference>?
12 13 |
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 12 optional :conferences, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse::Conference] } |
#end_ ⇒ Integer?
The number of the last element on the page, zero-indexed.
19 |
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 19 optional :end_, Integer, api_name: :end |
#first_page_uri ⇒ String?
/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Conferences.json?Page=0&PageSize=1
25 |
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 25 optional :first_page_uri, String |
#next_page_uri ⇒ String?
/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Conferences.json?Page=1&PageSize=1&PageToken=MTY4AjgyNDkwNzIxMQ
31 |
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 31 optional :next_page_uri, String |
#page ⇒ Integer?
Current page number, zero-indexed.
37 |
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 37 optional :page, Integer |
#page_size ⇒ Integer?
The number of items on the page
43 |
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 43 optional :page_size, Integer |
#start ⇒ Integer?
The number of the first element on the page, zero-indexed.
49 |
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 49 optional :start, Integer |
#uri ⇒ String?
The URI of the current page.
55 |
# File 'lib/telnyx/models/texml/accounts/conference_retrieve_conferences_response.rb', line 55 optional :uri, String |