Class: Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse
- Defined in:
- lib/telnyx/models/texml/accounts/conference_update_response.rb
Overview
Defined Under Namespace
Modules: ReasonConferenceEnded, Status
Instance Attribute Summary collapse
-
#account_sid ⇒ String?
The id of the account the resource belongs to.
-
#api_version ⇒ String?
The version of the API that was used to make the request.
-
#call_sid_ending_conference ⇒ String?
Caller ID, if present.
-
#date_created ⇒ String?
The timestamp of when the resource was created.
-
#date_updated ⇒ String?
The timestamp of when the resource was last updated.
-
#friendly_name ⇒ String?
A string that you assigned to describe this conference room.
-
#reason_conference_ended ⇒ Symbol, ...
The reason why a conference ended.
-
#region ⇒ String?
A string representing the region where the conference is hosted.
-
#sid ⇒ String?
The unique identifier of the conference.
-
#status ⇒ Symbol, ...
The status of this conference.
-
#subresource_uris ⇒ Hash{Symbol=>Object}?
A list of related resources identified by their relative URIs.
-
#uri ⇒ String?
The relative URI for this conference.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_sid: nil, api_version: nil, call_sid_ending_conference: nil, date_created: nil, date_updated: nil, friendly_name: nil, reason_conference_ended: nil, region: nil, sid: nil, status: nil, subresource_uris: nil, uri: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConferenceUpdateResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid: nil, api_version: nil, call_sid_ending_conference: nil, date_created: nil, date_updated: nil, friendly_name: nil, reason_conference_ended: nil, region: nil, sid: nil, status: nil, subresource_uris: nil, uri: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse for more details.
|
|
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 83
|
Instance Attribute Details
#account_sid ⇒ String?
The id of the account the resource belongs to.
13 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 13 optional :account_sid, String |
#api_version ⇒ String?
The version of the API that was used to make the request.
19 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 19 optional :api_version, String |
#call_sid_ending_conference ⇒ String?
Caller ID, if present.
25 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 25 optional :call_sid_ending_conference, String |
#date_created ⇒ String?
The timestamp of when the resource was created.
31 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 31 optional :date_created, String |
#date_updated ⇒ String?
The timestamp of when the resource was last updated.
37 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 37 optional :date_updated, String |
#friendly_name ⇒ String?
A string that you assigned to describe this conference room.
43 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 43 optional :friendly_name, String |
#reason_conference_ended ⇒ Symbol, ...
The reason why a conference ended. When a conference is in progress, will be null.
50 51 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 50 optional :reason_conference_ended, enum: -> { Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse::ReasonConferenceEnded } |
#region ⇒ String?
A string representing the region where the conference is hosted.
57 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 57 optional :region, String |
#sid ⇒ String?
The unique identifier of the conference.
63 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 63 optional :sid, String |
#status ⇒ Symbol, ...
The status of this conference.
69 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 69 optional :status, enum: -> { Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse::Status } |
#subresource_uris ⇒ Hash{Symbol=>Object}?
A list of related resources identified by their relative URIs.
75 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 75 optional :subresource_uris, Telnyx::Internal::Type::HashOf[Telnyx::Internal::Type::Unknown] |
#uri ⇒ String?
The relative URI for this conference.
81 |
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 81 optional :uri, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/conference_update_response.rb', line 123
|