Class: Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb

Overview

Defined Under Namespace

Modules: AmdStatusCallbackMethod, Beep, ConferenceRecord, ConferenceRecordingStatusCallbackMethod, ConferenceStatusCallbackMethod, ConferenceTrim, MachineDetection, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, StatusCallbackMethod, Trim Classes: CustomHeader

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 413

Instance Attribute Details

#account_sidString

Returns:

  • (String)


16
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 16

required :account_sid, String

#amd_status_callbackString?

The URL the result of answering machine detection will be sent to.

Returns:

  • (String, nil)


27
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 27

optional :amd_status_callback, String, api_name: :AmdStatusCallback

#amd_status_callback_methodSymbol, ...

HTTP request type used for ‘AmdStatusCallback`. Defaults to `POST`.



33
34
35
36
37
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 33

optional :amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::AmdStatusCallbackMethod
},
api_name: :AmdStatusCallbackMethod

#application_sidString?

The SID of the TeXML application that will handle the new participant’s call. Required unless joining an existing conference by its ConferenceSid.

Returns:

  • (String, nil)


44
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 44

optional :application_sid, String, api_name: :ApplicationSid

#beepSymbol, ...

Whether to play a notification beep to the conference when the participant enters and exits.



51
52
53
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 51

optional :beep,
enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::Beep },
api_name: :Beep

#call_sid_to_coachString?

The SID of the participant who is being coached. The participant being coached is the only participant who can hear the participant who is coaching.

Returns:

  • (String, nil)


69
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 69

optional :call_sid_to_coach, String, api_name: :CallSidToCoach

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 62

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


76
77
78
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 76

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


84
85
86
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 84

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#coachingBoolean?

Whether the participant is coaching another call. When ‘true`, `CallSidToCoach` has to be given.

Returns:

  • (Boolean, nil)


93
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 93

optional :coaching, Telnyx::Internal::Type::Boolean, api_name: :Coaching

#conference_recordSymbol, ...

Whether to record the conference the participant is joining. Defualts to ‘do-not-record`. The boolean values `true` and `false` are synonymous with `record-from-start` and `do-not-record` respectively.



101
102
103
104
105
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 101

optional :conference_record,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceRecord
},
api_name: :ConferenceRecord

#conference_recording_status_callbackString?

The URL the conference recording callbacks will be sent to.

Returns:

  • (String, nil)


111
112
113
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 111

optional :conference_recording_status_callback,
String,
api_name: :ConferenceRecordingStatusCallback

#conference_recording_status_callback_eventString?

The changes to the conference recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`. `failed` and `absent` are synonymous.

Returns:

  • (String, nil)


122
123
124
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 122

optional :conference_recording_status_callback_event,
String,
api_name: :ConferenceRecordingStatusCallbackEvent

#conference_recording_status_callback_methodSymbol, ...

HTTP request type used for ‘ConferenceRecordingStatusCallback`. Defaults to `POST`.



131
132
133
134
135
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 131

optional :conference_recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceRecordingStatusCallbackMethod
},
api_name: :ConferenceRecordingStatusCallbackMethod

#conference_recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


144
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 144

optional :conference_recording_timeout, Integer, api_name: :ConferenceRecordingTimeout

#conference_sidString

Returns:

  • (String)


21
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 21

required :conference_sid, String

#conference_status_callbackString?

The URL the conference callbacks will be sent to.

Returns:

  • (String, nil)


150
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 150

optional :conference_status_callback, String, api_name: :ConferenceStatusCallback

#conference_status_callback_eventString?

The changes to the conference’s state that should generate a call to ‘ConferenceStatusCallback`. Can be: `start`, `end`, `join` and `leave`. Separate multiple values with a space. By default no callbacks are sent.

Returns:

  • (String, nil)


158
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 158

optional :conference_status_callback_event, String, api_name: :ConferenceStatusCallbackEvent

#conference_status_callback_methodSymbol, ...

HTTP request type used for ‘ConferenceStatusCallback`. Defaults to `POST`.



164
165
166
167
168
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 164

optional :conference_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceStatusCallbackMethod
},
api_name: :ConferenceStatusCallbackMethod

#conference_trimSymbol, ...

Whether to trim any leading and trailing silence from the conference recording. Defaults to ‘trim-silence`.



175
176
177
178
179
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 175

optional :conference_trim,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceTrim
},
api_name: :ConferenceTrim

#custom_headersArray<Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.



186
187
188
189
190
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 186

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::CustomHeader]
},
api_name: :CustomHeaders

#early_mediaBoolean?

Whether participant shall be bridged to conference before the participant answers (from early media if available). Defaults to ‘false`.

Returns:

  • (Boolean, nil)


197
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 197

optional :early_media, Telnyx::Internal::Type::Boolean, api_name: :EarlyMedia

#end_conference_on_exitBoolean?

Whether to end the conference when the participant leaves. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


203
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 203

optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean, api_name: :EndConferenceOnExit

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


210
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 210

optional :from, String, api_name: :From

#labelString?

A unique label for the participant that will be added to the conference. The label can be used to reference the participant for updates via the TeXML REST API.

Returns:

  • (String, nil)


218
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 218

optional :label, String, api_name: :Label

#machine_detectionSymbol, ...

Whether to detect if a human or an answering machine picked up the call. Use ‘Enable` if you would like to ne notified as soon as the called party is identified. Use `DetectMessageEnd`, if you would like to leave a message on an answering machine.



227
228
229
230
231
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 227

optional :machine_detection,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::MachineDetection
},
api_name: :MachineDetection

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


238
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 238

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


245
246
247
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 245

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


254
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 254

optional :machine_detection_speech_threshold, Integer, api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

How long answering machine detection should go on for before sending an ‘Unknown` result. Given in milliseconds.

Returns:

  • (Integer, nil)


261
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 261

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#max_participantsInteger?

The maximum number of participants in the conference. Can be a positive integer from 2 to 800. The default value is 250.

Returns:

  • (Integer, nil)


268
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 268

optional :max_participants, Integer, api_name: :MaxParticipants

#mutedBoolean?

Whether the participant should be muted.

Returns:

  • (Boolean, nil)


274
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 274

optional :muted, Telnyx::Internal::Type::Boolean, api_name: :Muted

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Returns:

  • (String, nil)


280
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 280

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant’s call leg. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


286
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 286

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to ‘mono`.



292
293
294
295
296
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 292

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Returns:

  • (String, nil)


302
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 302

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.

Returns:

  • (String, nil)


310
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 310

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.



316
317
318
319
320
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 316

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



326
327
328
329
330
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 326

optional :recording_track,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::RecordingTrack
},
api_name: :RecordingTrack

#sip_auth_passwordString?

The password to use for SIP authentication.

Returns:

  • (String, nil)


336
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 336

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Returns:

  • (String, nil)


342
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 342

optional :sip_auth_username, String, api_name: :SipAuthUsername

#start_conference_on_enterBoolean?

Whether to start the conference when the participant enters. Defaults to ‘true`.

Returns:

  • (Boolean, nil)


348
349
350
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 348

optional :start_conference_on_enter,
Telnyx::Internal::Type::Boolean,
api_name: :StartConferenceOnEnter

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Returns:

  • (String, nil)


356
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 356

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventString?

The changes to the call’s state that should generate a call to ‘StatusCallback`. Can be: `initiated`, `ringing`, `answered`, and `completed`. Separate multiple values with a space. The default value is `completed`.

Returns:

  • (String, nil)


364
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 364

optional :status_callback_event, String, api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



370
371
372
373
374
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 370

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#time_limitInteger?

The maximum duration of the call in seconds.

Returns:

  • (Integer, nil)


380
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 380

optional :time_limit, Integer, api_name: :TimeLimit

#timeout_secondsInteger?

The number of seconds that we should allow the phone to ring before assuming there is no answer. Can be an integer between 5 and 120, inclusive. The default value is 30.

Returns:

  • (Integer, nil)


388
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 388

optional :timeout_seconds, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


395
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 395

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.



402
403
404
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 402

optional :trim,
enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::Trim },
api_name: :Trim

#wait_urlString?

The URL to call for an audio file to play while the participant is waiting for the conference to start.

Returns:

  • (String, nil)


411
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 411

optional :wait_url, String, api_name: :WaitUrl

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 527