Class: Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb

Overview

Defined Under Namespace

Modules: AmdStatusCallbackMethod, Beep, ConferenceRecord, ConferenceRecordingStatusCallbackMethod, ConferenceStatusCallbackMethod, ConferenceTrim, MachineDetection, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, StatusCallbackMethod, Trim Classes: CustomHeader

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, value:) ⇒ Object

Parameters:

  • name (String)

    The name of the custom header

  • value (String)

    The value of the custom header



# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 393

Instance Attribute Details

#account_sidString

Returns:

  • (String)


16
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 16

required :account_sid, String

#amd_status_callbackString?

The URL the result of answering machine detection will be sent to.

Returns:

  • (String, nil)


22
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 22

optional :amd_status_callback, String, api_name: :AmdStatusCallback

#amd_status_callback_methodSymbol, ...

HTTP request type used for ‘AmdStatusCallback`. Defaults to `POST`.



28
29
30
31
32
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 28

optional :amd_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::AmdStatusCallbackMethod
},
api_name: :AmdStatusCallbackMethod

#beepSymbol, ...

Whether to play a notification beep to the conference when the participant enters and exits.



39
40
41
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 39

optional :beep,
enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::Beep },
api_name: :Beep

#call_sid_to_coachString?

The SID of the participant who is being coached. The participant being coached is the only participant who can hear the participant who is coaching.

Returns:

  • (String, nil)


57
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 57

optional :call_sid_to_coach, String, api_name: :CallSidToCoach

#caller_idString?

To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If ommited, the display name will be the same as the number in the `From` field.

Returns:

  • (String, nil)


50
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 50

optional :caller_id, String, api_name: :CallerId

#cancel_playback_on_detect_message_endBoolean?

Whether to cancel ongoing playback on ‘greeting ended` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


64
65
66
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 64

optional :cancel_playback_on_detect_message_end,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnDetectMessageEnd

#cancel_playback_on_machine_detectionBoolean?

Whether to cancel ongoing playback on ‘machine` detection. Defaults to `true`.

Returns:

  • (Boolean, nil)


72
73
74
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 72

optional :cancel_playback_on_machine_detection,
Telnyx::Internal::Type::Boolean,
api_name: :CancelPlaybackOnMachineDetection

#coachingBoolean?

Whether the participant is coaching another call. When ‘true`, `CallSidToCoach` has to be given.

Returns:

  • (Boolean, nil)


81
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 81

optional :coaching, Telnyx::Internal::Type::Boolean, api_name: :Coaching

#conference_recordSymbol, ...

Whether to record the conference the participant is joining. Defualts to ‘do-not-record`. The boolean values `true` and `false` are synonymous with `record-from-start` and `do-not-record` respectively.



89
90
91
92
93
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 89

optional :conference_record,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceRecord
},
api_name: :ConferenceRecord

#conference_recording_status_callbackString?

The URL the conference recording callbacks will be sent to.

Returns:

  • (String, nil)


99
100
101
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 99

optional :conference_recording_status_callback,
String,
api_name: :ConferenceRecordingStatusCallback

#conference_recording_status_callback_eventString?

The changes to the conference recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`. `failed` and `absent` are synonymous.

Returns:

  • (String, nil)


110
111
112
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 110

optional :conference_recording_status_callback_event,
String,
api_name: :ConferenceRecordingStatusCallbackEvent

#conference_recording_status_callback_methodSymbol, ...

HTTP request type used for ‘ConferenceRecordingStatusCallback`. Defaults to `POST`.



119
120
121
122
123
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 119

optional :conference_recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceRecordingStatusCallbackMethod
},
api_name: :ConferenceRecordingStatusCallbackMethod

#conference_recording_timeoutInteger?

The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. Please note that the transcription is used to detect silence and the related charge will be applied. The minimum value is 0. The default value is 0 (infinite)

Returns:

  • (Integer, nil)


132
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 132

optional :conference_recording_timeout, Integer, api_name: :ConferenceRecordingTimeout

#conference_status_callbackString?

The URL the conference callbacks will be sent to.

Returns:

  • (String, nil)


138
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 138

optional :conference_status_callback, String, api_name: :ConferenceStatusCallback

#conference_status_callback_eventString?

The changes to the conference’s state that should generate a call to ‘ConferenceStatusCallback`. Can be: `start`, `end`, `join` and `leave`. Separate multiple values with a space. By default no callbacks are sent.

Returns:

  • (String, nil)


146
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 146

optional :conference_status_callback_event, String, api_name: :ConferenceStatusCallbackEvent

#conference_status_callback_methodSymbol, ...

HTTP request type used for ‘ConferenceStatusCallback`. Defaults to `POST`.



152
153
154
155
156
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 152

optional :conference_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceStatusCallbackMethod
},
api_name: :ConferenceStatusCallbackMethod

#conference_trimSymbol, ...

Whether to trim any leading and trailing silence from the conference recording. Defaults to ‘trim-silence`.



163
164
165
166
167
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 163

optional :conference_trim,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::ConferenceTrim
},
api_name: :ConferenceTrim

#custom_headersArray<Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams::CustomHeader>?

Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.



174
175
176
177
178
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 174

optional :custom_headers,
-> {
  Telnyx::Internal::Type::ArrayOf[Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::CustomHeader]
},
api_name: :CustomHeaders

#early_mediaBoolean?

Whether participant shall be bridged to conference before the participant answers (from early media if available). Defaults to ‘false`.

Returns:

  • (Boolean, nil)


185
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 185

optional :early_media, Telnyx::Internal::Type::Boolean, api_name: :EarlyMedia

#end_conference_on_exitBoolean?

Whether to end the conference when the participant leaves. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


191
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 191

optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean, api_name: :EndConferenceOnExit

#fromString?

The phone number of the party that initiated the call. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


198
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 198

optional :from, String, api_name: :From

#machine_detectionSymbol, ...

Whether to detect if a human or an answering machine picked up the call. Use ‘Enable` if you would like to ne notified as soon as the called party is identified. Use `DetectMessageEnd`, if you would like to leave a message on an answering machine.



207
208
209
210
211
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 207

optional :machine_detection,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::MachineDetection
},
api_name: :MachineDetection

#machine_detection_silence_timeoutInteger?

If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


218
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 218

optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout

#machine_detection_speech_end_thresholdInteger?

Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


225
226
227
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 225

optional :machine_detection_speech_end_threshold,
Integer,
api_name: :MachineDetectionSpeechEndThreshold

#machine_detection_speech_thresholdInteger?

Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.

Returns:

  • (Integer, nil)


234
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 234

optional :machine_detection_speech_threshold, Integer, api_name: :MachineDetectionSpeechThreshold

#machine_detection_timeoutInteger?

How long answering machine detection should go on for before sending an ‘Unknown` result. Given in milliseconds.

Returns:

  • (Integer, nil)


241
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 241

optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout

#max_participantsInteger?

The maximum number of participants in the conference. Can be a positive integer from 2 to 800. The default value is 250.

Returns:

  • (Integer, nil)


248
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 248

optional :max_participants, Integer, api_name: :MaxParticipants

#mutedBoolean?

Whether the participant should be muted.

Returns:

  • (Boolean, nil)


254
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 254

optional :muted, Telnyx::Internal::Type::Boolean, api_name: :Muted

#preferred_codecsString?

The list of comma-separated codecs to be offered on a call.

Returns:

  • (String, nil)


260
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 260

optional :preferred_codecs, String, api_name: :PreferredCodecs

#recordBoolean?

Whether to record the entire participant’s call leg. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


266
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 266

optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record

#recording_channelsSymbol, ...

The number of channels in the final recording. Defaults to ‘mono`.



272
273
274
275
276
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 272

optional :recording_channels,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::RecordingChannels
},
api_name: :RecordingChannels

#recording_status_callbackString?

The URL the recording callbacks will be sent to.

Returns:

  • (String, nil)


282
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 282

optional :recording_status_callback, String, api_name: :RecordingStatusCallback

#recording_status_callback_eventString?

The changes to the recording’s state that should generate a call to ‘RecoridngStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.

Returns:

  • (String, nil)


290
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 290

optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent

#recording_status_callback_methodSymbol, ...

HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.



296
297
298
299
300
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 296

optional :recording_status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::RecordingStatusCallbackMethod
},
api_name: :RecordingStatusCallbackMethod

#recording_trackSymbol, ...

The audio track to record for the call. The default is ‘both`.



306
307
308
309
310
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 306

optional :recording_track,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::RecordingTrack
},
api_name: :RecordingTrack

#sip_auth_passwordString?

The password to use for SIP authentication.

Returns:

  • (String, nil)


316
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 316

optional :sip_auth_password, String, api_name: :SipAuthPassword

#sip_auth_usernameString?

The username to use for SIP authentication.

Returns:

  • (String, nil)


322
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 322

optional :sip_auth_username, String, api_name: :SipAuthUsername

#start_conference_on_enterBoolean?

Whether to start the conference when the participant enters. Defaults to ‘true`.

Returns:

  • (Boolean, nil)


328
329
330
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 328

optional :start_conference_on_enter,
Telnyx::Internal::Type::Boolean,
api_name: :StartConferenceOnEnter

#status_callbackString?

URL destination for Telnyx to send status callback events to for the call.

Returns:

  • (String, nil)


336
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 336

optional :status_callback, String, api_name: :StatusCallback

#status_callback_eventString?

The changes to the call’s state that should generate a call to ‘StatusCallback`. Can be: `initiated`, `ringing`, `answered`, and `completed`. Separate multiple values with a space. The default value is `completed`.

Returns:

  • (String, nil)


344
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 344

optional :status_callback_event, String, api_name: :StatusCallbackEvent

#status_callback_methodSymbol, ...

HTTP request type used for ‘StatusCallback`.



350
351
352
353
354
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 350

optional :status_callback_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::StatusCallbackMethod
},
api_name: :StatusCallbackMethod

#time_limitInteger?

The maximum duration of the call in seconds.

Returns:

  • (Integer, nil)


360
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 360

optional :time_limit, Integer, api_name: :TimeLimit

#timeout_secondsInteger?

The number of seconds that we should allow the phone to ring before assuming there is no answer. Can be an integer between 5 and 120, inclusive. The default value is 30.

Returns:

  • (Integer, nil)


368
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 368

optional :timeout_seconds, Integer, api_name: :Timeout

#toString?

The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.

Returns:

  • (String, nil)


375
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 375

optional :to, String, api_name: :To

#trimSymbol, ...

Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.



382
383
384
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 382

optional :trim,
enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantParticipantsParams::Trim },
api_name: :Trim

#wait_urlString?

The URL to call for an audio file to play while the participant is waiting for the conference to start.

Returns:

  • (String, nil)


391
# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 391

optional :wait_url, String, api_name: :WaitUrl

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb', line 501