Module: Telnyx::Models::Texml::Accounts::Conferences::ParticipantParticipantsParams::MachineDetection

Extended by:
Internal::Type::Enum
Defined in:
lib/telnyx/models/texml/accounts/conferences/participant_participants_params.rb

Overview

Whether to detect if a human or an answering machine picked up the call. Use ‘Enable` if you would like to ne notified as soon as the called party is identified. Use `DetectMessageEnd`, if you would like to leave a message on an answering machine.

Constant Summary collapse

ENABLE =
:Enable
DETECT_MESSAGE_END =
:DetectMessageEnd

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info