Class: Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb

Overview

Defined Under Namespace

Classes: Participant

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#end_Integer?

The number of the last element on the page, zero-indexed.

Returns:

  • (Integer, nil)


14
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 14

optional :end_, Integer, api_name: :end

#first_page_uriString?

/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Conferences/6dc6cc1a-1ba1-4351-86b8-4c22c95cd98f/Participants.json?page=0&pagesize=20

Returns:

  • (String, nil)


20
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 20

optional :first_page_uri, String

#next_page_uriString?

/v2/texml/Accounts/61bf923e-5e4d-4595-a110-56190ea18a1b/Conferences/6dc6cc1a-1ba1-4351-86b8-4c22c95cd98f/Participants.json?Page=1&PageSize=1&PageToken=MTY4AjgyNDkwNzIxMQ

Returns:

  • (String, nil)


26
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 26

optional :next_page_uri, String

#pageInteger?

Current page number, zero-indexed.

Returns:

  • (Integer, nil)


32
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 32

optional :page, Integer

#page_sizeInteger?

The number of items on the page

Returns:

  • (Integer, nil)


38
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 38

optional :page_size, Integer

#participantsArray<Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse::Participant>?



43
44
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 43

optional :participants,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveParticipantsResponse::Participant] }

#startInteger?

The number of the first element on the page, zero-indexed.

Returns:

  • (Integer, nil)


50
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 50

optional :start, Integer

#uriString?

The URI of the current page.

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_participants_response.rb', line 56

optional :uri, String