Class: Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveResponse
- Defined in:
- lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#account_sid ⇒ String?
The id of the account the resource belongs to.
-
#api_version ⇒ String?
The version of the API that was used to make the request.
-
#call_sid ⇒ String?
The identifier of this participant’s call.
-
#call_sid_legacy ⇒ String?
The identifier of this participant’s call.
-
#coaching ⇒ Boolean?
Whether the participant is coaching another call.
-
#coaching_call_sid ⇒ String?
The identifier of the coached participant’s call.
-
#coaching_call_sid_legacy ⇒ String?
The identifier of the coached participant’s call.
-
#conference_sid ⇒ String?
The unique identifier for the conference.
-
#date_created ⇒ String?
The timestamp of when the resource was created.
-
#date_updated ⇒ String?
The timestamp of when the resource was last updated.
-
#end_conference_on_exit ⇒ Boolean?
Whether the conference ends when the participant leaves.
-
#hold ⇒ Boolean?
Whether the participant is on hold.
-
#muted ⇒ Boolean?
Whether the participant is muted.
-
#status ⇒ Symbol, ...
The status of the participant’s call in the conference.
-
#uri ⇒ String?
The relative URI for this participant.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid: nil, api_version: nil, call_sid: nil, call_sid_legacy: nil, coaching: nil, coaching_call_sid: nil, coaching_call_sid_legacy: nil, conference_sid: nil, date_created: nil, date_updated: nil, end_conference_on_exit: nil, hold: nil, muted: nil, status: nil, uri: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 101
|
Instance Attribute Details
#account_sid ⇒ String?
The id of the account the resource belongs to.
14 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 14 optional :account_sid, String |
#api_version ⇒ String?
The version of the API that was used to make the request.
20 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 20 optional :api_version, String |
#call_sid ⇒ String?
The identifier of this participant’s call.
26 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 26 optional :call_sid, String |
#call_sid_legacy ⇒ String?
The identifier of this participant’s call.
32 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 32 optional :call_sid_legacy, String |
#coaching ⇒ Boolean?
Whether the participant is coaching another call.
38 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 38 optional :coaching, Telnyx::Internal::Type::Boolean |
#coaching_call_sid ⇒ String?
The identifier of the coached participant’s call.
44 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 44 optional :coaching_call_sid, String |
#coaching_call_sid_legacy ⇒ String?
The identifier of the coached participant’s call.
50 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 50 optional :coaching_call_sid_legacy, String |
#conference_sid ⇒ String?
The unique identifier for the conference.
56 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 56 optional :conference_sid, String |
#date_created ⇒ String?
The timestamp of when the resource was created.
62 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 62 optional :date_created, String |
#date_updated ⇒ String?
The timestamp of when the resource was last updated.
68 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 68 optional :date_updated, String |
#end_conference_on_exit ⇒ Boolean?
Whether the conference ends when the participant leaves.
74 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 74 optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean |
#hold ⇒ Boolean?
Whether the participant is on hold.
80 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 80 optional :hold, Telnyx::Internal::Type::Boolean |
#muted ⇒ Boolean?
Whether the participant is muted.
86 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 86 optional :muted, Telnyx::Internal::Type::Boolean |
#status ⇒ Symbol, ...
The status of the participant’s call in the conference.
92 93 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 92 optional :status, enum: -> { Telnyx::Models::Texml::Accounts::Conferences::ParticipantRetrieveResponse::Status } |
#uri ⇒ String?
The relative URI for this participant.
99 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_retrieve_response.rb', line 99 optional :uri, String |