Class: Telnyx::Models::Texml::Accounts::Conferences::ParticipantUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::Conferences::ParticipantUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb
Overview
Defined Under Namespace
Modules: AnnounceMethod, HoldMethod
Instance Attribute Summary collapse
- #account_sid ⇒ String
-
#announce_method ⇒ Symbol, ...
The HTTP method used to call the ‘AnnounceUrl`.
-
#announce_url ⇒ String?
The URL to call to announce something to the participant.
-
#beep_on_exit ⇒ Boolean?
Whether to play a notification beep to the conference when the participant exits.
- #call_sid_or_participant_label ⇒ String
-
#call_sid_to_coach ⇒ String?
The SID of the participant who is being coached.
-
#coaching ⇒ Boolean?
Whether the participant is coaching another call.
- #conference_sid ⇒ String
-
#end_conference_on_exit ⇒ Boolean?
Whether to end the conference when the participant leaves.
-
#hold ⇒ Boolean?
Whether the participant should be on hold.
-
#hold_method ⇒ Symbol, ...
The HTTP method to use when calling the ‘HoldUrl`.
-
#hold_url ⇒ String?
The URL to be called using the ‘HoldMethod` for music that plays when the participant is on hold.
-
#muted ⇒ Boolean?
Whether the participant should be muted.
-
#wait_url ⇒ String?
The URL to call for an audio file to play while the participant is waiting for the conference to start.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_sid:, conference_sid:, call_sid_or_participant_label:, announce_method: nil, announce_url: nil, beep_on_exit: nil, call_sid_to_coach: nil, coaching: nil, end_conference_on_exit: nil, hold: nil, hold_method: nil, hold_url: nil, muted: nil, wait_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ParticipantUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_sid:, conference_sid:, call_sid_or_participant_label:, announce_method: nil, announce_url: nil, beep_on_exit: nil, call_sid_to_coach: nil, coaching: nil, end_conference_on_exit: nil, hold: nil, hold_method: nil, hold_url: nil, muted: nil, wait_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::Conferences::ParticipantUpdateParams for more details.
|
|
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 108
|
Instance Attribute Details
#account_sid ⇒ String
16 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 16 required :account_sid, String |
#announce_method ⇒ Symbol, ...
The HTTP method used to call the ‘AnnounceUrl`. Defaults to `POST`.
32 33 34 35 36 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 32 optional :announce_method, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantUpdateParams::AnnounceMethod }, api_name: :AnnounceMethod |
#announce_url ⇒ String?
The URL to call to announce something to the participant. The URL may return an MP3 fileo a WAV file, or a TwiML document that contains ‘<Play>`, `<Say>`, `<Pause>`, or `<Redirect>` verbs.
44 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 44 optional :announce_url, String, api_name: :AnnounceUrl |
#beep_on_exit ⇒ Boolean?
Whether to play a notification beep to the conference when the participant exits.
51 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 51 optional :beep_on_exit, Telnyx::Internal::Type::Boolean, api_name: :BeepOnExit |
#call_sid_or_participant_label ⇒ String
26 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 26 required :call_sid_or_participant_label, String |
#call_sid_to_coach ⇒ String?
The SID of the participant who is being coached. The participant being coached is the only participant who can hear the participant who is coaching.
58 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 58 optional :call_sid_to_coach, String, api_name: :CallSidToCoach |
#coaching ⇒ Boolean?
Whether the participant is coaching another call. When ‘true`, `CallSidToCoach` has to be given.
65 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 65 optional :coaching, Telnyx::Internal::Type::Boolean, api_name: :Coaching |
#conference_sid ⇒ String
21 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 21 required :conference_sid, String |
#end_conference_on_exit ⇒ Boolean?
Whether to end the conference when the participant leaves.
71 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 71 optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean, api_name: :EndConferenceOnExit |
#hold ⇒ Boolean?
Whether the participant should be on hold.
77 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 77 optional :hold, Telnyx::Internal::Type::Boolean, api_name: :Hold |
#hold_method ⇒ Symbol, ...
The HTTP method to use when calling the ‘HoldUrl`.
83 84 85 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 83 optional :hold_method, enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantUpdateParams::HoldMethod }, api_name: :HoldMethod |
#hold_url ⇒ String?
The URL to be called using the ‘HoldMethod` for music that plays when the participant is on hold. The URL may return an MP3 file, a WAV file, or a TwiML document that contains `<Play>`, `<Say>`, `<Pause>`, or `<Redirect>` verbs.
93 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 93 optional :hold_url, String, api_name: :HoldUrl |
#muted ⇒ Boolean?
Whether the participant should be muted.
99 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 99 optional :muted, Telnyx::Internal::Type::Boolean, api_name: :Muted |
#wait_url ⇒ String?
The URL to call for an audio file to play while the participant is waiting for the conference to start.
106 |
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 106 optional :wait_url, String, api_name: :WaitUrl |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 150
|