Class: Telnyx::Models::Texml::Accounts::Conferences::ParticipantUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb

Overview

Defined Under Namespace

Modules: AnnounceMethod, HoldMethod

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_sid:, conference_sid:, announce_method: nil, announce_url: nil, beep_on_exit: nil, call_sid_to_coach: nil, coaching: nil, end_conference_on_exit: nil, hold: nil, hold_method: nil, hold_url: nil, muted: nil, wait_url: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::Conferences::ParticipantUpdateParams for more details.

Parameters:

  • account_sid (String)
  • conference_sid (String)
  • announce_method (Symbol, Telnyx::Models::Texml::Accounts::Conferences::ParticipantUpdateParams::AnnounceMethod) (defaults to: nil)

    The HTTP method used to call the ‘AnnounceUrl`. Defaults to `POST`.

  • announce_url (String) (defaults to: nil)

    The URL to call to announce something to the participant. The URL may return an

  • beep_on_exit (Boolean) (defaults to: nil)

    Whether to play a notification beep to the conference when the participant exits

  • call_sid_to_coach (String) (defaults to: nil)

    The SID of the participant who is being coached. The participant being coached i

  • coaching (Boolean) (defaults to: nil)

    Whether the participant is coaching another call. When ‘true`, `CallSidToCoach`

  • end_conference_on_exit (Boolean) (defaults to: nil)

    Whether to end the conference when the participant leaves.

  • hold (Boolean) (defaults to: nil)

    Whether the participant should be on hold.

  • hold_method (Symbol, Telnyx::Models::Texml::Accounts::Conferences::ParticipantUpdateParams::HoldMethod) (defaults to: nil)

    The HTTP method to use when calling the ‘HoldUrl`.

  • hold_url (String) (defaults to: nil)

    The URL to be called using the ‘HoldMethod` for music that plays when the partic

  • muted (Boolean) (defaults to: nil)

    Whether the participant should be muted.

  • wait_url (String) (defaults to: nil)

    The URL to call for an audio file to play while the participant is waiting for t

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 103

Instance Attribute Details

#account_sidString

Returns:

  • (String)


16
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 16

required :account_sid, String

#announce_methodSymbol, ...

The HTTP method used to call the ‘AnnounceUrl`. Defaults to `POST`.



27
28
29
30
31
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 27

optional :announce_method,
enum: -> {
  Telnyx::Texml::Accounts::Conferences::ParticipantUpdateParams::AnnounceMethod
},
api_name: :AnnounceMethod

#announce_urlString?

The URL to call to announce something to the participant. The URL may return an MP3 fileo a WAV file, or a TwiML document that contains ‘<Play>`, `<Say>`, `<Pause>`, or `<Redirect>` verbs.

Returns:

  • (String, nil)


39
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 39

optional :announce_url, String, api_name: :AnnounceUrl

#beep_on_exitBoolean?

Whether to play a notification beep to the conference when the participant exits.

Returns:

  • (Boolean, nil)


46
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 46

optional :beep_on_exit, Telnyx::Internal::Type::Boolean, api_name: :BeepOnExit

#call_sid_to_coachString?

The SID of the participant who is being coached. The participant being coached is the only participant who can hear the participant who is coaching.

Returns:

  • (String, nil)


53
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 53

optional :call_sid_to_coach, String, api_name: :CallSidToCoach

#coachingBoolean?

Whether the participant is coaching another call. When ‘true`, `CallSidToCoach` has to be given.

Returns:

  • (Boolean, nil)


60
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 60

optional :coaching, Telnyx::Internal::Type::Boolean, api_name: :Coaching

#conference_sidString

Returns:

  • (String)


21
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 21

required :conference_sid, String

#end_conference_on_exitBoolean?

Whether to end the conference when the participant leaves.

Returns:

  • (Boolean, nil)


66
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 66

optional :end_conference_on_exit, Telnyx::Internal::Type::Boolean, api_name: :EndConferenceOnExit

#holdBoolean?

Whether the participant should be on hold.

Returns:

  • (Boolean, nil)


72
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 72

optional :hold, Telnyx::Internal::Type::Boolean, api_name: :Hold

#hold_methodSymbol, ...

The HTTP method to use when calling the ‘HoldUrl`.



78
79
80
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 78

optional :hold_method,
enum: -> { Telnyx::Texml::Accounts::Conferences::ParticipantUpdateParams::HoldMethod },
api_name: :HoldMethod

#hold_urlString?

The URL to be called using the ‘HoldMethod` for music that plays when the participant is on hold. The URL may return an MP3 file, a WAV file, or a TwiML document that contains `<Play>`, `<Say>`, `<Pause>`, or `<Redirect>` verbs.

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 88

optional :hold_url, String, api_name: :HoldUrl

#mutedBoolean?

Whether the participant should be muted.

Returns:

  • (Boolean, nil)


94
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 94

optional :muted, Telnyx::Internal::Type::Boolean, api_name: :Muted

#wait_urlString?

The URL to call for an audio file to play while the participant is waiting for the conference to start.

Returns:

  • (String, nil)


101
# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 101

optional :wait_url, String, api_name: :WaitUrl

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/texml/accounts/conferences/participant_update_params.rb', line 143