Class: Telnyx::Models::Texml::Accounts::UpdateCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Texml::Accounts::UpdateCall
- Defined in:
- lib/telnyx/models/texml/accounts/update_call.rb
Direct Known Subclasses
Defined Under Namespace
Modules: FallbackMethod, Method, StatusCallbackMethod
Instance Attribute Summary collapse
-
#fallback_method ⇒ Symbol, ...
HTTP request type used for ‘FallbackUrl`.
-
#fallback_url ⇒ String?
A failover URL for which Telnyx will retrieve the TeXML call instructions if the Url is not responding.
-
#http_method ⇒ Symbol, ...
HTTP request type used for ‘Url`.
-
#status ⇒ String?
The value to set the call status to.
-
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events to for the call.
-
#status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘StatusCallback`.
-
#texml ⇒ String?
TeXML to replace the current one with.
-
#url ⇒ String?
The URL where TeXML will make a request to retrieve a new set of TeXML instructions to continue the call flow.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(fallback_method: nil, fallback_url: nil, http_method: nil, status: nil, status_callback: nil, status_callback_method: nil, texml: nil, url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UpdateCall for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(fallback_method: nil, fallback_url: nil, http_method: nil, status: nil, status_callback: nil, status_callback_method: nil, texml: nil, url: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Texml::Accounts::UpdateCall for more details.
|
|
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 63
|
Instance Attribute Details
#fallback_method ⇒ Symbol, ...
HTTP request type used for ‘FallbackUrl`.
12 13 14 |
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 12 optional :fallback_method, enum: -> { Telnyx::Texml::Accounts::UpdateCall::FallbackMethod }, api_name: :FallbackMethod |
#fallback_url ⇒ String?
A failover URL for which Telnyx will retrieve the TeXML call instructions if the Url is not responding.
21 |
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 21 optional :fallback_url, String, api_name: :FallbackUrl |
#http_method ⇒ Symbol, ...
HTTP request type used for ‘Url`.
27 |
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 27 optional :http_method, enum: -> { Telnyx::Texml::Accounts::UpdateCall::Method }, api_name: :Method |
#status ⇒ String?
The value to set the call status to. Setting the status to completed ends the call.
34 |
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 34 optional :status, String, api_name: :Status |
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events to for the call.
40 |
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 40 optional :status_callback, String, api_name: :StatusCallback |
#status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘StatusCallback`.
46 47 48 |
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 46 optional :status_callback_method, enum: -> { Telnyx::Texml::Accounts::UpdateCall::StatusCallbackMethod }, api_name: :StatusCallbackMethod |
#texml ⇒ String?
TeXML to replace the current one with.
54 |
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 54 optional :texml, String, api_name: :Texml |
#url ⇒ String?
The URL where TeXML will make a request to retrieve a new set of TeXML instructions to continue the call flow.
61 |
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 61 optional :url, String, api_name: :Url |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml/accounts/update_call.rb', line 92
|