Class: Telnyx::Models::TexmlInitiateAICallParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::TexmlInitiateAICallParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/texml_initiate_ai_call_params.rb
Overview
Defined Under Namespace
Modules: AsyncAmdStatusCallbackMethod, ConversationCallbackMethod, DetectionMode, MachineDetection, RecordingChannels, RecordingStatusCallbackMethod, RecordingTrack, SipRegion, StatusCallbackMethod, Trim Classes: CustomHeader
Instance Attribute Summary collapse
-
#ai_assistant_dynamic_variables ⇒ Hash{Symbol=>String}?
Key-value map of dynamic variables to pass to the AI assistant.
-
#ai_assistant_id ⇒ String
The ID of the AI assistant to use for the call.
-
#ai_assistant_version ⇒ String?
The version of the AI assistant to use.
-
#async_amd ⇒ Boolean?
Select whether to perform answering machine detection in the background.
-
#async_amd_status_callback ⇒ String?
URL destination for Telnyx to send AMD callback events to for the call.
-
#async_amd_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘AsyncAmdStatusCallback`.
-
#caller_id ⇒ String?
To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number).
- #connection_id ⇒ String
-
#conversation_callback ⇒ String?
URL destination for Telnyx to send AI conversation callback events for this call.
-
#conversation_callback_method ⇒ Symbol, ...
HTTP request type used for ‘ConversationCallback` and `ConversationCallbacks`.
-
#conversation_callbacks ⇒ Array<String>?
Array of URL destinations for AI conversation callback events for this call.
-
#custom_headers ⇒ Array<Telnyx::Models::TexmlInitiateAICallParams::CustomHeader>?
Custom HTTP headers to be sent with the call.
-
#detection_mode ⇒ Symbol, ...
Allows you to choose between Premium and Standard detections.
-
#from ⇒ String
The phone number of the party initiating the call.
-
#machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection.
-
#machine_detection_silence_timeout ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine.
-
#machine_detection_speech_end_threshold ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human.
-
#machine_detection_speech_threshold ⇒ Integer?
Maximum threshold of a human greeting.
-
#machine_detection_timeout ⇒ Integer?
Maximum timeout threshold in milliseconds for overall detection.
-
#passports ⇒ String?
A string of passport identifiers to associate with the call.
-
#preferred_codecs ⇒ String?
The list of comma-separated codecs to be offered on a call.
-
#record ⇒ Boolean?
Whether to record the entire participant’s call leg.
-
#recording_channels ⇒ Symbol, ...
The number of channels in the final recording.
-
#recording_status_callback ⇒ String?
The URL the recording callbacks will be sent to.
-
#recording_status_callback_event ⇒ String?
The changes to the recording’s state that should generate a call to ‘RecordingStatusCallback`.
-
#recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘RecordingStatusCallback`.
-
#recording_timeout ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected.
-
#recording_track ⇒ Symbol, ...
The audio track to record for the call.
-
#send_recording_url ⇒ Boolean?
Whether to send RecordingUrl in webhooks.
-
#sip_auth_password ⇒ String?
The password to use for SIP authentication.
-
#sip_auth_username ⇒ String?
The username to use for SIP authentication.
-
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
-
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events for this AI call.
-
#status_callback_event ⇒ String?
The status callback events for which Telnyx should send a webhook for this AI call.
-
#status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘StatusCallback` and `StatusCallbacks` for this AI call.
-
#status_callbacks ⇒ Array<String>?
Array of URL destinations for Telnyx to send status callback events for this AI call.
-
#time_limit ⇒ Integer?
The maximum duration of the call in seconds.
-
#timeout_seconds ⇒ Integer?
The number of seconds to wait for the called party to answer the call before the call is canceled.
-
#to ⇒ String
The phone number of the called party.
-
#trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the recording.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(name:, value:) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, value:) ⇒ Object
|
|
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 301
|
Instance Attribute Details
#ai_assistant_dynamic_variables ⇒ Hash{Symbol=>String}?
Key-value map of dynamic variables to pass to the AI assistant.
39 40 41 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 39 optional :ai_assistant_dynamic_variables, Telnyx::Internal::Type::HashOf[String], api_name: :AIAssistantDynamicVariables |
#ai_assistant_id ⇒ String
The ID of the AI assistant to use for the call.
19 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 19 required :ai_assistant_id, String, api_name: :AIAssistantId |
#ai_assistant_version ⇒ String?
The version of the AI assistant to use.
47 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 47 optional :ai_assistant_version, String, api_name: :AIAssistantVersion |
#async_amd ⇒ Boolean?
Select whether to perform answering machine detection in the background. By default execution is blocked until Answering Machine Detection is completed.
54 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 54 optional :async_amd, Telnyx::Internal::Type::Boolean, api_name: :AsyncAmd |
#async_amd_status_callback ⇒ String?
URL destination for Telnyx to send AMD callback events to for the call.
60 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 60 optional :async_amd_status_callback, String, api_name: :AsyncAmdStatusCallback |
#async_amd_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘AsyncAmdStatusCallback`.
66 67 68 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 66 optional :async_amd_status_callback_method, enum: -> { Telnyx::TexmlInitiateAICallParams::AsyncAmdStatusCallbackMethod }, api_name: :AsyncAmdStatusCallbackMethod |
#caller_id ⇒ String?
To be used as the caller id name (SIP From Display Name) presented to the destination (‘To` number). The string should have a maximum of 128 characters, containing only letters, numbers, spaces, and `-_~!.+` special characters. If omitted, the display name will be the same as the number in the `From` field.
77 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 77 optional :caller_id, String, api_name: :CallerId |
#connection_id ⇒ String
13 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 13 required :connection_id, String |
#conversation_callback ⇒ String?
URL destination for Telnyx to send AI conversation callback events for this call. Events include ‘conversation_created` and `conversation_ended`.
84 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 84 optional :conversation_callback, String, api_name: :ConversationCallback |
#conversation_callback_method ⇒ Symbol, ...
HTTP request type used for ‘ConversationCallback` and `ConversationCallbacks`.
90 91 92 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 90 optional :conversation_callback_method, enum: -> { Telnyx::TexmlInitiateAICallParams::ConversationCallbackMethod }, api_name: :ConversationCallbackMethod |
#conversation_callbacks ⇒ Array<String>?
Array of URL destinations for AI conversation callback events for this call. Events include ‘conversation_created` and `conversation_ended`.
99 100 101 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 99 optional :conversation_callbacks, Telnyx::Internal::Type::ArrayOf[String], api_name: :ConversationCallbacks |
#custom_headers ⇒ Array<Telnyx::Models::TexmlInitiateAICallParams::CustomHeader>?
Custom HTTP headers to be sent with the call. Each header should be an object with ‘name’ and ‘value’ properties.
108 109 110 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 108 optional :custom_headers, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::TexmlInitiateAICallParams::CustomHeader] }, api_name: :CustomHeaders |
#detection_mode ⇒ Symbol, ...
Allows you to choose between Premium and Standard detections.
116 117 118 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 116 optional :detection_mode, enum: -> { Telnyx::TexmlInitiateAICallParams::DetectionMode }, api_name: :DetectionMode |
#from ⇒ String
The phone number of the party initiating the call. Phone numbers are formatted with a ‘+` and country code.
26 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 26 required :from, String, api_name: :From |
#machine_detection ⇒ Symbol, ...
Enables Answering Machine Detection.
124 125 126 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 124 optional :machine_detection, enum: -> { Telnyx::TexmlInitiateAICallParams::MachineDetection }, api_name: :MachineDetection |
#machine_detection_silence_timeout ⇒ Integer?
If initial silence duration is greater than this value, consider it a machine. Ignored when ‘premium` detection is used.
133 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 133 optional :machine_detection_silence_timeout, Integer, api_name: :MachineDetectionSilenceTimeout |
#machine_detection_speech_end_threshold ⇒ Integer?
Silence duration threshold after a greeting message or voice for it be considered human. Ignored when ‘premium` detection is used.
140 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 140 optional :machine_detection_speech_end_threshold, Integer, api_name: :MachineDetectionSpeechEndThreshold |
#machine_detection_speech_threshold ⇒ Integer?
Maximum threshold of a human greeting. If greeting longer than this value, considered machine. Ignored when ‘premium` detection is used.
147 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 147 optional :machine_detection_speech_threshold, Integer, api_name: :MachineDetectionSpeechThreshold |
#machine_detection_timeout ⇒ Integer?
Maximum timeout threshold in milliseconds for overall detection.
153 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 153 optional :machine_detection_timeout, Integer, api_name: :MachineDetectionTimeout |
#passports ⇒ String?
A string of passport identifiers to associate with the call.
159 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 159 optional :passports, String, api_name: :Passports |
#preferred_codecs ⇒ String?
The list of comma-separated codecs to be offered on a call.
165 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 165 optional :preferred_codecs, String, api_name: :PreferredCodecs |
#record ⇒ Boolean?
Whether to record the entire participant’s call leg. Defaults to ‘false`.
171 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 171 optional :record, Telnyx::Internal::Type::Boolean, api_name: :Record |
#recording_channels ⇒ Symbol, ...
The number of channels in the final recording. Defaults to ‘mono`.
177 178 179 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 177 optional :recording_channels, enum: -> { Telnyx::TexmlInitiateAICallParams::RecordingChannels }, api_name: :RecordingChannels |
#recording_status_callback ⇒ String?
The URL the recording callbacks will be sent to.
185 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 185 optional :recording_status_callback, String, api_name: :RecordingStatusCallback |
#recording_status_callback_event ⇒ String?
The changes to the recording’s state that should generate a call to ‘RecordingStatusCallback`. Can be: `in-progress`, `completed` and `absent`. Separate multiple values with a space. Defaults to `completed`.
193 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 193 optional :recording_status_callback_event, String, api_name: :RecordingStatusCallbackEvent |
#recording_status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘RecordingStatusCallback`. Defaults to `POST`.
199 200 201 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 199 optional :recording_status_callback_method, enum: -> { Telnyx::TexmlInitiateAICallParams::RecordingStatusCallbackMethod }, api_name: :RecordingStatusCallbackMethod |
#recording_timeout ⇒ Integer?
The number of seconds that Telnyx will wait for the recording to be stopped if silence is detected. The timer only starts when the speech is detected. The minimum value is 0. The default value is 0 (infinite).
209 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 209 optional :recording_timeout, Integer, api_name: :RecordingTimeout |
#recording_track ⇒ Symbol, ...
The audio track to record for the call. The default is ‘both`.
215 216 217 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 215 optional :recording_track, enum: -> { Telnyx::TexmlInitiateAICallParams::RecordingTrack }, api_name: :RecordingTrack |
#send_recording_url ⇒ Boolean?
Whether to send RecordingUrl in webhooks.
223 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 223 optional :send_recording_url, Telnyx::Internal::Type::Boolean, api_name: :SendRecordingUrl |
#sip_auth_password ⇒ String?
The password to use for SIP authentication.
229 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 229 optional :sip_auth_password, String, api_name: :SipAuthPassword |
#sip_auth_username ⇒ String?
The username to use for SIP authentication.
235 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 235 optional :sip_auth_username, String, api_name: :SipAuthUsername |
#sip_region ⇒ Symbol, ...
Defines the SIP region to be used for the call.
241 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 241 optional :sip_region, enum: -> { Telnyx::TexmlInitiateAICallParams::SipRegion }, api_name: :SipRegion |
#status_callback ⇒ String?
URL destination for Telnyx to send status callback events for this AI call. When provided, this per-call value overrides the status callback URL configured on the TeXML application/connection.
249 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 249 optional :status_callback, String, api_name: :StatusCallback |
#status_callback_event ⇒ String?
The status callback events for which Telnyx should send a webhook for this AI call. Multiple events can be defined when separated by a space. Valid values: initiated, ringing, answered, completed, no-answer, busy, canceled, failed, analyzed. When provided, this per-call value overrides the status callback events configured on the TeXML application/connection.
259 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 259 optional :status_callback_event, String, api_name: :StatusCallbackEvent |
#status_callback_method ⇒ Symbol, ...
HTTP request type used for ‘StatusCallback` and `StatusCallbacks` for this AI call. When provided, this per-call value overrides the status callback method configured on the TeXML application/connection.
267 268 269 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 267 optional :status_callback_method, enum: -> { Telnyx::TexmlInitiateAICallParams::StatusCallbackMethod }, api_name: :StatusCallbackMethod |
#status_callbacks ⇒ Array<String>?
Array of URL destinations for Telnyx to send status callback events for this AI call. When provided, these per-call values override the status callback URL configured on the TeXML application/connection.
277 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 277 optional :status_callbacks, Telnyx::Internal::Type::ArrayOf[String], api_name: :StatusCallbacks |
#time_limit ⇒ Integer?
The maximum duration of the call in seconds. The minimum value is 30 and the maximum value is 14400 (4 hours). Default is 14400 seconds.
284 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 284 optional :time_limit, Integer, api_name: :TimeLimit |
#timeout_seconds ⇒ Integer?
The number of seconds to wait for the called party to answer the call before the call is canceled. The minimum value is 5 and the maximum value is 120. Default is 30 seconds.
292 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 292 optional :timeout_seconds, Integer, api_name: :Timeout |
#to ⇒ String
The phone number of the called party. Phone numbers are formatted with a ‘+` and country code.
33 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 33 required :to, String, api_name: :To |
#trim ⇒ Symbol, ...
Whether to trim any leading and trailing silence from the recording. Defaults to ‘trim-silence`.
299 |
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 299 optional :trim, enum: -> { Telnyx::TexmlInitiateAICallParams::Trim }, api_name: :Trim |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/texml_initiate_ai_call_params.rb', line 394
|