Class: Telnyx::Models::Transcription::Payload::TranscriptionData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Transcription::Payload::TranscriptionData
- Defined in:
- lib/telnyx/models/transcription.rb
Overview
Defined Under Namespace
Modules: TranscriptionTrack
Instance Attribute Summary collapse
-
#confidence ⇒ Float?
Speech recognition confidence level.
-
#is_final ⇒ Boolean?
When false, it means that this is an interim result.
-
#transcript ⇒ String?
Recognized text.
-
#transcription_track ⇒ Symbol, ...
Indicates which leg of the call has been transcribed.
Instance Method Summary collapse
-
#initialize(confidence: nil, is_final: nil, transcript: nil, transcription_track: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TranscriptionData for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(confidence: nil, is_final: nil, transcript: nil, transcription_track: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::Transcription::Payload::TranscriptionData for more details.
|
|
# File 'lib/telnyx/models/transcription.rb', line 142
|
Instance Attribute Details
#confidence ⇒ Float?
Speech recognition confidence level.
120 |
# File 'lib/telnyx/models/transcription.rb', line 120 optional :confidence, Float |
#is_final ⇒ Boolean?
When false, it means that this is an interim result.
126 |
# File 'lib/telnyx/models/transcription.rb', line 126 optional :is_final, Telnyx::Internal::Type::Boolean |
#transcript ⇒ String?
Recognized text.
132 |
# File 'lib/telnyx/models/transcription.rb', line 132 optional :transcript, String |
#transcription_track ⇒ Symbol, ...
Indicates which leg of the call has been transcribed. This is only available when ‘transcription_engine` is set to `B`.
139 140 |
# File 'lib/telnyx/models/transcription.rb', line 139 optional :transcription_track, enum: -> { Telnyx::Transcription::Payload::TranscriptionData::TranscriptionTrack } |