Class: Telnyx::Models::UacConnectionCreateParams::ExternalUacSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::UacConnectionCreateParams::ExternalUacSettings
- Defined in:
- lib/telnyx/models/uac_connection_create_params.rb
Defined Under Namespace
Modules: Transport
Instance Attribute Summary collapse
-
#auth_username ⇒ String?
The authentication username used in SIP digest authentication.
-
#expiration_sec ⇒ Integer?
The registration interval, in seconds, indicating how often the system refreshes the SIP registration with the external SIP peer.
-
#from_user ⇒ String?
The user portion of the SIP From header used in outbound requests.
-
#outbound_proxy ⇒ String?
An optional SIP proxy used to route outbound requests before reaching the external SIP peer.
-
#password ⇒ String?
The SIP password used for digest authentication with the external SIP peer.
-
#proxy ⇒ String?
The SIP proxy address of the external SIP peer used for registrations and outbound call routing.
-
#transport ⇒ Symbol, ...
The transport protocol used for SIP signaling when communicating with the external SIP peer.
-
#username ⇒ String?
The SIP username used to authenticate with the external SIP peer for registrations and outbound calls.
Instance Method Summary collapse
-
#initialize(auth_username: nil, expiration_sec: nil, from_user: nil, outbound_proxy: nil, password: nil, proxy: nil, transport: nil, username: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalUacSettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(auth_username: nil, expiration_sec: nil, from_user: nil, outbound_proxy: nil, password: nil, proxy: nil, transport: nil, username: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::UacConnectionCreateParams::ExternalUacSettings for more details.
External SIP peer settings used by Telnyx when registering to your PBX and routing outbound calls.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 263 class ExternalUacSettings < Telnyx::Internal::Type::BaseModel # @!attribute auth_username # The authentication username used in SIP digest authentication. If not set, the # Username value will be used. # # @return [String, nil] optional :auth_username, String, nil?: true # @!attribute expiration_sec # The registration interval, in seconds, indicating how often the system refreshes # the SIP registration with the external SIP peer. # # @return [Integer, nil] optional :expiration_sec, Integer, nil?: true # @!attribute from_user # The user portion of the SIP From header used in outbound requests. This controls # the caller identity presented to the external SIP peer. # # @return [String, nil] optional :from_user, String, nil?: true # @!attribute outbound_proxy # An optional SIP proxy used to route outbound requests before reaching the # external SIP peer. # # @return [String, nil] optional :outbound_proxy, String, nil?: true # @!attribute password # The SIP password used for digest authentication with the external SIP peer. # # @return [String, nil] optional :password, String # @!attribute proxy # The SIP proxy address of the external SIP peer used for registrations and # outbound call routing. # # @return [String, nil] optional :proxy, String # @!attribute transport # The transport protocol used for SIP signaling when communicating with the # external SIP peer. One of UDP, TLS, or TCP. # # @return [Symbol, Telnyx::Models::UacConnectionCreateParams::ExternalUacSettings::Transport, nil] optional :transport, enum: -> { Telnyx::UacConnectionCreateParams::ExternalUacSettings::Transport }, nil?: true # @!attribute username # The SIP username used to authenticate with the external SIP peer for # registrations and outbound calls. Must start with a letter or number and contain # only letters, numbers, hyphens, and underscores. # # @return [String, nil] optional :username, String # @!method initialize(auth_username: nil, expiration_sec: nil, from_user: nil, outbound_proxy: nil, password: nil, proxy: nil, transport: nil, username: nil) # Some parameter documentations has been truncated, see # {Telnyx::Models::UacConnectionCreateParams::ExternalUacSettings} for more # details. # # External SIP peer settings used by Telnyx when registering to your PBX and # routing outbound calls. # # @param auth_username [String, nil] The authentication username used in SIP digest authentication. If not set, the U # # @param expiration_sec [Integer, nil] The registration interval, in seconds, indicating how often the system refreshes # # @param from_user [String, nil] The user portion of the SIP From header used in outbound requests. This controls # # @param outbound_proxy [String, nil] An optional SIP proxy used to route outbound requests before reaching the extern # # @param password [String] The SIP password used for digest authentication with the external SIP peer. # # @param proxy [String] The SIP proxy address of the external SIP peer used for registrations and outbou # # @param transport [Symbol, Telnyx::Models::UacConnectionCreateParams::ExternalUacSettings::Transport, nil] The transport protocol used for SIP signaling when communicating with the extern # # @param username [String] The SIP username used to authenticate with the external SIP peer for registratio # The transport protocol used for SIP signaling when communicating with the # external SIP peer. One of UDP, TLS, or TCP. # # @see Telnyx::Models::UacConnectionCreateParams::ExternalUacSettings#transport module Transport extend Telnyx::Internal::Type::Enum UDP = :UDP TLS = :TLS TCP = :TCP # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#auth_username ⇒ String?
The authentication username used in SIP digest authentication. If not set, the Username value will be used.
269 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 269 optional :auth_username, String, nil?: true |
#expiration_sec ⇒ Integer?
The registration interval, in seconds, indicating how often the system refreshes the SIP registration with the external SIP peer.
276 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 276 optional :expiration_sec, Integer, nil?: true |
#from_user ⇒ String?
The user portion of the SIP From header used in outbound requests. This controls the caller identity presented to the external SIP peer.
283 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 283 optional :from_user, String, nil?: true |
#outbound_proxy ⇒ String?
An optional SIP proxy used to route outbound requests before reaching the external SIP peer.
290 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 290 optional :outbound_proxy, String, nil?: true |
#password ⇒ String?
The SIP password used for digest authentication with the external SIP peer.
296 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 296 optional :password, String |
#proxy ⇒ String?
The SIP proxy address of the external SIP peer used for registrations and outbound call routing.
303 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 303 optional :proxy, String |
#transport ⇒ Symbol, ...
The transport protocol used for SIP signaling when communicating with the external SIP peer. One of UDP, TLS, or TCP.
310 311 312 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 310 optional :transport, enum: -> { Telnyx::UacConnectionCreateParams::ExternalUacSettings::Transport }, nil?: true |
#username ⇒ String?
The SIP username used to authenticate with the external SIP peer for registrations and outbound calls. Must start with a letter or number and contain only letters, numbers, hyphens, and underscores.
320 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 320 optional :username, String |