Class: Telnyx::Models::UacConnectionCreateParams::Inbound
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::UacConnectionCreateParams::Inbound
- Defined in:
- lib/telnyx/models/uac_connection_create_params.rb
Defined Under Namespace
Modules: AniNumberFormat, DefaultRoutingMethod, DnisNumberFormat, SimultaneousRinging
Instance Attribute Summary collapse
-
#ani_number_format ⇒ Symbol, ...
This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.
-
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
-
#codecs ⇒ Array<String>?
Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order.
-
#default_routing_method ⇒ Symbol, ...
Default routing method to be used when a number is associated with the connection.
- #dnis_number_format ⇒ Symbol, ...
-
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
-
#isup_headers_enabled ⇒ Boolean?
When set, inbound phone calls will receive ISUP parameters via SIP headers.
-
#prack_enabled ⇒ Boolean?
Enable PRACK messages as defined in RFC3262.
-
#shaken_stir_enabled ⇒ Boolean?
When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.
-
#simultaneous_ringing ⇒ Symbol, ...
When enabled, allows multiple devices to ring simultaneously on incoming calls.
-
#sip_compact_headers_enabled ⇒ Boolean?
Defaults to true.
-
#timeout_1xx_secs ⇒ Integer?
Time(sec) before aborting if connection is not made.
-
#timeout_2xx_secs ⇒ Integer?
Time(sec) before aborting if call is unanswered (min: 1, max: 600).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, simultaneous_ringing: nil, sip_compact_headers_enabled: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Inbound for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ani_number_format: nil, channel_limit: nil, codecs: nil, default_routing_method: nil, dnis_number_format: nil, generate_ringback_tone: nil, isup_headers_enabled: nil, prack_enabled: nil, shaken_stir_enabled: nil, simultaneous_ringing: nil, sip_compact_headers_enabled: nil, timeout_1xx_secs: nil, timeout_2xx_secs: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::UacConnectionCreateParams::Inbound for more details.
Inbound settings that can be supplied when creating or updating a UAC connection. The SIP subdomain fields returned in UAC connection responses are generated by Telnyx and are not accepted as request parameters.
|
|
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 452
|
Instance Attribute Details
#ani_number_format ⇒ Symbol, ...
This setting allows you to set the format with which the caller’s number (ANI) is sent for inbound phone calls.
368 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 368 optional :ani_number_format, enum: -> { Telnyx::UacConnectionCreateParams::Inbound::AniNumberFormat } |
#channel_limit ⇒ Integer?
When set, this will limit the total number of inbound calls to phone numbers associated with this connection.
375 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 375 optional :channel_limit, Integer |
#codecs ⇒ Array<String>?
Defines the list of codecs that Telnyx will send for inbound calls to a specific number on your portal account, in priority order. This only works when the Connection the number is assigned to uses Media Handling mode: default. OPUS and H.264 codecs are available only when using TCP or TLS transport for SIP.
384 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 384 optional :codecs, Telnyx::Internal::Type::ArrayOf[String] |
#default_routing_method ⇒ Symbol, ...
Default routing method to be used when a number is associated with the connection. Must be one of the routing method types or left blank, other values are not allowed.
392 393 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 392 optional :default_routing_method, enum: -> { Telnyx::UacConnectionCreateParams::Inbound::DefaultRoutingMethod } |
#dnis_number_format ⇒ Symbol, ...
398 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 398 optional :dnis_number_format, enum: -> { Telnyx::UacConnectionCreateParams::Inbound::DnisNumberFormat } |
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
404 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 404 optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean |
#isup_headers_enabled ⇒ Boolean?
When set, inbound phone calls will receive ISUP parameters via SIP headers. (Only when available and only when using TCP or TLS transport.)
411 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 411 optional :isup_headers_enabled, Telnyx::Internal::Type::Boolean |
#prack_enabled ⇒ Boolean?
Enable PRACK messages as defined in RFC3262.
417 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 417 optional :prack_enabled, Telnyx::Internal::Type::Boolean |
#shaken_stir_enabled ⇒ Boolean?
When enabled the SIP Connection will receive the Identity header with Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP transport.
425 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 425 optional :shaken_stir_enabled, Telnyx::Internal::Type::Boolean |
#simultaneous_ringing ⇒ Symbol, ...
When enabled, allows multiple devices to ring simultaneously on incoming calls.
431 432 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 431 optional :simultaneous_ringing, enum: -> { Telnyx::UacConnectionCreateParams::Inbound::SimultaneousRinging } |
#sip_compact_headers_enabled ⇒ Boolean?
Defaults to true.
438 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 438 optional :sip_compact_headers_enabled, Telnyx::Internal::Type::Boolean |
#timeout_1xx_secs ⇒ Integer?
Time(sec) before aborting if connection is not made.
444 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 444 optional :timeout_1xx_secs, Integer |
#timeout_2xx_secs ⇒ Integer?
Time(sec) before aborting if call is unanswered (min: 1, max: 600).
450 |
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 450 optional :timeout_2xx_secs, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/uac_connection_create_params.rb', line 498
|