Class: Telnyx::Models::UacConnectionListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::UacConnectionListResponse
- Defined in:
- lib/telnyx/models/uac_connection_list_response.rb
Overview
Defined Under Namespace
Modules: Authentication, FqdnOutboundAuthentication, NoiseSuppression, SipUriCallingPreference, WebhookAPIVersion Classes: ExternalUacSettings, Inbound, InternalUacSettings, Outbound
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Defaults to true.
-
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection.
-
#android_push_credential_id ⇒ String?
The uuid of the push credential for Android.
-
#authentication ⇒ Symbol, ...
The authentication strategy used by this connection.
-
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this connection.
- #connection_name ⇒ String?
-
#created_at ⇒ String?
ISO-8601 formatted date indicating when the resource was created.
-
#default_on_hold_comfort_noise_enabled ⇒ Boolean?
When enabled, Telnyx will generate comfort noise when you place the call on hold.
-
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection.
-
#encode_contact_header_enabled ⇒ Boolean?
Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.
-
#encrypted_media ⇒ Symbol, ...
Enable use of SRTP for encryption.
-
#external_uac_settings ⇒ Telnyx::Models::UacConnectionListResponse::ExternalUacSettings?
External SIP peer settings used by Telnyx when registering to your PBX and routing outbound calls.
-
#fqdn ⇒ String?
The Telnyx-managed FQDN generated for the UAC connection.
-
#fqdn_outbound_authentication ⇒ Symbol, ...
The fixed outbound authentication mode used by UAC FQDN records.
-
#fqdns ⇒ Array<Telnyx::Models::Fqdn>?
FQDN records managed automatically by the UAC connection lifecycle.
-
#id ⇒ String?
Identifies the type of resource.
- #inbound ⇒ Telnyx::Models::UacConnectionListResponse::Inbound?
-
#internal_uac_settings ⇒ Telnyx::Models::UacConnectionListResponse::InternalUacSettings?
Internal Telnyx-side settings for a UAC connection.
-
#ios_push_credential_id ⇒ String?
The uuid of the push credential for Ios.
-
#jitter_buffer ⇒ Telnyx::Models::ConnectionJitterBuffer?
Configuration options for Jitter Buffer.
-
#noise_suppression ⇒ Symbol, ...
Controls when noise suppression is applied to calls.
-
#noise_suppression_details ⇒ Telnyx::Models::ConnectionNoiseSuppressionDetails?
Configuration options for noise suppression.
-
#onnet_t38_passthrough_enabled ⇒ Boolean?
Enable on-net T38 if you prefer the sender and receiver negotiating T38 directly if both are on the Telnyx network.
- #outbound ⇒ Telnyx::Models::UacConnectionListResponse::Outbound?
-
#password ⇒ String?
The password to be used as part of the credentials.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#registration_status ⇒ String?
The most recently known SIP registration status for this UAC connection.
-
#registration_status_updated_at ⇒ String?
ISO 8601 formatted date indicating when the registration status was last updated.
- #rtcp_settings ⇒ Telnyx::Models::ConnectionRtcpSettings?
-
#sip_uri_calling_preference ⇒ Symbol, ...
This feature enables inbound SIP URI calls to your Credential Auth Connection.
-
#tags ⇒ Array<String>?
Tags associated with the connection.
-
#updated_at ⇒ String?
ISO-8601 formatted date indicating when the resource was updated.
-
#user_name ⇒ String?
The user name to be used as part of the credentials.
-
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
-
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails.
-
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent.
-
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(destination_uri: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see InternalUacSettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(destination_uri: nil) ⇒ Object
Some parameter documentations has been truncated, see InternalUacSettings for more details.
Internal Telnyx-side settings for a UAC connection.
|
|
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 257
|
Instance Attribute Details
#active ⇒ Boolean?
Defaults to true
17 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 17 optional :active, Telnyx::Internal::Type::Boolean |
#anchorsite_override ⇒ Symbol, ...
‘Latency` directs Telnyx to route media through the site with the lowest round-trip time to the user’s connection. Telnyx calculates this time using ICMP ping messages. This can be disabled by specifying a site to handle all media.
25 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 25 optional :anchorsite_override, enum: -> { Telnyx::AnchorsiteOverride } |
#android_push_credential_id ⇒ String?
The uuid of the push credential for Android
31 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 31 optional :android_push_credential_id, String, nil?: true |
#authentication ⇒ Symbol, ...
The authentication strategy used by this connection.
37 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 37 optional :authentication, enum: -> { Telnyx::Models::UacConnectionListResponse::Authentication } |
#call_cost_in_webhooks ⇒ Boolean?
Specifies if call cost webhooks should be sent for this connection.
43 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 43 optional :call_cost_in_webhooks, Telnyx::Internal::Type::Boolean |
#connection_name ⇒ String?
48 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 48 optional :connection_name, String |
#created_at ⇒ String?
ISO-8601 formatted date indicating when the resource was created.
54 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 54 optional :created_at, String |
#default_on_hold_comfort_noise_enabled ⇒ Boolean?
When enabled, Telnyx will generate comfort noise when you place the call on hold. If disabled, you will need to generate comfort noise or on hold music to avoid RTP timeout.
62 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 62 optional :default_on_hold_comfort_noise_enabled, Telnyx::Internal::Type::Boolean |
#dtmf_type ⇒ Symbol, ...
Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF digits sent to Telnyx will be accepted in all formats.
69 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 69 optional :dtmf_type, enum: -> { Telnyx::DtmfType } |
#encode_contact_header_enabled ⇒ Boolean?
Encode the SIP contact header sent by Telnyx to avoid issues for NAT or ALG scenarios.
76 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 76 optional :encode_contact_header_enabled, Telnyx::Internal::Type::Boolean |
#encrypted_media ⇒ Symbol, ...
Enable use of SRTP for encryption. Cannot be set if the transport_portocol is TLS.
83 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 83 optional :encrypted_media, enum: -> { Telnyx::EncryptedMedia }, nil?: true |
#external_uac_settings ⇒ Telnyx::Models::UacConnectionListResponse::ExternalUacSettings?
External SIP peer settings used by Telnyx when registering to your PBX and routing outbound calls.
90 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 90 optional :external_uac_settings, -> { Telnyx::Models::UacConnectionListResponse::ExternalUacSettings } |
#fqdn ⇒ String?
The Telnyx-managed FQDN generated for the UAC connection.
96 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 96 optional :fqdn, String |
#fqdn_outbound_authentication ⇒ Symbol, ...
The fixed outbound authentication mode used by UAC FQDN records.
102 103 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 102 optional :fqdn_outbound_authentication, enum: -> { Telnyx::Models::UacConnectionListResponse::FqdnOutboundAuthentication } |
#fqdns ⇒ Array<Telnyx::Models::Fqdn>?
FQDN records managed automatically by the UAC connection lifecycle.
109 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 109 optional :fqdns, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Fqdn] } |
#id ⇒ String?
Identifies the type of resource.
11 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 11 optional :id, String |
#inbound ⇒ Telnyx::Models::UacConnectionListResponse::Inbound?
114 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 114 optional :inbound, -> { Telnyx::Models::UacConnectionListResponse::Inbound } |
#internal_uac_settings ⇒ Telnyx::Models::UacConnectionListResponse::InternalUacSettings?
Internal Telnyx-side settings for a UAC connection.
120 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 120 optional :internal_uac_settings, -> { Telnyx::Models::UacConnectionListResponse::InternalUacSettings } |
#ios_push_credential_id ⇒ String?
The uuid of the push credential for Ios
126 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 126 optional :ios_push_credential_id, String, nil?: true |
#jitter_buffer ⇒ Telnyx::Models::ConnectionJitterBuffer?
Configuration options for Jitter Buffer. Enables Jitter Buffer for RTP streams of SIP Trunking calls. The feature is off unless enabled. You may define min and max values in msec for customized buffering behaviors. Larger values add latency but tolerate more jitter, while smaller values reduce latency but are more sensitive to jitter and reordering.
136 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 136 optional :jitter_buffer, -> { Telnyx::ConnectionJitterBuffer } |
#noise_suppression ⇒ Symbol, ...
Controls when noise suppression is applied to calls. When set to ‘inbound’, noise suppression is applied to incoming audio. When set to ‘outbound’, it’s applied to outgoing audio. When set to ‘both’, it’s applied in both directions. When set to ‘disabled’, noise suppression is turned off.
145 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 145 optional :noise_suppression, enum: -> { Telnyx::Models::UacConnectionListResponse::NoiseSuppression } |
#noise_suppression_details ⇒ Telnyx::Models::ConnectionNoiseSuppressionDetails?
Configuration options for noise suppression. These settings are stored regardless of the noise_suppression value, but only take effect when noise_suppression is not ‘disabled’. If you disable noise suppression and later re-enable it, the previously configured settings will be used.
154 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 154 optional :noise_suppression_details, -> { Telnyx::ConnectionNoiseSuppressionDetails } |
#onnet_t38_passthrough_enabled ⇒ Boolean?
Enable on-net T38 if you prefer the sender and receiver negotiating T38 directly if both are on the Telnyx network. If this is disabled, Telnyx will be able to use T38 on just one leg of the call depending on each leg’s settings.
162 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 162 optional :onnet_t38_passthrough_enabled, Telnyx::Internal::Type::Boolean |
#outbound ⇒ Telnyx::Models::UacConnectionListResponse::Outbound?
167 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 167 optional :outbound, -> { Telnyx::Models::UacConnectionListResponse::Outbound } |
#password ⇒ String?
The password to be used as part of the credentials. Must be 8 to 128 characters long.
174 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 174 optional :password, String |
#record_type ⇒ String?
Identifies the type of the resource.
180 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 180 optional :record_type, String |
#registration_status ⇒ String?
The most recently known SIP registration status for this UAC connection.
186 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 186 optional :registration_status, String, nil?: true |
#registration_status_updated_at ⇒ String?
ISO 8601 formatted date indicating when the registration status was last updated.
193 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 193 optional :registration_status_updated_at, String, nil?: true |
#rtcp_settings ⇒ Telnyx::Models::ConnectionRtcpSettings?
198 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 198 optional :rtcp_settings, -> { Telnyx::ConnectionRtcpSettings } |
#sip_uri_calling_preference ⇒ Symbol, ...
This feature enables inbound SIP URI calls to your Credential Auth Connection. If enabled for all (unrestricted) then anyone who calls the SIP URI <your-username>@telnyx.com will be connected to your Connection. You can also choose to allow only calls that are originated on any Connections under your account (internal).
208 209 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 208 optional :sip_uri_calling_preference, enum: -> { Telnyx::Models::UacConnectionListResponse::SipUriCallingPreference } |
#tags ⇒ Array<String>?
Tags associated with the connection.
215 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 215 optional :tags, Telnyx::Internal::Type::ArrayOf[String] |
#updated_at ⇒ String?
ISO-8601 formatted date indicating when the resource was updated.
221 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 221 optional :updated_at, String |
#user_name ⇒ String?
The user name to be used as part of the credentials. Must be 4-32 characters long and alphanumeric values only (no spaces or special characters). At least one of the first 5 characters must be a letter.
229 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 229 optional :user_name, String |
#webhook_api_version ⇒ Symbol, ...
Determines which webhook format will be used, Telnyx API v1 or v2.
235 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 235 optional :webhook_api_version, enum: -> { Telnyx::Models::UacConnectionListResponse::WebhookAPIVersion } |
#webhook_event_failover_url ⇒ String?
The failover URL where webhooks related to this connection will be sent if sending to the primary URL fails. Must include a scheme, such as ‘https’.
242 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 242 optional :webhook_event_failover_url, String, nil?: true |
#webhook_event_url ⇒ String?
The URL where webhooks related to this connection will be sent. Must include a scheme, such as ‘https’.
249 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 249 optional :webhook_event_url, String |
#webhook_timeout_secs ⇒ Integer?
Specifies how many seconds to wait before timing out a webhook.
255 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 255 optional :webhook_timeout_secs, Integer, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 348
|