Class: Telnyx::Models::UacConnectionListResponse::Outbound
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::UacConnectionListResponse::Outbound
- Defined in:
- lib/telnyx/models/uac_connection_list_response.rb
Overview
Defined Under Namespace
Modules: AniOverrideType, T38ReinviteSource
Instance Attribute Summary collapse
-
#ani_override ⇒ String?
Set a phone number as the ani_override value to override caller id number on outbound calls.
-
#ani_override_type ⇒ Symbol, ...
Specifies when we apply your ani_override setting.
-
#call_parking_enabled ⇒ Boolean?
Forces all SIP calls originated on this connection to be “parked” instead of “bridged” to the destination specified on the URI.
-
#channel_limit ⇒ Integer?
When set, this will limit the total number of outbound calls to phone numbers associated with this connection.
-
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
-
#instant_ringback_enabled ⇒ Boolean?
When set, ringback will not wait for indication before sending ringback tone to calling party.
-
#localization ⇒ String?
A 2-character country code specifying the country whose national dialing rules should be used.
-
#outbound_voice_profile_id ⇒ String?
Identifies the associated outbound voice profile.
-
#t38_reinvite_source ⇒ Symbol, ...
This setting only affects connections with Fax-type Outbound Voice Profiles.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ani_override: nil, ani_override_type: nil, call_parking_enabled: nil, channel_limit: nil, generate_ringback_tone: nil, instant_ringback_enabled: nil, localization: nil, outbound_voice_profile_id: nil, t38_reinvite_source: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Outbound for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ani_override: nil, ani_override_type: nil, call_parking_enabled: nil, channel_limit: nil, generate_ringback_tone: nil, instant_ringback_enabled: nil, localization: nil, outbound_voice_profile_id: nil, t38_reinvite_source: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::UacConnectionListResponse::Outbound for more details.
|
|
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 786
|
Instance Attribute Details
#ani_override ⇒ String?
Set a phone number as the ani_override value to override caller id number on outbound calls.
722 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 722 optional :ani_override, String |
#ani_override_type ⇒ Symbol, ...
Specifies when we apply your ani_override setting. Only applies when ani_override is not blank.
729 730 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 729 optional :ani_override_type, enum: -> { Telnyx::Models::UacConnectionListResponse::Outbound::AniOverrideType } |
#call_parking_enabled ⇒ Boolean?
Forces all SIP calls originated on this connection to be “parked” instead of “bridged” to the destination specified on the URI. Parked calls will return ringback to the caller and will await for a Call Control command to define which action will be taken next.
739 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 739 optional :call_parking_enabled, Telnyx::Internal::Type::Boolean, nil?: true |
#channel_limit ⇒ Integer?
When set, this will limit the total number of outbound calls to phone numbers associated with this connection.
746 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 746 optional :channel_limit, Integer |
#generate_ringback_tone ⇒ Boolean?
Generate ringback tone through 183 session progress message with early media.
752 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 752 optional :generate_ringback_tone, Telnyx::Internal::Type::Boolean |
#instant_ringback_enabled ⇒ Boolean?
When set, ringback will not wait for indication before sending ringback tone to calling party.
759 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 759 optional :instant_ringback_enabled, Telnyx::Internal::Type::Boolean |
#localization ⇒ String?
A 2-character country code specifying the country whose national dialing rules should be used. For example, if set to ‘US` then any US number can be dialed without preprending +1 to the number. When left blank, Telnyx will try US and GB dialing rules, in that order, by default.
768 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 768 optional :localization, String |
#outbound_voice_profile_id ⇒ String?
Identifies the associated outbound voice profile.
774 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 774 optional :outbound_voice_profile_id, String |
#t38_reinvite_source ⇒ Symbol, ...
This setting only affects connections with Fax-type Outbound Voice Profiles. The setting dictates whether or not Telnyx sends a t.38 reinvite.<br/><br/> By default, Telnyx will send the re-invite. If set to ‘customer`, the caller is expected to send the t.38 reinvite.
783 784 |
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 783 optional :t38_reinvite_source, enum: -> { Telnyx::Models::UacConnectionListResponse::Outbound::T38ReinviteSource } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/uac_connection_list_response.rb', line 819
|