Class: Telnyx::Models::UpdateRegulatoryRequirement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::UpdateRegulatoryRequirement
- Defined in:
- lib/telnyx/models/update_regulatory_requirement.rb
Instance Attribute Summary collapse
-
#field_value ⇒ String?
The value of the requirement.
-
#requirement_id ⇒ String?
Unique id for a requirement.
Instance Method Summary collapse
-
#initialize(field_value: nil, requirement_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UpdateRegulatoryRequirement for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field_value: nil, requirement_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::UpdateRegulatoryRequirement for more details.
|
|
# File 'lib/telnyx/models/update_regulatory_requirement.rb', line 20
|
Instance Attribute Details
#field_value ⇒ String?
The value of the requirement. For address and document requirements, this should be the ID of the resource. For textual, this should be the value of the requirement.
12 |
# File 'lib/telnyx/models/update_regulatory_requirement.rb', line 12 optional :field_value, String |
#requirement_id ⇒ String?
Unique id for a requirement.
18 |
# File 'lib/telnyx/models/update_regulatory_requirement.rb', line 18 optional :requirement_id, String |