Class: Telnyx::Models::UsageReportGetOptionsResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/usage_report_get_options_response.rb

Defined Under Namespace

Classes: RecordType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data: nil) ⇒ Object

An object following one of the schemas published in developers.telnyx.com/docs/api/v2/detail-records

Parameters:



20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/telnyx/models/usage_report_get_options_response.rb', line 20

class Data < Telnyx::Internal::Type::BaseModel
  # @!attribute product
  #   Telnyx Product
  #
  #   @return [String, nil]
  optional :product, String

  # @!attribute product_dimensions
  #   Telnyx Product Dimensions
  #
  #   @return [Array<String>, nil]
  optional :product_dimensions, Telnyx::Internal::Type::ArrayOf[String]

  # @!attribute product_metrics
  #   Telnyx Product Metrics
  #
  #   @return [Array<String>, nil]
  optional :product_metrics, Telnyx::Internal::Type::ArrayOf[String]

  # @!attribute record_types
  #   Subproducts if applicable
  #
  #   @return [Array<Telnyx::Models::UsageReportGetOptionsResponse::Data::RecordType>, nil]
  optional :record_types,
           -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::UsageReportGetOptionsResponse::Data::RecordType] }

  # @!method initialize(product: nil, product_dimensions: nil, product_metrics: nil, record_types: nil)
  #   An object following one of the schemas published in
  #   https://developers.telnyx.com/docs/api/v2/detail-records
  #
  #   @param product [String] Telnyx Product
  #
  #   @param product_dimensions [Array<String>] Telnyx Product Dimensions
  #
  #   @param product_metrics [Array<String>] Telnyx Product Metrics
  #
  #   @param record_types [Array<Telnyx::Models::UsageReportGetOptionsResponse::Data::RecordType>] Subproducts if applicable

  class RecordType < Telnyx::Internal::Type::BaseModel
    # @!attribute product_dimensions
    #   Telnyx Product Dimensions
    #
    #   @return [Array<String>, nil]
    optional :product_dimensions, Telnyx::Internal::Type::ArrayOf[String]

    # @!attribute product_metrics
    #   Telnyx Product Metrics
    #
    #   @return [Array<String>, nil]
    optional :product_metrics, Telnyx::Internal::Type::ArrayOf[String]

    # @!attribute record_type
    #   Telnyx Product type
    #
    #   @return [String, nil]
    optional :record_type, String

    # @!method initialize(product_dimensions: nil, product_metrics: nil, record_type: nil)
    #   An object following one of the schemas published in
    #   https://developers.telnyx.com/docs/api/v2/detail-records
    #
    #   @param product_dimensions [Array<String>] Telnyx Product Dimensions
    #
    #   @param product_metrics [Array<String>] Telnyx Product Metrics
    #
    #   @param record_type [String] Telnyx Product type
  end
end

Instance Attribute Details

#productString?

Telnyx Product

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/usage_report_get_options_response.rb', line 25

optional :product, String

#product_dimensionsArray<String>?

Telnyx Product Dimensions

Returns:

  • (Array<String>, nil)


31
# File 'lib/telnyx/models/usage_report_get_options_response.rb', line 31

optional :product_dimensions, Telnyx::Internal::Type::ArrayOf[String]

#product_metricsArray<String>?

Telnyx Product Metrics

Returns:

  • (Array<String>, nil)


37
# File 'lib/telnyx/models/usage_report_get_options_response.rb', line 37

optional :product_metrics, Telnyx::Internal::Type::ArrayOf[String]

#record_typesArray<Telnyx::Models::UsageReportGetOptionsResponse::Data::RecordType>?

Subproducts if applicable



43
44
# File 'lib/telnyx/models/usage_report_get_options_response.rb', line 43

optional :record_types,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::UsageReportGetOptionsResponse::Data::RecordType] }