Class: Telnyx::Models::UsageReportListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::UsageReportListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/usage_report_list_params.rb
Overview
Defined Under Namespace
Modules: Format
Instance Attribute Summary collapse
-
#authorization_bearer ⇒ String?
Authenticates the request with your Telnyx API V2 KEY.
-
#date_range ⇒ String?
A more user-friendly way to specify the timespan you want to filter by.
-
#dimensions ⇒ Array<String>
Breakout by specified product dimensions.
-
#end_date ⇒ String?
The end date for the time range you are interested in.
-
#filter ⇒ String?
Filter records on dimensions.
-
#format_ ⇒ Symbol, ...
Specify the response format (csv or json).
-
#managed_accounts ⇒ Boolean?
Return the aggregations for all Managed Accounts under the user making the request.
-
#metrics ⇒ Array<String>
Specified product usage values.
- #page_number ⇒ Integer?
- #page_size ⇒ Integer?
-
#product ⇒ String
Telnyx product.
-
#sort ⇒ Array<String>?
Specifies the sort order for results.
-
#start_date ⇒ String?
The start date for the time range you are interested in.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(dimensions:, metrics:, product:, date_range: nil, end_date: nil, filter: nil, format_: nil, managed_accounts: nil, page_number: nil, page_size: nil, sort: nil, start_date: nil, authorization_bearer: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see UsageReportListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(dimensions:, metrics:, product:, date_range: nil, end_date: nil, filter: nil, format_: nil, managed_accounts: nil, page_number: nil, page_size: nil, sort: nil, start_date: nil, authorization_bearer: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::UsageReportListParams for more details.
|
|
# File 'lib/telnyx/models/usage_report_list_params.rb', line 91
|
Instance Attribute Details
#authorization_bearer ⇒ String?
Authenticates the request with your Telnyx API V2 KEY
89 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 89 optional :authorization_bearer, String |
#date_range ⇒ String?
A more user-friendly way to specify the timespan you want to filter by. More options can be found in the Telnyx API Reference docs.
33 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 33 optional :date_range, String |
#dimensions ⇒ Array<String>
Breakout by specified product dimensions
14 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 14 required :dimensions, Telnyx::Internal::Type::ArrayOf[String] |
#end_date ⇒ String?
The end date for the time range you are interested in. The maximum time range is 31 days. Format: YYYY-MM-DDTHH:mm:ssZ
40 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 40 optional :end_date, String |
#filter ⇒ String?
Filter records on dimensions
46 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 46 optional :filter, String |
#format_ ⇒ Symbol, ...
Specify the response format (csv or json). JSON is returned by default, even if not specified.
53 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 53 optional :format_, enum: -> { Telnyx::UsageReportListParams::Format } |
#managed_accounts ⇒ Boolean?
Return the aggregations for all Managed Accounts under the user making the request.
60 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 60 optional :managed_accounts, Telnyx::Internal::Type::Boolean |
#metrics ⇒ Array<String>
Specified product usage values
20 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 20 required :metrics, Telnyx::Internal::Type::ArrayOf[String] |
#page_number ⇒ Integer?
65 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 65 optional :page_number, Integer |
#page_size ⇒ Integer?
70 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 70 optional :page_size, Integer |
#product ⇒ String
Telnyx product
26 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 26 required :product, String |
#sort ⇒ Array<String>?
Specifies the sort order for results
76 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 76 optional :sort, Telnyx::Internal::Type::ArrayOf[String] |
#start_date ⇒ String?
The start date for the time range you are interested in. The maximum time range is 31 days. Format: YYYY-MM-DDTHH:mm:ssZ
83 |
# File 'lib/telnyx/models/usage_report_list_params.rb', line 83 optional :start_date, String |