Class: Telnyx::Models::UserAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/user_address.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, administrative_area: nil, borough: nil, business_name: nil, country_code: nil, created_at: nil, customer_reference: nil, extended_address: nil, first_name: nil, last_name: nil, locality: nil, neighborhood: nil, phone_number: nil, postal_code: nil, record_type: nil, street_address: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Telnyx::Models::UserAddress for more details.

Parameters:

  • id (String) (defaults to: nil)

    Uniquely identifies the user address.

  • administrative_area (String) (defaults to: nil)

    The locality of the user address. For US addresses, this corresponds to the stat

  • borough (String) (defaults to: nil)

    The borough of the user address. This field is not used for addresses in the US

  • business_name (String) (defaults to: nil)

    The business name associated with the user address.

  • country_code (String) (defaults to: nil)

    The two-character (ISO 3166-1 alpha-2) country code of the user address.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was created.

  • customer_reference (String) (defaults to: nil)

    A customer reference string for customer look ups.

  • extended_address (String) (defaults to: nil)

    Additional street address information about the user address such as, but not li

  • first_name (String) (defaults to: nil)

    The first name associated with the user address.

  • last_name (String) (defaults to: nil)

    The last name associated with the user address.

  • locality (String) (defaults to: nil)

    The locality of the user address. For US addresses, this corresponds to the city

  • neighborhood (String) (defaults to: nil)

    The neighborhood of the user address. This field is not used for addresses in th

  • phone_number (String) (defaults to: nil)

    The phone number associated with the user address.

  • postal_code (String) (defaults to: nil)

    The postal code of the user address.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • street_address (String) (defaults to: nil)

    The primary street address information about the user address.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date indicating when the resource was updated.



# File 'lib/telnyx/models/user_address.rb', line 114

Instance Attribute Details

#administrative_areaString?

The locality of the user address. For US addresses, this corresponds to the state of the address.

Returns:

  • (String, nil)


18
# File 'lib/telnyx/models/user_address.rb', line 18

optional :administrative_area, String

#boroughString?

The borough of the user address. This field is not used for addresses in the US but is used for some international addresses.

Returns:

  • (String, nil)


25
# File 'lib/telnyx/models/user_address.rb', line 25

optional :borough, String

#business_nameString?

The business name associated with the user address.

Returns:

  • (String, nil)


31
# File 'lib/telnyx/models/user_address.rb', line 31

optional :business_name, String

#country_codeString?

The two-character (ISO 3166-1 alpha-2) country code of the user address.

Returns:

  • (String, nil)


37
# File 'lib/telnyx/models/user_address.rb', line 37

optional :country_code, String

#created_atString?

ISO 8601 formatted date indicating when the resource was created.

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/user_address.rb', line 43

optional :created_at, String

#customer_referenceString?

A customer reference string for customer look ups.

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/user_address.rb', line 49

optional :customer_reference, String

#extended_addressString?

Additional street address information about the user address such as, but not limited to, unit number or apartment number.

Returns:

  • (String, nil)


56
# File 'lib/telnyx/models/user_address.rb', line 56

optional :extended_address, String

#first_nameString?

The first name associated with the user address.

Returns:

  • (String, nil)


62
# File 'lib/telnyx/models/user_address.rb', line 62

optional :first_name, String

#idString?

Uniquely identifies the user address.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/user_address.rb', line 11

optional :id, String

#last_nameString?

The last name associated with the user address.

Returns:

  • (String, nil)


68
# File 'lib/telnyx/models/user_address.rb', line 68

optional :last_name, String

#localityString?

The locality of the user address. For US addresses, this corresponds to the city of the address.

Returns:

  • (String, nil)


75
# File 'lib/telnyx/models/user_address.rb', line 75

optional :locality, String

#neighborhoodString?

The neighborhood of the user address. This field is not used for addresses in the US but is used for some international addresses.

Returns:

  • (String, nil)


82
# File 'lib/telnyx/models/user_address.rb', line 82

optional :neighborhood, String

#phone_numberString?

The phone number associated with the user address.

Returns:

  • (String, nil)


88
# File 'lib/telnyx/models/user_address.rb', line 88

optional :phone_number, String

#postal_codeString?

The postal code of the user address.

Returns:

  • (String, nil)


94
# File 'lib/telnyx/models/user_address.rb', line 94

optional :postal_code, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


100
# File 'lib/telnyx/models/user_address.rb', line 100

optional :record_type, String

#street_addressString?

The primary street address information about the user address.

Returns:

  • (String, nil)


106
# File 'lib/telnyx/models/user_address.rb', line 106

optional :street_address, String

#updated_atString?

ISO 8601 formatted date indicating when the resource was updated.

Returns:

  • (String, nil)


112
# File 'lib/telnyx/models/user_address.rb', line 112

optional :updated_at, String