Class: Telnyx::Models::UserAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::UserAddress
- Defined in:
- lib/telnyx/models/user_address.rb
Overview
Instance Attribute Summary collapse
-
#administrative_area ⇒ String?
The locality of the user address.
-
#borough ⇒ String?
The borough of the user address.
-
#business_name ⇒ String?
The business name associated with the user address.
-
#country_code ⇒ String?
The two-character (ISO 3166-1 alpha-2) country code of the user address.
-
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#extended_address ⇒ String?
Additional street address information about the user address such as, but not limited to, unit number or apartment number.
-
#first_name ⇒ String?
The first name associated with the user address.
-
#id ⇒ String?
Uniquely identifies the user address.
-
#last_name ⇒ String?
The last name associated with the user address.
-
#locality ⇒ String?
The locality of the user address.
-
#neighborhood ⇒ String?
The neighborhood of the user address.
-
#phone_number ⇒ String?
The phone number associated with the user address.
-
#postal_code ⇒ String?
The postal code of the user address.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#street_address ⇒ String?
The primary street address information about the user address.
-
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
Instance Method Summary collapse
-
#initialize(id: nil, administrative_area: nil, borough: nil, business_name: nil, country_code: nil, created_at: nil, customer_reference: nil, extended_address: nil, first_name: nil, last_name: nil, locality: nil, neighborhood: nil, phone_number: nil, postal_code: nil, record_type: nil, street_address: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UserAddress for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, administrative_area: nil, borough: nil, business_name: nil, country_code: nil, created_at: nil, customer_reference: nil, extended_address: nil, first_name: nil, last_name: nil, locality: nil, neighborhood: nil, phone_number: nil, postal_code: nil, record_type: nil, street_address: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::UserAddress for more details.
|
|
# File 'lib/telnyx/models/user_address.rb', line 114
|
Instance Attribute Details
#administrative_area ⇒ String?
The locality of the user address. For US addresses, this corresponds to the state of the address.
18 |
# File 'lib/telnyx/models/user_address.rb', line 18 optional :administrative_area, String |
#borough ⇒ String?
The borough of the user address. This field is not used for addresses in the US but is used for some international addresses.
25 |
# File 'lib/telnyx/models/user_address.rb', line 25 optional :borough, String |
#business_name ⇒ String?
The business name associated with the user address.
31 |
# File 'lib/telnyx/models/user_address.rb', line 31 optional :business_name, String |
#country_code ⇒ String?
The two-character (ISO 3166-1 alpha-2) country code of the user address.
37 |
# File 'lib/telnyx/models/user_address.rb', line 37 optional :country_code, String |
#created_at ⇒ String?
ISO 8601 formatted date indicating when the resource was created.
43 |
# File 'lib/telnyx/models/user_address.rb', line 43 optional :created_at, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
49 |
# File 'lib/telnyx/models/user_address.rb', line 49 optional :customer_reference, String |
#extended_address ⇒ String?
Additional street address information about the user address such as, but not limited to, unit number or apartment number.
56 |
# File 'lib/telnyx/models/user_address.rb', line 56 optional :extended_address, String |
#first_name ⇒ String?
The first name associated with the user address.
62 |
# File 'lib/telnyx/models/user_address.rb', line 62 optional :first_name, String |
#id ⇒ String?
Uniquely identifies the user address.
11 |
# File 'lib/telnyx/models/user_address.rb', line 11 optional :id, String |
#last_name ⇒ String?
The last name associated with the user address.
68 |
# File 'lib/telnyx/models/user_address.rb', line 68 optional :last_name, String |
#locality ⇒ String?
The locality of the user address. For US addresses, this corresponds to the city of the address.
75 |
# File 'lib/telnyx/models/user_address.rb', line 75 optional :locality, String |
#neighborhood ⇒ String?
The neighborhood of the user address. This field is not used for addresses in the US but is used for some international addresses.
82 |
# File 'lib/telnyx/models/user_address.rb', line 82 optional :neighborhood, String |
#phone_number ⇒ String?
The phone number associated with the user address.
88 |
# File 'lib/telnyx/models/user_address.rb', line 88 optional :phone_number, String |
#postal_code ⇒ String?
The postal code of the user address.
94 |
# File 'lib/telnyx/models/user_address.rb', line 94 optional :postal_code, String |
#record_type ⇒ String?
Identifies the type of the resource.
100 |
# File 'lib/telnyx/models/user_address.rb', line 100 optional :record_type, String |
#street_address ⇒ String?
The primary street address information about the user address.
106 |
# File 'lib/telnyx/models/user_address.rb', line 106 optional :street_address, String |
#updated_at ⇒ String?
ISO 8601 formatted date indicating when the resource was updated.
112 |
# File 'lib/telnyx/models/user_address.rb', line 112 optional :updated_at, String |