Class: Telnyx::Models::UserAddressCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::UserAddressCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/user_address_create_params.rb
Overview
Instance Attribute Summary collapse
-
#administrative_area ⇒ String?
The locality of the user address.
-
#borough ⇒ String?
The borough of the user address.
-
#business_name ⇒ String
The business name associated with the user address.
-
#country_code ⇒ String
The two-character (ISO 3166-1 alpha-2) country code of the user address.
-
#customer_reference ⇒ String?
A customer reference string for customer look ups.
-
#extended_address ⇒ String?
Additional street address information about the user address such as, but not limited to, unit number or apartment number.
-
#first_name ⇒ String
The first name associated with the user address.
-
#last_name ⇒ String
The last name associated with the user address.
-
#locality ⇒ String
The locality of the user address.
-
#neighborhood ⇒ String?
The neighborhood of the user address.
-
#phone_number ⇒ String?
The phone number associated with the user address.
-
#postal_code ⇒ String?
The postal code of the user address.
-
#skip_address_verification ⇒ Boolean?
An optional boolean value specifying if verification of the address should be skipped or not.
-
#street_address ⇒ String
The primary street address information about the user address.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(business_name:, country_code:, first_name:, last_name:, locality:, street_address:, administrative_area: nil, borough: nil, customer_reference: nil, extended_address: nil, neighborhood: nil, phone_number: nil, postal_code: nil, skip_address_verification: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see UserAddressCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(business_name:, country_code:, first_name:, last_name:, locality:, street_address:, administrative_area: nil, borough: nil, customer_reference: nil, extended_address: nil, neighborhood: nil, phone_number: nil, postal_code: nil, skip_address_verification: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::UserAddressCreateParams for more details.
|
|
# File 'lib/telnyx/models/user_address_create_params.rb', line 109
|
Instance Attribute Details
#administrative_area ⇒ String?
The locality of the user address. For US addresses, this corresponds to the state of the address.
52 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 52 optional :administrative_area, String |
#borough ⇒ String?
The borough of the user address. This field is not used for addresses in the US but is used for some international addresses.
59 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 59 optional :borough, String |
#business_name ⇒ String
The business name associated with the user address.
14 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 14 required :business_name, String |
#country_code ⇒ String
The two-character (ISO 3166-1 alpha-2) country code of the user address.
20 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 20 required :country_code, String |
#customer_reference ⇒ String?
A customer reference string for customer look ups.
65 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 65 optional :customer_reference, String |
#extended_address ⇒ String?
Additional street address information about the user address such as, but not limited to, unit number or apartment number.
72 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 72 optional :extended_address, String |
#first_name ⇒ String
The first name associated with the user address.
26 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 26 required :first_name, String |
#last_name ⇒ String
The last name associated with the user address.
32 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 32 required :last_name, String |
#locality ⇒ String
The locality of the user address. For US addresses, this corresponds to the city of the address.
39 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 39 required :locality, String |
#neighborhood ⇒ String?
The neighborhood of the user address. This field is not used for addresses in the US but is used for some international addresses.
79 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 79 optional :neighborhood, String |
#phone_number ⇒ String?
The phone number associated with the user address.
85 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 85 optional :phone_number, String |
#postal_code ⇒ String?
The postal code of the user address.
91 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 91 optional :postal_code, String |
#skip_address_verification ⇒ Boolean?
An optional boolean value specifying if verification of the address should be skipped or not. UserAddresses are generally used for shipping addresses, and failure to validate your shipping address will likely result in a failure to deliver SIM cards or other items ordered from Telnyx. Do not use this parameter unless you are sure that the address is correct even though it cannot be validated. If this is set to any value other than true, verification of the address will be attempted, and the user address will not be allowed if verification fails. If verification fails but suggested values are available that might make the address correct, they will be present in the response as well. If this value is set to true, then the verification will not be attempted. Defaults to false (verification will be performed).
107 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 107 optional :skip_address_verification, Telnyx::Internal::Type::Boolean |
#street_address ⇒ String
The primary street address information about the user address.
45 |
# File 'lib/telnyx/models/user_address_create_params.rb', line 45 required :street_address, String |