Class: Telnyx::Models::VerifyProfile::Whatsapp
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VerifyProfile::Whatsapp
- Defined in:
- lib/telnyx/models/verify_profile.rb
Overview
Instance Attribute Summary collapse
-
#app_name ⇒ String?
The name that identifies the application requesting 2fa in the verification message.
-
#code_length ⇒ Integer?
The length of the verify code to generate.
-
#default_verification_timeout_secs ⇒ Integer?
For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires.
-
#messaging_template_id ⇒ String?
The message template identifier selected from /verify_profiles/templates.
-
#sender_phone_number ⇒ String?
Phone number registered on the customer WABA to send OTPs from.
-
#template_id ⇒ String?
Customer pre-approved authentication template name registered on Meta.
-
#waba_id ⇒ String?
Customer Meta WABA ID for Bring-Your-Own-WABA sending.
-
#whitelisted_destinations ⇒ Array<String>?
Enabled country destinations to send verification codes.
Instance Method Summary collapse
-
#initialize(app_name: nil, code_length: nil, default_verification_timeout_secs: nil, messaging_template_id: nil, sender_phone_number: nil, template_id: nil, waba_id: nil, whitelisted_destinations: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Whatsapp for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app_name: nil, code_length: nil, default_verification_timeout_secs: nil, messaging_template_id: nil, sender_phone_number: nil, template_id: nil, waba_id: nil, whitelisted_destinations: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VerifyProfile::Whatsapp for more details.
|
|
# File 'lib/telnyx/models/verify_profile.rb', line 379
|
Instance Attribute Details
#app_name ⇒ String?
The name that identifies the application requesting 2fa in the verification message.
328 |
# File 'lib/telnyx/models/verify_profile.rb', line 328 optional :app_name, String |
#code_length ⇒ Integer?
The length of the verify code to generate.
334 |
# File 'lib/telnyx/models/verify_profile.rb', line 334 optional :code_length, Integer |
#default_verification_timeout_secs ⇒ Integer?
For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires. Once the verification request expires, the user cannot use the code to verify their identity.
343 |
# File 'lib/telnyx/models/verify_profile.rb', line 343 optional :default_verification_timeout_secs, Integer |
#messaging_template_id ⇒ String?
The message template identifier selected from /verify_profiles/templates
349 |
# File 'lib/telnyx/models/verify_profile.rb', line 349 optional :messaging_template_id, String |
#sender_phone_number ⇒ String?
Phone number registered on the customer WABA to send OTPs from
355 |
# File 'lib/telnyx/models/verify_profile.rb', line 355 optional :sender_phone_number, String, nil?: true |
#template_id ⇒ String?
Customer pre-approved authentication template name registered on Meta
361 |
# File 'lib/telnyx/models/verify_profile.rb', line 361 optional :template_id, String, nil?: true |
#waba_id ⇒ String?
Customer Meta WABA ID for Bring-Your-Own-WABA sending
367 |
# File 'lib/telnyx/models/verify_profile.rb', line 367 optional :waba_id, String, nil?: true |
#whitelisted_destinations ⇒ Array<String>?
Enabled country destinations to send verification codes. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ‘[“*”]`, all destinations will be allowed. **Conditionally required:** this field must be provided when your organization is configured to require explicit whitelisted destinations; otherwise it is optional.
377 |
# File 'lib/telnyx/models/verify_profile.rb', line 377 optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String] |