Class: Telnyx::Models::VerifyProfileCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/telnyx/models/verify_profile_create_params.rb

Overview

Defined Under Namespace

Classes: Call, Flashcall, Rcs, SMS, Whatsapp

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(alpha_sender: nil, app_name: nil, code_length: nil, default_verification_timeout_secs: nil, messaging_template_id: nil, whitelisted_destinations: nil) ⇒ Object

Some parameter documentations has been truncated, see SMS for more details.

Parameters:

  • alpha_sender (String, nil) (defaults to: nil)

    The alphanumeric sender ID to use when sending to destinations that require an a

  • app_name (String) (defaults to: nil)

    The name that identifies the application requesting 2fa in the verification mess

  • code_length (Integer) (defaults to: nil)

    The length of the verify code to generate.

  • default_verification_timeout_secs (Integer) (defaults to: nil)

    For every request that is initiated via this Verify profile, this sets the numbe

  • messaging_template_id (String) (defaults to: nil)

    The message template identifier selected from /verify_profiles/templates

  • whitelisted_destinations (Array<String>) (defaults to: nil)

    Enabled country destinations to send verification codes. The elements in the lis



# File 'lib/telnyx/models/verify_profile_create_params.rb', line 104

Instance Attribute Details

#callTelnyx::Models::VerifyProfileCreateParams::Call?



18
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 18

optional :call, -> { Telnyx::VerifyProfileCreateParams::Call }

#flashcallTelnyx::Models::VerifyProfileCreateParams::Flashcall?



23
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 23

optional :flashcall, -> { Telnyx::VerifyProfileCreateParams::Flashcall }

#languageString?

Returns:

  • (String, nil)


28
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 28

optional :language, String

#nameString

Returns:

  • (String)


13
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 13

required :name, String

#rcsTelnyx::Models::VerifyProfileCreateParams::Rcs?



33
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 33

optional :rcs, -> { Telnyx::VerifyProfileCreateParams::Rcs }

#smsTelnyx::Models::VerifyProfileCreateParams::SMS?



38
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 38

optional :sms, -> { Telnyx::VerifyProfileCreateParams::SMS }

#webhook_failover_urlString?

Returns:

  • (String, nil)


43
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 43

optional :webhook_failover_url, String

#webhook_urlString?

Returns:

  • (String, nil)


48
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 48

optional :webhook_url, String

#whatsappTelnyx::Models::VerifyProfileCreateParams::Whatsapp?



53
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 53

optional :whatsapp, -> { Telnyx::VerifyProfileCreateParams::Whatsapp }