Class: Telnyx::Models::VerifyProfileCreateParams::Whatsapp
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VerifyProfileCreateParams::Whatsapp
- Defined in:
- lib/telnyx/models/verify_profile_create_params.rb
Instance Attribute Summary collapse
-
#app_name ⇒ String?
The name that identifies the application requesting 2fa in the verification message.
-
#default_verification_timeout_secs ⇒ Integer?
For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires.
-
#whitelisted_destinations ⇒ Array<String>?
Enabled country destinations to send verification codes.
Instance Method Summary collapse
-
#initialize(app_name: nil, default_verification_timeout_secs: nil, whitelisted_destinations: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Whatsapp for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app_name: nil, default_verification_timeout_secs: nil, whitelisted_destinations: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VerifyProfileCreateParams::Whatsapp for more details.
|
|
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 301
|
Instance Attribute Details
#app_name ⇒ String?
The name that identifies the application requesting 2fa in the verification message.
282 |
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 282 optional :app_name, String |
#default_verification_timeout_secs ⇒ Integer?
For every request that is initiated via this Verify profile, this sets the number of seconds before a verification request code expires. Once the verification request expires, the user cannot use the code to verify their identity.
291 |
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 291 optional :default_verification_timeout_secs, Integer |
#whitelisted_destinations ⇒ Array<String>?
Enabled country destinations to send verification codes. The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set to ‘[“*”]`, all destinations will be allowed.
299 |
# File 'lib/telnyx/models/verify_profile_create_params.rb', line 299 optional :whitelisted_destinations, Telnyx::Internal::Type::ArrayOf[String] |