Class: Telnyx::Models::VirtualCrossConnectCombined
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VirtualCrossConnectCombined
- Defined in:
- lib/telnyx/models/virtual_cross_connect_combined.rb
Overview
Defined Under Namespace
Modules: CloudProvider Classes: Region
Instance Attribute Summary collapse
-
#bandwidth_mbps ⇒ Float?
The desired throughput in Megabits per Second (Mbps) for your Virtual Cross Connect.
-
#bgp_asn ⇒ Float?
The Border Gateway Protocol (BGP) Autonomous System Number (ASN).
-
#cloud_provider ⇒ Symbol, ...
The Virtual Private Cloud with which you would like to establish a cross connect.
-
#cloud_provider_region ⇒ String?
The region where your Virtual Private Cloud hosts are located.
-
#name ⇒ String?
A user specified name for the interface.
-
#network_id ⇒ String?
The id of the network associated with the interface.
-
#primary_bgp_key ⇒ String?
The authentication key for BGP peer configuration.
-
#primary_cloud_account_id ⇒ String?
The identifier for your Virtual Private Cloud.
-
#primary_cloud_ip ⇒ String?
The IP address assigned for your side of the Virtual Cross Connect.
-
#primary_enabled ⇒ Boolean?
Indicates whether the primary circuit is enabled.
-
#primary_routing_announcement ⇒ Boolean?
Whether.
-
#primary_telnyx_ip ⇒ String?
The IP address assigned to the Telnyx side of the Virtual Cross Connect.
- #region ⇒ Telnyx::Models::VirtualCrossConnectCombined::Region?
-
#region_code ⇒ String?
The region interface is deployed to.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, bandwidth_mbps: nil, bgp_asn: nil, cloud_provider: nil, cloud_provider_region: nil, created_at: nil, name: nil, network_id: nil, primary_bgp_key: nil, primary_cloud_account_id: nil, primary_cloud_ip: nil, primary_enabled: nil, primary_routing_announcement: nil, primary_telnyx_ip: nil, record_type: nil, region: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see VirtualCrossConnectCombined for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, bandwidth_mbps: nil, bgp_asn: nil, cloud_provider: nil, cloud_provider_region: nil, created_at: nil, name: nil, network_id: nil, primary_bgp_key: nil, primary_cloud_account_id: nil, primary_cloud_ip: nil, primary_enabled: nil, primary_routing_announcement: nil, primary_telnyx_ip: nil, record_type: nil, region: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VirtualCrossConnectCombined for more details.
|
|
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 124
|
Instance Attribute Details
#bandwidth_mbps ⇒ Float?
The desired throughput in Megabits per Second (Mbps) for your Virtual Cross Connect.
12 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 12 optional :bandwidth_mbps, Float |
#bgp_asn ⇒ Float?
The Border Gateway Protocol (BGP) Autonomous System Number (ASN).
18 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 18 optional :bgp_asn, Float |
#cloud_provider ⇒ Symbol, ...
The Virtual Private Cloud with which you would like to establish a cross connect.
25 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 25 optional :cloud_provider, enum: -> { Telnyx::VirtualCrossConnectCombined::CloudProvider } |
#cloud_provider_region ⇒ String?
The region where your Virtual Private Cloud hosts are located.
31 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 31 optional :cloud_provider_region, String |
#name ⇒ String?
A user specified name for the interface.
37 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 37 optional :name, String |
#network_id ⇒ String?
The id of the network associated with the interface.
43 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 43 optional :network_id, String |
#primary_bgp_key ⇒ String?
The authentication key for BGP peer configuration.
49 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 49 optional :primary_bgp_key, String |
#primary_cloud_account_id ⇒ String?
The identifier for your Virtual Private Cloud.
55 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 55 optional :primary_cloud_account_id, String |
#primary_cloud_ip ⇒ String?
The IP address assigned for your side of the Virtual Cross Connect.
61 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 61 optional :primary_cloud_ip, String |
#primary_enabled ⇒ Boolean?
Indicates whether the primary circuit is enabled.
67 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 67 optional :primary_enabled, Telnyx::Internal::Type::Boolean |
#primary_routing_announcement ⇒ Boolean?
Whether
73 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 73 optional :primary_routing_announcement, Telnyx::Internal::Type::Boolean |
#primary_telnyx_ip ⇒ String?
The IP address assigned to the Telnyx side of the Virtual Cross Connect.
79 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 79 optional :primary_telnyx_ip, String |
#region ⇒ Telnyx::Models::VirtualCrossConnectCombined::Region?
84 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 84 optional :region, -> { Telnyx::VirtualCrossConnectCombined::Region } |
#region_code ⇒ String?
The region interface is deployed to.
90 |
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 90 optional :region_code, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/virtual_cross_connect_combined.rb', line 177
|