Class: Telnyx::Models::VirtualCrossConnectCreate
- Inherits:
-
Record
- Object
- Internal::Type::BaseModel
- Record
- Telnyx::Models::VirtualCrossConnectCreate
- Defined in:
- lib/telnyx/models/virtual_cross_connect_create.rb,
sig/telnyx/models/virtual_cross_connect_create.rbs
Direct Known Subclasses
Defined Under Namespace
Modules: CloudProvider
Instance Attribute Summary collapse
-
#bandwidth_mbps ⇒ Float?
The desired throughput in Megabits per Second (Mbps) for your Virtual Cross Connect.
The available bandwidths can be found using the /virtual_cross_connect_regions endpoint. -
#bgp_asn ⇒ Float?
The Border Gateway Protocol (BGP) Autonomous System Number (ASN).
-
#cloud_provider ⇒ Symbol, ...
The Virtual Private Cloud with which you would like to establish a cross connect.
-
#cloud_provider_region ⇒ String?
The region where your Virtual Private Cloud hosts are located.
The available regions can be found using the /virtual_cross_connect_regions endpoint. -
#name ⇒ String?
A user specified name for the interface.
-
#network_id ⇒ String?
The id of the network associated with the interface.
-
#primary_bgp_key ⇒ String?
The authentication key for BGP peer configuration.
-
#primary_cloud_account_id ⇒ String?
The identifier for your Virtual Private Cloud.
-
#primary_cloud_ip ⇒ String?
The IP address assigned for your side of the Virtual Cross Connect.
If none is provided, one will be generated for you.
This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted. -
#primary_telnyx_ip ⇒ String?
The IP address assigned to the Telnyx side of the Virtual Cross Connect.
If none is provided, one will be generated for you.
This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted. -
#region_code ⇒ String
The region the interface should be deployed to.
-
#secondary_bgp_key ⇒ String?
The authentication key for BGP peer configuration.
-
#secondary_cloud_account_id ⇒ String?
The identifier for your Virtual Private Cloud.
-
#secondary_cloud_ip ⇒ String?
The IP address assigned for your side of the Virtual Cross Connect.
If none is provided, one will be generated for you.
This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted. -
#secondary_telnyx_ip ⇒ String?
The IP address assigned to the Telnyx side of the Virtual Cross Connect.
If none is provided, one will be generated for you.
This value should be null for GCE as Google will only inform you of your assigned IP once the connection has been accepted.
Attributes inherited from Record
#created_at, #id, #record_type, #updated_at
Instance Method Summary collapse
-
#initialize(region_code:, name: nil, network_id: nil, status: nil, bandwidth_mbps: nil, bgp_asn: nil, cloud_provider: nil, cloud_provider_region: nil, primary_bgp_key: nil, primary_cloud_account_id: nil, primary_cloud_ip: nil, primary_enabled: nil, primary_telnyx_ip: nil, secondary_bgp_key: nil, secondary_cloud_account_id: nil, secondary_cloud_ip: nil, secondary_enabled: nil, secondary_telnyx_ip: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see VirtualCrossConnectCreate for more details.
- #primary_enabled ⇒ Boolean?
- #primary_enabled= ⇒ Boolean
- #secondary_enabled ⇒ Boolean?
- #secondary_enabled= ⇒ Boolean
- #status ⇒ Telnyx::Models::interface_status?
- #status= ⇒ Object
- #to_hash ⇒ {
Methods inherited from Record
#created_at=, #id=, #record_type=, #updated_at=
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(region_code:, name: nil, network_id: nil, status: nil, bandwidth_mbps: nil, bgp_asn: nil, cloud_provider: nil, cloud_provider_region: nil, primary_bgp_key: nil, primary_cloud_account_id: nil, primary_cloud_ip: nil, primary_enabled: nil, primary_telnyx_ip: nil, secondary_bgp_key: nil, secondary_cloud_account_id: nil, secondary_cloud_ip: nil, secondary_enabled: nil, secondary_telnyx_ip: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VirtualCrossConnectCreate for more details.
|
|
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 139
|
Instance Attribute Details
#bandwidth_mbps ⇒ Float?
The desired throughput in Megabits per Second (Mbps) for your Virtual Cross
Connect.
The available bandwidths can be found using the
/virtual_cross_connect_regions endpoint.
30 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 30 optional :bandwidth_mbps, Float |
#bgp_asn ⇒ Float?
The Border Gateway Protocol (BGP) Autonomous System Number (ASN). If null, value will be assigned by Telnyx.
37 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 37 optional :bgp_asn, Float |
#cloud_provider ⇒ Symbol, ...
The Virtual Private Cloud with which you would like to establish a cross connect.
44 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 44 optional :cloud_provider, enum: -> { Telnyx::VirtualCrossConnectCreate::CloudProvider } |
#cloud_provider_region ⇒ String?
The region where your Virtual Private Cloud hosts are located.
The
available regions can be found using the /virtual_cross_connect_regions
endpoint.
52 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 52 optional :cloud_provider_region, String |
#name ⇒ String?
A user specified name for the interface.
10 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 10 optional :name, String |
#network_id ⇒ String?
The id of the network associated with the interface.
16 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 16 optional :network_id, String |
#primary_bgp_key ⇒ String?
The authentication key for BGP peer configuration.
58 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 58 optional :primary_bgp_key, String |
#primary_cloud_account_id ⇒ String?
The identifier for your Virtual Private Cloud. The number will be different based upon your Cloud provider.
65 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 65 optional :primary_cloud_account_id, String |
#primary_cloud_ip ⇒ String?
The IP address assigned for your side of the Virtual Cross
Connect.
If none is provided, one will be generated for
you.
This value should be null for GCE as Google will only inform you
of your assigned IP once the connection has been accepted.
74 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 74 optional :primary_cloud_ip, String |
#primary_telnyx_ip ⇒ String?
The IP address assigned to the Telnyx side of the Virtual Cross
Connect.
If none is provided, one will be generated for
you.
This value should be null for GCE as Google will only inform you
of your assigned IP once the connection has been accepted.
83 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 83 optional :primary_telnyx_ip, String |
#region_code ⇒ String
The region the interface should be deployed to.
22 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 22 required :region_code, String |
#secondary_bgp_key ⇒ String?
The authentication key for BGP peer configuration.
89 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 89 optional :secondary_bgp_key, String |
#secondary_cloud_account_id ⇒ String?
The identifier for your Virtual Private Cloud. The number will be different
based upon your Cloud provider.
This attribute is only necessary for
GCE.
97 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 97 optional :secondary_cloud_account_id, String |
#secondary_cloud_ip ⇒ String?
The IP address assigned for your side of the Virtual Cross
Connect.
If none is provided, one will be generated for
you.
This value should be null for GCE as Google will only inform you
of your assigned IP once the connection has been accepted.
106 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 106 optional :secondary_cloud_ip, String |
#secondary_telnyx_ip ⇒ String?
The IP address assigned to the Telnyx side of the Virtual Cross
Connect.
If none is provided, one will be generated for
you.
This value should be null for GCE as Google will only inform you
of your assigned IP once the connection has been accepted.
115 |
# File 'lib/telnyx/models/virtual_cross_connect_create.rb', line 115 optional :secondary_telnyx_ip, String |
Instance Method Details
#primary_enabled ⇒ Boolean?
94 |
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 94
def primary_enabled: -> bool?
|
#primary_enabled= ⇒ Boolean
96 |
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 96
def primary_enabled=: (bool _) -> bool
|
#secondary_enabled ⇒ Boolean?
98 |
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 98
def secondary_enabled: -> bool?
|
#secondary_enabled= ⇒ Boolean
100 |
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 100
def secondary_enabled=: (bool _) -> bool
|
#status ⇒ Telnyx::Models::interface_status?
88 |
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 88
def status: -> Telnyx::Models::interface_status?
|
#status= ⇒ Object
90 |
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 90
def status=: (
|
#to_hash ⇒ {
123 |
# File 'sig/telnyx/models/virtual_cross_connect_create.rbs', line 123
def to_hash: -> {
|