Class: Telnyx::Models::VirtualCrossConnectUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VirtualCrossConnectUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/virtual_cross_connect_update_params.rb
Overview
Instance Attribute Summary collapse
- #id ⇒ String
-
#primary_cloud_ip ⇒ String?
The IP address assigned for your side of the Virtual Cross Connect.<br /><br />If none is provided, one will be generated for you.<br /><br />This value can not be patched once the VXC has bene provisioned.
-
#primary_enabled ⇒ Boolean?
Indicates whether the primary circuit is enabled.
-
#primary_routing_announcement ⇒ Boolean?
Whether the primary BGP route is being announced.
-
#secondary_cloud_ip ⇒ String?
The IP address assigned for your side of the Virtual Cross Connect.<br /><br />If none is provided, one will be generated for you.<br /><br />This value can not be patched once the VXC has bene provisioned.
-
#secondary_enabled ⇒ Boolean?
Indicates whether the secondary circuit is enabled.
-
#secondary_routing_announcement ⇒ Boolean?
Whether the secondary BGP route is being announced.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, primary_cloud_ip: nil, primary_enabled: nil, primary_routing_announcement: nil, secondary_cloud_ip: nil, secondary_enabled: nil, secondary_routing_announcement: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see VirtualCrossConnectUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, primary_cloud_ip: nil, primary_enabled: nil, primary_routing_announcement: nil, secondary_cloud_ip: nil, secondary_enabled: nil, secondary_routing_announcement: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VirtualCrossConnectUpdateParams for more details.
|
|
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 57
|
Instance Attribute Details
#id ⇒ String
13 |
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 13 required :id, String |
#primary_cloud_ip ⇒ String?
The IP address assigned for your side of the Virtual Cross Connect.<br /><br />If none is provided, one will be generated for you.<br /><br />This value can not be patched once the VXC has bene provisioned.
21 |
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 21 optional :primary_cloud_ip, String |
#primary_enabled ⇒ Boolean?
Indicates whether the primary circuit is enabled. Setting this to ‘false` will disable the circuit.
28 |
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 28 optional :primary_enabled, Telnyx::Internal::Type::Boolean |
#primary_routing_announcement ⇒ Boolean?
Whether the primary BGP route is being announced.
34 |
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 34 optional :primary_routing_announcement, Telnyx::Internal::Type::Boolean |
#secondary_cloud_ip ⇒ String?
The IP address assigned for your side of the Virtual Cross Connect.<br /><br />If none is provided, one will be generated for you.<br /><br />This value can not be patched once the VXC has bene provisioned.
42 |
# File 'lib/telnyx/models/virtual_cross_connect_update_params.rb', line 42 optional :secondary_cloud_ip, String |