Class: Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data
- Defined in:
- lib/telnyx/models/voice_clone_create_from_design_response.rb
Overview
Defined Under Namespace
Modules: Gender, RecordType
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
Timestamp when the voice clone was created.
-
#gender ⇒ Symbol, ...
Gender of the voice clone.
-
#id ⇒ String?
Unique identifier for the voice clone.
-
#label ⇒ String?
Voice style description.
-
#language ⇒ String?
ISO 639-1 language code of the voice clone.
-
#name ⇒ String?
Name of the voice clone.
-
#record_type ⇒ Symbol, ...
Identifies the resource type.
-
#source_voice_design_id ⇒ String?
UUID of the source voice design.
-
#source_voice_design_version ⇒ Integer?
Version of the source voice design used.
-
#updated_at ⇒ Time?
Timestamp when the voice clone was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, created_at: nil, gender: nil, label: nil, language: nil, name: nil, record_type: nil, source_voice_design_id: nil, source_voice_design_version: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, gender: nil, label: nil, language: nil, name: nil, record_type: nil, source_voice_design_id: nil, source_voice_design_version: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data for more details.
A voice clone object.
|
|
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 83
|
Instance Attribute Details
#created_at ⇒ Time?
Timestamp when the voice clone was created.
30 |
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 30 optional :created_at, Time |
#gender ⇒ Symbol, ...
Gender of the voice clone.
36 37 38 |
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 36 optional :gender, enum: -> { Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data::Gender }, nil?: true |
#id ⇒ String?
Unique identifier for the voice clone.
24 |
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 24 optional :id, String |
#label ⇒ String?
Voice style description. If not explicitly set on upload, falls back to the source design’s prompt text.
45 |
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 45 optional :label, String, nil?: true |
#language ⇒ String?
ISO 639-1 language code of the voice clone.
51 |
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 51 optional :language, String, nil?: true |
#name ⇒ String?
Name of the voice clone.
57 |
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 57 optional :name, String |
#record_type ⇒ Symbol, ...
Identifies the resource type.
63 |
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 63 optional :record_type, enum: -> { Telnyx::Models::VoiceCloneCreateFromDesignResponse::Data::RecordType } |
#source_voice_design_id ⇒ String?
UUID of the source voice design. ‘null` for upload-based clones.
69 |
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 69 optional :source_voice_design_id, String, nil?: true |
#source_voice_design_version ⇒ Integer?
Version of the source voice design used. ‘null` for upload-based clones.
75 |
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 75 optional :source_voice_design_version, Integer, nil?: true |
#updated_at ⇒ Time?
Timestamp when the voice clone was last updated.
81 |
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 81 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/voice_clone_create_from_design_response.rb', line 119
|