Class: Telnyx::Models::VoiceCloneData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VoiceCloneData
- Defined in:
- lib/telnyx/models/voice_clone_data.rb
Overview
Defined Under Namespace
Modules: Gender, ModelID, Provider, RecordType, Status
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
Timestamp when the voice clone was created.
-
#gender ⇒ Symbol, ...
Gender of the voice clone.
-
#id ⇒ String?
Unique identifier for the voice clone.
-
#label ⇒ String?
Voice style description.
-
#language ⇒ String?
ISO 639-1 language code of the voice clone.
-
#model_id ⇒ Symbol, ...
TTS model identifier for the voice clone.
-
#name ⇒ String?
Name of the voice clone.
-
#provider ⇒ Symbol, ...
Voice synthesis provider used for this clone.
-
#provider_supported_models ⇒ Array<String>?
List of TTS model identifiers supported by this clone’s provider.
-
#provider_voice_id ⇒ String?
Provider-specific voice identifier used for TTS synthesis.
-
#record_type ⇒ Symbol, ...
Identifies the resource type.
-
#source_voice_design_id ⇒ String?
UUID of the source voice design.
-
#source_voice_design_version ⇒ Integer?
Version of the source voice design used.
-
#status ⇒ Symbol, ...
Clone status.
-
#updated_at ⇒ Time?
Timestamp when the voice clone was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, created_at: nil, gender: nil, label: nil, language: nil, model_id: nil, name: nil, provider: nil, provider_supported_models: nil, provider_voice_id: nil, record_type: nil, source_voice_design_id: nil, source_voice_design_version: nil, status: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see VoiceCloneData for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, gender: nil, label: nil, language: nil, model_id: nil, name: nil, provider: nil, provider_supported_models: nil, provider_voice_id: nil, record_type: nil, source_voice_design_id: nil, source_voice_design_version: nil, status: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VoiceCloneData for more details.
A voice clone object.
|
|
# File 'lib/telnyx/models/voice_clone_data.rb', line 100
|
Instance Attribute Details
#created_at ⇒ Time?
Timestamp when the voice clone was created.
17 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 17 optional :created_at, Time |
#gender ⇒ Symbol, ...
Gender of the voice clone.
23 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 23 optional :gender, enum: -> { Telnyx::VoiceCloneData::Gender }, nil?: true |
#id ⇒ String?
Unique identifier for the voice clone.
11 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 11 optional :id, String |
#label ⇒ String?
Voice style description. If not explicitly set on upload, falls back to the source design’s prompt text.
30 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 30 optional :label, String, nil?: true |
#language ⇒ String?
ISO 639-1 language code of the voice clone.
36 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 36 optional :language, String, nil?: true |
#model_id ⇒ Symbol, ...
TTS model identifier for the voice clone.
42 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 42 optional :model_id, enum: -> { Telnyx::VoiceCloneData::ModelID } |
#name ⇒ String?
Name of the voice clone.
48 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 48 optional :name, String |
#provider ⇒ Symbol, ...
Voice synthesis provider used for this clone.
54 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 54 optional :provider, enum: -> { Telnyx::VoiceCloneData::Provider } |
#provider_supported_models ⇒ Array<String>?
List of TTS model identifiers supported by this clone’s provider.
60 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 60 optional :provider_supported_models, Telnyx::Internal::Type::ArrayOf[String] |
#provider_voice_id ⇒ String?
Provider-specific voice identifier used for TTS synthesis. May differ from the clone UUID depending on the provider and model.
67 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 67 optional :provider_voice_id, String, nil?: true |
#record_type ⇒ Symbol, ...
Identifies the resource type.
73 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 73 optional :record_type, enum: -> { Telnyx::VoiceCloneData::RecordType } |
#source_voice_design_id ⇒ String?
UUID of the source voice design. ‘null` for upload-based clones.
79 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 79 optional :source_voice_design_id, String, nil?: true |
#source_voice_design_version ⇒ Integer?
Version of the source voice design used. ‘null` for upload-based clones.
85 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 85 optional :source_voice_design_version, Integer, nil?: true |
#status ⇒ Symbol, ...
Clone status. pending for Ultra clones while on-prem import is in progress, active once ready, failed if verification timed out, expired if not kept alive.
92 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 92 optional :status, enum: -> { Telnyx::VoiceCloneData::Status } |
#updated_at ⇒ Time?
Timestamp when the voice clone was last updated.
98 |
# File 'lib/telnyx/models/voice_clone_data.rb', line 98 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/voice_clone_data.rb', line 146
|