Class: Telnyx::Models::VoiceDesignCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VoiceDesignCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/telnyx/models/voice_design_create_params.rb
Overview
Defined Under Namespace
Modules: Provider
Instance Attribute Summary collapse
-
#language ⇒ String?
Language for synthesis.
-
#max_new_tokens ⇒ Integer?
Maximum number of tokens to generate.
-
#name ⇒ String?
Name for the voice design.
-
#prompt ⇒ String
Natural language description of the voice style, e.g.
-
#provider ⇒ Symbol, ...
Voice synthesis provider.
-
#repetition_penalty ⇒ Float?
Repetition penalty to reduce repeated patterns in generated audio.
-
#temperature ⇒ Float?
Sampling temperature controlling randomness.
-
#text ⇒ String
Sample text to synthesize for this voice design.
-
#top_k ⇒ Integer?
Top-k sampling parameter — limits the token vocabulary considered at each step.
-
#top_p ⇒ Float?
Top-p (nucleus) sampling parameter — cumulative probability cutoff for token selection.
-
#voice_design_id ⇒ String?
ID of an existing voice design to add a new version to.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(prompt:, text:, language: nil, max_new_tokens: nil, name: nil, provider: nil, repetition_penalty: nil, temperature: nil, top_k: nil, top_p: nil, voice_design_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see VoiceDesignCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(prompt:, text:, language: nil, max_new_tokens: nil, name: nil, provider: nil, repetition_penalty: nil, temperature: nil, top_k: nil, top_p: nil, voice_design_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VoiceDesignCreateParams for more details.
|
|
# File 'lib/telnyx/models/voice_design_create_params.rb', line 86
|
Instance Attribute Details
#language ⇒ String?
Language for synthesis. Supported values: Auto, Chinese, English, Japanese, Korean, German, French, Russian, Portuguese, Spanish, Italian. Defaults to Auto.
28 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 28 optional :language, String |
#max_new_tokens ⇒ Integer?
Maximum number of tokens to generate. Default: 2048.
34 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 34 optional :max_new_tokens, Integer |
#name ⇒ String?
Name for the voice design. Required when creating a new design (‘voice_design_id` is not provided); ignored when adding a version. Cannot be a UUID.
42 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 42 optional :name, String |
#prompt ⇒ String
Natural language description of the voice style, e.g. ‘Speak in a warm, friendly tone with a slight British accent’.
15 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 15 required :prompt, String |
#provider ⇒ Symbol, ...
Voice synthesis provider. ‘telnyx` uses the Qwen3TTS model; `minimax` uses the Minimax speech models. Case-insensitive. Defaults to `telnyx`.
49 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 49 optional :provider, enum: -> { Telnyx::VoiceDesignCreateParams::Provider } |
#repetition_penalty ⇒ Float?
Repetition penalty to reduce repeated patterns in generated audio. Default: 1.05.
56 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 56 optional :repetition_penalty, Float |
#temperature ⇒ Float?
Sampling temperature controlling randomness. Higher values produce more varied output. Default: 0.9.
63 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 63 optional :temperature, Float |
#text ⇒ String
Sample text to synthesize for this voice design.
21 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 21 required :text, String |
#top_k ⇒ Integer?
Top-k sampling parameter — limits the token vocabulary considered at each step. Default: 50.
70 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 70 optional :top_k, Integer |
#top_p ⇒ Float?
Top-p (nucleus) sampling parameter — cumulative probability cutoff for token selection. Default: 1.0.
77 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 77 optional :top_p, Float |
#voice_design_id ⇒ String?
ID of an existing voice design to add a new version to. When provided, a new version is created instead of a new design.
84 |
# File 'lib/telnyx/models/voice_design_create_params.rb', line 84 optional :voice_design_id, String |