Class: Telnyx::Models::VoiceDesignData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::VoiceDesignData
- Defined in:
- lib/telnyx/models/voice_design_data.rb
Defined Under Namespace
Modules: Provider, RecordType
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
Timestamp when the voice design was first created.
-
#id ⇒ String?
Unique identifier for the voice design.
-
#name ⇒ String?
Name of the voice design.
-
#prompt ⇒ String?
Natural language prompt used to define the voice style for this version.
-
#provider ⇒ Symbol, ...
Voice synthesis provider used for this design.
-
#provider_supported_models ⇒ Array<String>?
List of TTS model identifiers supported by this design’s provider (e.g. ‘Qwen3TTS`, `speech-02-turbo`).
-
#provider_voice_id ⇒ String?
Provider-specific voice identifier.
-
#record_type ⇒ Symbol, ...
Identifies the resource type.
-
#text ⇒ String?
Sample text used to synthesize this version.
-
#updated_at ⇒ Time?
Timestamp when the voice design was last updated.
-
#version ⇒ Integer?
Version number of this voice design.
-
#version_created_at ⇒ Time?
Timestamp when this specific version was created.
-
#voice_sample_size ⇒ Integer?
Size of the voice sample audio in bytes.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, created_at: nil, name: nil, prompt: nil, provider: nil, provider_supported_models: nil, provider_voice_id: nil, record_type: nil, text: nil, updated_at: nil, version: nil, version_created_at: nil, voice_sample_size: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see VoiceDesignData for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, name: nil, prompt: nil, provider: nil, provider_supported_models: nil, provider_voice_id: nil, record_type: nil, text: nil, updated_at: nil, version: nil, version_created_at: nil, voice_sample_size: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::VoiceDesignData for more details.
A voice design object with full version detail.
|
|
# File 'lib/telnyx/models/voice_design_data.rb', line 86
|
Instance Attribute Details
#created_at ⇒ Time?
Timestamp when the voice design was first created.
16 |
# File 'lib/telnyx/models/voice_design_data.rb', line 16 optional :created_at, Time |
#id ⇒ String?
Unique identifier for the voice design.
10 |
# File 'lib/telnyx/models/voice_design_data.rb', line 10 optional :id, String |
#name ⇒ String?
Name of the voice design.
22 |
# File 'lib/telnyx/models/voice_design_data.rb', line 22 optional :name, String |
#prompt ⇒ String?
Natural language prompt used to define the voice style for this version.
28 |
# File 'lib/telnyx/models/voice_design_data.rb', line 28 optional :prompt, String |
#provider ⇒ Symbol, ...
Voice synthesis provider used for this design.
34 |
# File 'lib/telnyx/models/voice_design_data.rb', line 34 optional :provider, enum: -> { Telnyx::VoiceDesignData::Provider }, nil?: true |
#provider_supported_models ⇒ Array<String>?
List of TTS model identifiers supported by this design’s provider (e.g. ‘Qwen3TTS`, `speech-02-turbo`).
41 |
# File 'lib/telnyx/models/voice_design_data.rb', line 41 optional :provider_supported_models, Telnyx::Internal::Type::ArrayOf[String] |
#provider_voice_id ⇒ String?
Provider-specific voice identifier. For Telnyx designs this is the design version ID; for Minimax it is the Minimax-assigned voice ID.
48 |
# File 'lib/telnyx/models/voice_design_data.rb', line 48 optional :provider_voice_id, String, nil?: true |
#record_type ⇒ Symbol, ...
Identifies the resource type.
54 |
# File 'lib/telnyx/models/voice_design_data.rb', line 54 optional :record_type, enum: -> { Telnyx::VoiceDesignData::RecordType } |
#text ⇒ String?
Sample text used to synthesize this version.
60 |
# File 'lib/telnyx/models/voice_design_data.rb', line 60 optional :text, String |
#updated_at ⇒ Time?
Timestamp when the voice design was last updated.
66 |
# File 'lib/telnyx/models/voice_design_data.rb', line 66 optional :updated_at, Time |
#version ⇒ Integer?
Version number of this voice design.
72 |
# File 'lib/telnyx/models/voice_design_data.rb', line 72 optional :version, Integer |
#version_created_at ⇒ Time?
Timestamp when this specific version was created.
78 |
# File 'lib/telnyx/models/voice_design_data.rb', line 78 optional :version_created_at, Time |
#voice_sample_size ⇒ Integer?
Size of the voice sample audio in bytes.
84 |
# File 'lib/telnyx/models/voice_design_data.rb', line 84 optional :voice_sample_size, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/voice_design_data.rb', line 127
|