Class: Telnyx::Models::WebhookDeliveryListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/webhook_delivery_list_response.rb

Overview

Defined Under Namespace

Modules: Status Classes: Attempt, Webhook

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Telnyx::Internal::Type::BaseModel

Instance Attribute Details

#attemptsArray<Telnyx::Models::WebhookDeliveryListResponse::Attempt>?

Detailed delivery attempts, ordered by most recent.



17
18
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 17

optional :attempts,
-> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::WebhookDeliveryListResponse::Attempt] }

#finished_atTime?

ISO 8601 timestamp indicating when the last webhook response has been received.

Returns:

  • (Time, nil)


24
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 24

optional :finished_at, Time

#idString?

Uniquely identifies the webhook_delivery record.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 11

optional :id, String

#record_typeString?

Identifies the type of the resource.

Returns:

  • (String, nil)


30
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 30

optional :record_type, String

#started_atTime?

ISO 8601 timestamp indicating when the first request attempt was initiated.

Returns:

  • (Time, nil)


36
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 36

optional :started_at, Time

#statusSymbol, ...

Delivery status: ‘delivered’ when successfuly delivered or ‘failed’ if all attempts have failed.



43
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 43

optional :status, enum: -> { Telnyx::Models::WebhookDeliveryListResponse::Status }

#user_idString?

Uniquely identifies the user that owns the webhook_delivery record.

Returns:

  • (String, nil)


49
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 49

optional :user_id, String

#webhookTelnyx::Models::WebhookDeliveryListResponse::Webhook?

Original webhook JSON data. Payload fields vary according to event type.



55
# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 55

optional :webhook, -> { Telnyx::Models::WebhookDeliveryListResponse::Webhook }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/telnyx/models/webhook_delivery_list_response.rb', line 201