Class: Telnyx::Models::WebhookDeliveryRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::WebhookDeliveryRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/webhook_delivery_retrieve_response.rb
Overview
Defined Under Namespace
Modules: Status Classes: Attempt, Webhook
Instance Attribute Summary collapse
-
#attempts ⇒ Array<Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Attempt>?
Detailed delivery attempts, ordered by most recent.
-
#finished_at ⇒ Time?
ISO 8601 timestamp indicating when the last webhook response has been received.
-
#id ⇒ String?
Uniquely identifies the webhook_delivery record.
-
#record_type ⇒ String?
Identifies the type of the resource.
-
#started_at ⇒ Time?
ISO 8601 timestamp indicating when the first request attempt was initiated.
-
#status ⇒ Symbol, ...
Delivery status: ‘delivered’ when successfuly delivered or ‘failed’ if all attempts have failed.
-
#user_id ⇒ String?
Uniquely identifies the user that owns the webhook_delivery record.
-
#webhook ⇒ Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Webhook?
Original webhook JSON data.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Telnyx::Internal::Type::BaseModel
Instance Attribute Details
#attempts ⇒ Array<Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Attempt>?
Detailed delivery attempts, ordered by most recent.
28 29 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 28 optional :attempts, -> { Telnyx::Internal::Type::ArrayOf[Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Attempt] } |
#finished_at ⇒ Time?
ISO 8601 timestamp indicating when the last webhook response has been received.
35 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 35 optional :finished_at, Time |
#id ⇒ String?
Uniquely identifies the webhook_delivery record.
22 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 22 optional :id, String |
#record_type ⇒ String?
Identifies the type of the resource.
41 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 41 optional :record_type, String |
#started_at ⇒ Time?
ISO 8601 timestamp indicating when the first request attempt was initiated.
47 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 47 optional :started_at, Time |
#status ⇒ Symbol, ...
Delivery status: ‘delivered’ when successfuly delivered or ‘failed’ if all attempts have failed.
54 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 54 optional :status, enum: -> { Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Status } |
#user_id ⇒ String?
Uniquely identifies the user that owns the webhook_delivery record.
60 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 60 optional :user_id, String |
#webhook ⇒ Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Webhook?
Original webhook JSON data. Payload fields vary according to event type.
66 |
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 66 optional :webhook, -> { Telnyx::Models::WebhookDeliveryRetrieveResponse::Data::Webhook } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/webhook_delivery_retrieve_response.rb', line 212
|