Class: Telnyx::Models::Whatsapp::BusinessAccountRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Whatsapp::BusinessAccountRetrieveResponse::Data
- Defined in:
- lib/telnyx/models/whatsapp/business_account_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#account_review_status ⇒ String?
Account review status of Whatsapp business account.
-
#business_verification_status ⇒ String?
Business verification status of Whatsapp business account.
-
#country ⇒ String?
Country associated with Whatsapp business account.
- #created_at ⇒ Time?
-
#id ⇒ String?
Internal ID of Whatsapp business account.
-
#name ⇒ String?
Name of Whatsapp business account.
-
#phone_numbers_count ⇒ Integer?
Count of phone numbers associated with Whatsapp business account.
- #record_type ⇒ String?
-
#status ⇒ String?
Status of Whatsapp business account.
-
#waba_id ⇒ String?
WABA ID of Whatsapp business account.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, account_review_status: nil, business_verification_status: nil, country: nil, created_at: nil, name: nil, phone_numbers_count: nil, record_type: nil, status: nil, waba_id: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 76
|
Instance Attribute Details
#account_review_status ⇒ String?
Account review status of Whatsapp business account
28 |
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 28 optional :account_review_status, String |
#business_verification_status ⇒ String?
Business verification status of Whatsapp business account
34 |
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 34 optional :business_verification_status, String |
#country ⇒ String?
Country associated with Whatsapp business account
40 |
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 40 optional :country, String |
#created_at ⇒ Time?
45 |
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 45 optional :created_at, Time |
#id ⇒ String?
Internal ID of Whatsapp business account
22 |
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 22 optional :id, String |
#name ⇒ String?
Name of Whatsapp business account
51 |
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 51 optional :name, String |
#phone_numbers_count ⇒ Integer?
Count of phone numbers associated with Whatsapp business account
57 |
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 57 optional :phone_numbers_count, Integer |
#record_type ⇒ String?
62 |
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 62 optional :record_type, String |
#status ⇒ String?
Status of Whatsapp business account
68 |
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 68 optional :status, String |
#waba_id ⇒ String?
WABA ID of Whatsapp business account
74 |
# File 'lib/telnyx/models/whatsapp/business_account_retrieve_response.rb', line 74 optional :waba_id, String |