Module: Telnyx::Models::Whatsapp::TemplateCreateParams::Component
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/telnyx/models/whatsapp/template_create_params.rb
Overview
A template component. Additional Meta component types not listed here are also accepted.
Defined Under Namespace
Classes: Body, Buttons, Carousel, Footer, Header
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Header, Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Body, Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Footer, Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Buttons, Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Carousel)
Instance Method Summary collapse
-
#initialize(code_expiration_minutes: nil, text: nil, type: :FOOTER) ⇒ Object
Some parameter documentations has been truncated, see Footer for more details.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/telnyx/models/whatsapp/template_create_params.rb', line 427
|
.variants ⇒ Array(Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Header, Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Body, Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Footer, Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Buttons, Telnyx::Models::Whatsapp::TemplateCreateParams::Component::Carousel)
|
|
# File 'lib/telnyx/models/whatsapp/template_create_params.rb', line 466
|
Instance Method Details
#initialize(code_expiration_minutes: nil, text: nil, type: :FOOTER) ⇒ Object
Some parameter documentations has been truncated, see Footer for more details.
Optional footer displayed at the bottom of the message. Does not support variables.
|
|
# File 'lib/telnyx/models/whatsapp/template_create_params.rb', line 168
|