Class: Telnyx::Models::WireguardInterfaceRead
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::WireguardInterfaceRead
- Defined in:
- lib/telnyx/models/wireguard_interface_read.rb,
sig/telnyx/models/wireguard_interface_read.rbs
Overview
Defined Under Namespace
Classes: Region
Instance Attribute Summary collapse
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#enable_sip_trunking ⇒ Boolean?
Enable SIP traffic forwarding over VPN interface.
-
#endpoint ⇒ String?
readonly
Returns the value of attribute endpoint.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#name ⇒ String?
A user specified name for the interface.
-
#network_id ⇒ String?
The id of the network associated with the interface.
-
#public_key ⇒ String?
readonly
Returns the value of attribute public_key.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
- #region ⇒ Telnyx::Models::WireguardInterfaceRead::Region?
-
#region_code ⇒ String?
The region interface is deployed to.
-
#status ⇒ Telnyx::Models::interface_status?
readonly
Returns the value of attribute status.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Instance Method Summary collapse
- #created_at ⇒ String readonly
- #endpoint ⇒ String readonly
- #id ⇒ String readonly
- #initialize(id: nil, created_at: nil, enable_sip_trunking: nil, endpoint: nil, name: nil, network_id: nil, public_key: nil, record_type: nil, region: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object constructor
- #public_key ⇒ String readonly
- #record_type ⇒ String readonly
- #status ⇒ Object readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, enable_sip_trunking: nil, endpoint: nil, name: nil, network_id: nil, public_key: nil, record_type: nil, region: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 80
|
Instance Attribute Details
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
46 47 48 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 46 def created_at @created_at end |
#enable_sip_trunking ⇒ Boolean?
Enable SIP traffic forwarding over VPN interface.
11 |
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 11 optional :enable_sip_trunking, Telnyx::Internal::Type::Boolean |
#endpoint ⇒ String? (readonly)
Returns the value of attribute endpoint.
50 51 52 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 50 def endpoint @endpoint end |
#id ⇒ String? (readonly)
Returns the value of attribute id.
42 43 44 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 42 def id @id end |
#name ⇒ String?
A user specified name for the interface.
17 |
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 17 optional :name, String |
#network_id ⇒ String?
The id of the network associated with the interface.
23 |
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 23 optional :network_id, String |
#public_key ⇒ String? (readonly)
Returns the value of attribute public_key.
54 55 56 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 54 def public_key @public_key end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
58 59 60 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 58 def record_type @record_type end |
#region ⇒ Telnyx::Models::WireguardInterfaceRead::Region?
28 |
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 28 optional :region, -> { Telnyx::WireguardInterfaceRead::Region } |
#region_code ⇒ String?
The region interface is deployed to.
34 |
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 34 optional :region_code, String |
#status ⇒ Telnyx::Models::interface_status? (readonly)
Returns the value of attribute status.
62 63 64 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 62 def status @status end |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
68 69 70 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 68 def updated_at @updated_at end |
Instance Method Details
#created_at= ⇒ String (readonly)
48 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 48
def created_at=: (String) -> String
|
#endpoint= ⇒ String (readonly)
52 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 52
def endpoint=: (String) -> String
|
#id= ⇒ String (readonly)
44 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 44
def id=: (String) -> String
|
#public_key= ⇒ String (readonly)
56 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 56
def public_key=: (String) -> String
|
#record_type= ⇒ String (readonly)
60 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 60
def record_type=: (String) -> String
|
#status= ⇒ Object (readonly)
64 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 64
def status=: (
|
#to_hash ⇒ {
87 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 87
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
70 |
# File 'sig/telnyx/models/wireguard_interface_read.rbs', line 70
def updated_at=: (String) -> String
|