Class: Telnyx::Models::WireguardInterfaceRead

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/wireguard_interface_read.rb

Overview

Defined Under Namespace

Classes: Region

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, enable_sip_trunking: nil, endpoint: nil, name: nil, network_id: nil, public_key: nil, record_type: nil, region: nil, region_code: nil, status: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • enable_sip_trunking (Boolean) (defaults to: nil)

    Enable SIP traffic forwarding over VPN interface.

  • endpoint (String) (defaults to: nil)

    The Telnyx WireGuard peers ‘Peer.endpoint` value.

  • name (String) (defaults to: nil)

    A user specified name for the interface.

  • network_id (String) (defaults to: nil)

    The id of the network associated with the interface.

  • public_key (String) (defaults to: nil)

    The Telnyx WireGuard peers ‘Peer.PublicKey`.

  • record_type (String) (defaults to: nil)

    Identifies the type of the resource.

  • region (Telnyx::Models::WireguardInterfaceRead::Region) (defaults to: nil)
  • region_code (String) (defaults to: nil)

    The region interface is deployed to.

  • status (Symbol, Telnyx::Models::InterfaceStatus) (defaults to: nil)

    The current status of the interface deployment.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/wireguard_interface_read.rb', line 80

Instance Attribute Details

#enable_sip_trunkingBoolean?

Enable SIP traffic forwarding over VPN interface.

Returns:

  • (Boolean, nil)


11
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 11

optional :enable_sip_trunking, Telnyx::Internal::Type::Boolean

#nameString?

A user specified name for the interface.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 17

optional :name, String

#network_idString?

The id of the network associated with the interface.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 23

optional :network_id, String

#regionTelnyx::Models::WireguardInterfaceRead::Region?



28
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 28

optional :region, -> { Telnyx::WireguardInterfaceRead::Region }

#region_codeString?

The region interface is deployed to.

Returns:

  • (String, nil)


34
# File 'lib/telnyx/models/wireguard_interface_read.rb', line 34

optional :region_code, String