Class: Telnyx::Models::WireguardPeer
- Inherits:
-
Record
- Object
- Internal::Type::BaseModel
- Record
- Telnyx::Models::WireguardPeer
- Defined in:
- lib/telnyx/models/wireguard_peer.rb,
sig/telnyx/models/wireguard_peer.rbs
Overview
Direct Known Subclasses
Instance Attribute Summary collapse
-
#wireguard_interface_id ⇒ String?
The id of the wireguard interface associated with the peer.
Attributes inherited from Record
#created_at, #id, #record_type, #updated_at
Instance Method Summary collapse
-
#initialize(last_seen: nil, private_key: nil, wireguard_interface_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WireguardPeer for more details.
- #last_seen ⇒ String?
- #last_seen= ⇒ String
- #private_key ⇒ String?
- #private_key= ⇒ String
- #to_hash ⇒ {
Methods inherited from Record
#created_at=, #id=, #record_type=, #updated_at=
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(last_seen: nil, private_key: nil, wireguard_interface_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Telnyx::Models::WireguardPeer for more details.
|
|
# File 'lib/telnyx/models/wireguard_peer.rb', line 31
|
Instance Attribute Details
#wireguard_interface_id ⇒ String?
The id of the wireguard interface associated with the peer.
11 |
# File 'lib/telnyx/models/wireguard_peer.rb', line 11 optional :wireguard_interface_id, String |
Instance Method Details
#last_seen ⇒ String?
11 |
# File 'sig/telnyx/models/wireguard_peer.rbs', line 11
def last_seen: -> String?
|
#last_seen= ⇒ String
13 |
# File 'sig/telnyx/models/wireguard_peer.rbs', line 13
def last_seen=: (String _) -> String
|
#private_key ⇒ String?
15 |
# File 'sig/telnyx/models/wireguard_peer.rbs', line 15
def private_key: -> String?
|
#private_key= ⇒ String
17 |
# File 'sig/telnyx/models/wireguard_peer.rbs', line 17
def private_key=: (String _) -> String
|
#to_hash ⇒ {
25 |
# File 'sig/telnyx/models/wireguard_peer.rbs', line 25
def to_hash: -> {
|