Class: Telnyx::Models::Wireless::WdrReport
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Telnyx::Models::Wireless::WdrReport
- Defined in:
- lib/telnyx/models/wireless/wdr_report.rb,
sig/telnyx/models/wireless/wdr_report.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#created_at ⇒ String?
readonly
Returns the value of attribute created_at.
-
#end_time ⇒ String?
ISO 8601 formatted date-time indicating the end time.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#record_type ⇒ String?
readonly
Returns the value of attribute record_type.
-
#report_url ⇒ String?
The URL where the report content, when generated, will be published to.
-
#start_time ⇒ String?
ISO 8601 formatted date-time indicating the start time.
-
#status ⇒ Symbol, ...
Indicates the status of the report, which is updated asynchronously.
-
#updated_at ⇒ String?
readonly
Returns the value of attribute updated_at.
Instance Method Summary collapse
- #created_at ⇒ String readonly
- #id ⇒ String readonly
- #initialize(id: nil, created_at: nil, end_time: nil, record_type: nil, report_url: nil, start_time: nil, status: nil, updated_at: nil) ⇒ Object constructor
- #record_type ⇒ String readonly
- #to_hash ⇒ {
- #updated_at ⇒ String readonly
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, created_at: nil, end_time: nil, record_type: nil, report_url: nil, start_time: nil, status: nil, updated_at: nil) ⇒ Object
|
|
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 56
|
Instance Attribute Details
#created_at ⇒ String? (readonly)
Returns the value of attribute created_at.
39 40 41 |
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 39 def created_at @created_at end |
#end_time ⇒ String?
ISO 8601 formatted date-time indicating the end time.
11 |
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 11 optional :end_time, String |
#id ⇒ String? (readonly)
Returns the value of attribute id.
35 36 37 |
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 35 def id @id end |
#record_type ⇒ String? (readonly)
Returns the value of attribute record_type.
43 44 45 |
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 43 def record_type @record_type end |
#report_url ⇒ String?
The URL where the report content, when generated, will be published to.
17 |
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 17 optional :report_url, String |
#start_time ⇒ String?
ISO 8601 formatted date-time indicating the start time.
23 |
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 23 optional :start_time, String |
#status ⇒ Symbol, ...
Indicates the status of the report, which is updated asynchronously.
29 |
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 29 optional :status, enum: -> { Telnyx::Wireless::WdrReport::Status } |
#updated_at ⇒ String? (readonly)
Returns the value of attribute updated_at.
47 48 49 |
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 47 def updated_at @updated_at end |
Instance Method Details
#created_at= ⇒ String (readonly)
41 |
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 41
def created_at=: (String) -> String
|
#id= ⇒ String (readonly)
37 |
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 37
def id=: (String) -> String
|
#record_type= ⇒ String (readonly)
45 |
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 45
def record_type=: (String) -> String
|
#to_hash ⇒ {
62 |
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 62
def to_hash: -> {
|
#updated_at= ⇒ String (readonly)
49 |
# File 'sig/telnyx/models/wireless/wdr_report.rbs', line 49
def updated_at=: (String) -> String
|