Class: Telnyx::Models::Wireless::WdrReport

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/telnyx/models/wireless/wdr_report.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, created_at: nil, end_time: nil, record_type: nil, report_url: nil, start_time: nil, status: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String) (defaults to: nil)

    Identifies the resource.

  • created_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was created.

  • end_time (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating the end time.

  • record_type (String) (defaults to: nil)
  • report_url (String) (defaults to: nil)

    The URL where the report content, when generated, will be published to.

  • start_time (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating the start time.

  • status (Symbol, Telnyx::Models::Wireless::WdrReport::Status) (defaults to: nil)

    Indicates the status of the report, which is updated asynchronously.

  • updated_at (String) (defaults to: nil)

    ISO 8601 formatted date-time indicating when the resource was updated.



# File 'lib/telnyx/models/wireless/wdr_report.rb', line 56

Instance Attribute Details

#end_timeString?

ISO 8601 formatted date-time indicating the end time.

Returns:

  • (String, nil)


11
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 11

optional :end_time, String

#report_urlString?

The URL where the report content, when generated, will be published to.

Returns:

  • (String, nil)


17
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 17

optional :report_url, String

#start_timeString?

ISO 8601 formatted date-time indicating the start time.

Returns:

  • (String, nil)


23
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 23

optional :start_time, String

#statusSymbol, ...

Indicates the status of the report, which is updated asynchronously.



29
# File 'lib/telnyx/models/wireless/wdr_report.rb', line 29

optional :status, enum: -> { Telnyx::Wireless::WdrReport::Status }