Class: Telnyx::Resources::AI::Knowledge
- Inherits:
-
Object
- Object
- Telnyx::Resources::AI::Knowledge
- Defined in:
- lib/telnyx/resources/ai/knowledge.rb,
lib/telnyx/resources/ai/knowledge/collections.rb,
sig/telnyx/resources/ai/knowledge.rbs,
sig/telnyx/resources/ai/knowledge/collections.rbs
Defined Under Namespace
Classes: Collections
Instance Attribute Summary collapse
-
#collections ⇒ Telnyx::Resources::AI::Knowledge::Collections
readonly
Create and manage logical collections of your Telnyx data, tune retrieval settings, manage sources, and run collection-scoped semantic search.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Knowledge
constructor
private
A new instance of Knowledge.
Constructor Details
#initialize(client:) ⇒ Knowledge
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Knowledge.
15 16 17 18 |
# File 'lib/telnyx/resources/ai/knowledge.rb', line 15 def initialize(client:) @client = client @collections = Telnyx::Resources::AI::Knowledge::Collections.new(client: client) end |
Instance Attribute Details
#collections ⇒ Telnyx::Resources::AI::Knowledge::Collections (readonly)
Create and manage logical collections of your Telnyx data, tune retrieval settings, manage sources, and run collection-scoped semantic search.
10 11 12 |
# File 'lib/telnyx/resources/ai/knowledge.rb', line 10 def collections @collections end |