Class: Telnyx::Resources::AI::OpenAI
- Inherits:
-
Object
- Object
- Telnyx::Resources::AI::OpenAI
- Defined in:
- lib/telnyx/resources/ai/openai.rb,
lib/telnyx/resources/ai/openai/embeddings.rb
Defined Under Namespace
Classes: Embeddings
Instance Attribute Summary collapse
-
#embeddings ⇒ Telnyx::Resources::AI::OpenAI::Embeddings
readonly
OpenAI-compatible embeddings endpoints for generating vector representations of text.
Instance Method Summary collapse
-
#initialize(client:) ⇒ OpenAI
constructor
private
A new instance of OpenAI.
Constructor Details
#initialize(client:) ⇒ OpenAI
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of OpenAI.
15 16 17 18 |
# File 'lib/telnyx/resources/ai/openai.rb', line 15 def initialize(client:) @client = client @embeddings = Telnyx::Resources::AI::OpenAI::Embeddings.new(client: client) end |
Instance Attribute Details
#embeddings ⇒ Telnyx::Resources::AI::OpenAI::Embeddings (readonly)
OpenAI-compatible embeddings endpoints for generating vector representations of text
10 11 12 |
# File 'lib/telnyx/resources/ai/openai.rb', line 10 def @embeddings end |