Class: Telnyx::Resources::Calls::Actions
- Inherits:
-
Object
- Object
- Telnyx::Resources::Calls::Actions
- Defined in:
- lib/telnyx/resources/calls/actions.rb
Instance Method Summary collapse
-
#add_ai_assistant_messages(call_control_id, client_state: nil, command_id: nil, messages: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionAddAIAssistantMessagesResponse
Some parameter documentations has been truncated, see Models::Calls::ActionAddAIAssistantMessagesParams for more details.
-
#answer(call_control_id, billing_group_id: nil, client_state: nil, command_id: nil, custom_headers: nil, preferred_codecs: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, send_silence_when_idle: nil, sip_headers: nil, sound_modifications: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, transcription: nil, transcription_config: nil, webhook_url: nil, webhook_url_method: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionAnswerResponse
Some parameter documentations has been truncated, see Models::Calls::ActionAnswerParams for more details.
-
#bridge(call_control_id_to_bridge, call_control_id_to_bridge_with:, client_state: nil, command_id: nil, mute_dtmf: nil, park_after_unbridge: nil, play_ringtone: nil, queue: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, ringtone: nil, video_room_context: nil, video_room_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionBridgeResponse
Some parameter documentations has been truncated, see Models::Calls::ActionBridgeParams for more details.
-
#enqueue(call_control_id, queue_name:, client_state: nil, command_id: nil, keep_after_hangup: nil, max_size: nil, max_wait_time_secs: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionEnqueueResponse
Some parameter documentations has been truncated, see Models::Calls::ActionEnqueueParams for more details.
-
#gather(call_control_id, client_state: nil, command_id: nil, gather_id: nil, initial_timeout_millis: nil, inter_digit_timeout_millis: nil, maximum_digits: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherParams for more details.
-
#gather_using_ai(call_control_id, parameters:, assistant: nil, client_state: nil, command_id: nil, greeting: nil, interruption_settings: nil, language: nil, message_history: nil, send_message_history_updates: nil, send_partial_results: nil, transcription: nil, user_response_timeout_ms: nil, voice: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingAIResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingAIParams for more details.
-
#gather_using_audio(call_control_id, audio_url: nil, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_audio_url: nil, invalid_media_name: nil, maximum_digits: nil, maximum_tries: nil, media_name: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingAudioResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingAudioParams for more details.
-
#gather_using_speak(call_control_id, payload:, voice:, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_payload: nil, language: nil, maximum_digits: nil, maximum_tries: nil, minimum_digits: nil, payload_type: nil, service_level: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingSpeakResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingSpeakParams for more details.
-
#hangup(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionHangupResponse
Some parameter documentations has been truncated, see Models::Calls::ActionHangupParams for more details.
-
#initialize(client:) ⇒ Actions
constructor
private
A new instance of Actions.
-
#leave_queue(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionLeaveQueueResponse
Some parameter documentations has been truncated, see Models::Calls::ActionLeaveQueueParams for more details.
-
#pause_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionPauseRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionPauseRecordingParams for more details.
-
#refer(call_control_id, sip_address:, client_state: nil, command_id: nil, custom_headers: nil, sip_auth_password: nil, sip_auth_username: nil, sip_headers: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionReferResponse
Some parameter documentations has been truncated, see Models::Calls::ActionReferParams for more details.
-
#reject(call_control_id, cause:, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionRejectResponse
Some parameter documentations has been truncated, see Models::Calls::ActionRejectParams for more details.
-
#resume_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionResumeRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionResumeRecordingParams for more details.
-
#send_dtmf(call_control_id, digits:, client_state: nil, command_id: nil, duration_millis: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSendDtmfResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSendDtmfParams for more details.
-
#send_sip_info(call_control_id, body:, content_type:, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSendSipInfoResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSendSipInfoParams for more details.
-
#speak(call_control_id, payload:, voice:, client_state: nil, command_id: nil, language: nil, payload_type: nil, service_level: nil, stop: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSpeakResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSpeakParams for more details.
-
#start_ai_assistant(call_control_id, assistant: nil, client_state: nil, command_id: nil, greeting: nil, interruption_settings: nil, transcription: nil, voice: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartAIAssistantResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartAIAssistantParams for more details.
-
#start_forking(call_control_id, client_state: nil, command_id: nil, rx: nil, stream_type: nil, tx: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartForkingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartForkingParams for more details.
-
#start_noise_suppression(call_control_id, client_state: nil, command_id: nil, direction: nil, noise_suppression_engine: nil, noise_suppression_engine_config: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartNoiseSuppressionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartNoiseSuppressionParams for more details.
-
#start_playback(call_control_id, audio_type: nil, audio_url: nil, cache_audio: nil, client_state: nil, command_id: nil, loop_: nil, media_name: nil, overlay: nil, playback_content: nil, stop: nil, target_legs: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartPlaybackResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartPlaybackParams for more details.
-
#start_recording(call_control_id, channels:, format_:, client_state: nil, command_id: nil, custom_file_name: nil, max_length: nil, play_beep: nil, recording_track: nil, timeout_secs: nil, transcription: nil, transcription_engine: nil, transcription_language: nil, transcription_max_speaker_count: nil, transcription_min_speaker_count: nil, transcription_profanity_filter: nil, transcription_speaker_diarization: nil, trim: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartRecordingParams for more details.
-
#start_siprec(call_control_id, client_state: nil, connector_name: nil, include_metadata_custom_headers: nil, secure: nil, session_timeout_secs: nil, sip_transport: nil, siprec_track: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartSiprecResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartSiprecParams for more details.
-
#start_streaming(call_control_id, client_state: nil, command_id: nil, dialogflow_config: nil, enable_dialogflow: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_sampling_rate: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartStreamingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartStreamingParams for more details.
-
#start_transcription(call_control_id, client_state: nil, command_id: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_tracks: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartTranscriptionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartTranscriptionParams for more details.
-
#stop_ai_assistant(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopAIAssistantResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopAIAssistantParams for more details.
-
#stop_forking(call_control_id, client_state: nil, command_id: nil, stream_type: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopForkingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopForkingParams for more details.
-
#stop_gather(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopGatherResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopGatherParams for more details.
-
#stop_noise_suppression(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopNoiseSuppressionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopNoiseSuppressionParams for more details.
-
#stop_playback(call_control_id, client_state: nil, command_id: nil, overlay: nil, stop: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopPlaybackResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopPlaybackParams for more details.
-
#stop_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopRecordingParams for more details.
-
#stop_siprec(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopSiprecResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopSiprecParams for more details.
-
#stop_streaming(call_control_id, client_state: nil, command_id: nil, stream_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopStreamingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopStreamingParams for more details.
-
#stop_transcription(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopTranscriptionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopTranscriptionParams for more details.
-
#switch_supervisor_role(call_control_id, role:, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSwitchSupervisorRoleResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSwitchSupervisorRoleParams for more details.
-
#transfer(call_control_id, to:, answering_machine_detection: nil, answering_machine_detection_config: nil, audio_url: nil, client_state: nil, command_id: nil, custom_headers: nil, early_media: nil, from: nil, from_display_name: nil, media_encryption: nil, media_name: nil, mute_dtmf: nil, park_after_unbridge: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, sip_auth_password: nil, sip_auth_username: nil, sip_headers: nil, sip_region: nil, sip_transport_protocol: nil, sound_modifications: nil, target_leg_client_state: nil, time_limit_secs: nil, timeout_secs: nil, webhook_url: nil, webhook_url_method: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionTransferResponse
Some parameter documentations has been truncated, see Models::Calls::ActionTransferParams for more details.
-
#update_client_state(call_control_id, client_state:, request_options: {}) ⇒ Telnyx::Models::Calls::ActionUpdateClientStateResponse
Some parameter documentations has been truncated, see Models::Calls::ActionUpdateClientStateParams for more details.
Constructor Details
#initialize(client:) ⇒ Actions
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Actions.
1669 1670 1671 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1669 def initialize(client:) @client = client end |
Instance Method Details
#add_ai_assistant_messages(call_control_id, client_state: nil, command_id: nil, messages: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionAddAIAssistantMessagesResponse
Some parameter documentations has been truncated, see Models::Calls::ActionAddAIAssistantMessagesParams for more details.
Add messages to the conversation started by an AI assistant on the call.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/telnyx/resources/calls/actions.rb', line 27 def (call_control_id, params = {}) parsed, = Telnyx::Calls::ActionAddAIAssistantMessagesParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/ai_assistant_add_messages", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionAddAIAssistantMessagesResponse, options: ) end |
#answer(call_control_id, billing_group_id: nil, client_state: nil, command_id: nil, custom_headers: nil, preferred_codecs: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, send_silence_when_idle: nil, sip_headers: nil, sound_modifications: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, transcription: nil, transcription_config: nil, webhook_url: nil, webhook_url_method: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionAnswerResponse
Some parameter documentations has been truncated, see Models::Calls::ActionAnswerParams for more details.
Answer an incoming call. You must issue this command before executing subsequent commands on an incoming call.
**Expected Webhooks:**
-
‘call.answered`
-
‘streaming.started`, `streaming.stopped` or `streaming.failed` if `stream_url` was set
When the ‘record` parameter is set to `record-from-answer`, the response will include a `recording_id` field.
stream_
115 116 117 118 119 120 121 122 123 124 |
# File 'lib/telnyx/resources/calls/actions.rb', line 115 def answer(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionAnswerParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/answer", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionAnswerResponse, options: ) end |
#bridge(call_control_id_to_bridge, call_control_id_to_bridge_with:, client_state: nil, command_id: nil, mute_dtmf: nil, park_after_unbridge: nil, play_ringtone: nil, queue: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, ringtone: nil, video_room_context: nil, video_room_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionBridgeResponse
Some parameter documentations has been truncated, see Models::Calls::ActionBridgeParams for more details.
Bridge two call control calls.
**Expected Webhooks:**
-
‘call.bridged` for Leg A
-
‘call.bridged` for Leg B
call_
182 183 184 185 186 187 188 189 190 191 |
# File 'lib/telnyx/resources/calls/actions.rb', line 182 def bridge(call_control_id_to_bridge, params) parsed, = Telnyx::Calls::ActionBridgeParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/bridge", call_control_id_to_bridge], body: parsed, model: Telnyx::Models::Calls::ActionBridgeResponse, options: ) end |
#enqueue(call_control_id, queue_name:, client_state: nil, command_id: nil, keep_after_hangup: nil, max_size: nil, max_wait_time_secs: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionEnqueueResponse
Some parameter documentations has been truncated, see Models::Calls::ActionEnqueueParams for more details.
Put the call in a queue.
219 220 221 222 223 224 225 226 227 228 |
# File 'lib/telnyx/resources/calls/actions.rb', line 219 def enqueue(call_control_id, params) parsed, = Telnyx::Calls::ActionEnqueueParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/enqueue", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionEnqueueResponse, options: ) end |
#gather(call_control_id, client_state: nil, command_id: nil, gather_id: nil, initial_timeout_millis: nil, inter_digit_timeout_millis: nil, maximum_digits: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherParams for more details.
Gather DTMF signals to build interactive menus.
You can pass a list of valid digits. The ‘Answer` command must be issued before the `gather` command.
**Expected Webhooks:**
-
‘call.dtmf.received` (you may receive many of these webhooks)
-
‘call.gather.ended`
272 273 274 275 276 277 278 279 280 281 |
# File 'lib/telnyx/resources/calls/actions.rb', line 272 def gather(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionGatherParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/gather", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionGatherResponse, options: ) end |
#gather_using_ai(call_control_id, parameters:, assistant: nil, client_state: nil, command_id: nil, greeting: nil, interruption_settings: nil, language: nil, message_history: nil, send_message_history_updates: nil, send_partial_results: nil, transcription: nil, user_response_timeout_ms: nil, voice: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingAIResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingAIParams for more details.
Gather parameters defined in the request payload using a voice assistant.
You can pass parameters described as a JSON Schema object and the voice assistant will attempt to gather these informations.
**Expected Webhooks:**
-
‘call.ai_gather.ended`
-
‘call.conversation.ended`
-
‘call.ai_gather.partial_results` (if `send_partial_results` is set to `true`)
-
‘call.ai_gather.message_history_updated` (if `send_message_history_updates` is set to `true`)
336 337 338 339 340 341 342 343 344 345 |
# File 'lib/telnyx/resources/calls/actions.rb', line 336 def gather_using_ai(call_control_id, params) parsed, = Telnyx::Calls::ActionGatherUsingAIParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/gather_using_ai", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionGatherUsingAIResponse, options: ) end |
#gather_using_audio(call_control_id, audio_url: nil, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_audio_url: nil, invalid_media_name: nil, maximum_digits: nil, maximum_tries: nil, media_name: nil, minimum_digits: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingAudioResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingAudioParams for more details.
Play an audio file on the call until the required DTMF signals are gathered to build interactive menus.
You can pass a list of valid digits along with an ‘invalid_audio_url’, which will be played back at the beginning of each prompt. Playback will be interrupted when a DTMF signal is received. The ‘Answer command must be issued before the `gather_using_audio` command.
**Expected Webhooks:**
-
‘call.playback.started`
-
‘call.playback.ended`
-
‘call.dtmf.received` (you may receive many of these webhooks)
-
‘call.gather.ended`
400 401 402 403 404 405 406 407 408 409 |
# File 'lib/telnyx/resources/calls/actions.rb', line 400 def gather_using_audio(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionGatherUsingAudioParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/gather_using_audio", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionGatherUsingAudioResponse, options: ) end |
#gather_using_speak(call_control_id, payload:, voice:, client_state: nil, command_id: nil, inter_digit_timeout_millis: nil, invalid_payload: nil, language: nil, maximum_digits: nil, maximum_tries: nil, minimum_digits: nil, payload_type: nil, service_level: nil, terminating_digit: nil, timeout_millis: nil, valid_digits: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionGatherUsingSpeakResponse
Some parameter documentations has been truncated, see Models::Calls::ActionGatherUsingSpeakParams for more details.
Convert text to speech and play it on the call until the required DTMF signals are gathered to build interactive menus.
You can pass a list of valid digits along with an ‘invalid_payload’, which will be played back at the beginning of each prompt. Speech will be interrupted when a DTMF signal is received. The ‘Answer` command must be issued before the `gather_using_speak` command.
**Expected Webhooks:**
-
‘call.dtmf.received` (you may receive many of these webhooks)
-
‘call.gather.ended`
‘valid_
469 470 471 472 473 474 475 476 477 478 |
# File 'lib/telnyx/resources/calls/actions.rb', line 469 def gather_using_speak(call_control_id, params) parsed, = Telnyx::Calls::ActionGatherUsingSpeakParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/gather_using_speak", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionGatherUsingSpeakResponse, options: ) end |
#hangup(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionHangupResponse
Some parameter documentations has been truncated, see Models::Calls::ActionHangupParams for more details.
Hang up the call.
**Expected Webhooks:**
-
‘call.hangup`
-
‘call.recording.saved`
503 504 505 506 507 508 509 510 511 512 |
# File 'lib/telnyx/resources/calls/actions.rb', line 503 def hangup(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionHangupParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/hangup", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionHangupResponse, options: ) end |
#leave_queue(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionLeaveQueueResponse
Some parameter documentations has been truncated, see Models::Calls::ActionLeaveQueueParams for more details.
Removes the call from a queue.
532 533 534 535 536 537 538 539 540 541 |
# File 'lib/telnyx/resources/calls/actions.rb', line 532 def leave_queue(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionLeaveQueueParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/leave_queue", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionLeaveQueueResponse, options: ) end |
#pause_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionPauseRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionPauseRecordingParams for more details.
Pause recording the call. Recording can be resumed via Resume recording command.
**Expected Webhooks:**
There are no webhooks associated with this command.
567 568 569 570 571 572 573 574 575 576 |
# File 'lib/telnyx/resources/calls/actions.rb', line 567 def pause_recording(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionPauseRecordingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/record_pause", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionPauseRecordingResponse, options: ) end |
#refer(call_control_id, sip_address:, client_state: nil, command_id: nil, custom_headers: nil, sip_auth_password: nil, sip_auth_username: nil, sip_headers: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionReferResponse
Some parameter documentations has been truncated, see Models::Calls::ActionReferParams for more details.
Initiate a SIP Refer on a Call Control call. You can initiate a SIP Refer at any point in the duration of a call.
**Expected Webhooks:**
-
‘call.refer.started`
-
‘call.refer.completed`
-
‘call.refer.failed`
613 614 615 616 617 618 619 620 621 622 |
# File 'lib/telnyx/resources/calls/actions.rb', line 613 def refer(call_control_id, params) parsed, = Telnyx::Calls::ActionReferParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/refer", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionReferResponse, options: ) end |
#reject(call_control_id, cause:, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionRejectResponse
Some parameter documentations has been truncated, see Models::Calls::ActionRejectParams for more details.
Reject an incoming call.
**Expected Webhooks:**
-
‘call.hangup`
648 649 650 651 652 653 654 655 656 657 |
# File 'lib/telnyx/resources/calls/actions.rb', line 648 def reject(call_control_id, params) parsed, = Telnyx::Calls::ActionRejectParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/reject", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionRejectResponse, options: ) end |
#resume_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionResumeRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionResumeRecordingParams for more details.
Resume recording the call.
**Expected Webhooks:**
There are no webhooks associated with this command.
683 684 685 686 687 688 689 690 691 692 |
# File 'lib/telnyx/resources/calls/actions.rb', line 683 def resume_recording(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionResumeRecordingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/record_resume", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionResumeRecordingResponse, options: ) end |
#send_dtmf(call_control_id, digits:, client_state: nil, command_id: nil, duration_millis: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSendDtmfResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSendDtmfParams for more details.
Sends DTMF tones from this leg. DTMF tones will be heard by the other end of the call.
**Expected Webhooks:**
There are no webhooks associated with this command.
us
722 723 724 725 726 727 728 729 730 731 |
# File 'lib/telnyx/resources/calls/actions.rb', line 722 def send_dtmf(call_control_id, params) parsed, = Telnyx::Calls::ActionSendDtmfParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/send_dtmf", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionSendDtmfResponse, options: ) end |
#send_sip_info(call_control_id, body:, content_type:, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSendSipInfoResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSendSipInfoParams for more details.
Sends SIP info from this leg.
**Expected Webhooks:**
-
‘call.sip_info.received` (to be received on the target call leg)
759 760 761 762 763 764 765 766 767 768 |
# File 'lib/telnyx/resources/calls/actions.rb', line 759 def send_sip_info(call_control_id, params) parsed, = Telnyx::Calls::ActionSendSipInfoParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/send_sip_info", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionSendSipInfoResponse, options: ) end |
#speak(call_control_id, payload:, voice:, client_state: nil, command_id: nil, language: nil, payload_type: nil, service_level: nil, stop: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSpeakResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSpeakParams for more details.
Convert text to speech and play it back on the call. If multiple speak text commands are issued consecutively, the audio files will be placed in a queue awaiting playback.
**Expected Webhooks:**
-
‘call.speak.started`
-
‘call.speak.ended`
809 810 811 812 813 814 815 816 817 818 |
# File 'lib/telnyx/resources/calls/actions.rb', line 809 def speak(call_control_id, params) parsed, = Telnyx::Calls::ActionSpeakParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/speak", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionSpeakResponse, options: ) end |
#start_ai_assistant(call_control_id, assistant: nil, client_state: nil, command_id: nil, greeting: nil, interruption_settings: nil, transcription: nil, voice: nil, voice_settings: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartAIAssistantResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartAIAssistantParams for more details.
Start an AI assistant on the call.
**Expected Webhooks:**
-
‘call.conversation.ended`
-
‘call.conversation_insights.generated`
855 856 857 858 859 860 861 862 863 864 |
# File 'lib/telnyx/resources/calls/actions.rb', line 855 def start_ai_assistant(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartAIAssistantParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/ai_assistant_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartAIAssistantResponse, options: ) end |
#start_forking(call_control_id, client_state: nil, command_id: nil, rx: nil, stream_type: nil, tx: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartForkingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartForkingParams for more details.
Call forking allows you to stream the media from a call to a specific target in realtime. This stream can be used to enable realtime audio analysis to support a variety of use cases, including fraud detection, or the creation of AI-generated audio responses. Requests must specify either the ‘target` attribute or the `rx` and `tx` attributes.
**Expected Webhooks:**
-
‘call.fork.started`
-
‘call.fork.stopped`
899 900 901 902 903 904 905 906 907 908 |
# File 'lib/telnyx/resources/calls/actions.rb', line 899 def start_forking(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartForkingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/fork_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartForkingResponse, options: ) end |
#start_noise_suppression(call_control_id, client_state: nil, command_id: nil, direction: nil, noise_suppression_engine: nil, noise_suppression_engine_config: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartNoiseSuppressionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartNoiseSuppressionParams for more details.
Noise Suppression Start (BETA)
934 935 936 937 938 939 940 941 942 943 |
# File 'lib/telnyx/resources/calls/actions.rb', line 934 def start_noise_suppression(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartNoiseSuppressionParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/suppression_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartNoiseSuppressionResponse, options: ) end |
#start_playback(call_control_id, audio_type: nil, audio_url: nil, cache_audio: nil, client_state: nil, command_id: nil, loop_: nil, media_name: nil, overlay: nil, playback_content: nil, stop: nil, target_legs: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartPlaybackResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartPlaybackParams for more details.
Play an audio file on the call. If multiple play audio commands are issued consecutively, the audio files will be placed in a queue awaiting playback.
Notes:
-
When ‘overlay` is enabled, `target_legs` is limited to `self`.
-
A customer cannot Play Audio with ‘overlay=true` unless there is a Play Audio with `overlay=false` actively playing.
**Expected Webhooks:**
-
‘call.playback.started`
-
‘call.playback.ended`
993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/telnyx/resources/calls/actions.rb', line 993 def start_playback(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartPlaybackParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/playback_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartPlaybackResponse, options: ) end |
#start_recording(call_control_id, channels:, format_:, client_state: nil, command_id: nil, custom_file_name: nil, max_length: nil, play_beep: nil, recording_track: nil, timeout_secs: nil, transcription: nil, transcription_engine: nil, transcription_language: nil, transcription_max_speaker_count: nil, transcription_min_speaker_count: nil, transcription_profanity_filter: nil, transcription_speaker_diarization: nil, trim: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartRecordingParams for more details.
Start recording the call. Recording will stop on call hang-up, or can be initiated via the Stop Recording command.
**Expected Webhooks:**
-
‘call.recording.saved`
-
‘call.recording.transcription.saved`
-
‘call.recording.error`
1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1059 def start_recording(call_control_id, params) parsed, = Telnyx::Calls::ActionStartRecordingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/record_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartRecordingResponse, options: ) end |
#start_siprec(call_control_id, client_state: nil, connector_name: nil, include_metadata_custom_headers: nil, secure: nil, session_timeout_secs: nil, sip_transport: nil, siprec_track: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartSiprecResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartSiprecParams for more details.
Start siprec session to configured in SIPREC connector SRS.
**Expected Webhooks:**
-
‘siprec.started`
-
‘siprec.stopped`
-
‘siprec.failed`
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1104 def start_siprec(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartSiprecParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/siprec_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartSiprecResponse, options: ) end |
#start_streaming(call_control_id, client_state: nil, command_id: nil, dialogflow_config: nil, enable_dialogflow: nil, stream_bidirectional_codec: nil, stream_bidirectional_mode: nil, stream_bidirectional_sampling_rate: nil, stream_bidirectional_target_legs: nil, stream_codec: nil, stream_track: nil, stream_url: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartStreamingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartStreamingParams for more details.
Start streaming the media from a call to a specific WebSocket address or Dialogflow connection in near-realtime. Audio will be delivered as base64-encoded RTP payload (raw audio), wrapped in JSON payloads.
Please find more details about media streaming messages specification under the [link](developers.telnyx.com/docs/voice/programmable-voice/media-streaming).
stream_
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1157 def start_streaming(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartStreamingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/streaming_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartStreamingResponse, options: ) end |
#start_transcription(call_control_id, client_state: nil, command_id: nil, transcription_engine: nil, transcription_engine_config: nil, transcription_tracks: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStartTranscriptionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStartTranscriptionParams for more details.
Start real-time transcription. Transcription will stop on call hang-up, or can be initiated via the Transcription stop command.
**Expected Webhooks:**
-
‘call.transcription`
1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1197 def start_transcription(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStartTranscriptionParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/transcription_start", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStartTranscriptionResponse, options: ) end |
#stop_ai_assistant(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopAIAssistantResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopAIAssistantParams for more details.
Stop an AI assistant on the call.
1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1226 def stop_ai_assistant(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopAIAssistantParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/ai_assistant_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopAIAssistantResponse, options: ) end |
#stop_forking(call_control_id, client_state: nil, command_id: nil, stream_type: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopForkingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopForkingParams for more details.
Stop forking a call.
**Expected Webhooks:**
-
‘call.fork.stopped`
1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1261 def stop_forking(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopForkingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/fork_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopForkingResponse, options: ) end |
#stop_gather(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopGatherResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopGatherParams for more details.
Stop current gather.
**Expected Webhooks:**
-
‘call.gather.ended`
1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1294 def stop_gather(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopGatherParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/gather_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopGatherResponse, options: ) end |
#stop_noise_suppression(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopNoiseSuppressionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopNoiseSuppressionParams for more details.
Noise Suppression Stop (BETA)
1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1323 def stop_noise_suppression(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopNoiseSuppressionParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/suppression_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopNoiseSuppressionResponse, options: ) end |
#stop_playback(call_control_id, client_state: nil, command_id: nil, overlay: nil, stop: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopPlaybackResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopPlaybackParams for more details.
Stop audio being played on the call.
**Expected Webhooks:**
-
‘call.playback.ended` or `call.speak.ended`
1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1360 def stop_playback(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopPlaybackParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/playback_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopPlaybackResponse, options: ) end |
#stop_recording(call_control_id, client_state: nil, command_id: nil, recording_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopRecordingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopRecordingParams for more details.
Stop recording the call.
**Expected Webhooks:**
-
‘call.recording.saved`
1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1395 def stop_recording(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopRecordingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/record_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopRecordingResponse, options: ) end |
#stop_siprec(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopSiprecResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopSiprecParams for more details.
Stop SIPREC session.
**Expected Webhooks:**
-
‘siprec.stopped`
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1428 def stop_siprec(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopSiprecParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/siprec_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopSiprecResponse, options: ) end |
#stop_streaming(call_control_id, client_state: nil, command_id: nil, stream_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopStreamingResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopStreamingParams for more details.
Stop streaming a call to a WebSocket.
**Expected Webhooks:**
-
‘streaming.stopped`
1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1463 def stop_streaming(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopStreamingParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/streaming_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopStreamingResponse, options: ) end |
#stop_transcription(call_control_id, client_state: nil, command_id: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionStopTranscriptionResponse
Some parameter documentations has been truncated, see Models::Calls::ActionStopTranscriptionParams for more details.
Stop real-time transcription.
1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1492 def stop_transcription(call_control_id, params = {}) parsed, = Telnyx::Calls::ActionStopTranscriptionParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/transcription_stop", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionStopTranscriptionResponse, options: ) end |
#switch_supervisor_role(call_control_id, role:, request_options: {}) ⇒ Telnyx::Models::Calls::ActionSwitchSupervisorRoleResponse
Some parameter documentations has been truncated, see Models::Calls::ActionSwitchSupervisorRoleParams for more details.
Switch the supervisor role for a bridged call. This allows switching between different supervisor modes during an active call
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1520 def switch_supervisor_role(call_control_id, params) parsed, = Telnyx::Calls::ActionSwitchSupervisorRoleParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/switch_supervisor_role", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionSwitchSupervisorRoleResponse, options: ) end |
#transfer(call_control_id, to:, answering_machine_detection: nil, answering_machine_detection_config: nil, audio_url: nil, client_state: nil, command_id: nil, custom_headers: nil, early_media: nil, from: nil, from_display_name: nil, media_encryption: nil, media_name: nil, mute_dtmf: nil, park_after_unbridge: nil, record: nil, record_channels: nil, record_custom_file_name: nil, record_format: nil, record_max_length: nil, record_timeout_secs: nil, record_track: nil, record_trim: nil, sip_auth_password: nil, sip_auth_username: nil, sip_headers: nil, sip_region: nil, sip_transport_protocol: nil, sound_modifications: nil, target_leg_client_state: nil, time_limit_secs: nil, timeout_secs: nil, webhook_url: nil, webhook_url_method: nil, request_options: {}) ⇒ Telnyx::Models::Calls::ActionTransferResponse
Some parameter documentations has been truncated, see Models::Calls::ActionTransferParams for more details.
Transfer a call to a new destination. If the transfer is unsuccessful, a ‘call.hangup` webhook for the other call (Leg B) will be sent indicating that the transfer could not be completed. The original call will remain active and may be issued additional commands, potentially transfering the call to an alternate destination.
**Expected Webhooks:**
-
‘call.initiated`
-
‘call.bridged` to Leg B
-
‘call.answered` or `call.hangup`
-
‘call.machine.detection.ended` if `answering_machine_detection` was requested
-
‘call.machine.greeting.ended` if `answering_machine_detection` was requested to detect the end of machine greeting
-
‘call.machine.premium.detection.ended` if `answering_machine_detection=premium` was requested
-
‘call.machine.premium.greeting.ended` if `answering_machine_detection=premium` was requested and a beep was detected
1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1628 def transfer(call_control_id, params) parsed, = Telnyx::Calls::ActionTransferParams.dump_request(params) @client.request( method: :post, path: ["calls/%1$s/actions/transfer", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionTransferResponse, options: ) end |
#update_client_state(call_control_id, client_state:, request_options: {}) ⇒ Telnyx::Models::Calls::ActionUpdateClientStateResponse
Some parameter documentations has been truncated, see Models::Calls::ActionUpdateClientStateParams for more details.
Updates client state
1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 |
# File 'lib/telnyx/resources/calls/actions.rb', line 1655 def update_client_state(call_control_id, params) parsed, = Telnyx::Calls::ActionUpdateClientStateParams.dump_request(params) @client.request( method: :put, path: ["calls/%1$s/actions/client_state_update", call_control_id], body: parsed, model: Telnyx::Models::Calls::ActionUpdateClientStateResponse, options: ) end |