Class: Telnyx::Resources::Conferences
- Inherits:
-
Object
- Object
- Telnyx::Resources::Conferences
- Defined in:
- lib/telnyx/resources/conferences.rb,
lib/telnyx/resources/conferences/actions.rb
Overview
Conference command operations
Defined Under Namespace
Classes: Actions
Instance Attribute Summary collapse
-
#actions ⇒ Telnyx::Resources::Conferences::Actions
readonly
Conference command operations.
Instance Method Summary collapse
-
#create(call_control_id:, name:, beep_enabled: nil, client_state: nil, comfort_noise: nil, command_id: nil, duration_minutes: nil, hold_audio_url: nil, hold_media_name: nil, max_participants: nil, region: nil, start_conference_on_create: nil, request_options: {}) ⇒ Telnyx::Models::ConferenceCreateResponse
Some parameter documentations has been truncated, see Models::ConferenceCreateParams for more details.
-
#initialize(client:) ⇒ Conferences
constructor
private
A new instance of Conferences.
-
#list(filter: nil, page_number: nil, page_size: nil, region: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::Conference>
Some parameter documentations has been truncated, see Models::ConferenceListParams for more details.
-
#list_participants(conference_id, filter: nil, page_number: nil, page_size: nil, region: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::ConferenceListParticipantsResponse>
Some parameter documentations has been truncated, see Models::ConferenceListParticipantsParams for more details.
-
#retrieve(id, region: nil, request_options: {}) ⇒ Telnyx::Models::ConferenceRetrieveResponse
Retrieve an existing conference.
-
#retrieve_participant(participant_id, id:, request_options: {}) ⇒ Telnyx::Models::ConferenceRetrieveParticipantResponse
Retrieve details of a specific conference participant by their ID or label.
-
#update_participant(participant_id, id:, beep_enabled: nil, end_conference_on_exit: nil, soft_end_conference_on_exit: nil, request_options: {}) ⇒ Telnyx::Models::ConferenceUpdateParticipantResponse
Some parameter documentations has been truncated, see Models::ConferenceUpdateParticipantParams for more details.
Constructor Details
#initialize(client:) ⇒ Conferences
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Conferences.
234 235 236 237 |
# File 'lib/telnyx/resources/conferences.rb', line 234 def initialize(client:) @client = client @actions = Telnyx::Resources::Conferences::Actions.new(client: client) end |
Instance Attribute Details
#actions ⇒ Telnyx::Resources::Conferences::Actions (readonly)
Conference command operations
9 10 11 |
# File 'lib/telnyx/resources/conferences.rb', line 9 def actions @actions end |
Instance Method Details
#create(call_control_id:, name:, beep_enabled: nil, client_state: nil, comfort_noise: nil, command_id: nil, duration_minutes: nil, hold_audio_url: nil, hold_media_name: nil, max_participants: nil, region: nil, start_conference_on_create: nil, request_options: {}) ⇒ Telnyx::Models::ConferenceCreateResponse
Some parameter documentations has been truncated, see Models::ConferenceCreateParams for more details.
Create a conference from an existing call leg using a ‘call_control_id` and a conference name. Upon creating the conference, the call will be automatically bridged to the conference. Conferences will expire after all participants have left the conference or after 4 hours regardless of the number of active participants.
**Expected Webhooks:**
-
‘conference.created`
-
‘conference.participant.joined`
-
‘conference.participant.left`
-
‘conference.ended`
-
‘conference.recording.saved`
-
‘conference.floor.changed`
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/telnyx/resources/conferences.rb', line 60 def create(params) parsed, = Telnyx::ConferenceCreateParams.dump_request(params) @client.request( method: :post, path: "conferences", body: parsed, model: Telnyx::Models::ConferenceCreateResponse, options: ) end |
#list(filter: nil, page_number: nil, page_size: nil, region: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::Conference>
Some parameter documentations has been truncated, see Models::ConferenceListParams for more details.
Lists conferences. Conferences are created on demand, and will expire after all participants have left the conference or after 4 hours regardless of the number of active participants. Conferences are listed in descending order by ‘expires_at`.
119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/telnyx/resources/conferences.rb', line 119 def list(params = {}) parsed, = Telnyx::ConferenceListParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "conferences", query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"), page: Telnyx::Internal::DefaultFlatPagination, model: Telnyx::Conference, options: ) end |
#list_participants(conference_id, filter: nil, page_number: nil, page_size: nil, region: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::ConferenceListParticipantsResponse>
Some parameter documentations has been truncated, see Models::ConferenceListParticipantsParams for more details.
Lists conference participants
154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/telnyx/resources/conferences.rb', line 154 def list_participants(conference_id, params = {}) parsed, = Telnyx::ConferenceListParticipantsParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["conferences/%1$s/participants", conference_id], query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"), page: Telnyx::Internal::DefaultFlatPagination, model: Telnyx::Models::ConferenceListParticipantsResponse, options: ) end |
#retrieve(id, region: nil, request_options: {}) ⇒ Telnyx::Models::ConferenceRetrieveResponse
Retrieve an existing conference
84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/telnyx/resources/conferences.rb', line 84 def retrieve(id, params = {}) parsed, = Telnyx::ConferenceRetrieveParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["conferences/%1$s", id], query: query, model: Telnyx::Models::ConferenceRetrieveResponse, options: ) end |
#retrieve_participant(participant_id, id:, request_options: {}) ⇒ Telnyx::Models::ConferenceRetrieveParticipantResponse
Retrieve details of a specific conference participant by their ID or label.
180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/telnyx/resources/conferences.rb', line 180 def retrieve_participant(participant_id, params) parsed, = Telnyx::ConferenceRetrieveParticipantParams.dump_request(params) id = parsed.delete(:id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["conferences/%1$s/participants/%2$s", id, participant_id], model: Telnyx::Models::ConferenceRetrieveParticipantResponse, options: ) end |
#update_participant(participant_id, id:, beep_enabled: nil, end_conference_on_exit: nil, soft_end_conference_on_exit: nil, request_options: {}) ⇒ Telnyx::Models::ConferenceUpdateParticipantResponse
Some parameter documentations has been truncated, see Models::ConferenceUpdateParticipantParams for more details.
Update properties of a conference participant.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/telnyx/resources/conferences.rb', line 216 def update_participant(participant_id, params) parsed, = Telnyx::ConferenceUpdateParticipantParams.dump_request(params) id = parsed.delete(:id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :patch, path: ["conferences/%1$s/participants/%2$s", id, participant_id], body: parsed, model: Telnyx::Models::ConferenceUpdateParticipantResponse, options: ) end |