Class: Telnyx::Resources::Legacy::Reporting::BatchDetailRecords::SpeechToText
- Inherits:
-
Object
- Object
- Telnyx::Resources::Legacy::Reporting::BatchDetailRecords::SpeechToText
- Defined in:
- lib/telnyx/resources/legacy/reporting/batch_detail_records/speech_to_text.rb
Overview
Speech to text batch detail records
Instance Method Summary collapse
-
#create(end_date:, start_date:, request_options: {}) ⇒ Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextCreateResponse
Creates a new Speech to Text batch report request with the specified filters.
-
#delete(id, request_options: {}) ⇒ Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextDeleteResponse
Deletes a specific Speech to Text batch report request by ID.
-
#initialize(client:) ⇒ SpeechToText
constructor
private
A new instance of SpeechToText.
-
#list(request_options: {}) ⇒ Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextListResponse
Retrieves all Speech to Text batch report requests for the authenticated user.
-
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextRetrieveResponse
Retrieves a specific Speech to Text batch report request by ID.
Constructor Details
#initialize(client:) ⇒ SpeechToText
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of SpeechToText.
94 95 96 |
# File 'lib/telnyx/resources/legacy/reporting/batch_detail_records/speech_to_text.rb', line 94 def initialize(client:) @client = client end |
Instance Method Details
#create(end_date:, start_date:, request_options: {}) ⇒ Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextCreateResponse
Creates a new Speech to Text batch report request with the specified filters
23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/telnyx/resources/legacy/reporting/batch_detail_records/speech_to_text.rb', line 23 def create(params) parsed, = Telnyx::Legacy::Reporting::BatchDetailRecords::SpeechToTextCreateParams.dump_request(params) @client.request( method: :post, path: "legacy/reporting/batch_detail_records/speech_to_text", body: parsed, model: Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextCreateResponse, options: ) end |
#delete(id, request_options: {}) ⇒ Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextDeleteResponse
Deletes a specific Speech to Text batch report request by ID
82 83 84 85 86 87 88 89 |
# File 'lib/telnyx/resources/legacy/reporting/batch_detail_records/speech_to_text.rb', line 82 def delete(id, params = {}) @client.request( method: :delete, path: ["legacy/reporting/batch_detail_records/speech_to_text/%1$s", id], model: Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextDeleteResponse, options: params[:request_options] ) end |
#list(request_options: {}) ⇒ Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextListResponse
Retrieves all Speech to Text batch report requests for the authenticated user
63 64 65 66 67 68 69 70 |
# File 'lib/telnyx/resources/legacy/reporting/batch_detail_records/speech_to_text.rb', line 63 def list(params = {}) @client.request( method: :get, path: "legacy/reporting/batch_detail_records/speech_to_text", model: Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextListResponse, options: params[:request_options] ) end |
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextRetrieveResponse
Retrieves a specific Speech to Text batch report request by ID
45 46 47 48 49 50 51 52 |
# File 'lib/telnyx/resources/legacy/reporting/batch_detail_records/speech_to_text.rb', line 45 def retrieve(id, params = {}) @client.request( method: :get, path: ["legacy/reporting/batch_detail_records/speech_to_text/%1$s", id], model: Telnyx::Models::Legacy::Reporting::BatchDetailRecords::SpeechToTextRetrieveResponse, options: params[:request_options] ) end |