Class: Telnyx::Resources::MeetingSessions::Artifacts
- Inherits:
-
Object
- Object
- Telnyx::Resources::MeetingSessions::Artifacts
- Defined in:
- lib/telnyx/resources/meeting_sessions/artifacts.rb,
sig/telnyx/resources/meeting_sessions/artifacts.rbs
Overview
Create and retrieve asynchronous summaries and action-item artifacts.
Instance Method Summary collapse
-
#create(id, type:, request_options: {}) ⇒ Telnyx::Models::MeetingSessions::MeetingSessionArtifactResponse
Requests asynchronous generation of one
summaryoraction_itemsartifact. -
#initialize(client:) ⇒ Artifacts
constructor
private
A new instance of Artifacts.
-
#list(id, request_options: {}) ⇒ Telnyx::Models::MeetingSessions::ArtifactListResponse
Returns a list of artifacts for a meeting session.
-
#retrieve(artifact_id, id:, request_options: {}) ⇒ Telnyx::Models::MeetingSessions::MeetingSessionArtifactResponse
Retrieves a single meeting session artifact by ID.
Constructor Details
#initialize(client:) ⇒ Artifacts
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Artifacts.
86 87 88 |
# File 'lib/telnyx/resources/meeting_sessions/artifacts.rb', line 86 def initialize(client:) @client = client end |
Instance Method Details
#create(id, type:, request_options: {}) ⇒ Telnyx::Models::MeetingSessions::MeetingSessionArtifactResponse
Requests asynchronous generation of one summary or action_items artifact.
Each type requires its own request. Generation requires transcript content and
configured inference and currently reads at most the first 10,000 segments, so
exceptionally long transcripts may produce incomplete artifacts or fail model
limits.
25 26 27 28 29 30 31 32 33 34 |
# File 'lib/telnyx/resources/meeting_sessions/artifacts.rb', line 25 def create(id, params) parsed, = Telnyx::MeetingSessions::ArtifactCreateParams.dump_request(params) @client.request( method: :post, path: ["meeting_sessions/%1$s/artifacts", id], body: parsed, model: Telnyx::MeetingSessions::MeetingSessionArtifactResponse, options: ) end |
#list(id, request_options: {}) ⇒ Telnyx::Models::MeetingSessions::ArtifactListResponse
Returns a list of artifacts for a meeting session.
74 75 76 77 78 79 80 81 |
# File 'lib/telnyx/resources/meeting_sessions/artifacts.rb', line 74 def list(id, params = {}) @client.request( method: :get, path: ["meeting_sessions/%1$s/artifacts", id], model: Telnyx::Models::MeetingSessions::ArtifactListResponse, options: params[:request_options] ) end |
#retrieve(artifact_id, id:, request_options: {}) ⇒ Telnyx::Models::MeetingSessions::MeetingSessionArtifactResponse
Retrieves a single meeting session artifact by ID.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/telnyx/resources/meeting_sessions/artifacts.rb', line 49 def retrieve(artifact_id, params) parsed, = Telnyx::MeetingSessions::ArtifactRetrieveParams.dump_request(params) id = parsed.delete(:id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["meeting_sessions/%1$s/artifacts/%2$s", id, artifact_id], model: Telnyx::MeetingSessions::MeetingSessionArtifactResponse, options: ) end |