Class: Telnyx::Resources::Messaging10dlc::CampaignBuilder
- Inherits:
-
Object
- Object
- Telnyx::Resources::Messaging10dlc::CampaignBuilder
- Defined in:
- lib/telnyx/resources/messaging_10dlc/campaign_builder.rb,
lib/telnyx/resources/messaging_10dlc/campaign_builder/brand.rb
Overview
Campaign operations
Defined Under Namespace
Classes: Brand
Instance Attribute Summary collapse
-
#brand ⇒ Telnyx::Resources::Messaging10dlc::CampaignBuilder::Brand
readonly
Campaign operations.
Instance Method Summary collapse
-
#initialize(client:) ⇒ CampaignBuilder
constructor
private
A new instance of CampaignBuilder.
-
#submit(brand_id:, description:, usecase:, age_gated: nil, auto_renewal: nil, direct_lending: nil, embedded_link: nil, embedded_link_sample: nil, embedded_phone: nil, help_keywords: nil, help_message: nil, message_flow: nil, mno_ids: nil, number_pool: nil, optin_keywords: nil, optin_message: nil, optout_keywords: nil, optout_message: nil, privacy_policy_link: nil, reference_id: nil, reseller_id: nil, sample1: nil, sample2: nil, sample3: nil, sample4: nil, sample5: nil, subscriber_help: nil, subscriber_optin: nil, subscriber_optout: nil, sub_usecases: nil, tag: nil, terms_and_conditions: nil, terms_and_conditions_link: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Telnyx::Models::Messaging10dlc::TelnyxCampaignCsp
Some parameter documentations has been truncated, see Models::Messaging10dlc::CampaignBuilderSubmitParams for more details.
Constructor Details
#initialize(client:) ⇒ CampaignBuilder
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of CampaignBuilder.
115 116 117 118 |
# File 'lib/telnyx/resources/messaging_10dlc/campaign_builder.rb', line 115 def initialize(client:) @client = client @brand = Telnyx::Resources::Messaging10dlc::CampaignBuilder::Brand.new(client: client) end |
Instance Attribute Details
#brand ⇒ Telnyx::Resources::Messaging10dlc::CampaignBuilder::Brand (readonly)
Campaign operations
10 11 12 |
# File 'lib/telnyx/resources/messaging_10dlc/campaign_builder.rb', line 10 def brand @brand end |
Instance Method Details
#submit(brand_id:, description:, usecase:, age_gated: nil, auto_renewal: nil, direct_lending: nil, embedded_link: nil, embedded_link_sample: nil, embedded_phone: nil, help_keywords: nil, help_message: nil, message_flow: nil, mno_ids: nil, number_pool: nil, optin_keywords: nil, optin_message: nil, optout_keywords: nil, optout_message: nil, privacy_policy_link: nil, reference_id: nil, reseller_id: nil, sample1: nil, sample2: nil, sample3: nil, sample4: nil, sample5: nil, subscriber_help: nil, subscriber_optin: nil, subscriber_optout: nil, sub_usecases: nil, tag: nil, terms_and_conditions: nil, terms_and_conditions_link: nil, webhook_failover_url: nil, webhook_url: nil, request_options: {}) ⇒ Telnyx::Models::Messaging10dlc::TelnyxCampaignCsp
Some parameter documentations has been truncated, see Models::Messaging10dlc::CampaignBuilderSubmitParams for more details.
Before creating a campaign, use the [Qualify By Usecase endpoint](developers.telnyx.com/api-reference/campaign/qualify-by-usecase) to ensure that the brand you want to assign a new campaign to is qualified for the desired use case of that campaign. **Please note:** After campaign creation, you’ll only be able to edit the campaign’s sample messages. Creating a campaign will entail an upfront, non-refundable three month’s cost that will depend on the campaign’s use case ([see 10DLC Costs section for details](developers.telnyx.com/api-reference/campaign/get-campaign-cost)).
101 102 103 104 105 106 107 108 109 110 |
# File 'lib/telnyx/resources/messaging_10dlc/campaign_builder.rb', line 101 def submit(params) parsed, = Telnyx::Messaging10dlc::CampaignBuilderSubmitParams.dump_request(params) @client.request( method: :post, path: "10dlc/campaignBuilder", body: parsed, model: Telnyx::Messaging10dlc::TelnyxCampaignCsp, options: ) end |