Class: Telnyx::Resources::MessagingHostedNumberOrders
- Inherits:
-
Object
- Object
- Telnyx::Resources::MessagingHostedNumberOrders
- Defined in:
- lib/telnyx/resources/messaging_hosted_number_orders.rb,
lib/telnyx/resources/messaging_hosted_number_orders/actions.rb
Defined Under Namespace
Classes: Actions
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#check_eligibility(phone_numbers:, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderCheckEligibilityResponse
Check hosted messaging eligibility.
-
#create(messaging_profile_id: nil, phone_numbers: nil, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderCreateResponse
Some parameter documentations has been truncated, see Models::MessagingHostedNumberOrderCreateParams for more details.
-
#create_verification_codes(id, phone_numbers:, verification_method:, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderCreateVerificationCodesResponse
Create verification codes to validate numbers of the hosted order.
-
#delete(id, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderDeleteResponse
Delete a messaging hosted number order and all associated phone numbers.
-
#initialize(client:) ⇒ MessagingHostedNumberOrders
constructor
private
A new instance of MessagingHostedNumberOrders.
-
#list(page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::MessagingHostedNumberOrder>
List messaging hosted number orders.
-
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderRetrieveResponse
Retrieve a messaging hosted number order.
-
#validate_codes(id, verification_codes:, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderValidateCodesResponse
Validate the verification codes sent to the numbers of the hosted order.
Constructor Details
#initialize(client:) ⇒ MessagingHostedNumberOrders
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of MessagingHostedNumberOrders.
176 177 178 179 |
# File 'lib/telnyx/resources/messaging_hosted_number_orders.rb', line 176 def initialize(client:) @client = client @actions = Telnyx::Resources::MessagingHostedNumberOrders::Actions.new(client: client) end |
Instance Attribute Details
#actions ⇒ Telnyx::Resources::MessagingHostedNumberOrders::Actions (readonly)
7 8 9 |
# File 'lib/telnyx/resources/messaging_hosted_number_orders.rb', line 7 def actions @actions end |
Instance Method Details
#check_eligibility(phone_numbers:, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderCheckEligibilityResponse
Check hosted messaging eligibility
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/telnyx/resources/messaging_hosted_number_orders.rb', line 110 def check_eligibility(params) parsed, = Telnyx::MessagingHostedNumberOrderCheckEligibilityParams.dump_request(params) @client.request( method: :post, path: "messaging_hosted_number_orders/eligibility_numbers_check", body: parsed, model: Telnyx::Models::MessagingHostedNumberOrderCheckEligibilityResponse, options: ) end |
#create(messaging_profile_id: nil, phone_numbers: nil, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderCreateResponse
Some parameter documentations has been truncated, see Models::MessagingHostedNumberOrderCreateParams for more details.
Create a messaging hosted number order
25 26 27 28 29 30 31 32 33 34 |
# File 'lib/telnyx/resources/messaging_hosted_number_orders.rb', line 25 def create(params = {}) parsed, = Telnyx::MessagingHostedNumberOrderCreateParams.dump_request(params) @client.request( method: :post, path: "messaging_hosted_number_orders", body: parsed, model: Telnyx::Models::MessagingHostedNumberOrderCreateResponse, options: ) end |
#create_verification_codes(id, phone_numbers:, verification_method:, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderCreateVerificationCodesResponse
Create verification codes to validate numbers of the hosted order. The verification codes will be sent to the numbers of the hosted order.
137 138 139 140 141 142 143 144 145 146 |
# File 'lib/telnyx/resources/messaging_hosted_number_orders.rb', line 137 def create_verification_codes(id, params) parsed, = Telnyx::MessagingHostedNumberOrderCreateVerificationCodesParams.dump_request(params) @client.request( method: :post, path: ["messaging_hosted_number_orders/%1$s/verification_codes", id], body: parsed, model: Telnyx::Models::MessagingHostedNumberOrderCreateVerificationCodesResponse, options: ) end |
#delete(id, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderDeleteResponse
Delete a messaging hosted number order and all associated phone numbers.
90 91 92 93 94 95 96 97 |
# File 'lib/telnyx/resources/messaging_hosted_number_orders.rb', line 90 def delete(id, params = {}) @client.request( method: :delete, path: ["messaging_hosted_number_orders/%1$s", id], model: Telnyx::Models::MessagingHostedNumberOrderDeleteResponse, options: params[:request_options] ) end |
#list(page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::MessagingHostedNumberOrder>
List messaging hosted number orders
67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/telnyx/resources/messaging_hosted_number_orders.rb', line 67 def list(params = {}) parsed, = Telnyx::MessagingHostedNumberOrderListParams.dump_request(params) @client.request( method: :get, path: "messaging_hosted_number_orders", query: parsed.transform_keys(page_number: "page[number]", page_size: "page[size]"), page: Telnyx::Internal::DefaultFlatPagination, model: Telnyx::MessagingHostedNumberOrder, options: ) end |
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderRetrieveResponse
Retrieve a messaging hosted number order
47 48 49 50 51 52 53 54 |
# File 'lib/telnyx/resources/messaging_hosted_number_orders.rb', line 47 def retrieve(id, params = {}) @client.request( method: :get, path: ["messaging_hosted_number_orders/%1$s", id], model: Telnyx::Models::MessagingHostedNumberOrderRetrieveResponse, options: params[:request_options] ) end |
#validate_codes(id, verification_codes:, request_options: {}) ⇒ Telnyx::Models::MessagingHostedNumberOrderValidateCodesResponse
Validate the verification codes sent to the numbers of the hosted order. The verification codes must be created in the verification codes endpoint.
162 163 164 165 166 167 168 169 170 171 |
# File 'lib/telnyx/resources/messaging_hosted_number_orders.rb', line 162 def validate_codes(id, params) parsed, = Telnyx::MessagingHostedNumberOrderValidateCodesParams.dump_request(params) @client.request( method: :post, path: ["messaging_hosted_number_orders/%1$s/validation_codes", id], body: parsed, model: Telnyx::Models::MessagingHostedNumberOrderValidateCodesResponse, options: ) end |