Class: Telnyx::Resources::Porting::Events
- Inherits:
-
Object
- Object
- Telnyx::Resources::Porting::Events
- Defined in:
- lib/telnyx/resources/porting/events.rb,
sig/telnyx/resources/porting/events.rbs
Overview
Endpoints related to porting orders management.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Events
constructor
private
A new instance of Events.
-
#list(filter: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::Porting::PortingEventDeletedPayload, Telnyx::Models::Porting::PortingEventMessagingChangedPayload, Telnyx::Models::Porting::PortingEventStatusChangedEvent, Telnyx::Models::Porting::PortingEventNewCommentEvent, Telnyx::Models::Porting::PortingEventSplitEvent, Telnyx::Models::Porting::PortingEventWithoutWebhook>
Some parameter documentations has been truncated, see Models::Porting::EventListParams for more details.
-
#republish(id, request_options: {}) ⇒ nil
Republishes the specified porting event, triggering re-delivery of the corresponding webhook to your account.
-
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::Porting::EventRetrieveResponse
Returns the details of a single porting event, including its type and payload.
Constructor Details
#initialize(client:) ⇒ Events
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Events.
85 86 87 |
# File 'lib/telnyx/resources/porting/events.rb', line 85 def initialize(client:) @client = client end |
Instance Method Details
#list(filter: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::Porting::PortingEventDeletedPayload, Telnyx::Models::Porting::PortingEventMessagingChangedPayload, Telnyx::Models::Porting::PortingEventStatusChangedEvent, Telnyx::Models::Porting::PortingEventNewCommentEvent, Telnyx::Models::Porting::PortingEventSplitEvent, Telnyx::Models::Porting::PortingEventWithoutWebhook>
Some parameter documentations has been truncated, see Models::Porting::EventListParams for more details.
Returns a paginated list of porting-related events on your account, such as status changes on porting orders. Supports filtering and is useful for auditing or reconciling webhook deliveries.
48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/telnyx/resources/porting/events.rb', line 48 def list(params = {}) parsed, = Telnyx::Porting::EventListParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "porting/events", query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"), page: Telnyx::Internal::DefaultFlatPagination, model: Telnyx::Porting::PortingEvent, options: ) end |
#republish(id, request_options: {}) ⇒ nil
Republishes the specified porting event, triggering re-delivery of the corresponding webhook to your account.
73 74 75 76 77 78 79 80 |
# File 'lib/telnyx/resources/porting/events.rb', line 73 def republish(id, params = {}) @client.request( method: :post, path: ["porting/events/%1$s/republish", id], model: NilClass, options: params[:request_options] ) end |
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::Porting::EventRetrieveResponse
Returns the details of a single porting event, including its type and payload.
19 20 21 22 23 24 25 26 |
# File 'lib/telnyx/resources/porting/events.rb', line 19 def retrieve(id, params = {}) @client.request( method: :get, path: ["porting/events/%1$s", id], model: Telnyx::Models::Porting::EventRetrieveResponse, options: params[:request_options] ) end |