Class: Telnyx::Resources::PublicInternetGateways
- Inherits:
-
Object
- Object
- Telnyx::Resources::PublicInternetGateways
- Defined in:
- lib/telnyx/resources/public_internet_gateways.rb,
sig/telnyx/resources/public_internet_gateways.rbs
Overview
Public Internet Gateway operations
Instance Method Summary collapse
-
#create(body:, request_options: {}) ⇒ Telnyx::Models::PublicInternetGatewayCreateResponse
Requests creation of a public internet gateway on the specified network, giving the network internet egress.
-
#delete(id, request_options: {}) ⇒ Telnyx::Models::PublicInternetGatewayDeleteResponse
Deletes the specified public internet gateway, removing internet egress through it.
-
#initialize(client:) ⇒ PublicInternetGateways
constructor
private
A new instance of PublicInternetGateways.
-
#list(filter: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::PublicInternetGatewayRead>
Some parameter documentations has been truncated, see Models::PublicInternetGatewayListParams for more details.
-
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::PublicInternetGatewayRetrieveResponse
Returns the details of a single public internet gateway by its identifier.
Constructor Details
#initialize(client:) ⇒ PublicInternetGateways
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of PublicInternetGateways.
106 107 108 |
# File 'lib/telnyx/resources/public_internet_gateways.rb', line 106 def initialize(client:) @client = client end |
Instance Method Details
#create(body:, request_options: {}) ⇒ Telnyx::Models::PublicInternetGatewayCreateResponse
Requests creation of a public internet gateway on the specified network, giving the network internet egress. Creation is asynchronous, so the request is accepted and completes in the background.
19 20 21 22 23 24 25 26 27 28 |
# File 'lib/telnyx/resources/public_internet_gateways.rb', line 19 def create(params) parsed, = Telnyx::PublicInternetGatewayCreateParams.dump_request(params) @client.request( method: :post, path: "public_internet_gateways", body: parsed[:body], model: Telnyx::Models::PublicInternetGatewayCreateResponse, options: ) end |
#delete(id, request_options: {}) ⇒ Telnyx::Models::PublicInternetGatewayDeleteResponse
Deletes the specified public internet gateway, removing internet egress through it.
94 95 96 97 98 99 100 101 |
# File 'lib/telnyx/resources/public_internet_gateways.rb', line 94 def delete(id, params = {}) @client.request( method: :delete, path: ["public_internet_gateways/%1$s", id], model: Telnyx::Models::PublicInternetGatewayDeleteResponse, options: params[:request_options] ) end |
#list(filter: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::PublicInternetGatewayRead>
Some parameter documentations has been truncated, see Models::PublicInternetGatewayListParams for more details.
Returns a paginated list of the public internet gateways on your account, with support for filtering.
69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/telnyx/resources/public_internet_gateways.rb', line 69 def list(params = {}) parsed, = Telnyx::PublicInternetGatewayListParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "public_internet_gateways", query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"), page: Telnyx::Internal::DefaultFlatPagination, model: Telnyx::PublicInternetGatewayRead, options: ) end |
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::PublicInternetGatewayRetrieveResponse
Returns the details of a single public internet gateway by its identifier.
41 42 43 44 45 46 47 48 |
# File 'lib/telnyx/resources/public_internet_gateways.rb', line 41 def retrieve(id, params = {}) @client.request( method: :get, path: ["public_internet_gateways/%1$s", id], model: Telnyx::Models::PublicInternetGatewayRetrieveResponse, options: params[:request_options] ) end |