Class: Telnyx::Resources::Rcs::Brands
- Inherits:
-
Object
- Object
- Telnyx::Resources::Rcs::Brands
- Defined in:
- lib/telnyx/resources/rcs/brands.rb,
sig/telnyx/resources/rcs/brands.rbs
Overview
Manage the legal business entities that operate RCS agents.
Instance Method Summary collapse
-
#create(addresses:, contacts:, display_name:, identifiers:, legal_entity_type:, legal_name:, organization_type:, website_url:, profile_id: nil, request_options: {}) ⇒ Telnyx::Models::Rcs::BrandResponse
Some parameter documentations has been truncated, see Models::Rcs::BrandCreateParams for more details.
-
#initialize(client:) ⇒ Brands
constructor
private
A new instance of Brands.
-
#list(request_options: {}) ⇒ Array<Telnyx::Models::Rcs::BrandResponse>
Lists RCS brands owned by the authenticated organization.
-
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::Rcs::BrandResponse
Retrieves an RCS brand and its current lifecycle status.
-
#submit(id, request_options: {}) ⇒ Telnyx::Models::Rcs::BrandResponse
Starts asynchronous provider provisioning and external review for a brand.
-
#update(id, addresses: nil, contacts: nil, display_name: nil, identifiers: nil, legal_entity_type: nil, legal_name: nil, organization_type: nil, profile_id: nil, website_url: nil, request_options: {}) ⇒ Telnyx::Models::Rcs::BrandResponse
Some parameter documentations has been truncated, see Models::Rcs::BrandUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ Brands
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Brands.
157 158 159 |
# File 'lib/telnyx/resources/rcs/brands.rb', line 157 def initialize(client:) @client = client end |
Instance Method Details
#create(addresses:, contacts:, display_name:, identifiers:, legal_entity_type:, legal_name:, organization_type:, website_url:, profile_id: nil, request_options: {}) ⇒ Telnyx::Models::Rcs::BrandResponse
Some parameter documentations has been truncated, see Models::Rcs::BrandCreateParams for more details.
Creates an editable RCS brand draft. Creating the draft does not begin external review.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/telnyx/resources/rcs/brands.rb', line 39 def create(params) parsed, = Telnyx::Rcs::BrandCreateParams.dump_request(params) @client.request( method: :post, path: "rcs/brands", body: parsed, model: Telnyx::Rcs::BrandResponse, options: ) end |
#list(request_options: {}) ⇒ Array<Telnyx::Models::Rcs::BrandResponse>
Lists RCS brands owned by the authenticated organization.
123 124 125 126 127 128 129 130 |
# File 'lib/telnyx/resources/rcs/brands.rb', line 123 def list(params = {}) @client.request( method: :get, path: "rcs/brands", model: Telnyx::Internal::Type::ArrayOf[Telnyx::Rcs::BrandResponse], options: params[:request_options] ) end |
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::Rcs::BrandResponse
Retrieves an RCS brand and its current lifecycle status.
61 62 63 64 65 66 67 68 |
# File 'lib/telnyx/resources/rcs/brands.rb', line 61 def retrieve(id, params = {}) @client.request( method: :get, path: ["rcs/brands/%1$s", id], model: Telnyx::Rcs::BrandResponse, options: params[:request_options] ) end |
#submit(id, request_options: {}) ⇒ Telnyx::Models::Rcs::BrandResponse
Starts asynchronous provider provisioning and external review for a brand. Repeating this request for an in-progress brand returns its current state without creating new work.
145 146 147 148 149 150 151 152 |
# File 'lib/telnyx/resources/rcs/brands.rb', line 145 def submit(id, params = {}) @client.request( method: :post, path: ["rcs/brands/%1$s/submit", id], model: Telnyx::Rcs::BrandResponse, options: params[:request_options] ) end |
#update(id, addresses: nil, contacts: nil, display_name: nil, identifiers: nil, legal_entity_type: nil, legal_name: nil, organization_type: nil, profile_id: nil, website_url: nil, request_options: {}) ⇒ Telnyx::Models::Rcs::BrandResponse
Some parameter documentations has been truncated, see Models::Rcs::BrandUpdateParams for more details.
Updates one or more fields on a brand while its status is CREATED. Submitted
brands cannot be changed.
103 104 105 106 107 108 109 110 111 112 |
# File 'lib/telnyx/resources/rcs/brands.rb', line 103 def update(id, params = {}) parsed, = Telnyx::Rcs::BrandUpdateParams.dump_request(params) @client.request( method: :patch, path: ["rcs/brands/%1$s", id], body: parsed, model: Telnyx::Rcs::BrandResponse, options: ) end |