Class: Telnyx::Resources::SessionAnalysis
- Inherits:
-
Object
- Object
- Telnyx::Resources::SessionAnalysis
- Defined in:
- lib/telnyx/resources/session_analysis.rb,
lib/telnyx/resources/session_analysis/metadata.rb
Overview
Analyze voice AI sessions, costs, and event hierarchies across Telnyx products.
Defined Under Namespace
Classes: Metadata
Instance Attribute Summary collapse
-
#metadata ⇒ Telnyx::Resources::SessionAnalysis::Metadata
readonly
Analyze voice AI sessions, costs, and event hierarchies across Telnyx products.
Instance Method Summary collapse
-
#initialize(client:) ⇒ SessionAnalysis
constructor
private
A new instance of SessionAnalysis.
-
#retrieve(event_id, record_type:, date_time: nil, expand: nil, include_children: nil, max_depth: nil, request_options: {}) ⇒ Telnyx::Models::SessionAnalysisRetrieveResponse
Some parameter documentations has been truncated, see Models::SessionAnalysisRetrieveParams for more details.
Constructor Details
#initialize(client:) ⇒ SessionAnalysis
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of SessionAnalysis.
55 56 57 58 |
# File 'lib/telnyx/resources/session_analysis.rb', line 55 def initialize(client:) @client = client @metadata = Telnyx::Resources::SessionAnalysis::Metadata.new(client: client) end |
Instance Attribute Details
#metadata ⇒ Telnyx::Resources::SessionAnalysis::Metadata (readonly)
Analyze voice AI sessions, costs, and event hierarchies across Telnyx products.
9 10 11 |
# File 'lib/telnyx/resources/session_analysis.rb', line 9 def @metadata end |
Instance Method Details
#retrieve(event_id, record_type:, date_time: nil, expand: nil, include_children: nil, max_depth: nil, request_options: {}) ⇒ Telnyx::Models::SessionAnalysisRetrieveResponse
Some parameter documentations has been truncated, see Models::SessionAnalysisRetrieveParams for more details.
Retrieves a full session analysis tree for a given event, including costs, child events, and product linkages.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/telnyx/resources/session_analysis.rb', line 36 def retrieve(event_id, params) parsed, = Telnyx::SessionAnalysisRetrieveParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) record_type = parsed.delete(:record_type) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["session_analysis/%1$s/%2$s", record_type, event_id], query: query, model: Telnyx::Models::SessionAnalysisRetrieveResponse, options: ) end |