Class: Telnyx::Resources::SipRegistrationStatus
- Inherits:
-
Object
- Object
- Telnyx::Resources::SipRegistrationStatus
- Defined in:
- lib/telnyx/resources/sip_registration_status.rb
Overview
UAC connection operations
Instance Method Summary collapse
-
#initialize(client:) ⇒ SipRegistrationStatus
constructor
private
A new instance of SipRegistrationStatus.
-
#retrieve(connection_id:, credential_type:, request_options: {}) ⇒ Telnyx::Models::SipRegistrationStatusRetrieveResponse
Some parameter documentations has been truncated, see Models::SipRegistrationStatusRetrieveParams for more details.
Constructor Details
#initialize(client:) ⇒ SipRegistrationStatus
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of SipRegistrationStatus.
40 41 42 |
# File 'lib/telnyx/resources/sip_registration_status.rb', line 40 def initialize(client:) @client = client end |
Instance Method Details
#retrieve(connection_id:, credential_type:, request_options: {}) ⇒ Telnyx::Models::SipRegistrationStatusRetrieveResponse
Some parameter documentations has been truncated, see Models::SipRegistrationStatusRetrieveParams for more details.
Returns the live SIP registration state of a UAC connection: whether it is currently registered, when it last registered, and the last response Telnyx received from the registrar. Only ‘uac_external_credential` is supported today.
25 26 27 28 29 30 31 32 33 34 35 |
# File 'lib/telnyx/resources/sip_registration_status.rb', line 25 def retrieve(params) parsed, = Telnyx::SipRegistrationStatusRetrieveParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "sip_registration_status", query: query, model: Telnyx::Models::SipRegistrationStatusRetrieveResponse, options: ) end |