Class: Telnyx::Resources::Storage
- Inherits:
-
Object
- Object
- Telnyx::Resources::Storage
- Defined in:
- lib/telnyx/resources/storage.rb,
lib/telnyx/resources/storage/buckets.rb,
lib/telnyx/resources/storage/migrations.rb,
lib/telnyx/resources/storage/buckets/usage.rb,
lib/telnyx/resources/storage/migration_sources.rb,
lib/telnyx/resources/storage/migrations/actions.rb,
lib/telnyx/resources/storage/buckets/ssl_certificate.rb
Overview
Migrate data from an external provider into Telnyx Cloud Storage
Defined Under Namespace
Classes: Buckets, MigrationSources, Migrations
Instance Attribute Summary collapse
-
#buckets ⇒ Telnyx::Resources::Storage::Buckets
readonly
Presigned object URL operations.
-
#migration_sources ⇒ Telnyx::Resources::Storage::MigrationSources
readonly
Migrate data from an external provider into Telnyx Cloud Storage.
-
#migrations ⇒ Telnyx::Resources::Storage::Migrations
readonly
Migrate data from an external provider into Telnyx Cloud Storage.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Storage
constructor
private
A new instance of Storage.
-
#list_migration_source_coverage(request_options: {}) ⇒ Telnyx::Models::StorageListMigrationSourceCoverageResponse
List Migration Source coverage.
Constructor Details
#initialize(client:) ⇒ Storage
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Storage.
40 41 42 43 44 45 |
# File 'lib/telnyx/resources/storage.rb', line 40 def initialize(client:) @client = client @buckets = Telnyx::Resources::Storage::Buckets.new(client: client) @migration_sources = Telnyx::Resources::Storage::MigrationSources.new(client: client) @migrations = Telnyx::Resources::Storage::Migrations.new(client: client) end |
Instance Attribute Details
#buckets ⇒ Telnyx::Resources::Storage::Buckets (readonly)
Presigned object URL operations
9 10 11 |
# File 'lib/telnyx/resources/storage.rb', line 9 def buckets @buckets end |
#migration_sources ⇒ Telnyx::Resources::Storage::MigrationSources (readonly)
Migrate data from an external provider into Telnyx Cloud Storage
13 14 15 |
# File 'lib/telnyx/resources/storage.rb', line 13 def migration_sources @migration_sources end |
#migrations ⇒ Telnyx::Resources::Storage::Migrations (readonly)
Migrate data from an external provider into Telnyx Cloud Storage
17 18 19 |
# File 'lib/telnyx/resources/storage.rb', line 17 def migrations @migrations end |
Instance Method Details
#list_migration_source_coverage(request_options: {}) ⇒ Telnyx::Models::StorageListMigrationSourceCoverageResponse
List Migration Source coverage
28 29 30 31 32 33 34 35 |
# File 'lib/telnyx/resources/storage.rb', line 28 def list_migration_source_coverage(params = {}) @client.request( method: :get, path: "storage/migration_source_coverage", model: Telnyx::Models::StorageListMigrationSourceCoverageResponse, options: params[:request_options] ) end |