Class: Telnyx::Resources::TermsOfService::NumberReputation
- Inherits:
-
Object
- Object
- Telnyx::Resources::TermsOfService::NumberReputation
- Defined in:
- lib/telnyx/resources/terms_of_service/number_reputation.rb
Overview
Terms of Service agreement endpoints
Instance Method Summary collapse
-
#agree(request_options: {}) ⇒ nil
Accept the Terms of Service for the Number Reputation product.
-
#initialize(client:) ⇒ NumberReputation
constructor
private
A new instance of NumberReputation.
Constructor Details
#initialize(client:) ⇒ NumberReputation
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of NumberReputation.
33 34 35 |
# File 'lib/telnyx/resources/terms_of_service/number_reputation.rb', line 33 def initialize(client:) @client = client end |
Instance Method Details
#agree(request_options: {}) ⇒ nil
Accept the Terms of Service for the Number Reputation product. Must be called before using Number Reputation endpoints.
Returns ‘400` with error code `10015` if the user has already agreed to the current ToS version.
21 22 23 24 25 26 27 28 |
# File 'lib/telnyx/resources/terms_of_service/number_reputation.rb', line 21 def agree(params = {}) @client.request( method: :post, path: "terms_of_service/number_reputation/agree", model: NilClass, options: params[:request_options] ) end |