Class: Telnyx::Resources::Texml
- Inherits:
-
Object
- Object
- Telnyx::Resources::Texml
- Defined in:
- lib/telnyx/resources/texml.rb,
lib/telnyx/resources/texml/accounts.rb,
lib/telnyx/resources/texml/accounts/calls.rb,
lib/telnyx/resources/texml/accounts/queues.rb,
lib/telnyx/resources/texml/accounts/recordings.rb,
lib/telnyx/resources/texml/accounts/conferences.rb,
lib/telnyx/resources/texml/accounts/calls/siprec.rb,
lib/telnyx/resources/texml/accounts/calls/streams.rb,
lib/telnyx/resources/texml/accounts/transcriptions.rb,
lib/telnyx/resources/texml/accounts/recordings/json.rb,
lib/telnyx/resources/texml/accounts/calls/recordings.rb,
lib/telnyx/resources/texml/accounts/transcriptions/json.rb,
lib/telnyx/resources/texml/accounts/calls/recordings_json.rb,
lib/telnyx/resources/texml/accounts/conferences/participants.rb
Defined Under Namespace
Classes: Accounts
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(client:) ⇒ Texml
constructor
private
A new instance of Texml.
-
#secrets(name:, value:, request_options: {}) ⇒ Telnyx::Models::TexmlSecretsResponse
Some parameter documentations has been truncated, see Models::TexmlSecretsParams for more details.
Constructor Details
#initialize(client:) ⇒ Texml
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Texml.
43 44 45 46 |
# File 'lib/telnyx/resources/texml.rb', line 43 def initialize(client:) @client = client @accounts = Telnyx::Resources::Texml::Accounts.new(client: client) end |
Instance Attribute Details
#accounts ⇒ Telnyx::Resources::Texml::Accounts (readonly)
7 8 9 |
# File 'lib/telnyx/resources/texml.rb', line 7 def accounts @accounts end |
Instance Method Details
#secrets(name:, value:, request_options: {}) ⇒ Telnyx::Models::TexmlSecretsResponse
Some parameter documentations has been truncated, see Models::TexmlSecretsParams for more details.
Create a TeXML secret which can be later used as a Dynamic Parameter for TeXML when using Mustache Templates in your TeXML. In your TeXML you will be able to use your secret name, and this name will be replaced by the actual secret value when processing the TeXML on Telnyx side. The secrets are not visible in any logs.
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/telnyx/resources/texml.rb', line 29 def secrets(params) parsed, = Telnyx::TexmlSecretsParams.dump_request(params) @client.request( method: :post, path: "texml/secrets", body: parsed, model: Telnyx::Models::TexmlSecretsResponse, options: ) end |