Class: Telnyx::Resources::Texml::Accounts::Conferences

Inherits:
Object
  • Object
show all
Defined in:
lib/telnyx/resources/texml/accounts/conferences.rb,
lib/telnyx/resources/texml/accounts/conferences/participants.rb

Overview

TeXML REST Commands

Defined Under Namespace

Classes: Participants

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Conferences

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Conferences.

Parameters:



184
185
186
187
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 184

def initialize(client:)
  @client = client
  @participants = Telnyx::Resources::Texml::Accounts::Conferences::Participants.new(client: client)
end

Instance Attribute Details

#participantsTelnyx::Resources::Texml::Accounts::Conferences::Participants (readonly)

TeXML REST Commands



11
12
13
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 11

def participants
  @participants
end

Instance Method Details

#retrieve(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceRetrieveResponse

Returns a conference resource.

Parameters:

  • conference_sid (String)

    The ConferenceSid that uniquely identifies a conference.

  • account_sid (String)

    The id of the account the resource belongs to.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



26
27
28
29
30
31
32
33
34
35
36
37
38
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 26

def retrieve(conference_sid, params)
  parsed, options = Telnyx::Texml::Accounts::ConferenceRetrieveParams.dump_request(params)
   =
    parsed.delete(:account_sid) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :get,
    path: ["texml/Accounts/%1$s/Conferences/%2$s", , conference_sid],
    model: Telnyx::Models::Texml::Accounts::ConferenceRetrieveResponse,
    options: options
  )
end

#retrieve_conferences(account_sid, date_created: nil, date_updated: nil, friendly_name: nil, page: nil, page_size: nil, page_token: nil, status: nil, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse

Some parameter documentations has been truncated, see Models::Texml::Accounts::ConferenceRetrieveConferencesParams for more details.

Lists conference resources.

Parameters:

  • account_sid (String)

    The id of the account the resource belongs to.

  • date_created (String)

    Filters conferences by the creation date. Expected format is YYYY-MM-DD. Also ac

  • date_updated (String)

    Filters conferences by the time they were last updated. Expected format is YYYY-

  • friendly_name (String)

    Filters conferences by their friendly name.

  • page (Integer)

    The number of the page to be displayed, zero-indexed, should be used in conjucti

  • page_size (Integer)

    The number of records to be displayed on a page

  • page_token (String)

    Used to request the next page of results.

  • status (Symbol, Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesParams::Status)

    Filters conferences by status.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 107

def retrieve_conferences(, params = {})
  parsed, options = Telnyx::Texml::Accounts::ConferenceRetrieveConferencesParams.dump_request(params)
  query = Telnyx::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["texml/Accounts/%1$s/Conferences", ],
    query: query.transform_keys(
      date_created: "DateCreated",
      date_updated: "DateUpdated",
      friendly_name: "FriendlyName",
      page: "Page",
      page_size: "PageSize",
      page_token: "PageToken",
      status: "Status"
    ),
    model: Telnyx::Models::Texml::Accounts::ConferenceRetrieveConferencesResponse,
    options: options
  )
end

#retrieve_recordings(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse

Lists conference recordings

Parameters:

  • conference_sid (String)

    The ConferenceSid that uniquely identifies a conference.

  • account_sid (String)

    The id of the account the resource belongs to.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 140

def retrieve_recordings(conference_sid, params)
  parsed, options = Telnyx::Texml::Accounts::ConferenceRetrieveRecordingsParams.dump_request(params)
   =
    parsed.delete(:account_sid) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :get,
    path: ["texml/Accounts/%1$s/Conferences/%2$s/Recordings", , conference_sid],
    model: Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsResponse,
    options: options
  )
end

#retrieve_recordings_json(conference_sid, account_sid:, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsJsonResponse

Returns recordings for a conference identified by conference_sid.

Parameters:

  • conference_sid (String)

    The ConferenceSid that uniquely identifies a conference.

  • account_sid (String)

    The id of the account the resource belongs to.

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 167

def retrieve_recordings_json(conference_sid, params)
  parsed, options = Telnyx::Texml::Accounts::ConferenceRetrieveRecordingsJsonParams.dump_request(params)
   =
    parsed.delete(:account_sid) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :get,
    path: ["texml/Accounts/%1$s/Conferences/%2$s/Recordings.json", , conference_sid],
    model: Telnyx::Models::Texml::Accounts::ConferenceRetrieveRecordingsJsonResponse,
    options: options
  )
end

#update(conference_sid, account_sid:, announce_method: nil, announce_url: nil, status: nil, request_options: {}) ⇒ Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse

Some parameter documentations has been truncated, see Models::Texml::Accounts::ConferenceUpdateParams for more details.

Updates a conference resource.

Parameters:

  • conference_sid (String)

    Path param: The ConferenceSid that uniquely identifies a conference.

  • account_sid (String)

    Path param: The id of the account the resource belongs to.

  • announce_method (Symbol, Telnyx::Models::Texml::Accounts::ConferenceUpdateParams::AnnounceMethod)

    Body param: The HTTP method used to call the ‘AnnounceUrl`. Defaults to `POST`.

  • announce_url (String)

    Body param: The URL we should call to announce something into the conference. Th

  • status (String)

    Body param: The new status of the resource. Specifying ‘completed` will end the

  • request_options (Telnyx::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/telnyx/resources/texml/accounts/conferences.rb', line 62

def update(conference_sid, params)
  parsed, options = Telnyx::Texml::Accounts::ConferenceUpdateParams.dump_request(params)
   =
    parsed.delete(:account_sid) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :post,
    path: ["texml/Accounts/%1$s/Conferences/%2$s", , conference_sid],
    headers: {"content-type" => "application/x-www-form-urlencoded"},
    body: parsed,
    model: Telnyx::Models::Texml::Accounts::ConferenceUpdateResponse,
    options: options
  )
end