Class: Telnyx::Resources::UacConnections
- Inherits:
-
Object
- Object
- Telnyx::Resources::UacConnections
- Defined in:
- lib/telnyx/resources/uac_connections.rb,
lib/telnyx/resources/uac_connections/actions.rb
Overview
UAC connection operations
Defined Under Namespace
Classes: Actions
Instance Attribute Summary collapse
-
#actions ⇒ Telnyx::Resources::UacConnections::Actions
readonly
UAC connection operations.
Instance Method Summary collapse
-
#create(connection_name:, active: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_in_webhooks: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, external_uac_settings: nil, inbound: nil, internal_uac_settings: nil, ios_push_credential_id: nil, jitter_buffer: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, password: nil, rtcp_settings: nil, sip_uri_calling_preference: nil, tags: nil, user_name: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Telnyx::Models::UacConnectionCreateResponse
Some parameter documentations has been truncated, see Models::UacConnectionCreateParams for more details.
-
#delete(id, request_options: {}) ⇒ Telnyx::Models::UacConnectionDeleteResponse
Deletes an existing UAC connection.
-
#initialize(client:) ⇒ UacConnections
constructor
private
A new instance of UacConnections.
-
#list(filter: nil, page_number: nil, page_size: nil, sort: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::UacConnectionListResponse>
Some parameter documentations has been truncated, see Models::UacConnectionListParams for more details.
-
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::UacConnectionRetrieveResponse
Retrieves the details of an existing UAC connection.
-
#update(id, active: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_in_webhooks: nil, connection_name: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, external_uac_settings: nil, inbound: nil, internal_uac_settings: nil, ios_push_credential_id: nil, jitter_buffer: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, password: nil, rtcp_settings: nil, sip_uri_calling_preference: nil, tags: nil, user_name: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Telnyx::Models::UacConnectionUpdateResponse
Some parameter documentations has been truncated, see Models::UacConnectionUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ UacConnections
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of UacConnections.
250 251 252 253 |
# File 'lib/telnyx/resources/uac_connections.rb', line 250 def initialize(client:) @client = client @actions = Telnyx::Resources::UacConnections::Actions.new(client: client) end |
Instance Attribute Details
#actions ⇒ Telnyx::Resources::UacConnections::Actions (readonly)
UAC connection operations
9 10 11 |
# File 'lib/telnyx/resources/uac_connections.rb', line 9 def actions @actions end |
Instance Method Details
#create(connection_name:, active: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_in_webhooks: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, external_uac_settings: nil, inbound: nil, internal_uac_settings: nil, ios_push_credential_id: nil, jitter_buffer: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, password: nil, rtcp_settings: nil, sip_uri_calling_preference: nil, tags: nil, user_name: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Telnyx::Models::UacConnectionCreateResponse
Some parameter documentations has been truncated, see Models::UacConnectionCreateParams for more details.
Creates a UAC connection. A UAC (User Agent Client) Connection registers Telnyx to your PBX — the opposite of a standard SIP trunk, where the PBX registers to Telnyx. Use UAC when your PBX doesn’t support outbound SIP registration or you need Telnyx to maintain the registration.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/telnyx/resources/uac_connections.rb', line 80 def create(params) parsed, = Telnyx::UacConnectionCreateParams.dump_request(params) @client.request( method: :post, path: "uac_connections", body: parsed, model: Telnyx::Models::UacConnectionCreateResponse, options: ) end |
#delete(id, request_options: {}) ⇒ Telnyx::Models::UacConnectionDeleteResponse
Deletes an existing UAC connection.
238 239 240 241 242 243 244 245 |
# File 'lib/telnyx/resources/uac_connections.rb', line 238 def delete(id, params = {}) @client.request( method: :delete, path: ["uac_connections/%1$s", id], model: Telnyx::Models::UacConnectionDeleteResponse, options: params[:request_options] ) end |
#list(filter: nil, page_number: nil, page_size: nil, sort: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::UacConnectionListResponse>
Some parameter documentations has been truncated, see Models::UacConnectionListParams for more details.
Returns a list of your UAC connections. A UAC (User Agent Client) Connection registers Telnyx to your PBX — the opposite of a standard SIP trunk, where the PBX registers to Telnyx. Use UAC when your PBX doesn’t support outbound SIP registration or you need Telnyx to maintain the registration.
filter[connection_
214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/telnyx/resources/uac_connections.rb', line 214 def list(params = {}) parsed, = Telnyx::UacConnectionListParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "uac_connections", query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"), page: Telnyx::Internal::DefaultFlatPagination, model: Telnyx::Models::UacConnectionListResponse, options: ) end |
#retrieve(id, request_options: {}) ⇒ Telnyx::Models::UacConnectionRetrieveResponse
Retrieves the details of an existing UAC connection.
102 103 104 105 106 107 108 109 |
# File 'lib/telnyx/resources/uac_connections.rb', line 102 def retrieve(id, params = {}) @client.request( method: :get, path: ["uac_connections/%1$s", id], model: Telnyx::Models::UacConnectionRetrieveResponse, options: params[:request_options] ) end |
#update(id, active: nil, anchorsite_override: nil, android_push_credential_id: nil, call_cost_in_webhooks: nil, connection_name: nil, default_on_hold_comfort_noise_enabled: nil, dtmf_type: nil, encode_contact_header_enabled: nil, encrypted_media: nil, external_uac_settings: nil, inbound: nil, internal_uac_settings: nil, ios_push_credential_id: nil, jitter_buffer: nil, noise_suppression: nil, noise_suppression_details: nil, onnet_t38_passthrough_enabled: nil, outbound: nil, password: nil, rtcp_settings: nil, sip_uri_calling_preference: nil, tags: nil, user_name: nil, webhook_api_version: nil, webhook_event_failover_url: nil, webhook_event_url: nil, webhook_timeout_secs: nil, request_options: {}) ⇒ Telnyx::Models::UacConnectionUpdateResponse
Some parameter documentations has been truncated, see Models::UacConnectionUpdateParams for more details.
Updates settings of an existing UAC connection.
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/telnyx/resources/uac_connections.rb', line 179 def update(id, params = {}) parsed, = Telnyx::UacConnectionUpdateParams.dump_request(params) @client.request( method: :patch, path: ["uac_connections/%1$s", id], body: parsed, model: Telnyx::Models::UacConnectionUpdateResponse, options: ) end |