Class: Telnyx::Resources::VoiceSDKCallReports
- Inherits:
-
Object
- Object
- Telnyx::Resources::VoiceSDKCallReports
- Defined in:
- lib/telnyx/resources/voice_sdk_call_reports.rb
Overview
Retrieve raw Voice SDK call report stats payloads for WebRTC call troubleshooting.
Instance Method Summary collapse
-
#initialize(client:) ⇒ VoiceSDKCallReports
constructor
private
A new instance of VoiceSDKCallReports.
-
#list(page_number: nil, page_size: nil, sort: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::VoiceSDKCallReportListResponse>
Some parameter documentations has been truncated, see Models::VoiceSDKCallReportListParams for more details.
-
#retrieve(call_id, request_options: {}) ⇒ Array<Telnyx::Models::VoiceSDKCallReportRetrieveResponseItem>
Returns raw call report stats JSON payloads stored for the authenticated user and ‘call_id`.
Constructor Details
#initialize(client:) ⇒ VoiceSDKCallReports
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of VoiceSDKCallReports.
66 67 68 |
# File 'lib/telnyx/resources/voice_sdk_call_reports.rb', line 66 def initialize(client:) @client = client end |
Instance Method Details
#list(page_number: nil, page_size: nil, sort: nil, request_options: {}) ⇒ Telnyx::Internal::DefaultFlatPagination<Telnyx::Models::VoiceSDKCallReportListResponse>
Some parameter documentations has been truncated, see Models::VoiceSDKCallReportListParams for more details.
Returns paginated raw call report stats JSON payloads stored for the authenticated user. The user is derived from Telnyx authentication, not from request parameters.
50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/telnyx/resources/voice_sdk_call_reports.rb', line 50 def list(params = {}) parsed, = Telnyx::VoiceSDKCallReportListParams.dump_request(params) query = Telnyx::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "voice_sdk_call_reports", query: query.transform_keys(page_number: "page[number]", page_size: "page[size]"), page: Telnyx::Internal::DefaultFlatPagination, model: Telnyx::Models::VoiceSDKCallReportListResponse, options: ) end |
#retrieve(call_id, request_options: {}) ⇒ Array<Telnyx::Models::VoiceSDKCallReportRetrieveResponseItem>
Returns raw call report stats JSON payloads stored for the authenticated user and ‘call_id`. The user is derived from Telnyx authentication, not from request parameters.
21 22 23 24 25 26 27 28 |
# File 'lib/telnyx/resources/voice_sdk_call_reports.rb', line 21 def retrieve(call_id, params = {}) @client.request( method: :get, path: ["voice_sdk_call_reports/%1$s", call_id], model: Telnyx::Internal::Type::ArrayOf[Telnyx::Models::VoiceSDKCallReportRetrieveResponseItem], options: params[:request_options] ) end |